(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    706670,      20474]*)
(*NotebookOutlinePosition[    707356,      20498]*)
(*  CellTagsIndexPosition[    707312,      20494]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Bereitstellung der Substitutionsmatrix"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Wie wir bereits bei der formalen Einf\[UDoubleDot]hrung des paarweisen \
Alignments gesehen haben, ist das Kernst\[UDoubleDot]ck des Verfahrens die \
Substitutionsmatrix. Wir werden hier die BLOSUM62-Matrix verwenden, die wir \
zuerst aus einer lokalen Datei einlesen und dann mit dem Befehl ",
  StyleBox["Partition[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " in das richtige (24\[Times]24) Format bringen (vgl. Abb. 3.2)."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[TextData[{
  "F\[UDoubleDot]r das Einlesen einer Datei ist neben dem Dateinamen die \
Angabe des Verzeichnisses notwendig, in dem sie sich befindet. Mit den Befehl \
",
  StyleBox["SetDirectory[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "  kann ein solches Verzeichnis spezifiziert werden. Dabei wird der Pfad in \
Anf\[UDoubleDot]hrungszeichen gesetzt.  Eine solche Angabe kann z.B. lauten:\n\
\n",
  StyleBox["SetDirectory[\"C:\\Mathematica-Exkurs Alignment\"]; ",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"]
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(<< Graphics`Graphics`; << Graphics`Arrow`;\)], "Input"],

Cell[BoxData[
    \(\(blosum = 
        Partition[
          Flatten[ReadList["\<blosum62.txt\>", Number, 
              RecordLists \[Rule] True, 
              RecordSeparators \[Rule] {"\<\n\>", "\< \>"}]], 
          24];\)\)], "Input"],

Cell[TextData[{
  "Mit dem Befehl ",
  StyleBox["Dimensions[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " k\[ODoubleDot]nnen wir wie \[UDoubleDot]blich die Dimension der \
eingelesenen Matrix \[UDoubleDot]berpr\[UDoubleDot]fen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[blosum]\)], "Input"],

Cell[BoxData[
    \({24, 24}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "An dieser Stelle ist die Substitutionsmatrix eine reine Zahlenmatrix, der \
wir im Folgenden eine Bedeutung zuweisen m\[UDoubleDot]ssen. Die universelle \
Anordnung jeder Substitutionsmatrix erlaubt uns, die Zeilen und Spalten mit \
einem Label zu versehen. Die Abfolge von Labels legen wir als Zeichenkette in \
einer Variablen ",
  StyleBox["proteinRef",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ab."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(proteinRef = Characters["\<ARNDCQEGHILKMFPSTWYVBZX*\>"]\)], "Input"],

Cell[BoxData[
    \({"A", "R", "N", "D", "C", "Q", "E", "G", "H", "I", "L", "K", "M", "F", 
      "P", "S", "T", "W", "Y", "V", "B", "Z", "X", "*"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Der Begriff ",
    FontSize->13],
  StyleBox["TableForm[]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->13,
    FontWeight->"Bold"],
  StyleBox["erlaubt eine \[UDoubleDot]bersichtliche Ausgabe der mit Labels \
versehenen Substitutionsmatrix.",
    FontSize->13]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[blosum, TableHeadings \[Rule] {proteinRef, proteinRef}, 
      TableSpacing \[Rule] 0.5, TableAlignments \[Rule] Right]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"A\"\>", "\<\"R\"\>", "\<\"N\"\>", "\<\"D\"\>", \
"\<\"C\"\>", "\<\"Q\"\>", "\<\"E\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"I\"\>", \
"\<\"L\"\>", "\<\"K\"\>", "\<\"M\"\>", "\<\"F\"\>", "\<\"P\"\>", "\<\"S\"\>", \
"\<\"T\"\>", "\<\"W\"\>", "\<\"Y\"\>", "\<\"V\"\>", "\<\"B\"\>", "\<\"Z\"\>", \
"\<\"X\"\>", "\<\"*\"\>"},
          {"\<\"A\"\>", "4", \(-1\), \(-2\), \(-2\), "0", \(-1\), \(-1\), 
            "0", \(-2\), \(-1\), \(-1\), \(-1\), \(-1\), \(-2\), \(-1\), "1", 
            "0", \(-3\), \(-2\), "0", \(-2\), \(-1\), "0", \(-4\)},
          {"\<\"R\"\>", \(-1\), "5", "0", \(-2\), \(-3\), "1", "0", \(-2\), 
            "0", \(-3\), \(-2\), 
            "2", \(-1\), \(-3\), \(-2\), \(-1\), \(-1\), \(-3\), \(-2\), \(-3\
\), \(-1\), "0", \(-1\), \(-4\)},
          {"\<\"N\"\>", \(-2\), "0", "6", "1", \(-3\), "0", "0", "0", 
            "1", \(-3\), \(-3\), "0", \(-2\), \(-3\), \(-2\), "1", 
            "0", \(-4\), \(-2\), \(-3\), "3", "0", \(-1\), \(-4\)},
          {"\<\"D\"\>", \(-2\), \(-2\), "1", "6", \(-3\), "0", 
            "2", \(-1\), \(-1\), \(-3\), \(-4\), \(-1\), \(-3\), \(-3\), \(-1\
\), "0", \(-1\), \(-4\), \(-3\), \(-3\), "4", "1", \(-1\), \(-4\)},
          {"\<\"C\"\>", "0", \(-3\), \(-3\), \(-3\), 
            "9", \(-3\), \(-4\), \(-3\), \(-3\), \(-1\), \(-1\), \(-3\), \(-1\
\), \(-2\), \(-3\), \(-1\), \(-1\), \(-2\), \(-2\), \(-1\), \(-3\), \(-3\), \
\(-2\), \(-4\)},
          {"\<\"Q\"\>", \(-1\), "1", "0", "0", \(-3\), "5", "2", \(-2\), 
            "0", \(-3\), \(-2\), "1", "0", \(-3\), \(-1\), 
            "0", \(-1\), \(-2\), \(-1\), \(-2\), "0", "3", \(-1\), \(-4\)},
          {"\<\"E\"\>", \(-1\), "0", "0", "2", \(-4\), "2", "5", \(-2\), 
            "0", \(-3\), \(-3\), "1", \(-2\), \(-3\), \(-1\), 
            "0", \(-1\), \(-3\), \(-2\), \(-2\), "1", "4", \(-1\), \(-4\)},
          {"\<\"G\"\>", "0", \(-2\), "0", \(-1\), \(-3\), \(-2\), \(-2\), 
            "6", \(-2\), \(-4\), \(-4\), \(-2\), \(-3\), \(-3\), \(-2\), 
            
            "0", \(-2\), \(-2\), \(-3\), \(-3\), \(-1\), \(-2\), \(-1\), \(-4\
\)},
          {"\<\"H\"\>", \(-2\), "0", "1", \(-1\), \(-3\), "0", "0", \(-2\), 
            "8", \(-3\), \(-3\), \(-1\), \(-2\), \(-1\), \(-2\), \(-1\), \(-2\
\), \(-2\), "2", \(-3\), "0", "0", \(-1\), \(-4\)},
          {"\<\"I\"\>", \(-1\), \(-3\), \(-3\), \(-3\), \(-1\), \(-3\), \
\(-3\), \(-4\), \(-3\), "4", "2", \(-3\), "1", 
            "0", \(-3\), \(-2\), \(-1\), \(-3\), \(-1\), 
            "3", \(-3\), \(-3\), \(-1\), \(-4\)},
          {"\<\"L\"\>", \(-1\), \(-2\), \(-3\), \(-4\), \(-1\), \(-2\), \
\(-3\), \(-4\), \(-3\), "2", "4", \(-2\), "2", 
            "0", \(-3\), \(-2\), \(-1\), \(-2\), \(-1\), 
            "1", \(-4\), \(-3\), \(-1\), \(-4\)},
          {"\<\"K\"\>", \(-1\), "2", "0", \(-1\), \(-3\), "1", 
            "1", \(-2\), \(-1\), \(-3\), \(-2\), "5", \(-1\), \(-3\), \(-1\), 
            "0", \(-1\), \(-3\), \(-2\), \(-2\), "0", "1", \(-1\), \(-4\)},
          {"\<\"M\"\>", \(-1\), \(-1\), \(-2\), \(-3\), \(-1\), 
            "0", \(-2\), \(-3\), \(-2\), "1", "2", \(-1\), "5", 
            "0", \(-2\), \(-1\), \(-1\), \(-1\), \(-1\), 
            "1", \(-3\), \(-1\), \(-1\), \(-4\)},
          {"\<\"F\"\>", \(-2\), \(-3\), \(-3\), \(-3\), \(-2\), \(-3\), \
\(-3\), \(-3\), \(-1\), "0", "0", \(-3\), "0", "6", \(-4\), \(-2\), \(-2\), 
            "1", "3", \(-1\), \(-3\), \(-3\), \(-1\), \(-4\)},
          {"\<\"P\"\>", \(-1\), \(-2\), \(-2\), \(-1\), \(-3\), \(-1\), \
\(-1\), \(-2\), \(-2\), \(-3\), \(-3\), \(-1\), \(-2\), \(-4\), 
            "7", \(-1\), \(-1\), \(-4\), \(-3\), \(-2\), \(-2\), \(-1\), \(-2\
\), \(-4\)},
          {"\<\"S\"\>", "1", \(-1\), "1", "0", \(-1\), "0", "0", 
            "0", \(-1\), \(-2\), \(-2\), "0", \(-1\), \(-2\), \(-1\), "4", 
            "1", \(-3\), \(-2\), \(-2\), "0", "0", "0", \(-4\)},
          {"\<\"T\"\>", "0", \(-1\), 
            "0", \(-1\), \(-1\), \(-1\), \(-1\), \(-2\), \(-2\), \(-1\), \(-1\
\), \(-1\), \(-1\), \(-2\), \(-1\), "1", "5", \(-2\), \(-2\), 
            "0", \(-1\), \(-1\), "0", \(-4\)},
          {"\<\"W\"\>", \(-3\), \(-3\), \(-4\), \(-4\), \(-2\), \(-2\), \
\(-3\), \(-2\), \(-2\), \(-3\), \(-2\), \(-3\), \(-1\), 
            "1", \(-4\), \(-3\), \(-2\), "11", 
            "2", \(-3\), \(-4\), \(-3\), \(-2\), \(-4\)},
          {"\<\"Y\"\>", \(-2\), \(-2\), \(-2\), \(-3\), \(-2\), \(-1\), \
\(-2\), \(-3\), "2", \(-1\), \(-1\), \(-2\), \(-1\), 
            "3", \(-3\), \(-2\), \(-2\), "2", 
            "7", \(-1\), \(-3\), \(-2\), \(-1\), \(-4\)},
          {"\<\"V\"\>", 
            "0", \(-3\), \(-3\), \(-3\), \(-1\), \(-2\), \(-2\), \(-3\), \(-3\
\), "3", "1", \(-2\), "1", \(-1\), \(-2\), \(-2\), "0", \(-3\), \(-1\), 
            "4", \(-3\), \(-2\), \(-1\), \(-4\)},
          {"\<\"B\"\>", \(-2\), \(-1\), "3", "4", \(-3\), "0", "1", \(-1\), 
            "0", \(-3\), \(-4\), "0", \(-3\), \(-3\), \(-2\), 
            "0", \(-1\), \(-4\), \(-3\), \(-3\), "4", "1", \(-1\), \(-4\)},
          {"\<\"Z\"\>", \(-1\), "0", "0", "1", \(-3\), "3", "4", \(-2\), 
            "0", \(-3\), \(-3\), "1", \(-1\), \(-3\), \(-1\), 
            "0", \(-1\), \(-3\), \(-2\), \(-2\), "1", "4", \(-1\), \(-4\)},
          {"\<\"X\"\>", 
            "0", \(-1\), \(-1\), \(-1\), \(-2\), \(-1\), \(-1\), \(-1\), \(-1\
\), \(-1\), \(-1\), \(-1\), \(-1\), \(-1\), \(-2\), "0", 
            "0", \(-2\), \(-1\), \(-1\), \(-1\), \(-1\), \(-1\), \(-4\)},
          {"\<\"*\"\>", \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \
\(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \
\(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), \(-4\), "1"}
          },
        RowSpacings->0.5,
        ColumnSpacings->0.5,
        RowAlignments->Baseline,
        ColumnAlignments->{Right}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"A", "R", "N", "D", "C", "Q", "E", "G",
           "H", "I", "L", "K", "M", "F", "P", "S", "T", "W", "Y", "V", "B", 
          "Z", "X", "*"}, {"A", "R", "N", "D", "C", "Q", "E", "G", "H", "I", 
          "L", "K", "M", "F", "P", "S", "T", "W", "Y", "V", "B", "Z", "X", 
          "*"}}, TableSpacing -> .5, TableAlignments -> Right]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Abbildung 3.2 zeigt diese Darstellung der BLOSUM62-Substitutionsmatrix. \
Wir werden nun die beiden Beispielsequenzen diskutieren. Der Befehl ",
  StyleBox["Characters[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zerlegt dabei die als Zeichenkette eingetragenen Sequenzen in ihre \
Einzelsymbole."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(\(\(prot1 = Characters["\<KEFHNGHT\>"];\)\[IndentingNewLine]
    \(prot2 = Characters["\<KYFHKAGNQHSPT\>"];\)\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Als Erstes ben\[ODoubleDot]tigen wir nun eine Funktion, die zu zwei \
gegebenen Symbolen den entsprechenden Eintrag aus der Substitutionsmatrix \
extrahiert. Dies geschieht einfach mit dem Befehl ",
  StyleBox["Part[...]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " oder seiner Kurzform ",
  StyleBox["[[]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Allerdings ist der Umweg \[UDoubleDot]ber die Labels ",
  StyleBox["proteinRef",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " der Substitutionsmatrix ",
  StyleBox["blosum",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zu beachten: Man hat ein Symbol aus der ersten Sequenz, ",
  "s1",
  ", und ein Symbol aus der zweiten Sequenz, ",
  "s2",
  ", gegeben und ben\[ODoubleDot]tigt nun die Position dieser Symbole in der \
Label-Liste ",
  StyleBox["proteinRef",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Dies geschieht jeweils mit ",
  StyleBox["Position[proteinRef, si]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", wobei allerdings der ",
  StyleBox["Part",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl noch erforderlich ist, um unn\[ODoubleDot]tige Klammern zu \
vermeiden. Mit diesen Zahlen kann man nun das Element aus der \
Substitutionsmatrix ansprechen. F\[UDoubleDot]r die folgende Untersuchung ist \
es w\[UDoubleDot]nschenswert, diesen Prozess in einer Funktion abzulegen. Wir \
werden hier eine sehr allgemeine Fassung dieser Funktion formulieren, die als \
Argumente (also als frei zu spezifizierende Parameter) nicht nur die beiden \
Symbole selbst (dies w\[ADoubleDot]re der elementarste Fall einer solchen \
Funktion) hat, sondern auch die Label-Liste und die Substitutionsmatrix. Auf \
diese Weise ist es nicht erforderlich, die Variablennamen ",
  StyleBox["proteinRef",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und ",
  StyleBox["blosum",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " beizubehalten; sie werden im Inneren der Funktion nicht verwendet. Eine \
weitere Abweichung von der naheliegenden Realisierung der Funktion wird sein, \
statt die beiden Symbole direkt als Argument zuzulassen, die gesamten \
Sequenzen und die beiden Positionen der Symbole in den Sequenzen an die \
Funktion zu \[UDoubleDot]bergeben. Der Vorteil dieses scheinbar viel \
komplizierteren Konstrukts liegt darin, im Folgenden die Positionen als ",
  "Laufindizes",
  " in einer Schleife verwenden zu k\[ODoubleDot]nnen. Die Definition dieser \
Funktion ",
  StyleBox["coordFun",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " erfolgt wie gewohnt mit Hilfe der Module-Umgebung. Zuerst werden die \
beiden Symbole in tempor\[ADoubleDot]re Variablen geschrieben (z.B. ",
  StyleBox["tmp1 = seq1[[posA]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "); dann wird die Position dieser Symbole in der Label-Liste abgefragt (",
  StyleBox["tmp3 = Position[ref, tmp1][[1, 1]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "; wie zuvor eliminiert der ",
  StyleBox["Part",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl, ...",
  StyleBox["[[1, 1]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " st\[ODoubleDot]rende Klammern); schlie\[SZ]lich k\[ODoubleDot]nnen diese \
beiden Positionen zum Zugriff auf das Matrixelement verwendet werden. \
Insgesamt hat man:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(coordFun[ref_, seq1_, seq2_, posA_, posB_, mat_] := 
      Module[{tmp1, tmp2, tmp3, tmp4}, \[IndentingNewLine]tmp1 = 
          seq1[\([posA]\)]; \[IndentingNewLine]tmp2 = 
          seq2[\([posB]\)]; \[IndentingNewLine]tmp3 = \(Position[ref, 
              tmp1]\)[\([1, 1]\)]; \[IndentingNewLine]tmp4 = \(Position[ref, 
              tmp2]\)[\([1, 1]\)]; \[IndentingNewLine]mat[\([tmp3, 
            tmp4]\)]]\)], "Input"],

Cell[TextData[StyleBox["Will man zum Beispiel unter den vorliegenden \
Variablenbezeichnungen den Eintrag der Substitutionsmatrix ermitteln, der den \
Score f\[UDoubleDot]r eine Paarung des jeweils zweiten Symbols der Sequenzen \
angibt, so geschieht dies mit dem Befehl:",
  FontFamily->"Times New Roman",
  FontSize->13]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(coordFun[proteinRef, prot1, prot2, 2, 2, blosum]\)], "Input"],

Cell[BoxData[
    \(\(-2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die etwas aufwendige Gestaltung unserer Funktion ",
  StyleBox["coordFun",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " erweist sich nun als vorteilhaft. Durch die Verwendung der \
Symbolpositionen k\[ODoubleDot]nnen wir unmittelbar eine Matrix anlegen, die \
zu jedem Symbolpaar der beiden Sequenzen den entsprechenden Score enth\
\[ADoubleDot]lt. Dies erreichen wir mit dem Befehl ",
  StyleBox["Table",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und zwei Laufindizes, die jeweils von 1 bis zur L\[ADoubleDot]nge der \
Sequenz (z.B. ",
  StyleBox["Length[prot1]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") laufen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(coordTab = 
        Table[coordFun[proteinRef, prot1, prot2, i, j, blosum], {i, 1, 
            Length[prot1]}, {j, 1, Length[prot2]}];\)\)], "Input"],

Cell[TextData[{
  "Die Ausgabe erfolgt dann \[UDoubleDot]ber den Formatierungsbefehl ",
  StyleBox["TableForm",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Dabei verwenden wir die beiden Sequenzen noch zur Bezeichnung der Zeilen \
und Spalten (mit ",
  StyleBox["TableHeadings",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "), legen den Abstand der einzelnen Eintr\[ADoubleDot]ge fest (mit ",
  StyleBox["TableSpacing",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") und erzwingen zudem (mit ",
  StyleBox["TableAlignments",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") eine rechtsb\[UDoubleDot]ndige Ausgabe."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[coordTab, \ TableHeadings \[Rule] {prot1, prot2}, 
      TableSpacing \[Rule] 1, TableAlignments \[Rule] Right]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", \
"\<\"K\"\>", "\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"Q\"\>", "\<\"H\"\>", \
"\<\"S\"\>", "\<\"P\"\>", "\<\"T\"\>"},
          {"\<\"K\"\>", "5", \(-2\), \(-3\), \(-1\), "5", \(-1\), \(-2\), "0",
             "1", \(-1\), "0", \(-1\), \(-1\)},
          {"\<\"E\"\>", "1", \(-2\), \(-3\), "0", "1", \(-1\), \(-2\), "0", 
            "2", "0", "0", \(-1\), \(-1\)},
          {"\<\"F\"\>", \(-3\), "3", 
            "6", \(-1\), \(-3\), \(-2\), \(-3\), \(-3\), \(-3\), \(-1\), \(-2\
\), \(-4\), \(-2\)},
          {"\<\"H\"\>", \(-1\), "2", \(-1\), "8", \(-1\), \(-2\), \(-2\), "1",
             "0", "8", \(-1\), \(-2\), \(-2\)},
          {"\<\"N\"\>", "0", \(-2\), \(-3\), "1", "0", \(-2\), "0", "6", "0", 
            "1", "1", \(-2\), "0"},
          {"\<\"G\"\>", \(-2\), \(-3\), \(-3\), \(-2\), \(-2\), "0", "6", 
            "0", \(-2\), \(-2\), "0", \(-2\), \(-2\)},
          {"\<\"H\"\>", \(-1\), "2", \(-1\), "8", \(-1\), \(-2\), \(-2\), "1",
             "0", "8", \(-1\), \(-2\), \(-2\)},
          {"\<\"T\"\>", \(-1\), \(-2\), \(-2\), \(-2\), \(-1\), "0", \(-2\), 
            "0", \(-1\), \(-2\), "1", \(-1\), "5"}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Right}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"K", "E", "F", "H", "N", "G", "H", 
          "T"}, {"K", "Y", "F", "H", "K", "A", "G", "N", "Q", "H", "S", "P", 
          "T"}}, TableSpacing -> 1, TableAlignments -> Right]]]], "Output"]
}, Open  ]],

Cell["\<\
Eine solche Tabelle k\[ODoubleDot]nnte eine erste Orientierung bei einer \
Nachbearbeitung eines Alignments von Hand (etwa die Auswahl von \
Teilsequenzen) liefern.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[TextData[{
  "Nach Einrichten dieser Infrastruktur f\[UDoubleDot]r den Umgang mit der \
Substitutionsmatrix k\[ODoubleDot]nnen wir uns nun dem ersten Verfahren \
zuwenden, dem Needleman-Wunsch-Algorithmus f\[UDoubleDot]r ein globales \
Alignment der beiden Sequenzen. Dies ist Gegenstand des zweiten ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurses. Zuerst diskutieren wir die rekursive Bestimmung der ",
  StyleBox["F",
    FontSlant->"Italic"],
  "-Matrix. Dabei durchlaufen wir die bereits im vorangegangenen Kapitel \
diskutierten Schritte: Initialisierung, Rekursion und Terminierung.\n"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Needleman-Wunsch-Verfahren"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Die Initialisierung der ",
  StyleBox["F",
    FontSlant->"Italic"],
  "-Matrix f\[UDoubleDot]r das Needleman-Wunsch-Verfahren erfolgt durch Einf\
\[UDoubleDot]gen einer nullten Zeile und Spalte, die den kumulierten \
Gap-Penalty als Eintr\[ADoubleDot]ge enthalten. Zuerst legen wir den \
Gap-Penalty fest:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(\(gP = 5;\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Dabei ist klar, dass wir in einer sp\[ADoubleDot]teren Funktion, \
die das gesamte Needleman-Wunsch-Verfahren umfasst, diesen Parameter als \
Argument frei angebenwollen. Dazukommen wir aber sp\[ADoubleDot]ter. Als N\
\[ADoubleDot]chstes legen wir die Initialisierungseintr\[ADoubleDot]ge der ",
    FontFamily->"Times New Roman",
    FontSize->13],
  StyleBox["F",
    FontFamily->"Times New Roman",
    FontSize->13,
    FontSlant->"Italic"],
  StyleBox["-Matrix fest.Wir haben uns als Format dieser ",
    FontFamily->"Times New Roman",
    FontSize->13],
  StyleBox["F",
    FontFamily->"Times New Roman",
    FontSize->13,
    FontSlant->"Italic"],
  StyleBox["-Matrixelemente f\[UDoubleDot]r ein Zahlenpaar entschieden: Der \
erste Eintrag gibt das tats\[ADoubleDot]chliche Matrixelement an, w\
\[ADoubleDot]hrend der zweite Eintrag den Zeiger darstellt, der codiert, aus \
welchem vorangehenden Matrixelement das vorliegende Element in der Rekursion \
seinen Wert erhalten hat. Dabei verwenden wir einen Zahlencode \
f\[UDoubleDot]r den Zeiger: 1 = \"diagonal\", 2 = \"oben\" und 3= \"links\". \
Den Zustand 0 verwenden wir (im oberen linken Matrixelement) f\[UDoubleDot]r \
das Fehlen eines Zeigerzustands.",
    FontFamily->"Times New Roman",
    FontSize->13]
}], "Text"],

Cell[BoxData[
    \(\(FF[0, 0] = {0, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(FF[i_, 0] = {\(-i\)*gP, 2};\)\)], "Input"],

Cell[BoxData[
    \(\(FF[0, j_] = {\(-j\)*gP, 3};\)\)], "Input"],

Cell[TextData[{
  "Zur Rekursion verwenden wir eine ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife. Im Inneren der Schleife steht dabei einfach die Maximumsabfrage \
zwischen den drei vorangehenden (mit Score und Gap-Penalty verrechneten) \
Matrixeintr\[ADoubleDot]gen, so wie wir es bereits kennen gelernt haben. Da \
wir diese Maximumsabfrage sowohl zur Ermittlung des Matrixelements als auch \
zur Zeigerbestimmung ben\[ODoubleDot]tigen, legen wir die drei-elementige \
Liste in einer Variablen ",
  StyleBox["tmp1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ab, um dann zur Festlegung des Matrixelements darauf zuzugreifen. Zudem \
ist noch zu beachten, dass durch die zweielementige Struktur der ",
  StyleBox["F",
    FontSlant->"Italic"],
  "-Matrixeintr\[ADoubleDot]ge die Gr\[ODoubleDot]\[SZ]e ",
  StyleBox["FF[i, j][[1]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " den tats\[ADoubleDot]chlichen Matrixeintrag liefert und ",
  StyleBox["FF[i, j][[2]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " den zugeh\[ODoubleDot]rigen Wert der Zeigervariablen ausgibt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(Do[{\[IndentingNewLine]tmp1 = {\(FF[i - 1, j - 1]\)[\([1]\)] + 
              coordFun[proteinRef, prot1, prot2, i, j, 
                blosum], \[IndentingNewLine]\(FF[i - 1, j]\)[\([1]\)] - 
              gP, \(FF[i, j - 1]\)[\([1]\)] - 
              gP\[IndentingNewLine]}; \ \[IndentingNewLine]\ 
        FF[i, j] = {Max[
              tmp1], \(Position[tmp1, Max[tmp1]]\)[\([1, 
                1]\)]}\[IndentingNewLine]}, {i, 1, Length[prot1]}, {j, 1, 
        Length[prot2]}]\)], "Input"],

Cell[TextData[{
  "Wie gewohnt stehen die einzelnen Befehle der ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife als Liste in geschweiften Klammern. Deutlich zu erkennen ist \
auch, dass jedes Matrixelement ",
  StyleBox["FF[i, j]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " als zwei-elementige Liste definiert wird (mit dem \
tats\[ADoubleDot]chlichen Matrixeintrag als erstes Element und dem Zeiger als \
zweites Element). Interessant ist noch die Zeigergewinnung: Wir haben die \
drei-elementige Liste so organisiert, dass die Elementposition dem oben \
eingef\[UDoubleDot]hrten Code des Zeigers entspricht: Liefert das erste \
Element das Maximum, so ist der Zeigerzustand gerade 1 (\"diagonal\") und so \
fort. Auf diese Weise l\[ADoubleDot]sst sich der Zeigerzustand recht elegant \
durch ",
  StyleBox["Position[tmp1, Max[tmp1]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ermitteln. \n\nWir wenden uns nun der Ausgabe des Ergebnisses zu. Das \
Ziel ist, die ",
  StyleBox["F",
    FontSlant->"Italic"],
  "-Matrix abzubilden, die Zeiger als Pfeile einzutragen und schlie\[SZ]lich \
den optimalen Pfad, der sich durch Zur\[UDoubleDot]ckverfolgen (Traceback) \
vom rechten unteren Matrixelement aus ergibt, zu gewinnen. In einem zweiten \
Schritt werden wir die Ausgabe dieser Nebenrechnungen \
unterdr\[UDoubleDot]cken und nur das tats\[ADoubleDot]chliche Alignment der \
beiden Sequenzen ausgeben. Legen wir zuerst die in der ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife berechneten Matrixelemente in einer Tabelle ab:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(FFTab = 
        Table[FF[i, j], {i, 0, Length[prot1]}, {j, 0, 
            Length[prot2]}];\)\)], "Input"],

Cell[TextData[{
  "Durch Anwenden von Substitutionsregeln, bei denen jedes Elementpaar ",
  StyleBox["{n1, n2}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " entweder durch nur das erste oder nur das zweite Element ersetzt wird, \
teilen wir die Tabelle in zwei getrennte Tabellen f\[UDoubleDot]r die \
Matrixelemente und die Zeigerzust\[ADoubleDot]nde auf."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(FFTabA = 
        FFTab /. {n1_, n2_Integer} \[Rule] \ n1;\)\), "\[IndentingNewLine]", 
    \(\(FFTabB = FFTab /. {n1_, n2_Integer} \[Rule] \ n2;\)\)}], "Input"],

Cell[TextData[{
  "Man erkennt auch hier wieder das zentrale Ordnungsprinzip der \
Substitutionsregeln in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", so wie wir es bereits in Kapitel 1.5 diskutiert haben: Der Unterstrich \
(engl. underscore, _ ) bezeichnet ein beliebiges Element; auf der linken \
Seite kann man diesem beliebigen Element einen Namen zuweisen, falls man \
darauf noch einmal im Rahmen der Substitutionsregel zugreifen will (z.B. ",
  StyleBox["n1_",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "); auf der rechten Seite kann das Element n\[ADoubleDot]her \
charakterisiert werden, so dass die Substitutionsregel nur auf Elemente mit \
einer bestimmten Eigenschaft angewendet wird (z.B. ",
  StyleBox["Integer",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", wenn man nur ganzzahlige Elemente diskutieren m\[ODoubleDot]chte). In \
unserem Fall wurde die Spezifizierung des zweiten Eintrags in diesem Paar \
(also",
  StyleBox[" n2_Integer",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") zur Sicherheit vorgenommen, da die Ersetzungsregel sonst im Extremfall \
von Sequenzen der L\[ADoubleDot]nge 2, die zum Alignment gebracht werden \
sollen, auf der Ebene der gesamten Liste operieren w\[UDoubleDot]rde: Auch \
ein Objekt ",
  StyleBox["{liste1,liste2}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " erf\[UDoubleDot]llt das Schema ",
  StyleBox["{n1,n2}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und w\[UDoubleDot]rde z.B. komplett durch ",
  StyleBox["liste1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ersetzt; es erf\[UDoubleDot]llt aber nicht das Schema ",
  StyleBox["{n1,n2_Integer}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". \n\nDas Ziel einer angemessen formatierten Ausgabe dieser Matrix \
verbinden wir mit der Gew\[ODoubleDot]hnung an einige etwas \
fortgeschrittenere Grafik-Befehle. Die Alternative w\[ADoubleDot]re, die \
Darstellung mit dem Befehl ",
  StyleBox["TableForm[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und den dort verf\[UDoubleDot]gbaren Formatierungsoptionen zu erreichen. \
Hier wollen wir den Weg gehen, die Eintr\[ADoubleDot]ge in Grafikelemente zu \
verwandeln. W\[ADoubleDot]hrend beim ",
  StyleBox["Plot",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl eine konkrete mathematische Funktion dargestellt wird, erlaubt die \
",
  StyleBox["Graphics",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Umgebung die Umsetzung sehr allgemeiner Grafikelemente. Typische Elemente \
sind Liniensegmente (mit dem Befehl ",
  StyleBox["Line[punkt1, punkt2, ...]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "), Punkte (mit ",
  StyleBox["Point[koordinate]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") oder platzierter Text (mit ",
  StyleBox["Text[textsegment, koordinate]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "). Dargestellt werden solche Elemente dann mit der Kombination ",
  StyleBox["Show[Graphics[grafikbefehle]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". \n\nDie hier angestrebte Grafik besteht aus drei Segmenten: In ",
  StyleBox["p1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " wird jeder Eintrag von",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["FFTabA",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " als Text an einem zugeh\[ODoubleDot]rigen Punkt des Grafikfensters \
platziert. F\[UDoubleDot]r das (",
  StyleBox["i, j",
    FontSlant->"Italic"],
  ")te Element lautet dieser Befehl ",
  StyleBox["Text[FFTabA[[i, j]], {j, dim1 - (i-1)}]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", wobei dim1 als Abk\[UDoubleDot]rzung f\[UDoubleDot]r ",
  StyleBox["Dimensions[FFTabA][[1]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " verwendet wurde (vgl. die folgenden Befehlszeilen). Man erkennt an der \
zweiten Koordinate, dass man das unterschiedliche Koordinatensystem von \
Matrizen (der \"Nullpunkt\" liegt oben links) und Grafiken (der Nullpunkt \
liegt unten links) zu ber\[UDoubleDot]cksichtigen hat. Bemerkenswerterweise \
lassen sich diese Grafikbefehle ",
  StyleBox["Text[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zu jedem Matrixelement wiederum mit ",
  StyleBox["Table[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " als Tabelle strukturieren und durch einen ",
  StyleBox["Show[Graphics[]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl darstellen. Mit ",
  StyleBox["p2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und ",
  StyleBox["p3",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " werden die Achsenbeschriftungen bereitgestellt. Dazu verwenden wir erneut \
die Symbolsequenzen ",
  StyleBox["prot1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und ",
  StyleBox["prot2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " als Zeichenketten, die in den ",
  StyleBox["Text",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl eingesetzt werden. Mit ",
  StyleBox["Prepend[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " werden Leerzeichen vor jede Sequenz gesetzt, mit dem Befehl ",
  StyleBox["Rectangle[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", einer entsprechenden, von Hand getroffenen Koordinatenwahl und der \
Formatierungsanweisung ",
  StyleBox["GrayLevel[0.9]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " werden diese Achsenbeschriftungen noch grau hinterlegt. \
Zun\[ADoubleDot]chst werden (mit dem Befehl ",
  StyleBox["DisplayFunction \[Rule] Identity",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") die Grafikausgaben unterdr\[UDoubleDot]ckt, um sie dann etwas sp\
\[ADoubleDot]ter gemeinsam darzustellen. Zu Beginn legen wir noch einige Abk\
\[UDoubleDot]rzungen f\[UDoubleDot]r mehrfach auftretende Dimensionsabfragen \
an."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(dim1 = \(Dimensions[FFTabA]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(dim2 = \(Dimensions[FFTabA]\)[\([2]\)];\)\), "\[IndentingNewLine]", 
    \(\(len1 = Length[prot1];\)\), "\[IndentingNewLine]", 
    \(\(len2 = Length[prot2];\)\), "\[IndentingNewLine]", 
    \(\(p1 = 
        Show[Graphics[
            Table[Text[FFTabA[\([i, j]\)], {j, dim1 - \((i - 1)\)}], {i, 1, 
                dim1}, {j, 1, dim2}]], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(p2 = 
        Show[Graphics[{{GrayLevel[0.9], 
                Rectangle[{\(-0.5\), 0}, {0.5, len1 + 2.5}]}, 
              Table[Text[\(Prepend[prot1, "\< \>"]\)[\([j]\)], {0, 
                    len1 + 1 - \((j - 1)\)}], {j, 1, len1 + 1}]}], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(p3 = 
        Show[Graphics[{{GrayLevel[0.9], 
                Rectangle[{0.5, len1 + 1.5}, {len2 + 1.5, len1 + 2.5}]}, 
              Table[Text[\(Prepend[prot2, "\< \>"]\)[\([j]\)], {j, 
                    len1 + 2}], {j, 1, len2 + 1}]}], 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[TextData[{
  "Die gemeinsame Ausgabe der Bestandteile erfolgt nun wie gewohnt mit Hilfe \
des ",
  StyleBox["Show",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls, nun mit der Einstellung ",
  StyleBox["DisplayFunction \[Rule] $DisplayFunction",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p4 = 
        Show[p3, p2, p1, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0555556 0.0634921 0.0147151 0.0560575 [
[.11905 .57529 -5 -6.28125 ]
[.11905 .57529 5 6.28125 ]
[.18254 .57529 -5 -6.28125 ]
[.18254 .57529 5 6.28125 ]
[.24603 .57529 -5 -6.28125 ]
[.24603 .57529 5 6.28125 ]
[.30952 .57529 -5 -6.28125 ]
[.30952 .57529 5 6.28125 ]
[.37302 .57529 -5 -6.28125 ]
[.37302 .57529 5 6.28125 ]
[.43651 .57529 -5 -6.28125 ]
[.43651 .57529 5 6.28125 ]
[.5 .57529 -5 -6.28125 ]
[.5 .57529 5 6.28125 ]
[.56349 .57529 -5 -6.28125 ]
[.56349 .57529 5 6.28125 ]
[.62698 .57529 -5 -6.28125 ]
[.62698 .57529 5 6.28125 ]
[.69048 .57529 -5 -6.28125 ]
[.69048 .57529 5 6.28125 ]
[.75397 .57529 -5 -6.28125 ]
[.75397 .57529 5 6.28125 ]
[.81746 .57529 -5 -6.28125 ]
[.81746 .57529 5 6.28125 ]
[.88095 .57529 -5 -6.28125 ]
[.88095 .57529 5 6.28125 ]
[.94444 .57529 -5 -6.28125 ]
[.94444 .57529 5 6.28125 ]
[.05556 .51923 -5 -6.28125 ]
[.05556 .51923 5 6.28125 ]
[.05556 .46318 -5 -6.28125 ]
[.05556 .46318 5 6.28125 ]
[.05556 .40712 -5 -6.28125 ]
[.05556 .40712 5 6.28125 ]
[.05556 .35106 -5 -6.28125 ]
[.05556 .35106 5 6.28125 ]
[.05556 .295 -5 -6.28125 ]
[.05556 .295 5 6.28125 ]
[.05556 .23895 -5 -6.28125 ]
[.05556 .23895 5 6.28125 ]
[.05556 .18289 -5 -6.28125 ]
[.05556 .18289 5 6.28125 ]
[.05556 .12683 -5 -6.28125 ]
[.05556 .12683 5 6.28125 ]
[.05556 .07077 -5 -6.28125 ]
[.05556 .07077 5 6.28125 ]
[.11905 .51923 -3 -4.5 ]
[.11905 .51923 3 4.5 ]
[.18254 .51923 -9 -4.5 ]
[.18254 .51923 9 4.5 ]
[.24603 .51923 -9 -4.5 ]
[.24603 .51923 9 4.5 ]
[.30952 .51923 -9 -4.5 ]
[.30952 .51923 9 4.5 ]
[.37302 .51923 -9 -4.5 ]
[.37302 .51923 9 4.5 ]
[.43651 .51923 -9 -4.5 ]
[.43651 .51923 9 4.5 ]
[.5 .51923 -9 -4.5 ]
[.5 .51923 9 4.5 ]
[.56349 .51923 -9 -4.5 ]
[.56349 .51923 9 4.5 ]
[.62698 .51923 -9 -4.5 ]
[.62698 .51923 9 4.5 ]
[.69048 .51923 -9 -4.5 ]
[.69048 .51923 9 4.5 ]
[.75397 .51923 -9 -4.5 ]
[.75397 .51923 9 4.5 ]
[.81746 .51923 -9 -4.5 ]
[.81746 .51923 9 4.5 ]
[.88095 .51923 -9 -4.5 ]
[.88095 .51923 9 4.5 ]
[.94444 .51923 -9 -4.5 ]
[.94444 .51923 9 4.5 ]
[.11905 .46318 -6 -4.5 ]
[.11905 .46318 6 4.5 ]
[.18254 .46318 -3 -4.5 ]
[.18254 .46318 3 4.5 ]
[.24603 .46318 -3 -4.5 ]
[.24603 .46318 3 4.5 ]
[.30952 .46318 -6 -4.5 ]
[.30952 .46318 6 4.5 ]
[.37302 .46318 -9 -4.5 ]
[.37302 .46318 9 4.5 ]
[.43651 .46318 -9 -4.5 ]
[.43651 .46318 9 4.5 ]
[.5 .46318 -9 -4.5 ]
[.5 .46318 9 4.5 ]
[.56349 .46318 -9 -4.5 ]
[.56349 .46318 9 4.5 ]
[.62698 .46318 -9 -4.5 ]
[.62698 .46318 9 4.5 ]
[.69048 .46318 -9 -4.5 ]
[.69048 .46318 9 4.5 ]
[.75397 .46318 -9 -4.5 ]
[.75397 .46318 9 4.5 ]
[.81746 .46318 -9 -4.5 ]
[.81746 .46318 9 4.5 ]
[.88095 .46318 -9 -4.5 ]
[.88095 .46318 9 4.5 ]
[.94444 .46318 -9 -4.5 ]
[.94444 .46318 9 4.5 ]
[.11905 .40712 -9 -4.5 ]
[.11905 .40712 9 4.5 ]
[.18254 .40712 -3 -4.5 ]
[.18254 .40712 3 4.5 ]
[.24603 .40712 -3 -4.5 ]
[.24603 .40712 3 4.5 ]
[.30952 .40712 -6 -4.5 ]
[.30952 .40712 6 4.5 ]
[.37302 .40712 -6 -4.5 ]
[.37302 .40712 6 4.5 ]
[.43651 .40712 -6 -4.5 ]
[.43651 .40712 6 4.5 ]
[.5 .40712 -9 -4.5 ]
[.5 .40712 9 4.5 ]
[.56349 .40712 -9 -4.5 ]
[.56349 .40712 9 4.5 ]
[.62698 .40712 -9 -4.5 ]
[.62698 .40712 9 4.5 ]
[.69048 .40712 -9 -4.5 ]
[.69048 .40712 9 4.5 ]
[.75397 .40712 -9 -4.5 ]
[.75397 .40712 9 4.5 ]
[.81746 .40712 -9 -4.5 ]
[.81746 .40712 9 4.5 ]
[.88095 .40712 -9 -4.5 ]
[.88095 .40712 9 4.5 ]
[.94444 .40712 -9 -4.5 ]
[.94444 .40712 9 4.5 ]
[.11905 .35106 -9 -4.5 ]
[.11905 .35106 9 4.5 ]
[.18254 .35106 -6 -4.5 ]
[.18254 .35106 6 4.5 ]
[.24603 .35106 -3 -4.5 ]
[.24603 .35106 3 4.5 ]
[.30952 .35106 -3 -4.5 ]
[.30952 .35106 3 4.5 ]
[.37302 .35106 -3 -4.5 ]
[.37302 .35106 3 4.5 ]
[.43651 .35106 -6 -4.5 ]
[.43651 .35106 6 4.5 ]
[.5 .35106 -6 -4.5 ]
[.5 .35106 6 4.5 ]
[.56349 .35106 -9 -4.5 ]
[.56349 .35106 9 4.5 ]
[.62698 .35106 -9 -4.5 ]
[.62698 .35106 9 4.5 ]
[.69048 .35106 -9 -4.5 ]
[.69048 .35106 9 4.5 ]
[.75397 .35106 -9 -4.5 ]
[.75397 .35106 9 4.5 ]
[.81746 .35106 -9 -4.5 ]
[.81746 .35106 9 4.5 ]
[.88095 .35106 -9 -4.5 ]
[.88095 .35106 9 4.5 ]
[.94444 .35106 -9 -4.5 ]
[.94444 .35106 9 4.5 ]
[.11905 .295 -9 -4.5 ]
[.11905 .295 9 4.5 ]
[.18254 .295 -9 -4.5 ]
[.18254 .295 9 4.5 ]
[.24603 .295 -6 -4.5 ]
[.24603 .295 6 4.5 ]
[.30952 .295 -3 -4.5 ]
[.30952 .295 3 4.5 ]
[.37302 .295 -6 -4.5 ]
[.37302 .295 6 4.5 ]
[.43651 .295 -6 -4.5 ]
[.43651 .295 6 4.5 ]
[.5 .295 -3 -4.5 ]
[.5 .295 3 4.5 ]
[.56349 .295 -3 -4.5 ]
[.56349 .295 3 4.5 ]
[.62698 .295 -6 -4.5 ]
[.62698 .295 6 4.5 ]
[.69048 .295 -6 -4.5 ]
[.69048 .295 6 4.5 ]
[.75397 .295 -9 -4.5 ]
[.75397 .295 9 4.5 ]
[.81746 .295 -9 -4.5 ]
[.81746 .295 9 4.5 ]
[.88095 .295 -9 -4.5 ]
[.88095 .295 9 4.5 ]
[.94444 .295 -9 -4.5 ]
[.94444 .295 9 4.5 ]
[.11905 .23895 -9 -4.5 ]
[.11905 .23895 9 4.5 ]
[.18254 .23895 -9 -4.5 ]
[.18254 .23895 9 4.5 ]
[.24603 .23895 -6 -4.5 ]
[.24603 .23895 6 4.5 ]
[.30952 .23895 -6 -4.5 ]
[.30952 .23895 6 4.5 ]
[.37302 .23895 -6 -4.5 ]
[.37302 .23895 6 4.5 ]
[.43651 .23895 -6 -4.5 ]
[.43651 .23895 6 4.5 ]
[.5 .23895 -6 -4.5 ]
[.5 .23895 6 4.5 ]
[.56349 .23895 -3 -4.5 ]
[.56349 .23895 3 4.5 ]
[.62698 .23895 -3 -4.5 ]
[.62698 .23895 3 4.5 ]
[.69048 .23895 -3 -4.5 ]
[.69048 .23895 3 4.5 ]
[.75397 .23895 -6 -4.5 ]
[.75397 .23895 6 4.5 ]
[.81746 .23895 -6 -4.5 ]
[.81746 .23895 6 4.5 ]
[.88095 .23895 -9 -4.5 ]
[.88095 .23895 9 4.5 ]
[.94444 .23895 -9 -4.5 ]
[.94444 .23895 9 4.5 ]
[.11905 .18289 -9 -4.5 ]
[.11905 .18289 9 4.5 ]
[.18254 .18289 -9 -4.5 ]
[.18254 .18289 9 4.5 ]
[.24603 .18289 -9 -4.5 ]
[.24603 .18289 9 4.5 ]
[.30952 .18289 -6 -4.5 ]
[.30952 .18289 6 4.5 ]
[.37302 .18289 -3 -4.5 ]
[.37302 .18289 3 4.5 ]
[.43651 .18289 -6 -4.5 ]
[.43651 .18289 6 4.5 ]
[.5 .18289 -6 -4.5 ]
[.5 .18289 6 4.5 ]
[.56349 .18289 -6 -4.5 ]
[.56349 .18289 6 4.5 ]
[.62698 .18289 -6 -4.5 ]
[.62698 .18289 6 4.5 ]
[.69048 .18289 -3 -4.5 ]
[.69048 .18289 3 4.5 ]
[.75397 .18289 -3 -4.5 ]
[.75397 .18289 3 4.5 ]
[.81746 .18289 -6 -4.5 ]
[.81746 .18289 6 4.5 ]
[.88095 .18289 -6 -4.5 ]
[.88095 .18289 6 4.5 ]
[.94444 .18289 -9 -4.5 ]
[.94444 .18289 9 4.5 ]
[.11905 .12683 -9 -4.5 ]
[.11905 .12683 9 4.5 ]
[.18254 .12683 -9 -4.5 ]
[.18254 .12683 9 4.5 ]
[.24603 .12683 -9 -4.5 ]
[.24603 .12683 9 4.5 ]
[.30952 .12683 -9 -4.5 ]
[.30952 .12683 9 4.5 ]
[.37302 .12683 -3 -4.5 ]
[.37302 .12683 3 4.5 ]
[.43651 .12683 -3 -4.5 ]
[.43651 .12683 3 4.5 ]
[.5 .12683 -6 -4.5 ]
[.5 .12683 6 4.5 ]
[.56349 .12683 -6 -4.5 ]
[.56349 .12683 6 4.5 ]
[.62698 .12683 -6 -4.5 ]
[.62698 .12683 6 4.5 ]
[.69048 .12683 -6 -4.5 ]
[.69048 .12683 6 4.5 ]
[.75397 .12683 -6 -4.5 ]
[.75397 .12683 6 4.5 ]
[.81746 .12683 -6 -4.5 ]
[.81746 .12683 6 4.5 ]
[.88095 .12683 -3 -4.5 ]
[.88095 .12683 3 4.5 ]
[.94444 .12683 -3 -4.5 ]
[.94444 .12683 3 4.5 ]
[.11905 .07077 -9 -4.5 ]
[.11905 .07077 9 4.5 ]
[.18254 .07077 -9 -4.5 ]
[.18254 .07077 9 4.5 ]
[.24603 .07077 -9 -4.5 ]
[.24603 .07077 9 4.5 ]
[.30952 .07077 -9 -4.5 ]
[.30952 .07077 9 4.5 ]
[.37302 .07077 -6 -4.5 ]
[.37302 .07077 6 4.5 ]
[.43651 .07077 -3 -4.5 ]
[.43651 .07077 3 4.5 ]
[.5 .07077 -3 -4.5 ]
[.5 .07077 3 4.5 ]
[.56349 .07077 -6 -4.5 ]
[.56349 .07077 6 4.5 ]
[.62698 .07077 -6 -4.5 ]
[.62698 .07077 6 4.5 ]
[.69048 .07077 -6 -4.5 ]
[.69048 .07077 6 4.5 ]
[.75397 .07077 -6 -4.5 ]
[.75397 .07077 6 4.5 ]
[.81746 .07077 -6 -4.5 ]
[.81746 .07077 6 4.5 ]
[.88095 .07077 -6 -4.5 ]
[.88095 .07077 6 4.5 ]
[.94444 .07077 -6 -4.5 ]
[.94444 .07077 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.9 g
.0873 .54726 m
.0873 .60332 L
.97619 .60332 L
.97619 .54726 L
F
0 g
gsave
.11905 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18254 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24603 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30952 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37302 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43651 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56349 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62698 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75397 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81746 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88095 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.94444 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.9 g
.02381 .01472 m
.02381 .60332 L
.0873 .60332 L
.0873 .01472 L
F
0 g
gsave
.05556 .51923 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .46318 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .40712 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .35106 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .295 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .23895 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .18289 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .12683 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .07077 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
[(0)] .11905 .51923 0 0 Mshowa
[(-45)] .18254 .51923 0 0 Mshowa
[(-45)] .24603 .51923 0 0 Mshowa
[(-45)] .30952 .51923 0 0 Mshowa
[(-45)] .37302 .51923 0 0 Mshowa
[(-45)] .43651 .51923 0 0 Mshowa
[(-45)] .5 .51923 0 0 Mshowa
[(-45)] .56349 .51923 0 0 Mshowa
[(-45)] .62698 .51923 0 0 Mshowa
[(-45)] .69048 .51923 0 0 Mshowa
[(-45)] .75397 .51923 0 0 Mshowa
[(-45)] .81746 .51923 0 0 Mshowa
[(-45)] .88095 .51923 0 0 Mshowa
[(-45)] .94444 .51923 0 0 Mshowa
[(-5)] .11905 .46318 0 0 Mshowa
[(5)] .18254 .46318 0 0 Mshowa
[(0)] .24603 .46318 0 0 Mshowa
[(-5)] .30952 .46318 0 0 Mshowa
[(-10)] .37302 .46318 0 0 Mshowa
[(-15)] .43651 .46318 0 0 Mshowa
[(-20)] .5 .46318 0 0 Mshowa
[(-25)] .56349 .46318 0 0 Mshowa
[(-30)] .62698 .46318 0 0 Mshowa
[(-35)] .69048 .46318 0 0 Mshowa
[(-40)] .75397 .46318 0 0 Mshowa
[(-45)] .81746 .46318 0 0 Mshowa
[(-46)] .88095 .46318 0 0 Mshowa
[(-46)] .94444 .46318 0 0 Mshowa
[(-10)] .11905 .40712 0 0 Mshowa
[(0)] .18254 .40712 0 0 Mshowa
[(3)] .24603 .40712 0 0 Mshowa
[(-2)] .30952 .40712 0 0 Mshowa
[(-5)] .37302 .40712 0 0 Mshowa
[(-9)] .43651 .40712 0 0 Mshowa
[(-14)] .5 .40712 0 0 Mshowa
[(-19)] .56349 .40712 0 0 Mshowa
[(-24)] .62698 .40712 0 0 Mshowa
[(-28)] .69048 .40712 0 0 Mshowa
[(-33)] .75397 .40712 0 0 Mshowa
[(-38)] .81746 .40712 0 0 Mshowa
[(-43)] .88095 .40712 0 0 Mshowa
[(-47)] .94444 .40712 0 0 Mshowa
[(-15)] .11905 .35106 0 0 Mshowa
[(-5)] .18254 .35106 0 0 Mshowa
[(3)] .24603 .35106 0 0 Mshowa
[(9)] .30952 .35106 0 0 Mshowa
[(4)] .37302 .35106 0 0 Mshowa
[(-1)] .43651 .35106 0 0 Mshowa
[(-6)] .5 .35106 0 0 Mshowa
[(-11)] .56349 .35106 0 0 Mshowa
[(-16)] .62698 .35106 0 0 Mshowa
[(-21)] .69048 .35106 0 0 Mshowa
[(-26)] .75397 .35106 0 0 Mshowa
[(-31)] .81746 .35106 0 0 Mshowa
[(-36)] .88095 .35106 0 0 Mshowa
[(-41)] .94444 .35106 0 0 Mshowa
[(-20)] .11905 .295 0 0 Mshowa
[(-10)] .18254 .295 0 0 Mshowa
[(-2)] .24603 .295 0 0 Mshowa
[(4)] .30952 .295 0 0 Mshowa
[(17)] .37302 .295 0 0 Mshowa
[(12)] .43651 .295 0 0 Mshowa
[(7)] .5 .295 0 0 Mshowa
[(2)] .56349 .295 0 0 Mshowa
[(-3)] .62698 .295 0 0 Mshowa
[(-8)] .69048 .295 0 0 Mshowa
[(-13)] .75397 .295 0 0 Mshowa
[(-18)] .81746 .295 0 0 Mshowa
[(-23)] .88095 .295 0 0 Mshowa
[(-28)] .94444 .295 0 0 Mshowa
[(-25)] .11905 .23895 0 0 Mshowa
[(-15)] .18254 .23895 0 0 Mshowa
[(-7)] .24603 .23895 0 0 Mshowa
[(-1)] .30952 .23895 0 0 Mshowa
[(12)] .37302 .23895 0 0 Mshowa
[(17)] .43651 .23895 0 0 Mshowa
[(12)] .5 .23895 0 0 Mshowa
[(7)] .56349 .23895 0 0 Mshowa
[(8)] .62698 .23895 0 0 Mshowa
[(3)] .69048 .23895 0 0 Mshowa
[(-2)] .75397 .23895 0 0 Mshowa
[(-7)] .81746 .23895 0 0 Mshowa
[(-12)] .88095 .23895 0 0 Mshowa
[(-17)] .94444 .23895 0 0 Mshowa
[(-30)] .11905 .18289 0 0 Mshowa
[(-20)] .18254 .18289 0 0 Mshowa
[(-12)] .24603 .18289 0 0 Mshowa
[(-6)] .30952 .18289 0 0 Mshowa
[(7)] .37302 .18289 0 0 Mshowa
[(12)] .43651 .18289 0 0 Mshowa
[(17)] .5 .18289 0 0 Mshowa
[(18)] .56349 .18289 0 0 Mshowa
[(13)] .62698 .18289 0 0 Mshowa
[(8)] .69048 .18289 0 0 Mshowa
[(3)] .75397 .18289 0 0 Mshowa
[(-2)] .81746 .18289 0 0 Mshowa
[(-7)] .88095 .18289 0 0 Mshowa
[(-12)] .94444 .18289 0 0 Mshowa
[(-35)] .11905 .12683 0 0 Mshowa
[(-25)] .18254 .12683 0 0 Mshowa
[(-17)] .24603 .12683 0 0 Mshowa
[(-11)] .30952 .12683 0 0 Mshowa
[(2)] .37302 .12683 0 0 Mshowa
[(7)] .43651 .12683 0 0 Mshowa
[(12)] .5 .12683 0 0 Mshowa
[(15)] .56349 .12683 0 0 Mshowa
[(19)] .62698 .12683 0 0 Mshowa
[(14)] .69048 .12683 0 0 Mshowa
[(16)] .75397 .12683 0 0 Mshowa
[(11)] .81746 .12683 0 0 Mshowa
[(6)] .88095 .12683 0 0 Mshowa
[(1)] .94444 .12683 0 0 Mshowa
[(-40)] .11905 .07077 0 0 Mshowa
[(-30)] .18254 .07077 0 0 Mshowa
[(-22)] .24603 .07077 0 0 Mshowa
[(-16)] .30952 .07077 0 0 Mshowa
[(-3)] .37302 .07077 0 0 Mshowa
[(2)] .43651 .07077 0 0 Mshowa
[(7)] .5 .07077 0 0 Mshowa
[(10)] .56349 .07077 0 0 Mshowa
[(15)] .62698 .07077 0 0 Mshowa
[(18)] .69048 .07077 0 0 Mshowa
[(13)] .75397 .07077 0 0 Mshowa
[(17)] .81746 .07077 0 0 Mshowa
[(12)] .88095 .07077 0 0 Mshowa
[(11)] .94444 .07077 0 0 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`00
1`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
o`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1`3Vi^H3000000P0i^KV
2@3oool300000080oooo0P00000:0?ooo`800000103oool2000000T0oooo100000020?ooo`@00000
203oool5000000040?ooo`0000000000000000h0oooo0P00000<0?ooo`@00000403oool00`000000
oooo0?ooo`0:0?ooo`D000000P3oool2000000T0oooo1@0000020?ooo`8000002P3oool500000080
oooo0P0000090?ooo`D000000P3oool2000000T0oooo1@0000030?ooo`030000003oool0oooo00L0
oooo1@0000000`3oool0000000000002000000P0oooo1@0000000`3oool0000000000003000000`0
oooo00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H:0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`001`3oool80>KViP030000003V
i^H0i^KV00L0i^KV1`3oool5000000050?ooo`000000oooo0?ooo`0000002P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool000L0oooo203Vi^H00`000000i^KV0>KViP070>KViP030?ooo`0000000000008000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo100000050?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0100000040?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool0oooo100000040?ooo`040000003oool0oooo0?ooo`<000001`3oool4
000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool2000000`0oooo00<000000?ooo`3oool00P3oool2000000/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`001`3oool60>KViP050000003Vi^H0
00000>KViP0000001`3Vi^H80?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`001`3oool60>KViPD0
00001`3Vi^H90?ooo`8000000`3oool2000000X0oooo0P0000040?ooo`8000002P3oool2000000@0
oooo0P00000:0?ooo`800000103oool3000000d0oooo0P00000=0?ooo`8000003`3oool4000000`0
oooo0P0000040?ooo`8000002P3oool2000000@0oooo0`00000:0?ooo`800000103oool2000000X0
oooo0P0000040?ooo`8000002P3oool2000000<0oooo100000090?ooo`800000103oool2000000X0
oooo0P0000040?ooo`8000003P3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3o
ool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80
i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo0007
0?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0
oooo00070?ooo`H0i^KV0`0000000`3Vi^H00000000000060>KViPP0oooo0P0000040?ooo`800000
2@3oool4000000<0oooo0P0000090?ooo`D000000`3oool00`000000oooo0?ooo`070?ooo`D00000
00<0oooo0000000000000`0000080?ooo`@00000403oool00`000000oooo0?ooo`0:0?ooo`D00000
00<0oooo0000000000000P0000080?ooo`D000000P3oool2000000T0oooo1@000000103oool00000
00000000000:0?ooo`D000000`3oool3000000L0oooo1@000000103oool000000000000000090?oo
o`D0000000<0oooo0000000000000`00000:0?ooo`<000003`3oool5000000l0oooo00070?ooo`L0
i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo
00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:
0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool03`3oool000L0oooo1`3Vi^H0
10000000i^KV0>KViP0000070>KViPT0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo0`00000;0?ooo`040000003oool0oooo0?ooo`D00000
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000403oool00`00
0000oooo0?ooo`0?0?ooo`001`3oool70>KViP@000001`3Vi^H00`3oool0000000000002000000D0
oooo00@000000?ooo`3oool0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`020?oo
o`8000000`3oool4000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool2000000/0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool0oooo0`00000;0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool300000140oooo00<000000?ooo`3oool03`3oool000L0oooo1`3V
i^H010000000i^KV0>KViP0000070>KViPL0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00l0oooo00070?ooo`H0i^KV0P000000103Vi^H000000000000000060>KViPP0oooo0P0000040?oo
o`<000002@3oool2000000@0oooo0`0000090?ooo`8000000`3oool4000000T0oooo0P0000040?oo
o`8000002`3oool2000000l0oooo1000000<0?ooo`800000103oool2000000X0oooo0P0000040?oo
o`<000002@3oool2000000@0oooo0`00000:0?ooo`8000001@3oool2000000T0oooo0P0000040?oo
o`<000002@3oool2000000@0oooo0P00000=0?ooo`<000003`3oool200000140oooo00070?oooa80
i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo0007
0?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0
oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko
0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3oool80>KViP800000203Vi^H80?ooo`80
0000103oool2000000T0oooo100000030?ooo`8000002@3oool5000000030?ooo`00000000000080
00002`3oool3000000l0oooo00<000000?ooo`3oool02P3oool5000000030?ooo`00000000000080
0000203oool5000000<0oooo00<000000?ooo`3oool01`3oool500000080oooo0P0000090?ooo`D0
00000P3oool2000000h0oooo0P00000@0?ooo`8000004P3oool400000100oooo00<000000?ooo`3o
ool02P3oool5000000030?ooo`0000000000008000002P3oool000L0oooo1`3Vi^H010000000i^KV
0>KViP0000070>KViPL0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?oo
o`3oool0000000h0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0<0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool0000000d0oooo00070?ooo`L0i^KV00<000000>KViP00
00000P0000060>KViPT0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00070?ooo`L0i^KV00<000000>KViP3Vi^H0203Vi^H00`3oool0000000000002000000D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`04000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00@00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo100000020?ooo`<00000403oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool2000000/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`8000004P3oool00`000000oooo0?ooo`090?oo
o`@00000103oool00`000000oooo0?ooo`070?ooo`@000001@3oool00`000000oooo0?ooo`030?oo
o`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00070?ooo`L0
i^KV00<000000>KViP3Vi^H0203Vi^H70?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0303oool010000000oooo0?ooo`00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000004@3oool010000000oooo0?ooo`00000>0?ooo`040000003o
ool0oooo000000d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0
oooo00070?ooo`P0i^KV0`0000070>KViPP0oooo0P0000040?ooo`8000002P3oool2000000@0oooo
0P00000:0?ooo`800000103oool2000000d0oooo0`00000<0?ooo`@00000303oool2000000@0oooo
0P00000:0?ooo`8000000`3oool4000000T0oooo0P0000040?ooo`8000002P3oool2000000@0oooo
0P00000>0?ooo`800000403oool2000001<0oooo0P00000?0?ooo`@00000303oool2000000@0oooo
0P00000;0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo
00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?oo
o`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1P3V
i^H3000000030>KViP000000i^KV00H0i^KV1`3oool4000000<0oooo0P0000090?ooo`D000000P3o
ool2000000h0oooo00<000000?ooo`3oool03@3oool5000000P0oooo1@0000000`3oool000000000
0002000000P0oooo1@0000030?ooo`030000003oool0oooo00L0oooo1@0000000`3oool000000000
0002000000d0oooo00<000000?ooo`3oool03P3oool200000140oooo0P00000B0?ooo`@00000403o
ool00`000000oooo0?ooo`0:0?ooo`D0000000<0oooo0000000000000P0000080?ooo`D000000`3o
ool00`000000oooo0?ooo`090?ooo`001`3oool70>KViP040000003Vi^H00000000000L0i^KV1`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0
oooo00d0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`001`3oool70>KViP040000
003Vi^H00000000000L0i^KV203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool000L0oooo1`3Vi^H2000000030>KViP000000i^KV00H0
i^KV00<0oooo0000000000000P0000040?ooo`030000003oool0oooo0080oooo0P0000030?ooo`@0
0000103oool00`000000oooo0?ooo`020?ooo`8000001P3oool4000000D0oooo00<000000?ooo`3o
ool01P3oool4000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`80
00004`3oool00`000000oooo0?ooo`090?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`@0
00001@3oool00`000000oooo0?ooo`030?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00P0oooo00070?ooo`L0i^KV0P0000000`3Vi^H000000>KViP060>KViPL0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?
0?ooo`040000003oool0oooo00000140oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`001`3oool60>KV
iP80000000@0i^KV00000000000000001P3Vi^H80?ooo`800000103oool3000000T0oooo0P000004
0?ooo`<000002`3oool4000000l0oooo0P00000;0?ooo`800000103oool2000000X0oooo0P000003
0?ooo`@000002@3oool2000000@0oooo0P00000<0?ooo`@000003`3oool200000140oooo0P00000C
0?ooo`8000003`3oool4000000`0oooo0P0000040?ooo`8000002P3oool2000000<0oooo1000000:
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
o`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo
00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1P3Vi^H30000
00030>KViP000000000000H0i^KV1`3oool4000000<0oooo0P0000090?ooo`D000000P3oool20000
00`0oooo1000000=0?ooo`<000002`3oool5000000<0oooo00<000000?ooo`3oool01`3oool50000
00030?ooo`0000000000008000003@3oool00`000000oooo0?ooo`0=0?ooo`@000004P3oool20000
0140oooo0P00000<0?ooo`D000000P3oool2000000T0oooo1@0000020?ooo`8000002@3oool40000
00<0oooo0P0000090?ooo`@000000`3oool2000000/0oooo00070?ooo`L0i^KV00@000000>KViP3V
i^H000001`3Vi^H70?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0180oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000=0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0
oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H80?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`D000003@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>
0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000X0oooo00070?ooo`L0i^KV100000070>KViP030?ooo`000000000000800000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0100000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`@00000103oool00`00
0000oooo0?ooo`0:0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo100000050?ooo`030000003oool0
oooo00L0oooo100000030?ooo`8000001P3oool4000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo10000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0100000040?ooo`030000003oool0
oooo0080oooo0P00000;0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV1`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0000000>0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo000000h0oooo00@000000?ooo`3oool000004@3oool010000000oooo0?ooo`00000?0?oo
o`040000003oool0oooo000000d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000002P3oool000L0oooo1P3Vi^H2000000040>KViP000000
0000000000H0i^KV203oool2000000@0oooo0P00000:0?ooo`800000103oool2000000d0oooo0P00
000>0?ooo`8000003@3oool2000000<0oooo100000090?ooo`800000103oool2000000`0oooo1000
000?0?ooo`8000004`3oool200000140oooo0P00000=0?ooo`800000103oool2000000X0oooo0P00
00040?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`800000103oool2000000/0oooo0007
0?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0
oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko
0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo
4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KViPL0oooo1@000002
0?ooo`8000003@3oool2000000d0oooo0P00000?0?ooo`<000004P3oool300000100oooo1@00000=
0?ooo`<00000303oool5000000030?ooo`000000000000<000001`3oool5000000040?ooo`000000
0000000000X0oooo100000020?ooo`D000001`3oool400000080oooo0`00000:0?ooo`8000000`3o
ool5000000P0oooo0P0000030?ooo`<000002`3oool3000000030?ooo`000000000000<000002@3o
ool000L0oooo1`3Vi^H3000000P0i^KV2@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool000L0oooo203Vi^H00`000000i^KV0>KViP070>KViPT0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03P3oool3000000l0oooo1@00000B0?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo1@0000030?ooo`030000
003oool0oooo00T0oooo00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H00`3oool000000000
0002000000@0oooo00<000000?ooo`3oool00P3oool2000000H0oooo100000030?ooo`8000003`3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool0
00002`3oool4000000@0oooo00<000000?ooo`3oool01`3oool400000080oooo0`0000060?ooo`@0
0000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`@00000103oool01000
0000oooo0?ooo`3oool3000000@0oooo100000040?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool0oooo100000040?ooo`040000003oool0oooo0?ooo`<000000`3oool4000000D0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3o
ool00`0000030?ooo`@000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00T0oooo00070?ooo`P0i^KV0P0000080>KViPT0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000003P3oool01000
0000oooo0?ooo`00000@0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool02@3oool000L0oooo203Vi^H010000000i^KV0>KViP0000060>KViPP0oooo0P0000040?oo
o`<00000303oool3000000`0oooo0P00000@0?ooo`<000004@3oool200000180oooo0P00000@0?oo
o`<00000303oool2000000@0oooo0P00000:0?ooo`800000103oool3000000X0oooo0P0000040?oo
o`8000002P3oool2000000@0oooo0`0000090?ooo`800000103oool2000000X0oooo0P0000040?oo
o`<000002P3oool2000000<0oooo0P00000;0?ooo`001`3oool70>KViPD000001P3Vi^Ko0?ooo`P0
oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko
0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo
4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool0
00L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV1`3oool500000080oooo0P00000:0?ooo`80
0000403oool200000180oooo1000000@0?ooo`8000003`3oool3000000`0oooo1@0000030?ooo`<0
00001`3oool5000000040?ooo`0000000000000000T0oooo100000040?ooo`<00000203oool40000
00<0oooo0P00000:0?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000002`3oool30000
0080oooo0P00000;0?ooo`<000000`3oool00`000000oooo0?ooo`090?ooo`001`3oool60>KViPD0
00001`3Vi^H90?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
2`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0
i^KV2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`00000@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0=0?ooo`<000003@3oool010000000oooo0?ooo`3oool5000000T0oooo00<0
00000?ooo`3oool00P3oool3000000T0oooo00<000000?ooo`3oool00P3oool5000000T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01P3oool5000000<0oooo00<000000?ooo`3oool01`3oool5000000<0oooo00<000000?ooo`3o
ool02@3oool000L0oooo1`3Vi^H00`000000i^KV0>KViP080>KViP030?ooo`000000000000800000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`00000A0?ooo`030000003oool0oooo00T0oooo100000040?ooo`030000003oool0oooo
00P0oooo100000030?ooo`8000002@3oool400000080oooo00@000000?ooo`3oool000001@3oool4
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@00000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool4000000@0oooo00<000000?oo
o`3oool00P3oool2000000<0oooo100000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0100000050?ooo`040000003oool0oooo0?ooo`8000000`3oool400000080oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0400000080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`080?ooo`001`3oool70>KViP8000002@3Vi^H90?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000004@3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0
oooo00h0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000090?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool000000080oooo00@000000?ooo`3oool000002@3oool00`000000oooo00000002
0?ooo`040000003oool0oooo000000X0oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3V
i^H80?ooo`800000103oool2000000X0oooo0P00000@0?ooo`8000004`3oool200000140oooo0`00
000?0?ooo`<00000303oool2000000D0oooo0P0000090?ooo`800000103oool3000000T0oooo0P00
00050?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`800000103oool2000000X0oooo0P00
00040?ooo`8000002`3oool2000000<0oooo0P00000;0?ooo`8000000P3oool4000000X0oooo0007
0?ooo`H0i^KV1@0000070>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80
i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo0007
0?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0
oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^H;
0?ooo`8000003@3oool200000100oooo0P00000C0?ooo`8000003@3oool500000080oooo0P000009
0?ooo`D000000P3oool2000000T0oooo100000030?ooo`8000002@3oool4000000<0oooo0P00000:
0?ooo`800000103oool2000000/0oooo0P0000040?ooo`8000002`3oool300000080oooo0P00000;
0?ooo`<000000P3oool2000000/0oooo0`000000103oool0000000000000000;0?ooo`<0000000@0
oooo00000000000000002`3oool000L0oooo1P3Vi^H3000000030>KViP000000000000H0i^KV2P3o
ool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000004@3oool010000000oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000090?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00002`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo
00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H=0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00`0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`D0000000D0oooo0000003oool0oooo000000080?ooo`D00000
103oool00`000000oooo0?ooo`060?ooo`D0000000D0oooo0000003oool0oooo000000080?ooo`D0
000000D0oooo0000003oool0oooo0000000:0?ooo`001`3oool70>KViP<00000203Vi^H40?ooo`@0
00000`3oool2000000d0oooo0P00000?0?ooo`040000003oool0oooo000000/0oooo100000030?oo
o`8000001`3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00@00000103oool00`000000oooo0?ooo`020?ooo`8000000`3oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@00000103oool00`000000oooo0?oo
o`020?ooo`8000000`3oool4000000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`3oool4000000D0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`@000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo100000020?ooo`040000003o
ool0oooo000000<0oooo0P0000030?ooo`@000000P3oool010000000oooo0?ooo`0000020?ooo`<0
00000`3oool400000080oooo00@000000?ooo`3oool000000P3oool3000000/0oooo00070?ooo`L0
i^KV00<000000>KViP000000203Vi^H;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03P3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000090?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo000000020?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo
00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H;0?ooo`<00000303oool3000000l0oooo
0P00000C0?ooo`<000003@3oool2000000@0oooo0P00000:0?ooo`800000103oool3000000T0oooo
0P0000040?ooo`8000002P3oool2000000@0oooo0`0000090?ooo`800000103oool2000000/0oooo
0P0000040?ooo`<000002P3oool2000000<0oooo0P00000;0?ooo`8000000`3oool3000000X0oooo
0P0000030?ooo`<000002P3oool2000000<0oooo0`00000:0?ooo`001`3oool60>KViP<0000000<0
i^KV0000000000001P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KV
i_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3o
oolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?oo
o`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV203o
ool200000140oooo0`0000020?ooo`8000002`3oool300000080oooo0P00000;0?ooo`<000000P3o
ool2000000`0oooo0`0000020?ooo`8000002`3oool300000080oooo0P00000;0?ooo`<000000P3o
ool2000000/0oooo0`0000020?ooo`8000002`3oool300000080oooo0P00000<0?ooo`<000000P3o
ool2000000/0oooo0`0000020?ooo`8000002`3oool300000080oooo0P00000;0?ooo`<000000P3o
ool2000000/0oooo0`0000020?ooo`8000002`3oool000L0oooo4P3Vi^H70?ooo`040000003oool0
oooo00000140oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`09
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`080?ooo`001`3ooolB0>KViPL0oooo00@000000?ooo`3o
ool000003P3oool5000000@0oooo00<000000?ooo`3oool01P3oool5000000@0oooo00<000000?oo
o`3oool01P3oool5000000@0oooo00<000000?ooo`3oool01`3oool5000000@0oooo00<000000?oo
o`3oool01P3oool5000000@0oooo00<000000?ooo`3oool01P3oool5000000@0oooo00<000000?oo
o`3oool01P3oool5000000@0oooo00<000000?ooo`3oool01P3oool5000000@0oooo00<000000?oo
o`3oool01`3oool5000000@0oooo00<000000?ooo`3oool01P3oool5000000@0oooo00<000000?oo
o`3oool01P3oool5000000@0oooo00<000000?ooo`3oool01P3oool5000000@0oooo00<000000?oo
o`3oool01P3oool5000000@0oooo00<000000?ooo`3oool0203oool000L0oooo4P3Vi^H70?ooo`04
0000003oool0oooo000000P0oooo100000020?ooo`040000003oool0oooo000000<0oooo0P000003
0?ooo`@000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool400000080oooo00@0
00000?ooo`3oool000000`3oool2000000@0oooo100000020?ooo`040000003oool0oooo000000<0
oooo0P0000030?ooo`@000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool40000
0080oooo00@000000?ooo`3oool000000`3oool2000000<0oooo100000020?ooo`040000003oool0
oooo000000<0oooo0P0000030?ooo`@000000P3oool010000000oooo0?ooo`0000030?ooo`800000
103oool400000080oooo00@000000?ooo`3oool000000`3oool2000000<0oooo100000020?ooo`04
0000003oool0oooo000000<0oooo0P0000030?ooo`@000000P3oool010000000oooo0?ooo`000003
0?ooo`8000000`3oool400000080oooo00@000000?ooo`3oool000000`3oool2000000<0oooo1000
00020?ooo`040000003oool0oooo000000<0oooo0P00000;0?ooo`001`3ooolB0>KViPL0oooo00@0
00000?ooo`3oool000003`3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo
00070?oooa80i^KV203oool200000140oooo0P0000030?ooo`<000002P3oool2000000<0oooo0`00
000:0?ooo`8000000`3oool3000000/0oooo0P0000030?ooo`<000002P3oool2000000<0oooo0`00
000:0?ooo`8000000`3oool3000000X0oooo0P0000030?ooo`<000002P3oool2000000<0oooo0`00
000;0?ooo`8000000`3oool3000000X0oooo0P0000030?ooo`<000002P3oool2000000<0oooo0`00
000:0?ooo`8000000`3oool3000000X0oooo0P0000030?ooo`<000002P3oool000L0oooo4P3Vi^Ko
0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo
4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooooo0>KViQ40i^KV2@3oool0
00L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV
2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oookl0i^KV0P00001?0>KViPT0oooo00070?oo
obX0i^KV0`0000000`3Vi^H000000000000>0>KViP<000003P3Vi^H3000000l0i^KV0`0000000`3V
i^H000000000000<0>KViP<0000000<0i^KV0000000000003@3Vi^H2000000030>KViP0000000000
00h0i^KV0P00000>0>KViP<0000000<0i^KV0000003Vi^H03`3Vi^H2000000h0i^KV0`0000000`3V
i^H000000000000=0>KViP<000003P3Vi^H300000100i^KV0`0000080>KViPT0oooo00070?ooob/0
i^KV00@000000>KViP3Vi^H00000403Vi^H00`000000i^KV0>KViP0>0>KViP030000003Vi^H0i^KV
00l0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000>0>KViP050000003V
i^H0i^KV0>KViP0000003@3Vi^H010000000i^KV0>KViP00000>0>KViP040000003Vi^H000000000
00l0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000>0>KViP040000003V
i^H0i^KV000000h0i^KV00<000000>KViP3Vi^H0403Vi^H00`000000i^KV0>KViP070>KViPT0oooo
00070?ooob/0i^KV0`00000A0>KViP030000003Vi^H0i^KV00h0i^KV00<000000>KViP3Vi^H03`3V
i^H010000000i^KV0>KViP00000>0>KViP<00000403Vi^H3000000h0i^KV00<000000>KViP000000
0P00000=0>KViP040000003Vi^H00000000000l0i^KV00@000000>KViP3Vi^H000003P3Vi^H01000
0000i^KV0>KViP00000A0>KViP030000003Vi^H0i^KV00`0i^KV0`00000@0>KViP030000003Vi^H0
i^KV00L0i^KV2@3oool000L0oooo:`3Vi^H00`000000i^KV0000000@0>KViP030000003Vi^H00000
00l0i^KV0P00000@0>KViP@000003P3Vi^H00`000000i^KV0000000@0>KViP030000003Vi^H00000
00h0i^KV00<000000>KViP3Vi^H03`3Vi^H2000000030>KViP000000i^KV00h0i^KV00@000000>KV
iP3Vi^H000003P3Vi^H4000000l0i^KV0P00000?0>KViP040000003Vi^H0i^KV000000l0i^KV00<0
00000>KViP3Vi^H01`3Vi^H90?ooo`001`3oool[0>KViP040000003Vi^H0i^KV000000h0i^KV00D0
00000>KViP3Vi^H0i^KV0000000>0>KViP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP3V
i^H000003P3Vi^H010000000i^KV0>KViP00000@0>KViP030000003Vi^H0i^KV00d0i^KV00<00000
0>KViP3Vi^H03`3Vi^H2000000030>KViP000000i^KV00h0i^KV00@000000>KViP3Vi^H000003P3V
i^H010000000i^KV0>KViP00000>0>KViP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP3V
i^H000003@3Vi^H01@000000i^KV0000003Vi^H0000000L0i^KV2@3oool000L0oooo:P3Vi^H30000
00030>KViP000000000000`0i^KV0`0000000`3Vi^H000000000000=0>KViPD000003@3Vi^H20000
00040>KViP0000000000000000`0i^KV0`0000000`3Vi^H000000000000>0>KViP800000403Vi^H3
000000d0i^KV0P000000103Vi^H0000000000000000?0>KViP8000003P3Vi^H2000000040>KViP00
00000000000000d0i^KV1000000=0>KViP@000003P3Vi^H5000000L0i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0
ooooo`3Vi^HA0>KViPT0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.894534, -0.262555, \
0.0550141, 0.0623104}}]
}, Open  ]],

Cell["Dieses Grafikelement stellt die Basis f\[UDoubleDot]r Abb. 3.11 dar.", \
"Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[TextData[{
  "Der n\[ADoubleDot]chste Schritt besteht im Eintragen der Zeiger in diese \
Ausgabegrafik. \n",
  StyleBox["\nErneut gibt es verschiedene Wege, dies zu realisieren. Eine \
elegante Variante w\[ADoubleDot]re, die Parameter des entsprechenden \
Grafikbefehls zur Erzeugung der Pfeile aus den Werten der Zeiger explizit zu \
berechnen. Aus Gr\[UDoubleDot]nden der \[CapitalUDoubleDot]bersichtlichkeit \
werden wir hier stattdessen drei unterschiedliche Pfeile, die den drei \
Zeigerzust\[ADoubleDot]nden entsprechen, definieren und die Position in der \
Matrix als Argumente des Grafikbefehls verwenden. F\[UDoubleDot]r den ",
    FontColor->GrayLevel[0.500008]],
  StyleBox["Zeiger",
    FontColor->GrayLevel[0.500008]],
  StyleBox["zustand 1 hat man etwa:",
    FontColor->GrayLevel[0.500008]]
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(arrA[i_, j_] := 
        Show[Graphics[
            Arrow[{i + 0.7, Length[prot1] + 1.3 - \((j)\)}, {i + 0.3, 
                Length[prot1] + 1.7 - \((j)\)}, HeadScaling \[Rule] Relative, 
              HeadWidth \[Rule] 1]], 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[TextData[{
  "Wie schon zuvor bei den Koordinaten des ",
  StyleBox["Text",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls ist die genaue Wahl der Skalierungsfaktoren und \
Koordinatenangaben rein empirisch durch Trial-and-Error ermittelt worden. Man \
erkennt, wie sich diese Koordinaten mit der Position in der Matrix (den \
Argumenten der Funktion ",
  StyleBox["arrA",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") \[ADoubleDot]ndern. Die entsprechenden Befehle f\[UDoubleDot]r die \
beiden anderen Zust\[ADoubleDot]nde der ",
  "Zeiger",
  "variablen lauten:  "
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[{
    \(\(arrB[i_, j_] := 
        Show[Graphics[
            Arrow[{i + 1.0, Length[prot1] + 1.3 - \((j)\)}, {i + 1.0, 
                Length[prot1] + 1.7 - \((j)\)}, HeadScaling \[Rule] Relative, 
              HeadWidth \[Rule] 1]], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(arrC[i_, j_] := 
        Show[Graphics[
            Arrow[{i + 0.7, Length[prot1] + 1.0 - \((j)\)}, {i + 0.3, 
                Length[prot1] + 1.0 - \((j)\)}, HeadScaling \[Rule] Relative, 
              HeadWidth \[Rule] 1]], 
          DisplayFunction \[Rule] Identity];\)\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[TextData[{
  "Mit einer Metafunktion ",
  StyleBox["arrXX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", die neben der Matrixposition noch den Wert der Zeigervariablen als \
Argument enth\[ADoubleDot]lt, kann man nun zwischen diesen drei Befehlen ausw\
\[ADoubleDot]hlen. Dabei besteht diese Funktion ",
  StyleBox["arrXX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " nur aus einer ",
  StyleBox["If",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Anweisung, die jedem ",
  "Zeiger",
  "zustand den entsprechenden Grafikbefehl zuweist. "
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(arrXX[ll_, i_, j_] := 
        If[ll \[Equal] 1, arrA[i, j], 
          If[ll \[Equal] 2, arrB[i, j], 
            If[ll \[Equal] 3, arrC[i, j], 
              Show[Graphics[{GrayLevel[1], Point[{i, j}]}, 
                  DisplayFunction \[Rule] Identity]]]]];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell["\<\
Die Entscheidung f\[UDoubleDot]r die Matrixposition als Argument erlaubt es \
nun, diese Befehle zu nutzen, um einer ganzen Matrix das entsprechende \
Zeigerfeld zuzuweisen. Dies erreichen wir mit dem n\[ADoubleDot]chsten \
Befehl, der einfach auf eine Matrix angewendet wird:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(arrowfield[mat_] := 
        Module[{dd1, 
            dd2}, \[IndentingNewLine]dd1\  = \ \(Dimensions[
                mat]\)[\([1]\)]; \[IndentingNewLine]dd2\  = \ \(Dimensions[
                mat]\)[\([2]\)]; \[IndentingNewLine]Table[
            arrXX[mat[\([i, j]\)], \((j - 1)\), \((i - 1)\)], {i, 1, 
              dd1}, {j, 1, dd2}]];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[TextData[{
  "Innerhalb der Module-Umgebung erkennt man hier zun\[ADoubleDot]chst Abk\
\[UDoubleDot]rzungen f\[UDoubleDot]r die Matrixdimension und dann einen \
einfachen ",
  StyleBox["Table",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl, der auf jede Stelle der Matrix die Funktion ",
  StyleBox["arrXX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " anwendet. Mit der oben definierten Matrix ",
  StyleBox["FFTabB",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", in der gerade die Werte der ",
  "Zeiger",
  "variablen stehen, haben wir die f\[UDoubleDot]r die Funktion ",
  StyleBox["arrowfield",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.501961]],
  " erforderliche Struktur vorliegen. Wir wenden diesen Befehl an:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(p5 = arrowfield[FFTabB];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[TextData[{
  "Das Resultat ist eine Struktur aus Grafikbefehlen, die wir nun mit Hilfe \
eines einfachen ",
  StyleBox["Show",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.501961]],
  "-Befehls darstellen k\[ODoubleDot]nnen:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p6 = Show[p5, DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",\

  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0695169 0.0147151 0.0654004 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto fill
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto
-0.2 0.1 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 g
.008 w
.02381 .01472 Mdot
0 g
.5 Mabswid
[ ] 0 setdash
.14199 .60332 m
.11418 .60332 L
s
% Start of user PostScript
1.7 9. 1.3 9. MAarrowhead1
% End of user PostScript
.21151 .60332 m
.1837 .60332 L
s
% Start of user PostScript
2.7 9. 2.3 9. MAarrowhead1
% End of user PostScript
.28102 .60332 m
.25322 .60332 L
s
% Start of user PostScript
3.7 9. 3.3 9. MAarrowhead1
% End of user PostScript
.35054 .60332 m
.32273 .60332 L
s
% Start of user PostScript
4.7 9. 4.3 9. MAarrowhead1
% End of user PostScript
.42006 .60332 m
.39225 .60332 L
s
% Start of user PostScript
5.7 9. 5.3 9. MAarrowhead1
% End of user PostScript
.48957 .60332 m
.46177 .60332 L
s
% Start of user PostScript
6.7 9. 6.3 9. MAarrowhead1
% End of user PostScript
.55909 .60332 m
.53128 .60332 L
s
% Start of user PostScript
7.7 9. 7.3 9. MAarrowhead1
% End of user PostScript
.62861 .60332 m
.6008 .60332 L
s
% Start of user PostScript
8.7 9. 8.3 9. MAarrowhead1
% End of user PostScript
.69812 .60332 m
.67032 .60332 L
s
% Start of user PostScript
9.7 9. 9.3 9. MAarrowhead1
% End of user PostScript
.76764 .60332 m
.73983 .60332 L
s
% Start of user PostScript
10.7 9. 10.3 9. MAarrowhead1
% End of user PostScript
.83716 .60332 m
.80935 .60332 L
s
% Start of user PostScript
11.7 9. 11.3 9. MAarrowhead1
% End of user PostScript
.90667 .60332 m
.87887 .60332 L
s
% Start of user PostScript
12.7 9. 12.3 9. MAarrowhead1
% End of user PostScript
.97619 .60332 m
.94838 .60332 L
s
% Start of user PostScript
13.7 9. 13.3 9. MAarrowhead1
% End of user PostScript
.09333 .55754 m
.09333 .5837 L
s
% Start of user PostScript
1. 8.3 1. 8.7 MAarrowhead1
% End of user PostScript
.14199 .55754 m
.11418 .5837 L
s
% Start of user PostScript
1.7 8.3 1.3 8.7 MAarrowhead1
% End of user PostScript
.21151 .53792 m
.1837 .53792 L
s
% Start of user PostScript
2.7 8. 2.3 8. MAarrowhead1
% End of user PostScript
.28102 .53792 m
.25322 .53792 L
s
% Start of user PostScript
3.7 8. 3.3 8. MAarrowhead1
% End of user PostScript
.35054 .53792 m
.32273 .53792 L
s
% Start of user PostScript
4.7 8. 4.3 8. MAarrowhead1
% End of user PostScript
.42006 .53792 m
.39225 .53792 L
s
% Start of user PostScript
5.7 8. 5.3 8. MAarrowhead1
% End of user PostScript
.48957 .53792 m
.46177 .53792 L
s
% Start of user PostScript
6.7 8. 6.3 8. MAarrowhead1
% End of user PostScript
.55909 .53792 m
.53128 .53792 L
s
% Start of user PostScript
7.7 8. 7.3 8. MAarrowhead1
% End of user PostScript
.62861 .53792 m
.6008 .53792 L
s
% Start of user PostScript
8.7 8. 8.3 8. MAarrowhead1
% End of user PostScript
.69812 .53792 m
.67032 .53792 L
s
% Start of user PostScript
9.7 8. 9.3 8. MAarrowhead1
% End of user PostScript
.76764 .53792 m
.73983 .53792 L
s
% Start of user PostScript
10.7 8. 10.3 8. MAarrowhead1
% End of user PostScript
.83716 .55754 m
.80935 .5837 L
s
% Start of user PostScript
11.7 8.3 11.3 8.7 MAarrowhead1
% End of user PostScript
.90667 .55754 m
.87887 .5837 L
s
% Start of user PostScript
12.7 8.3 12.3 8.7 MAarrowhead1
% End of user PostScript
.97619 .55754 m
.94838 .5837 L
s
% Start of user PostScript
13.7 8.3 13.3 8.7 MAarrowhead1
% End of user PostScript
.09333 .49214 m
.09333 .5183 L
s
% Start of user PostScript
1. 7.3 1. 7.7 MAarrowhead1
% End of user PostScript
.16284 .49214 m
.16284 .5183 L
s
% Start of user PostScript
2. 7.3 2. 7.7 MAarrowhead1
% End of user PostScript
.21151 .49214 m
.1837 .5183 L
s
% Start of user PostScript
2.7 7.3 2.3 7.7 MAarrowhead1
% End of user PostScript
.28102 .47252 m
.25322 .47252 L
s
% Start of user PostScript
3.7 7. 3.3 7. MAarrowhead1
% End of user PostScript
.35054 .49214 m
.32273 .5183 L
s
% Start of user PostScript
4.7 7.3 4.3 7.7 MAarrowhead1
% End of user PostScript
.42006 .49214 m
.39225 .5183 L
s
% Start of user PostScript
5.7 7.3 5.3 7.7 MAarrowhead1
% End of user PostScript
.48957 .47252 m
.46177 .47252 L
s
% Start of user PostScript
6.7 7. 6.3 7. MAarrowhead1
% End of user PostScript
.55909 .47252 m
.53128 .47252 L
s
% Start of user PostScript
7.7 7. 7.3 7. MAarrowhead1
% End of user PostScript
.62861 .47252 m
.6008 .47252 L
s
% Start of user PostScript
8.7 7. 8.3 7. MAarrowhead1
% End of user PostScript
.69812 .49214 m
.67032 .5183 L
s
% Start of user PostScript
9.7 7.3 9.3 7.7 MAarrowhead1
% End of user PostScript
.76764 .47252 m
.73983 .47252 L
s
% Start of user PostScript
10.7 7. 10.3 7. MAarrowhead1
% End of user PostScript
.83716 .47252 m
.80935 .47252 L
s
% Start of user PostScript
11.7 7. 11.3 7. MAarrowhead1
% End of user PostScript
.90667 .47252 m
.87887 .47252 L
s
% Start of user PostScript
12.7 7. 12.3 7. MAarrowhead1
% End of user PostScript
.97619 .49214 m
.94838 .5183 L
s
% Start of user PostScript
13.7 7.3 13.3 7.7 MAarrowhead1
% End of user PostScript
.09333 .42674 m
.09333 .4529 L
s
% Start of user PostScript
1. 6.3 1. 6.7 MAarrowhead1
% End of user PostScript
.16284 .42674 m
.16284 .4529 L
s
% Start of user PostScript
2. 6.3 2. 6.7 MAarrowhead1
% End of user PostScript
.21151 .42674 m
.1837 .4529 L
s
% Start of user PostScript
2.7 6.3 2.3 6.7 MAarrowhead1
% End of user PostScript
.28102 .42674 m
.25322 .4529 L
s
% Start of user PostScript
3.7 6.3 3.3 6.7 MAarrowhead1
% End of user PostScript
.35054 .40712 m
.32273 .40712 L
s
% Start of user PostScript
4.7 6. 4.3 6. MAarrowhead1
% End of user PostScript
.42006 .40712 m
.39225 .40712 L
s
% Start of user PostScript
5.7 6. 5.3 6. MAarrowhead1
% End of user PostScript
.48957 .40712 m
.46177 .40712 L
s
% Start of user PostScript
6.7 6. 6.3 6. MAarrowhead1
% End of user PostScript
.55909 .40712 m
.53128 .40712 L
s
% Start of user PostScript
7.7 6. 7.3 6. MAarrowhead1
% End of user PostScript
.62861 .40712 m
.6008 .40712 L
s
% Start of user PostScript
8.7 6. 8.3 6. MAarrowhead1
% End of user PostScript
.69812 .40712 m
.67032 .40712 L
s
% Start of user PostScript
9.7 6. 9.3 6. MAarrowhead1
% End of user PostScript
.76764 .40712 m
.73983 .40712 L
s
% Start of user PostScript
10.7 6. 10.3 6. MAarrowhead1
% End of user PostScript
.83716 .40712 m
.80935 .40712 L
s
% Start of user PostScript
11.7 6. 11.3 6. MAarrowhead1
% End of user PostScript
.90667 .40712 m
.87887 .40712 L
s
% Start of user PostScript
12.7 6. 12.3 6. MAarrowhead1
% End of user PostScript
.97619 .40712 m
.94838 .40712 L
s
% Start of user PostScript
13.7 6. 13.3 6. MAarrowhead1
% End of user PostScript
.09333 .36134 m
.09333 .3875 L
s
% Start of user PostScript
1. 5.3 1. 5.7 MAarrowhead1
% End of user PostScript
.16284 .36134 m
.16284 .3875 L
s
% Start of user PostScript
2. 5.3 2. 5.7 MAarrowhead1
% End of user PostScript
.23236 .36134 m
.23236 .3875 L
s
% Start of user PostScript
3. 5.3 3. 5.7 MAarrowhead1
% End of user PostScript
.30188 .36134 m
.30188 .3875 L
s
% Start of user PostScript
4. 5.3 4. 5.7 MAarrowhead1
% End of user PostScript
.35054 .36134 m
.32273 .3875 L
s
% Start of user PostScript
4.7 5.3 4.3 5.7 MAarrowhead1
% End of user PostScript
.42006 .34172 m
.39225 .34172 L
s
% Start of user PostScript
5.7 5. 5.3 5. MAarrowhead1
% End of user PostScript
.48957 .34172 m
.46177 .34172 L
s
% Start of user PostScript
6.7 5. 6.3 5. MAarrowhead1
% End of user PostScript
.55909 .34172 m
.53128 .34172 L
s
% Start of user PostScript
7.7 5. 7.3 5. MAarrowhead1
% End of user PostScript
.62861 .34172 m
.6008 .34172 L
s
% Start of user PostScript
8.7 5. 8.3 5. MAarrowhead1
% End of user PostScript
.69812 .34172 m
.67032 .34172 L
s
% Start of user PostScript
9.7 5. 9.3 5. MAarrowhead1
% End of user PostScript
.76764 .36134 m
.73983 .3875 L
s
% Start of user PostScript
10.7 5.3 10.3 5.7 MAarrowhead1
% End of user PostScript
.83716 .34172 m
.80935 .34172 L
s
% Start of user PostScript
11.7 5. 11.3 5. MAarrowhead1
% End of user PostScript
.90667 .34172 m
.87887 .34172 L
s
% Start of user PostScript
12.7 5. 12.3 5. MAarrowhead1
% End of user PostScript
.97619 .34172 m
.94838 .34172 L
s
% Start of user PostScript
13.7 5. 13.3 5. MAarrowhead1
% End of user PostScript
.09333 .29594 m
.09333 .3221 L
s
% Start of user PostScript
1. 4.3 1. 4.7 MAarrowhead1
% End of user PostScript
.16284 .29594 m
.16284 .3221 L
s
% Start of user PostScript
2. 4.3 2. 4.7 MAarrowhead1
% End of user PostScript
.23236 .29594 m
.23236 .3221 L
s
% Start of user PostScript
3. 4.3 3. 4.7 MAarrowhead1
% End of user PostScript
.30188 .29594 m
.30188 .3221 L
s
% Start of user PostScript
4. 4.3 4. 4.7 MAarrowhead1
% End of user PostScript
.37139 .29594 m
.37139 .3221 L
s
% Start of user PostScript
5. 4.3 5. 4.7 MAarrowhead1
% End of user PostScript
.42006 .29594 m
.39225 .3221 L
s
% Start of user PostScript
5.7 4.3 5.3 4.7 MAarrowhead1
% End of user PostScript
.48957 .27632 m
.46177 .27632 L
s
% Start of user PostScript
6.7 4. 6.3 4. MAarrowhead1
% End of user PostScript
.55909 .29594 m
.53128 .3221 L
s
% Start of user PostScript
7.7 4.3 7.3 4.7 MAarrowhead1
% End of user PostScript
.62861 .29594 m
.6008 .3221 L
s
% Start of user PostScript
8.7 4.3 8.3 4.7 MAarrowhead1
% End of user PostScript
.69812 .27632 m
.67032 .27632 L
s
% Start of user PostScript
9.7 4. 9.3 4. MAarrowhead1
% End of user PostScript
.76764 .27632 m
.73983 .27632 L
s
% Start of user PostScript
10.7 4. 10.3 4. MAarrowhead1
% End of user PostScript
.83716 .27632 m
.80935 .27632 L
s
% Start of user PostScript
11.7 4. 11.3 4. MAarrowhead1
% End of user PostScript
.90667 .27632 m
.87887 .27632 L
s
% Start of user PostScript
12.7 4. 12.3 4. MAarrowhead1
% End of user PostScript
.97619 .27632 m
.94838 .27632 L
s
% Start of user PostScript
13.7 4. 13.3 4. MAarrowhead1
% End of user PostScript
.09333 .23054 m
.09333 .2567 L
s
% Start of user PostScript
1. 3.3 1. 3.7 MAarrowhead1
% End of user PostScript
.16284 .23054 m
.16284 .2567 L
s
% Start of user PostScript
2. 3.3 2. 3.7 MAarrowhead1
% End of user PostScript
.23236 .23054 m
.23236 .2567 L
s
% Start of user PostScript
3. 3.3 3. 3.7 MAarrowhead1
% End of user PostScript
.30188 .23054 m
.30188 .2567 L
s
% Start of user PostScript
4. 3.3 4. 3.7 MAarrowhead1
% End of user PostScript
.37139 .23054 m
.37139 .2567 L
s
% Start of user PostScript
5. 3.3 5. 3.7 MAarrowhead1
% End of user PostScript
.44091 .23054 m
.44091 .2567 L
s
% Start of user PostScript
6. 3.3 6. 3.7 MAarrowhead1
% End of user PostScript
.48957 .23054 m
.46177 .2567 L
s
% Start of user PostScript
6.7 3.3 6.3 3.7 MAarrowhead1
% End of user PostScript
.55909 .23054 m
.53128 .2567 L
s
% Start of user PostScript
7.7 3.3 7.3 3.7 MAarrowhead1
% End of user PostScript
.62861 .21092 m
.6008 .21092 L
s
% Start of user PostScript
8.7 3. 8.3 3. MAarrowhead1
% End of user PostScript
.69812 .21092 m
.67032 .21092 L
s
% Start of user PostScript
9.7 3. 9.3 3. MAarrowhead1
% End of user PostScript
.76764 .21092 m
.73983 .21092 L
s
% Start of user PostScript
10.7 3. 10.3 3. MAarrowhead1
% End of user PostScript
.83716 .23054 m
.80935 .2567 L
s
% Start of user PostScript
11.7 3.3 11.3 3.7 MAarrowhead1
% End of user PostScript
.90667 .21092 m
.87887 .21092 L
s
% Start of user PostScript
12.7 3. 12.3 3. MAarrowhead1
% End of user PostScript
.97619 .21092 m
.94838 .21092 L
s
% Start of user PostScript
13.7 3. 13.3 3. MAarrowhead1
% End of user PostScript
.09333 .16514 m
.09333 .1913 L
s
% Start of user PostScript
1. 2.3 1. 2.7 MAarrowhead1
% End of user PostScript
.16284 .16514 m
.16284 .1913 L
s
% Start of user PostScript
2. 2.3 2. 2.7 MAarrowhead1
% End of user PostScript
.23236 .16514 m
.23236 .1913 L
s
% Start of user PostScript
3. 2.3 3. 2.7 MAarrowhead1
% End of user PostScript
.30188 .16514 m
.30188 .1913 L
s
% Start of user PostScript
4. 2.3 4. 2.7 MAarrowhead1
% End of user PostScript
.35054 .16514 m
.32273 .1913 L
s
% Start of user PostScript
4.7 2.3 4.3 2.7 MAarrowhead1
% End of user PostScript
.44091 .16514 m
.44091 .1913 L
s
% Start of user PostScript
6. 2.3 6. 2.7 MAarrowhead1
% End of user PostScript
.51043 .16514 m
.51043 .1913 L
s
% Start of user PostScript
7. 2.3 7. 2.7 MAarrowhead1
% End of user PostScript
.55909 .16514 m
.53128 .1913 L
s
% Start of user PostScript
7.7 2.3 7.3 2.7 MAarrowhead1
% End of user PostScript
.62861 .16514 m
.6008 .1913 L
s
% Start of user PostScript
8.7 2.3 8.3 2.7 MAarrowhead1
% End of user PostScript
.69812 .14552 m
.67032 .14552 L
s
% Start of user PostScript
9.7 2. 9.3 2. MAarrowhead1
% End of user PostScript
.76764 .16514 m
.73983 .1913 L
s
% Start of user PostScript
10.7 2.3 10.3 2.7 MAarrowhead1
% End of user PostScript
.83716 .14552 m
.80935 .14552 L
s
% Start of user PostScript
11.7 2. 11.3 2. MAarrowhead1
% End of user PostScript
.90667 .14552 m
.87887 .14552 L
s
% Start of user PostScript
12.7 2. 12.3 2. MAarrowhead1
% End of user PostScript
.97619 .14552 m
.94838 .14552 L
s
% Start of user PostScript
13.7 2. 13.3 2. MAarrowhead1
% End of user PostScript
.09333 .09974 m
.09333 .1259 L
s
% Start of user PostScript
1. 1.3 1. 1.7 MAarrowhead1
% End of user PostScript
.16284 .09974 m
.16284 .1259 L
s
% Start of user PostScript
2. 1.3 2. 1.7 MAarrowhead1
% End of user PostScript
.23236 .09974 m
.23236 .1259 L
s
% Start of user PostScript
3. 1.3 3. 1.7 MAarrowhead1
% End of user PostScript
.30188 .09974 m
.30188 .1259 L
s
% Start of user PostScript
4. 1.3 4. 1.7 MAarrowhead1
% End of user PostScript
.37139 .09974 m
.37139 .1259 L
s
% Start of user PostScript
5. 1.3 5. 1.7 MAarrowhead1
% End of user PostScript
.44091 .09974 m
.44091 .1259 L
s
% Start of user PostScript
6. 1.3 6. 1.7 MAarrowhead1
% End of user PostScript
.48957 .09974 m
.46177 .1259 L
s
% Start of user PostScript
6.7 1.3 6.3 1.7 MAarrowhead1
% End of user PostScript
.55909 .09974 m
.53128 .1259 L
s
% Start of user PostScript
7.7 1.3 7.3 1.7 MAarrowhead1
% End of user PostScript
.62861 .09974 m
.6008 .1259 L
s
% Start of user PostScript
8.7 1.3 8.3 1.7 MAarrowhead1
% End of user PostScript
.69812 .09974 m
.67032 .1259 L
s
% Start of user PostScript
9.7 1.3 9.3 1.7 MAarrowhead1
% End of user PostScript
.76764 .08012 m
.73983 .08012 L
s
% Start of user PostScript
10.7 1. 10.3 1. MAarrowhead1
% End of user PostScript
.83716 .09974 m
.80935 .1259 L
s
% Start of user PostScript
11.7 1.3 11.3 1.7 MAarrowhead1
% End of user PostScript
.90667 .08012 m
.87887 .08012 L
s
% Start of user PostScript
12.7 1. 12.3 1. MAarrowhead1
% End of user PostScript
.97619 .09974 m
.94838 .1259 L
s
% Start of user PostScript
13.7 1.3 13.3 1.7 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00e03oool9000001h0oooo2@00000L0?ooo`00e@3oool00`000000oooo
0?ooo`0T0?ooo`8000008P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool001/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`070?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo
0000000A0?ooo`030000003oool000000140oooo00<000000?ooo`0000004@3oool00`000000oooo
0000000T0?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`0000003@3oool001X0oooo
0P00000B0?ooo`8000004P3oool200000180oooo0P00000A0?ooo`<000004@3oool3000000D0oooo
0P00000B0?ooo`8000004P3oool200000180oooo0P00000U0?ooo`<000009@3oool2000000h0oooo
000J0?ooo`8000004P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool200000180oooo0P0000050?ooo`<000004@3oool300000140oooo0`00
000A0?ooo`<000009@3oool3000002@0oooo1000000=0?ooo`006`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool200000180oooo0P00000B
0?ooo`8000004P3oool2000002H0oooo0P00000U0?ooo`8000003`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00<40oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00<00oooo2@00000O
0?ooo`T000002P3oool9000000/0oooo2@0000080?ooo`00`@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0100oooo0P00000B0?ooo`8000003P3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001/0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0@@3oool001/0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0@P3oool001/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0@`3oool001/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0A03oool001/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool2000001d0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`8000004P3oool2000002H0oooo0P000017
0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`040?ooo`8000007`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo0P00000B0?ooo`8000009@3oool00`000000oooo000000190?oo
o`006P3oool200000180oooo0P00000B0?ooo`8000004P3oool2000000@0oooo0`00000N0?ooo`<0
00004@3oool3000000@0oooo0P00000B0?ooo`8000009P3oool2000004X0oooo000K0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00<0oooo1000000N0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
0`3oool300000140oooo0`00000U0?ooo`<00000B@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00:d0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0<0?ooo`00[03oool9000000/0oooo2@00000;0?ooo`T000007P3oool9000000/0oooo2@00
00080?ooo`00[@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0903oool200000180oooo0P00000>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo02h0oooo000K0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0_0?ooo`006`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0<03oool001/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo0P00
000B0?ooo`800000CP3oool2000003<0oooo000K0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`8000004P3oool2000004d0oooo00<00000
0?ooo`000000=@3oool001X0oooo0P00000B0?ooo`8000004P3oool200000180oooo0P00000A0?oo
o`<000004@3oool3000000@0oooo0`00000A0?ooo`<00000C@3oool3000003D0oooo000K0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`80
00004P3oool2000004h0oooo0P00000f0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00QP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0303oool008@0oooo2@00000c0?ooo`T000002`3oool9000000/0oooo
2@00000:0?ooo`T000002`3oool9000000P0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
J@3oool001/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1Z0?ooo`006`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06/0oooo000K0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0K03oool001/0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`1]0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06h0oooo
000J0?ooo`8000004P3oool200000180oooo0P00000B0?ooo`8000004@3oool3000000D0oooo0P00
000V0?ooo`8000004P3oool200000740oooo000J0?ooo`8000004P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool2000000D0oooo0`00000U
0?ooo`<000004@3oool300000740oooo000K0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00`3oool2000002H0oooo0P00000B0?ooo`800000LP3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00700oooo2@00000;0?ooo`T000002`3oool90000
00/0oooo2@00000;0?ooo`T000007`3oool9000000X0oooo2@00000;0?ooo`T00000203oool00740
oooo0P00000B0?ooo`8000004P3oool200000180oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0100oooo0P00000B0?ooo`8000003P3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001/0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0440oooo000K0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`120?ooo`006`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0@`3o
ool001/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1e0?ooo`030000003oool0
oooo04@0oooo000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo0P00001f0?ooo`800000A`3oool001/0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool2000007D0oooo00<000000?ooo`000000B@3oool001X0oooo
0P00000B0?ooo`8000004P3oool200000180oooo0P0000040?ooo`<00000M@3oool2000004X0oooo
000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00<0oooo1000001d0?ooo`<00000B@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool005h0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303o
ool005`0oooo2@00000;0?ooo`T000002`3oool9000000/0oooo2@00000;0?ooo`T000002`3oool9
000000/0oooo2@00000;0?ooo`T000002P3oool9000000/0oooo2@0000080?ooo`00G@3oool20000
0180oooo0P00000B0?ooo`8000004P3oool200000180oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool20000
0180oooo0P00000>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3=0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3>0?ooo`00
6`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`3?0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3@0?ooo`006`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo0P00000B0?ooo`800000d`3oool0
01/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`8000004P3oool20000
0=D0oooo000J0?ooo`8000004P3oool2000000@0oooo0`00000A0?ooo`<00000e@3oool001/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`@00000403oool400000=@0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo001:0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0200oooo00180?ooo`T00000<`3oool9000000/0oooo2@00000;0?ooo`T000007`3o
ool9000000/0oooo2@00000:0?ooo`T00000703oool004T0oooo0P00000j0?ooo`8000004P3oool2
00000180oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0100oooo0P00000R0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`070?ooo`006`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`080?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0;0?ooo`006P3oool200000180oooo0P000005
0?ooo`8000009P3oool200000180oooo0P00001>0?ooo`800000C@3oool2000000h0oooo000J0?oo
o`8000004P3oool00`000000oooo0?ooo`030?ooo`@00000903oool400000100oooo0`00001=0?oo
o`<00000C03oool4000000d0oooo000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00`3oool2000002H0oooo0P00000B0?ooo`800000CP3oool2000004d0oooo0P00000?0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0B03oool003@0oooo
2@00000;0?ooo`T000002`3oool9000000/0oooo2@00000;0?ooo`T000002`3oool9000000/0oooo
2@00000;0?ooo`T000002`3oool9000004<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo000K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
1P3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`340?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`006`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo000K0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`340?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000<<0
oooo00@000000?ooo`3oool00000403oool00`000000oooo0000000A0?ooo`030000003oool00000
00d0oooo000J0?ooo`8000001@3oool300000<@0oooo0`00000A0?ooo`8000004P3oool2000000h0
oooo000J0?ooo`8000001@3oool300000<@0oooo0`00000@0?ooo`@00000403oool4000000d0oooo
000K0?ooo`030000003oool0oooo00<0oooo0P0000350?ooo`8000004@3oool200000180oooo0P00
000?0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`008@3o
ool9000000X0oooo2@00000;0?ooo`T000002`3oool9000000/0oooo2@00000;0?ooo`T000002`3o
ool9000000/0oooo2@00000;0?ooo`T000002`3oool9000000/0oooo2@00000:0?ooo`T000002`3o
ool9000000P0oooo000R0?ooo`030000003oool0oooo0100oooo0P00000B0?ooo`8000004P3oool2
00000180oooo0P00000B0?ooo`8000004P3oool200000180oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool2
00000180oooo0P00000>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.36034, -0.225047, \
0.0502462, 0.0534089}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p6 = 
        Show[p4, p5, DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",\

  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0555556 0.0634921 0.0147151 0.0560575 [
[.11905 .57529 -5 -6.28125 ]
[.11905 .57529 5 6.28125 ]
[.18254 .57529 -5 -6.28125 ]
[.18254 .57529 5 6.28125 ]
[.24603 .57529 -5 -6.28125 ]
[.24603 .57529 5 6.28125 ]
[.30952 .57529 -5 -6.28125 ]
[.30952 .57529 5 6.28125 ]
[.37302 .57529 -5 -6.28125 ]
[.37302 .57529 5 6.28125 ]
[.43651 .57529 -5 -6.28125 ]
[.43651 .57529 5 6.28125 ]
[.5 .57529 -5 -6.28125 ]
[.5 .57529 5 6.28125 ]
[.56349 .57529 -5 -6.28125 ]
[.56349 .57529 5 6.28125 ]
[.62698 .57529 -5 -6.28125 ]
[.62698 .57529 5 6.28125 ]
[.69048 .57529 -5 -6.28125 ]
[.69048 .57529 5 6.28125 ]
[.75397 .57529 -5 -6.28125 ]
[.75397 .57529 5 6.28125 ]
[.81746 .57529 -5 -6.28125 ]
[.81746 .57529 5 6.28125 ]
[.88095 .57529 -5 -6.28125 ]
[.88095 .57529 5 6.28125 ]
[.94444 .57529 -5 -6.28125 ]
[.94444 .57529 5 6.28125 ]
[.05556 .51923 -5 -6.28125 ]
[.05556 .51923 5 6.28125 ]
[.05556 .46318 -5 -6.28125 ]
[.05556 .46318 5 6.28125 ]
[.05556 .40712 -5 -6.28125 ]
[.05556 .40712 5 6.28125 ]
[.05556 .35106 -5 -6.28125 ]
[.05556 .35106 5 6.28125 ]
[.05556 .295 -5 -6.28125 ]
[.05556 .295 5 6.28125 ]
[.05556 .23895 -5 -6.28125 ]
[.05556 .23895 5 6.28125 ]
[.05556 .18289 -5 -6.28125 ]
[.05556 .18289 5 6.28125 ]
[.05556 .12683 -5 -6.28125 ]
[.05556 .12683 5 6.28125 ]
[.05556 .07077 -5 -6.28125 ]
[.05556 .07077 5 6.28125 ]
[.11905 .51923 -3 -4.5 ]
[.11905 .51923 3 4.5 ]
[.18254 .51923 -9 -4.5 ]
[.18254 .51923 9 4.5 ]
[.24603 .51923 -9 -4.5 ]
[.24603 .51923 9 4.5 ]
[.30952 .51923 -9 -4.5 ]
[.30952 .51923 9 4.5 ]
[.37302 .51923 -9 -4.5 ]
[.37302 .51923 9 4.5 ]
[.43651 .51923 -9 -4.5 ]
[.43651 .51923 9 4.5 ]
[.5 .51923 -9 -4.5 ]
[.5 .51923 9 4.5 ]
[.56349 .51923 -9 -4.5 ]
[.56349 .51923 9 4.5 ]
[.62698 .51923 -9 -4.5 ]
[.62698 .51923 9 4.5 ]
[.69048 .51923 -9 -4.5 ]
[.69048 .51923 9 4.5 ]
[.75397 .51923 -9 -4.5 ]
[.75397 .51923 9 4.5 ]
[.81746 .51923 -9 -4.5 ]
[.81746 .51923 9 4.5 ]
[.88095 .51923 -9 -4.5 ]
[.88095 .51923 9 4.5 ]
[.94444 .51923 -9 -4.5 ]
[.94444 .51923 9 4.5 ]
[.11905 .46318 -6 -4.5 ]
[.11905 .46318 6 4.5 ]
[.18254 .46318 -3 -4.5 ]
[.18254 .46318 3 4.5 ]
[.24603 .46318 -3 -4.5 ]
[.24603 .46318 3 4.5 ]
[.30952 .46318 -6 -4.5 ]
[.30952 .46318 6 4.5 ]
[.37302 .46318 -9 -4.5 ]
[.37302 .46318 9 4.5 ]
[.43651 .46318 -9 -4.5 ]
[.43651 .46318 9 4.5 ]
[.5 .46318 -9 -4.5 ]
[.5 .46318 9 4.5 ]
[.56349 .46318 -9 -4.5 ]
[.56349 .46318 9 4.5 ]
[.62698 .46318 -9 -4.5 ]
[.62698 .46318 9 4.5 ]
[.69048 .46318 -9 -4.5 ]
[.69048 .46318 9 4.5 ]
[.75397 .46318 -9 -4.5 ]
[.75397 .46318 9 4.5 ]
[.81746 .46318 -9 -4.5 ]
[.81746 .46318 9 4.5 ]
[.88095 .46318 -9 -4.5 ]
[.88095 .46318 9 4.5 ]
[.94444 .46318 -9 -4.5 ]
[.94444 .46318 9 4.5 ]
[.11905 .40712 -9 -4.5 ]
[.11905 .40712 9 4.5 ]
[.18254 .40712 -3 -4.5 ]
[.18254 .40712 3 4.5 ]
[.24603 .40712 -3 -4.5 ]
[.24603 .40712 3 4.5 ]
[.30952 .40712 -6 -4.5 ]
[.30952 .40712 6 4.5 ]
[.37302 .40712 -6 -4.5 ]
[.37302 .40712 6 4.5 ]
[.43651 .40712 -6 -4.5 ]
[.43651 .40712 6 4.5 ]
[.5 .40712 -9 -4.5 ]
[.5 .40712 9 4.5 ]
[.56349 .40712 -9 -4.5 ]
[.56349 .40712 9 4.5 ]
[.62698 .40712 -9 -4.5 ]
[.62698 .40712 9 4.5 ]
[.69048 .40712 -9 -4.5 ]
[.69048 .40712 9 4.5 ]
[.75397 .40712 -9 -4.5 ]
[.75397 .40712 9 4.5 ]
[.81746 .40712 -9 -4.5 ]
[.81746 .40712 9 4.5 ]
[.88095 .40712 -9 -4.5 ]
[.88095 .40712 9 4.5 ]
[.94444 .40712 -9 -4.5 ]
[.94444 .40712 9 4.5 ]
[.11905 .35106 -9 -4.5 ]
[.11905 .35106 9 4.5 ]
[.18254 .35106 -6 -4.5 ]
[.18254 .35106 6 4.5 ]
[.24603 .35106 -3 -4.5 ]
[.24603 .35106 3 4.5 ]
[.30952 .35106 -3 -4.5 ]
[.30952 .35106 3 4.5 ]
[.37302 .35106 -3 -4.5 ]
[.37302 .35106 3 4.5 ]
[.43651 .35106 -6 -4.5 ]
[.43651 .35106 6 4.5 ]
[.5 .35106 -6 -4.5 ]
[.5 .35106 6 4.5 ]
[.56349 .35106 -9 -4.5 ]
[.56349 .35106 9 4.5 ]
[.62698 .35106 -9 -4.5 ]
[.62698 .35106 9 4.5 ]
[.69048 .35106 -9 -4.5 ]
[.69048 .35106 9 4.5 ]
[.75397 .35106 -9 -4.5 ]
[.75397 .35106 9 4.5 ]
[.81746 .35106 -9 -4.5 ]
[.81746 .35106 9 4.5 ]
[.88095 .35106 -9 -4.5 ]
[.88095 .35106 9 4.5 ]
[.94444 .35106 -9 -4.5 ]
[.94444 .35106 9 4.5 ]
[.11905 .295 -9 -4.5 ]
[.11905 .295 9 4.5 ]
[.18254 .295 -9 -4.5 ]
[.18254 .295 9 4.5 ]
[.24603 .295 -6 -4.5 ]
[.24603 .295 6 4.5 ]
[.30952 .295 -3 -4.5 ]
[.30952 .295 3 4.5 ]
[.37302 .295 -6 -4.5 ]
[.37302 .295 6 4.5 ]
[.43651 .295 -6 -4.5 ]
[.43651 .295 6 4.5 ]
[.5 .295 -3 -4.5 ]
[.5 .295 3 4.5 ]
[.56349 .295 -3 -4.5 ]
[.56349 .295 3 4.5 ]
[.62698 .295 -6 -4.5 ]
[.62698 .295 6 4.5 ]
[.69048 .295 -6 -4.5 ]
[.69048 .295 6 4.5 ]
[.75397 .295 -9 -4.5 ]
[.75397 .295 9 4.5 ]
[.81746 .295 -9 -4.5 ]
[.81746 .295 9 4.5 ]
[.88095 .295 -9 -4.5 ]
[.88095 .295 9 4.5 ]
[.94444 .295 -9 -4.5 ]
[.94444 .295 9 4.5 ]
[.11905 .23895 -9 -4.5 ]
[.11905 .23895 9 4.5 ]
[.18254 .23895 -9 -4.5 ]
[.18254 .23895 9 4.5 ]
[.24603 .23895 -6 -4.5 ]
[.24603 .23895 6 4.5 ]
[.30952 .23895 -6 -4.5 ]
[.30952 .23895 6 4.5 ]
[.37302 .23895 -6 -4.5 ]
[.37302 .23895 6 4.5 ]
[.43651 .23895 -6 -4.5 ]
[.43651 .23895 6 4.5 ]
[.5 .23895 -6 -4.5 ]
[.5 .23895 6 4.5 ]
[.56349 .23895 -3 -4.5 ]
[.56349 .23895 3 4.5 ]
[.62698 .23895 -3 -4.5 ]
[.62698 .23895 3 4.5 ]
[.69048 .23895 -3 -4.5 ]
[.69048 .23895 3 4.5 ]
[.75397 .23895 -6 -4.5 ]
[.75397 .23895 6 4.5 ]
[.81746 .23895 -6 -4.5 ]
[.81746 .23895 6 4.5 ]
[.88095 .23895 -9 -4.5 ]
[.88095 .23895 9 4.5 ]
[.94444 .23895 -9 -4.5 ]
[.94444 .23895 9 4.5 ]
[.11905 .18289 -9 -4.5 ]
[.11905 .18289 9 4.5 ]
[.18254 .18289 -9 -4.5 ]
[.18254 .18289 9 4.5 ]
[.24603 .18289 -9 -4.5 ]
[.24603 .18289 9 4.5 ]
[.30952 .18289 -6 -4.5 ]
[.30952 .18289 6 4.5 ]
[.37302 .18289 -3 -4.5 ]
[.37302 .18289 3 4.5 ]
[.43651 .18289 -6 -4.5 ]
[.43651 .18289 6 4.5 ]
[.5 .18289 -6 -4.5 ]
[.5 .18289 6 4.5 ]
[.56349 .18289 -6 -4.5 ]
[.56349 .18289 6 4.5 ]
[.62698 .18289 -6 -4.5 ]
[.62698 .18289 6 4.5 ]
[.69048 .18289 -3 -4.5 ]
[.69048 .18289 3 4.5 ]
[.75397 .18289 -3 -4.5 ]
[.75397 .18289 3 4.5 ]
[.81746 .18289 -6 -4.5 ]
[.81746 .18289 6 4.5 ]
[.88095 .18289 -6 -4.5 ]
[.88095 .18289 6 4.5 ]
[.94444 .18289 -9 -4.5 ]
[.94444 .18289 9 4.5 ]
[.11905 .12683 -9 -4.5 ]
[.11905 .12683 9 4.5 ]
[.18254 .12683 -9 -4.5 ]
[.18254 .12683 9 4.5 ]
[.24603 .12683 -9 -4.5 ]
[.24603 .12683 9 4.5 ]
[.30952 .12683 -9 -4.5 ]
[.30952 .12683 9 4.5 ]
[.37302 .12683 -3 -4.5 ]
[.37302 .12683 3 4.5 ]
[.43651 .12683 -3 -4.5 ]
[.43651 .12683 3 4.5 ]
[.5 .12683 -6 -4.5 ]
[.5 .12683 6 4.5 ]
[.56349 .12683 -6 -4.5 ]
[.56349 .12683 6 4.5 ]
[.62698 .12683 -6 -4.5 ]
[.62698 .12683 6 4.5 ]
[.69048 .12683 -6 -4.5 ]
[.69048 .12683 6 4.5 ]
[.75397 .12683 -6 -4.5 ]
[.75397 .12683 6 4.5 ]
[.81746 .12683 -6 -4.5 ]
[.81746 .12683 6 4.5 ]
[.88095 .12683 -3 -4.5 ]
[.88095 .12683 3 4.5 ]
[.94444 .12683 -3 -4.5 ]
[.94444 .12683 3 4.5 ]
[.11905 .07077 -9 -4.5 ]
[.11905 .07077 9 4.5 ]
[.18254 .07077 -9 -4.5 ]
[.18254 .07077 9 4.5 ]
[.24603 .07077 -9 -4.5 ]
[.24603 .07077 9 4.5 ]
[.30952 .07077 -9 -4.5 ]
[.30952 .07077 9 4.5 ]
[.37302 .07077 -6 -4.5 ]
[.37302 .07077 6 4.5 ]
[.43651 .07077 -3 -4.5 ]
[.43651 .07077 3 4.5 ]
[.5 .07077 -3 -4.5 ]
[.5 .07077 3 4.5 ]
[.56349 .07077 -6 -4.5 ]
[.56349 .07077 6 4.5 ]
[.62698 .07077 -6 -4.5 ]
[.62698 .07077 6 4.5 ]
[.69048 .07077 -6 -4.5 ]
[.69048 .07077 6 4.5 ]
[.75397 .07077 -6 -4.5 ]
[.75397 .07077 6 4.5 ]
[.81746 .07077 -6 -4.5 ]
[.81746 .07077 6 4.5 ]
[.88095 .07077 -6 -4.5 ]
[.88095 .07077 6 4.5 ]
[.94444 .07077 -6 -4.5 ]
[.94444 .07077 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto fill
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto
-0.2 0.1 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.9 g
.0873 .54726 m
.0873 .60332 L
.97619 .60332 L
.97619 .54726 L
F
0 g
gsave
.11905 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18254 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24603 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30952 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37302 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43651 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56349 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62698 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75397 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81746 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88095 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.94444 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.9 g
.02381 .01472 m
.02381 .60332 L
.0873 .60332 L
.0873 .01472 L
F
0 g
gsave
.05556 .51923 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .46318 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .40712 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .35106 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .295 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .23895 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .18289 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .12683 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .07077 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
[(0)] .11905 .51923 0 0 Mshowa
[(-45)] .18254 .51923 0 0 Mshowa
[(-45)] .24603 .51923 0 0 Mshowa
[(-45)] .30952 .51923 0 0 Mshowa
[(-45)] .37302 .51923 0 0 Mshowa
[(-45)] .43651 .51923 0 0 Mshowa
[(-45)] .5 .51923 0 0 Mshowa
[(-45)] .56349 .51923 0 0 Mshowa
[(-45)] .62698 .51923 0 0 Mshowa
[(-45)] .69048 .51923 0 0 Mshowa
[(-45)] .75397 .51923 0 0 Mshowa
[(-45)] .81746 .51923 0 0 Mshowa
[(-45)] .88095 .51923 0 0 Mshowa
[(-45)] .94444 .51923 0 0 Mshowa
[(-5)] .11905 .46318 0 0 Mshowa
[(5)] .18254 .46318 0 0 Mshowa
[(0)] .24603 .46318 0 0 Mshowa
[(-5)] .30952 .46318 0 0 Mshowa
[(-10)] .37302 .46318 0 0 Mshowa
[(-15)] .43651 .46318 0 0 Mshowa
[(-20)] .5 .46318 0 0 Mshowa
[(-25)] .56349 .46318 0 0 Mshowa
[(-30)] .62698 .46318 0 0 Mshowa
[(-35)] .69048 .46318 0 0 Mshowa
[(-40)] .75397 .46318 0 0 Mshowa
[(-45)] .81746 .46318 0 0 Mshowa
[(-46)] .88095 .46318 0 0 Mshowa
[(-46)] .94444 .46318 0 0 Mshowa
[(-10)] .11905 .40712 0 0 Mshowa
[(0)] .18254 .40712 0 0 Mshowa
[(3)] .24603 .40712 0 0 Mshowa
[(-2)] .30952 .40712 0 0 Mshowa
[(-5)] .37302 .40712 0 0 Mshowa
[(-9)] .43651 .40712 0 0 Mshowa
[(-14)] .5 .40712 0 0 Mshowa
[(-19)] .56349 .40712 0 0 Mshowa
[(-24)] .62698 .40712 0 0 Mshowa
[(-28)] .69048 .40712 0 0 Mshowa
[(-33)] .75397 .40712 0 0 Mshowa
[(-38)] .81746 .40712 0 0 Mshowa
[(-43)] .88095 .40712 0 0 Mshowa
[(-47)] .94444 .40712 0 0 Mshowa
[(-15)] .11905 .35106 0 0 Mshowa
[(-5)] .18254 .35106 0 0 Mshowa
[(3)] .24603 .35106 0 0 Mshowa
[(9)] .30952 .35106 0 0 Mshowa
[(4)] .37302 .35106 0 0 Mshowa
[(-1)] .43651 .35106 0 0 Mshowa
[(-6)] .5 .35106 0 0 Mshowa
[(-11)] .56349 .35106 0 0 Mshowa
[(-16)] .62698 .35106 0 0 Mshowa
[(-21)] .69048 .35106 0 0 Mshowa
[(-26)] .75397 .35106 0 0 Mshowa
[(-31)] .81746 .35106 0 0 Mshowa
[(-36)] .88095 .35106 0 0 Mshowa
[(-41)] .94444 .35106 0 0 Mshowa
[(-20)] .11905 .295 0 0 Mshowa
[(-10)] .18254 .295 0 0 Mshowa
[(-2)] .24603 .295 0 0 Mshowa
[(4)] .30952 .295 0 0 Mshowa
[(17)] .37302 .295 0 0 Mshowa
[(12)] .43651 .295 0 0 Mshowa
[(7)] .5 .295 0 0 Mshowa
[(2)] .56349 .295 0 0 Mshowa
[(-3)] .62698 .295 0 0 Mshowa
[(-8)] .69048 .295 0 0 Mshowa
[(-13)] .75397 .295 0 0 Mshowa
[(-18)] .81746 .295 0 0 Mshowa
[(-23)] .88095 .295 0 0 Mshowa
[(-28)] .94444 .295 0 0 Mshowa
[(-25)] .11905 .23895 0 0 Mshowa
[(-15)] .18254 .23895 0 0 Mshowa
[(-7)] .24603 .23895 0 0 Mshowa
[(-1)] .30952 .23895 0 0 Mshowa
[(12)] .37302 .23895 0 0 Mshowa
[(17)] .43651 .23895 0 0 Mshowa
[(12)] .5 .23895 0 0 Mshowa
[(7)] .56349 .23895 0 0 Mshowa
[(8)] .62698 .23895 0 0 Mshowa
[(3)] .69048 .23895 0 0 Mshowa
[(-2)] .75397 .23895 0 0 Mshowa
[(-7)] .81746 .23895 0 0 Mshowa
[(-12)] .88095 .23895 0 0 Mshowa
[(-17)] .94444 .23895 0 0 Mshowa
[(-30)] .11905 .18289 0 0 Mshowa
[(-20)] .18254 .18289 0 0 Mshowa
[(-12)] .24603 .18289 0 0 Mshowa
[(-6)] .30952 .18289 0 0 Mshowa
[(7)] .37302 .18289 0 0 Mshowa
[(12)] .43651 .18289 0 0 Mshowa
[(17)] .5 .18289 0 0 Mshowa
[(18)] .56349 .18289 0 0 Mshowa
[(13)] .62698 .18289 0 0 Mshowa
[(8)] .69048 .18289 0 0 Mshowa
[(3)] .75397 .18289 0 0 Mshowa
[(-2)] .81746 .18289 0 0 Mshowa
[(-7)] .88095 .18289 0 0 Mshowa
[(-12)] .94444 .18289 0 0 Mshowa
[(-35)] .11905 .12683 0 0 Mshowa
[(-25)] .18254 .12683 0 0 Mshowa
[(-17)] .24603 .12683 0 0 Mshowa
[(-11)] .30952 .12683 0 0 Mshowa
[(2)] .37302 .12683 0 0 Mshowa
[(7)] .43651 .12683 0 0 Mshowa
[(12)] .5 .12683 0 0 Mshowa
[(15)] .56349 .12683 0 0 Mshowa
[(19)] .62698 .12683 0 0 Mshowa
[(14)] .69048 .12683 0 0 Mshowa
[(16)] .75397 .12683 0 0 Mshowa
[(11)] .81746 .12683 0 0 Mshowa
[(6)] .88095 .12683 0 0 Mshowa
[(1)] .94444 .12683 0 0 Mshowa
[(-40)] .11905 .07077 0 0 Mshowa
[(-30)] .18254 .07077 0 0 Mshowa
[(-22)] .24603 .07077 0 0 Mshowa
[(-16)] .30952 .07077 0 0 Mshowa
[(-3)] .37302 .07077 0 0 Mshowa
[(2)] .43651 .07077 0 0 Mshowa
[(7)] .5 .07077 0 0 Mshowa
[(10)] .56349 .07077 0 0 Mshowa
[(15)] .62698 .07077 0 0 Mshowa
[(18)] .69048 .07077 0 0 Mshowa
[(13)] .75397 .07077 0 0 Mshowa
[(17)] .81746 .07077 0 0 Mshowa
[(12)] .88095 .07077 0 0 Mshowa
[(11)] .94444 .07077 0 0 Mshowa
1 g
.008 w
.05556 .01472 Mdot
0 g
.5 Mabswid
[ ] 0 setdash
.16349 .51923 m
.1381 .51923 L
s
% Start of user PostScript
1.7 9. 1.3 9. MAarrowhead1
% End of user PostScript
.22698 .51923 m
.20159 .51923 L
s
% Start of user PostScript
2.7 9. 2.3 9. MAarrowhead1
% End of user PostScript
.29048 .51923 m
.26508 .51923 L
s
% Start of user PostScript
3.7 9. 3.3 9. MAarrowhead1
% End of user PostScript
.35397 .51923 m
.32857 .51923 L
s
% Start of user PostScript
4.7 9. 4.3 9. MAarrowhead1
% End of user PostScript
.41746 .51923 m
.39206 .51923 L
s
% Start of user PostScript
5.7 9. 5.3 9. MAarrowhead1
% End of user PostScript
.48095 .51923 m
.45556 .51923 L
s
% Start of user PostScript
6.7 9. 6.3 9. MAarrowhead1
% End of user PostScript
.54444 .51923 m
.51905 .51923 L
s
% Start of user PostScript
7.7 9. 7.3 9. MAarrowhead1
% End of user PostScript
.60794 .51923 m
.58254 .51923 L
s
% Start of user PostScript
8.7 9. 8.3 9. MAarrowhead1
% End of user PostScript
.67143 .51923 m
.64603 .51923 L
s
% Start of user PostScript
9.7 9. 9.3 9. MAarrowhead1
% End of user PostScript
.73492 .51923 m
.70952 .51923 L
s
% Start of user PostScript
10.7 9. 10.3 9. MAarrowhead1
% End of user PostScript
.79841 .51923 m
.77302 .51923 L
s
% Start of user PostScript
11.7 9. 11.3 9. MAarrowhead1
% End of user PostScript
.8619 .51923 m
.83651 .51923 L
s
% Start of user PostScript
12.7 9. 12.3 9. MAarrowhead1
% End of user PostScript
.9254 .51923 m
.9 .51923 L
s
% Start of user PostScript
13.7 9. 13.3 9. MAarrowhead1
% End of user PostScript
.11905 .47999 m
.11905 .50242 L
s
% Start of user PostScript
1. 8.3 1. 8.7 MAarrowhead1
% End of user PostScript
.16349 .47999 m
.1381 .50242 L
s
% Start of user PostScript
1.7 8.3 1.3 8.7 MAarrowhead1
% End of user PostScript
.22698 .46318 m
.20159 .46318 L
s
% Start of user PostScript
2.7 8. 2.3 8. MAarrowhead1
% End of user PostScript
.29048 .46318 m
.26508 .46318 L
s
% Start of user PostScript
3.7 8. 3.3 8. MAarrowhead1
% End of user PostScript
.35397 .46318 m
.32857 .46318 L
s
% Start of user PostScript
4.7 8. 4.3 8. MAarrowhead1
% End of user PostScript
.41746 .46318 m
.39206 .46318 L
s
% Start of user PostScript
5.7 8. 5.3 8. MAarrowhead1
% End of user PostScript
.48095 .46318 m
.45556 .46318 L
s
% Start of user PostScript
6.7 8. 6.3 8. MAarrowhead1
% End of user PostScript
.54444 .46318 m
.51905 .46318 L
s
% Start of user PostScript
7.7 8. 7.3 8. MAarrowhead1
% End of user PostScript
.60794 .46318 m
.58254 .46318 L
s
% Start of user PostScript
8.7 8. 8.3 8. MAarrowhead1
% End of user PostScript
.67143 .46318 m
.64603 .46318 L
s
% Start of user PostScript
9.7 8. 9.3 8. MAarrowhead1
% End of user PostScript
.73492 .46318 m
.70952 .46318 L
s
% Start of user PostScript
10.7 8. 10.3 8. MAarrowhead1
% End of user PostScript
.79841 .47999 m
.77302 .50242 L
s
% Start of user PostScript
11.7 8.3 11.3 8.7 MAarrowhead1
% End of user PostScript
.8619 .47999 m
.83651 .50242 L
s
% Start of user PostScript
12.7 8.3 12.3 8.7 MAarrowhead1
% End of user PostScript
.9254 .47999 m
.9 .50242 L
s
% Start of user PostScript
13.7 8.3 13.3 8.7 MAarrowhead1
% End of user PostScript
.11905 .42393 m
.11905 .44636 L
s
% Start of user PostScript
1. 7.3 1. 7.7 MAarrowhead1
% End of user PostScript
.18254 .42393 m
.18254 .44636 L
s
% Start of user PostScript
2. 7.3 2. 7.7 MAarrowhead1
% End of user PostScript
.22698 .42393 m
.20159 .44636 L
s
% Start of user PostScript
2.7 7.3 2.3 7.7 MAarrowhead1
% End of user PostScript
.29048 .40712 m
.26508 .40712 L
s
% Start of user PostScript
3.7 7. 3.3 7. MAarrowhead1
% End of user PostScript
.35397 .42393 m
.32857 .44636 L
s
% Start of user PostScript
4.7 7.3 4.3 7.7 MAarrowhead1
% End of user PostScript
.41746 .42393 m
.39206 .44636 L
s
% Start of user PostScript
5.7 7.3 5.3 7.7 MAarrowhead1
% End of user PostScript
.48095 .40712 m
.45556 .40712 L
s
% Start of user PostScript
6.7 7. 6.3 7. MAarrowhead1
% End of user PostScript
.54444 .40712 m
.51905 .40712 L
s
% Start of user PostScript
7.7 7. 7.3 7. MAarrowhead1
% End of user PostScript
.60794 .40712 m
.58254 .40712 L
s
% Start of user PostScript
8.7 7. 8.3 7. MAarrowhead1
% End of user PostScript
.67143 .42393 m
.64603 .44636 L
s
% Start of user PostScript
9.7 7.3 9.3 7.7 MAarrowhead1
% End of user PostScript
.73492 .40712 m
.70952 .40712 L
s
% Start of user PostScript
10.7 7. 10.3 7. MAarrowhead1
% End of user PostScript
.79841 .40712 m
.77302 .40712 L
s
% Start of user PostScript
11.7 7. 11.3 7. MAarrowhead1
% End of user PostScript
.8619 .40712 m
.83651 .40712 L
s
% Start of user PostScript
12.7 7. 12.3 7. MAarrowhead1
% End of user PostScript
.9254 .42393 m
.9 .44636 L
s
% Start of user PostScript
13.7 7.3 13.3 7.7 MAarrowhead1
% End of user PostScript
.11905 .36788 m
.11905 .3903 L
s
% Start of user PostScript
1. 6.3 1. 6.7 MAarrowhead1
% End of user PostScript
.18254 .36788 m
.18254 .3903 L
s
% Start of user PostScript
2. 6.3 2. 6.7 MAarrowhead1
% End of user PostScript
.22698 .36788 m
.20159 .3903 L
s
% Start of user PostScript
2.7 6.3 2.3 6.7 MAarrowhead1
% End of user PostScript
.29048 .36788 m
.26508 .3903 L
s
% Start of user PostScript
3.7 6.3 3.3 6.7 MAarrowhead1
% End of user PostScript
.35397 .35106 m
.32857 .35106 L
s
% Start of user PostScript
4.7 6. 4.3 6. MAarrowhead1
% End of user PostScript
.41746 .35106 m
.39206 .35106 L
s
% Start of user PostScript
5.7 6. 5.3 6. MAarrowhead1
% End of user PostScript
.48095 .35106 m
.45556 .35106 L
s
% Start of user PostScript
6.7 6. 6.3 6. MAarrowhead1
% End of user PostScript
.54444 .35106 m
.51905 .35106 L
s
% Start of user PostScript
7.7 6. 7.3 6. MAarrowhead1
% End of user PostScript
.60794 .35106 m
.58254 .35106 L
s
% Start of user PostScript
8.7 6. 8.3 6. MAarrowhead1
% End of user PostScript
.67143 .35106 m
.64603 .35106 L
s
% Start of user PostScript
9.7 6. 9.3 6. MAarrowhead1
% End of user PostScript
.73492 .35106 m
.70952 .35106 L
s
% Start of user PostScript
10.7 6. 10.3 6. MAarrowhead1
% End of user PostScript
.79841 .35106 m
.77302 .35106 L
s
% Start of user PostScript
11.7 6. 11.3 6. MAarrowhead1
% End of user PostScript
.8619 .35106 m
.83651 .35106 L
s
% Start of user PostScript
12.7 6. 12.3 6. MAarrowhead1
% End of user PostScript
.9254 .35106 m
.9 .35106 L
s
% Start of user PostScript
13.7 6. 13.3 6. MAarrowhead1
% End of user PostScript
.11905 .31182 m
.11905 .33424 L
s
% Start of user PostScript
1. 5.3 1. 5.7 MAarrowhead1
% End of user PostScript
.18254 .31182 m
.18254 .33424 L
s
% Start of user PostScript
2. 5.3 2. 5.7 MAarrowhead1
% End of user PostScript
.24603 .31182 m
.24603 .33424 L
s
% Start of user PostScript
3. 5.3 3. 5.7 MAarrowhead1
% End of user PostScript
.30952 .31182 m
.30952 .33424 L
s
% Start of user PostScript
4. 5.3 4. 5.7 MAarrowhead1
% End of user PostScript
.35397 .31182 m
.32857 .33424 L
s
% Start of user PostScript
4.7 5.3 4.3 5.7 MAarrowhead1
% End of user PostScript
.41746 .295 m
.39206 .295 L
s
% Start of user PostScript
5.7 5. 5.3 5. MAarrowhead1
% End of user PostScript
.48095 .295 m
.45556 .295 L
s
% Start of user PostScript
6.7 5. 6.3 5. MAarrowhead1
% End of user PostScript
.54444 .295 m
.51905 .295 L
s
% Start of user PostScript
7.7 5. 7.3 5. MAarrowhead1
% End of user PostScript
.60794 .295 m
.58254 .295 L
s
% Start of user PostScript
8.7 5. 8.3 5. MAarrowhead1
% End of user PostScript
.67143 .295 m
.64603 .295 L
s
% Start of user PostScript
9.7 5. 9.3 5. MAarrowhead1
% End of user PostScript
.73492 .31182 m
.70952 .33424 L
s
% Start of user PostScript
10.7 5.3 10.3 5.7 MAarrowhead1
% End of user PostScript
.79841 .295 m
.77302 .295 L
s
% Start of user PostScript
11.7 5. 11.3 5. MAarrowhead1
% End of user PostScript
.8619 .295 m
.83651 .295 L
s
% Start of user PostScript
12.7 5. 12.3 5. MAarrowhead1
% End of user PostScript
.9254 .295 m
.9 .295 L
s
% Start of user PostScript
13.7 5. 13.3 5. MAarrowhead1
% End of user PostScript
.11905 .25576 m
.11905 .27819 L
s
% Start of user PostScript
1. 4.3 1. 4.7 MAarrowhead1
% End of user PostScript
.18254 .25576 m
.18254 .27819 L
s
% Start of user PostScript
2. 4.3 2. 4.7 MAarrowhead1
% End of user PostScript
.24603 .25576 m
.24603 .27819 L
s
% Start of user PostScript
3. 4.3 3. 4.7 MAarrowhead1
% End of user PostScript
.30952 .25576 m
.30952 .27819 L
s
% Start of user PostScript
4. 4.3 4. 4.7 MAarrowhead1
% End of user PostScript
.37302 .25576 m
.37302 .27819 L
s
% Start of user PostScript
5. 4.3 5. 4.7 MAarrowhead1
% End of user PostScript
.41746 .25576 m
.39206 .27819 L
s
% Start of user PostScript
5.7 4.3 5.3 4.7 MAarrowhead1
% End of user PostScript
.48095 .23895 m
.45556 .23895 L
s
% Start of user PostScript
6.7 4. 6.3 4. MAarrowhead1
% End of user PostScript
.54444 .25576 m
.51905 .27819 L
s
% Start of user PostScript
7.7 4.3 7.3 4.7 MAarrowhead1
% End of user PostScript
.60794 .25576 m
.58254 .27819 L
s
% Start of user PostScript
8.7 4.3 8.3 4.7 MAarrowhead1
% End of user PostScript
.67143 .23895 m
.64603 .23895 L
s
% Start of user PostScript
9.7 4. 9.3 4. MAarrowhead1
% End of user PostScript
.73492 .23895 m
.70952 .23895 L
s
% Start of user PostScript
10.7 4. 10.3 4. MAarrowhead1
% End of user PostScript
.79841 .23895 m
.77302 .23895 L
s
% Start of user PostScript
11.7 4. 11.3 4. MAarrowhead1
% End of user PostScript
.8619 .23895 m
.83651 .23895 L
s
% Start of user PostScript
12.7 4. 12.3 4. MAarrowhead1
% End of user PostScript
.9254 .23895 m
.9 .23895 L
s
% Start of user PostScript
13.7 4. 13.3 4. MAarrowhead1
% End of user PostScript
.11905 .1997 m
.11905 .22213 L
s
% Start of user PostScript
1. 3.3 1. 3.7 MAarrowhead1
% End of user PostScript
.18254 .1997 m
.18254 .22213 L
s
% Start of user PostScript
2. 3.3 2. 3.7 MAarrowhead1
% End of user PostScript
.24603 .1997 m
.24603 .22213 L
s
% Start of user PostScript
3. 3.3 3. 3.7 MAarrowhead1
% End of user PostScript
.30952 .1997 m
.30952 .22213 L
s
% Start of user PostScript
4. 3.3 4. 3.7 MAarrowhead1
% End of user PostScript
.37302 .1997 m
.37302 .22213 L
s
% Start of user PostScript
5. 3.3 5. 3.7 MAarrowhead1
% End of user PostScript
.43651 .1997 m
.43651 .22213 L
s
% Start of user PostScript
6. 3.3 6. 3.7 MAarrowhead1
% End of user PostScript
.48095 .1997 m
.45556 .22213 L
s
% Start of user PostScript
6.7 3.3 6.3 3.7 MAarrowhead1
% End of user PostScript
.54444 .1997 m
.51905 .22213 L
s
% Start of user PostScript
7.7 3.3 7.3 3.7 MAarrowhead1
% End of user PostScript
.60794 .18289 m
.58254 .18289 L
s
% Start of user PostScript
8.7 3. 8.3 3. MAarrowhead1
% End of user PostScript
.67143 .18289 m
.64603 .18289 L
s
% Start of user PostScript
9.7 3. 9.3 3. MAarrowhead1
% End of user PostScript
.73492 .18289 m
.70952 .18289 L
s
% Start of user PostScript
10.7 3. 10.3 3. MAarrowhead1
% End of user PostScript
.79841 .1997 m
.77302 .22213 L
s
% Start of user PostScript
11.7 3.3 11.3 3.7 MAarrowhead1
% End of user PostScript
.8619 .18289 m
.83651 .18289 L
s
% Start of user PostScript
12.7 3. 12.3 3. MAarrowhead1
% End of user PostScript
.9254 .18289 m
.9 .18289 L
s
% Start of user PostScript
13.7 3. 13.3 3. MAarrowhead1
% End of user PostScript
.11905 .14365 m
.11905 .16607 L
s
% Start of user PostScript
1. 2.3 1. 2.7 MAarrowhead1
% End of user PostScript
.18254 .14365 m
.18254 .16607 L
s
% Start of user PostScript
2. 2.3 2. 2.7 MAarrowhead1
% End of user PostScript
.24603 .14365 m
.24603 .16607 L
s
% Start of user PostScript
3. 2.3 3. 2.7 MAarrowhead1
% End of user PostScript
.30952 .14365 m
.30952 .16607 L
s
% Start of user PostScript
4. 2.3 4. 2.7 MAarrowhead1
% End of user PostScript
.35397 .14365 m
.32857 .16607 L
s
% Start of user PostScript
4.7 2.3 4.3 2.7 MAarrowhead1
% End of user PostScript
.43651 .14365 m
.43651 .16607 L
s
% Start of user PostScript
6. 2.3 6. 2.7 MAarrowhead1
% End of user PostScript
.5 .14365 m
.5 .16607 L
s
% Start of user PostScript
7. 2.3 7. 2.7 MAarrowhead1
% End of user PostScript
.54444 .14365 m
.51905 .16607 L
s
% Start of user PostScript
7.7 2.3 7.3 2.7 MAarrowhead1
% End of user PostScript
.60794 .14365 m
.58254 .16607 L
s
% Start of user PostScript
8.7 2.3 8.3 2.7 MAarrowhead1
% End of user PostScript
.67143 .12683 m
.64603 .12683 L
s
% Start of user PostScript
9.7 2. 9.3 2. MAarrowhead1
% End of user PostScript
.73492 .14365 m
.70952 .16607 L
s
% Start of user PostScript
10.7 2.3 10.3 2.7 MAarrowhead1
% End of user PostScript
.79841 .12683 m
.77302 .12683 L
s
% Start of user PostScript
11.7 2. 11.3 2. MAarrowhead1
% End of user PostScript
.8619 .12683 m
.83651 .12683 L
s
% Start of user PostScript
12.7 2. 12.3 2. MAarrowhead1
% End of user PostScript
.9254 .12683 m
.9 .12683 L
s
% Start of user PostScript
13.7 2. 13.3 2. MAarrowhead1
% End of user PostScript
.11905 .08759 m
.11905 .11001 L
s
% Start of user PostScript
1. 1.3 1. 1.7 MAarrowhead1
% End of user PostScript
.18254 .08759 m
.18254 .11001 L
s
% Start of user PostScript
2. 1.3 2. 1.7 MAarrowhead1
% End of user PostScript
.24603 .08759 m
.24603 .11001 L
s
% Start of user PostScript
3. 1.3 3. 1.7 MAarrowhead1
% End of user PostScript
.30952 .08759 m
.30952 .11001 L
s
% Start of user PostScript
4. 1.3 4. 1.7 MAarrowhead1
% End of user PostScript
.37302 .08759 m
.37302 .11001 L
s
% Start of user PostScript
5. 1.3 5. 1.7 MAarrowhead1
% End of user PostScript
.43651 .08759 m
.43651 .11001 L
s
% Start of user PostScript
6. 1.3 6. 1.7 MAarrowhead1
% End of user PostScript
.48095 .08759 m
.45556 .11001 L
s
% Start of user PostScript
6.7 1.3 6.3 1.7 MAarrowhead1
% End of user PostScript
.54444 .08759 m
.51905 .11001 L
s
% Start of user PostScript
7.7 1.3 7.3 1.7 MAarrowhead1
% End of user PostScript
.60794 .08759 m
.58254 .11001 L
s
% Start of user PostScript
8.7 1.3 8.3 1.7 MAarrowhead1
% End of user PostScript
.67143 .08759 m
.64603 .11001 L
s
% Start of user PostScript
9.7 1.3 9.3 1.7 MAarrowhead1
% End of user PostScript
.73492 .07077 m
.70952 .07077 L
s
% Start of user PostScript
10.7 1. 10.3 1. MAarrowhead1
% End of user PostScript
.79841 .08759 m
.77302 .11001 L
s
% Start of user PostScript
11.7 1.3 11.3 1.7 MAarrowhead1
% End of user PostScript
.8619 .07077 m
.83651 .07077 L
s
% Start of user PostScript
12.7 1. 12.3 1. MAarrowhead1
% End of user PostScript
.9254 .08759 m
.9 .11001 L
s
% Start of user PostScript
13.7 1.3 13.3 1.7 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`00
1`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
o`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1`3Vi^H3000000P0i^KV
2@3oool300000080oooo0P00000:0?ooo`800000103oool2000000T0oooo100000020?ooo`@00000
203oool5000000040?ooo`0000000000000000h0oooo0P00000<0?ooo`@00000403oool00`000000
oooo0?ooo`0:0?ooo`D000000P3oool2000000T0oooo1@0000020?ooo`8000002P3oool500000080
oooo0P0000090?ooo`D000000P3oool2000000T0oooo1@0000030?ooo`030000003oool0oooo00L0
oooo1@0000000`3oool0000000000002000000P0oooo1@0000000`3oool0000000000003000000`0
oooo00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H:0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00070?ooo`P0i^KV
00<000000>KViP3Vi^H01`3Vi^H70?ooo`D0000000D0oooo0000003oool0oooo0000000:0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`T000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo00000008000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo
00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H00`3oool000000000000200000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`@000001@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00@00000103oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo0?ooo`@00000103oool010000000oooo0?ooo`3oool3000000L0oooo1000
00050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0;0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo0P00000<0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00
1`3oool60>KViP050000003Vi^H000000>KViP0000001`3Vi^H80?ooo`030000003oool000000080
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000;0?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0<0?ooo`001`3oool60>KViPD000001`3Vi^H90?ooo`8000000`3oool2000000X0oooo0P000004
0?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`800000103oool3000000d0oooo0P00000=
0?ooo`8000003`3oool4000000`0oooo0P0000040?ooo`8000002P3oool2000000@0oooo0`00000:
0?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000002P3oool2000000<0oooo10000009
0?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000003P3oool000L0oooo4P3Vi^Ko0?oo
o`P0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0503oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`001`3ooolB0>KViPT0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0P00
000@0?ooo`8000004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`001`3ooolB0>KViPT0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`800000403oool200000280oooo0P00000S
0?ooo`8000006@3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000l0oooo00<000000?oo
o`0000003`3oool00`000000oooo0000000@0?ooo`8000008P3oool200000280oooo00<000000?oo
o`0000006`3oool000L0oooo4P3Vi^H80?ooo`<000003`3oool300000100oooo0P00000@0?ooo`80
0000403oool200000100oooo0P0000040?ooo`<000003`3oool300000100oooo0P00000@0?ooo`80
00008P3oool2000002<0oooo0P00000L0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0`00000?0?ooo`@00000
3`3oool3000000l0oooo0`00000Q0?ooo`<000008P3oool3000001/0oooo00070?oooa80i^KVo`3o
ool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1P3Vi^H3000000030>KViP0000000000
00H0i^KV203oool2000000@0oooo0P0000090?ooo`@000000`3oool2000000T0oooo1@0000030?oo
o`030000003oool0oooo00L0oooo1@0000000`3oool0000000000003000000P0oooo1000000@0?oo
o`030000003oool0oooo00X0oooo1@0000000`3oool0000000000002000000P0oooo1@0000020?oo
o`8000002@3oool5000000040?ooo`0000000000000000X0oooo1@0000030?ooo`<000001`3oool5
000000040?ooo`0000000000000000T0oooo1@0000000`3oool0000000000003000000X0oooo0`00
000?0?ooo`D000003`3oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000d0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`001`3oool7
0>KViP040000003Vi^H0i^KV000000L0i^KV2@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000000000H000000P3o
ool010000000oooo0?ooo`3oool5000000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`T0
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000P000000P3oool010000000
oooo0?ooo`0000040?ooo`P00000103oool00`000000oooo0?ooo`0?0?ooo`001`3oool70>KViP@0
00001`3Vi^H00`3oool0000000000002000000D0oooo00@000000?ooo`3oool0oooo0P0000030?oo
o`@00000103oool00`000000oooo0?ooo`020?ooo`8000000`3oool4000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool20000
00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
oooo0`0000020?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
0000203oool3000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00
1`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV1`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000>0?ooo`040000
003oool0oooo000000d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool03`3oool000L0oooo1P3Vi^H2000000040>KViP0000000000000000H0i^KV203oool2
000000@0oooo0`0000090?ooo`800000103oool3000000T0oooo0P0000030?ooo`@000002@3oool2
000000@0oooo0P00000;0?ooo`8000003`3oool4000000`0oooo0P0000040?ooo`8000002P3oool2
000000@0oooo0`0000090?ooo`800000103oool3000000X0oooo0P0000050?ooo`8000002@3oool2
000000@0oooo0`0000090?ooo`800000103oool2000000d0oooo0`00000?0?ooo`8000004@3oool0
00L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1;0?ooo`00
1`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0C03oool000L0oooo4P3Vi^H90?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00L0oooo0P00000A0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0C@3o
ool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0P00000J0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`8000008P3oool2
00000500oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`800000703oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000003`3oool00`00
0000oooo0000000R0?ooo`800000DP3oool000L0oooo4P3Vi^H80?ooo`<000003`3oool300000100
oooo0P00000@0?ooo`800000103oool2000001`0oooo0P00000@0?ooo`<000000`3oool300000100
oooo0P00000R0?ooo`800000D`3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo
0`00000L0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool4000000l0oooo
0`00000Q0?ooo`<00000DP3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3oool80>KViP800000203Vi^H80?ooo`800000103oool2000000T0oooo100000030?oo
o`8000002@3oool5000000030?ooo`0000000000008000002`3oool3000000l0oooo00<000000?oo
o`3oool02P3oool5000000030?ooo`000000000000800000203oool5000000<0oooo00<000000?oo
o`3oool01`3oool500000080oooo0P0000090?ooo`D000000P3oool2000000h0oooo0P00000@0?oo
o`8000004P3oool400000100oooo00<000000?ooo`3oool02P3oool5000000030?ooo`0000000000
008000002P3oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000h0oooo00@000000?ooo`3o
ool000003P3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000003@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000d0
oooo00070?ooo`L0i^KV00<000000>KViP0000000P0000060>KViPT0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000001`0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo00P000000`3oool010000000oooo0?ooo`0000030?ooo`P00000
1@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T000001`3oool00`000000oooo
0?ooo`08000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`001`3o
ool70>KViP030000003Vi^H0i^KV00P0i^KV00<0oooo0000000000000P0000050?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`@000000P3oool300000100oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000:0?ooo`8000001@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo100000040?ooo`030000003oool0oooo
008000001@3oool4000000D0oooo00@000000?ooo`3oool000000P3oool4000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`001`3oool70>KViP030000003Vi^H0i^KV
00P0i^KV1`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00@000000?oo
o`3oool000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo00000140oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000=0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`001`3oool80>KViP<0
00001`3Vi^H80?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000002P3oool2000000@0
oooo0P00000=0?ooo`<00000303oool4000000`0oooo0P0000040?ooo`8000002P3oool2000000<0
oooo100000090?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000003P3oool200000100
oooo0P00000C0?ooo`8000003`3oool4000000`0oooo0P0000040?ooo`8000002`3oool000L0oooo
4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0>@3oool000L0oooo4P3Vi^H90?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0j0?ooo`001`3ooolB0>KV
iPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00L0oooo0P00000@0?ooo`800000A`3oool00`000000oooo0?ooo`0k0?ooo`001`3ooolB0>KViPT0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`150?ooo`800000?P3oool000L0oooo
4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000l0oooo00<000000?ooo`000000AP3oool200000400oooo
00070?oooa80i^KV203oool3000000l0oooo0`00000@0?ooo`800000403oool200000100oooo0P00
000@0?ooo`800000103oool3000000l0oooo0`0000160?ooo`800000@@3oool000L0oooo4P3Vi^H9
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`<000003`3oool4000004D0oooo0`0000100?ooo`001`3ooolB0>KVi_l0oooo203oool000L0
oooo4P3Vi^Ko0?ooo`P0oooo00070?ooo`H0i^KV0`0000000`3Vi^H000000>KViP060>KViPL0oooo
100000030?ooo`8000002@3oool500000080oooo0P00000>0?ooo`030000003oool0oooo00d0oooo
1@0000080?ooo`D0000000<0oooo0000000000000P0000080?ooo`D000000`3oool00`000000oooo
0?ooo`070?ooo`D0000000<0oooo0000000000000P00000=0?ooo`030000003oool0oooo00h0oooo
0P00000A0?ooo`8000004P3oool400000100oooo00<000000?ooo`3oool02P3oool5000000030?oo
o`000000000000800000203oool5000000<0oooo00<000000?ooo`3oool02@3oool000L0oooo1`3V
i^H010000000i^KV0000000000070>KViPL0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0
000000d0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000L0oooo1`3Vi^H0
10000000i^KV0000000000070>KViPP0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000200000000`3oool000000?oo
o`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`0000040?ooo`P000001@3oool00`000000oooo0?ooo`020?ooo`P000001`3oool00`000000oooo
0?ooo`08000000P0oooo00<000000?ooo`000000200000040?ooo`030000003oool0oooo0080oooo
2@0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000L0oooo1`3V
i^H2000000030>KViP000000i^KV00H0i^KV00<0oooo0000000000000P0000040?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`8000001P3o
ool4000000D0oooo00<000000?ooo`3oool01P3oool4000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool010000000oooo0000000000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool4000000@0oooo00<000000?ooo`3oool0
0P0000050?ooo`@000001@3oool010000000oooo0000000000020?ooo`@00000103oool00`000000
oooo0?ooo`030?ooo`8000000P3oool4000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`001`3oool70>KViP80000000<0i^KV0000003Vi^H01P3Vi^H70?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0:0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003`3oool010000000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool000L0
oooo1P3Vi^H2000000040>KViP0000000000000000H0i^KV203oool2000000@0oooo0`0000090?oo
o`800000103oool3000000/0oooo1000000?0?ooo`8000002`3oool2000000@0oooo0P00000:0?oo
o`8000000`3oool4000000T0oooo0P0000040?ooo`800000303oool4000000l0oooo0P00000A0?oo
o`8000004`3oool2000000l0oooo1000000<0?ooo`800000103oool2000000X0oooo0P0000030?oo
o`@000002P3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV2@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo06l0oooo00070?oooa80i^KV2@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0700oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool200000140oooo00<00000
0?ooo`3oool0L@3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01@3oool2000002<0oooo00<000000?ooo`3oool03`3oool2000007@0oooo00070?oooa80
i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo0P00000R0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`000000MP3oool000L0oooo4P3Vi^H80?ooo`<00000
3`3oool300000100oooo0P00000@0?ooo`800000403oool2000000@0oooo0P00000R0?ooo`<00000
403oool2000007L0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo0`00000Q0?ooo`@000003`3oool3000007H0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1P3Vi^H3000000030>KViP000000000000H0
i^KV1`3oool4000000<0oooo0P0000090?ooo`D000000P3oool2000000`0oooo1000000=0?ooo`<0
00002`3oool5000000<0oooo00<000000?ooo`3oool01`3oool5000000030?ooo`00000000000080
00003@3oool00`000000oooo0?ooo`0=0?ooo`@000004P3oool200000140oooo0P00000<0?ooo`D0
00000P3oool2000000T0oooo1@0000020?ooo`8000002@3oool4000000<0oooo0P0000090?ooo`@0
00000`3oool2000000/0oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`00000:0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV203oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool5000000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000000700000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`09000000@0oooo00<000000?ooo`3oool00P3oool9000000<0oooo00<00000
0?ooo`3oool0103oool8000000L0oooo00<000000?ooo`3oool0200000060?ooo`040000003oool0
oooo000000d0oooo00<000000?ooo`3oool00P3oool8000000D0oooo00@000000?ooo`3oool0oooo
2P0000030?ooo`030000003oool0oooo00@0oooo200000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000002P3oool000L0oooo1`3Vi^H4000000L0i^KV00<0oooo000000000000
0P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo100000040?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool00000000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`02000000/0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`@000001@3oool010000000oooo0?ooo`0000060?ooo`@00000
0`3oool2000000H0oooo100000040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`@00000
103oool00`000000oooo0?ooo`020?ooo`<000000P3oool4000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00P3oool2000000/0oooo
00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000h0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000003P3oool01000
0000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool00000
3@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000:0?ooo`001`3oool60>KViP80000000@0i^KV00000000000000001P3Vi^H80?ooo`80
0000103oool2000000X0oooo0P0000040?ooo`8000003@3oool2000000h0oooo0P00000=0?ooo`80
00000`3oool4000000T0oooo0P0000040?ooo`800000303oool4000000l0oooo0P00000C0?ooo`80
00004@3oool2000000d0oooo0P0000040?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`80
0000103oool2000000X0oooo0P0000040?ooo`8000002`3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo
00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0B`3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`1<0?ooo`001`3ooolB0>KViPT0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04d0oooo00070?oooa80
i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`060?ooo`800000J`3oool200000500oooo00070?oooa80i^KV
2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`040?ooo`800000J`3oool200000580oooo00070?oooa80i^KV203o
ool3000000l0oooo0`00000@0?ooo`800000403oool2000000@0oooo0P00001[0?ooo`800000D`3o
ool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo0`00001Z0?ooo`<00000DP3oool0
00L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KViPL0oooo
1@0000020?ooo`8000003@3oool2000000d0oooo0P00000?0?ooo`<000004P3oool300000100oooo
1@00000=0?ooo`<00000303oool5000000030?ooo`000000000000<000001`3oool5000000040?oo
o`0000000000000000X0oooo100000020?ooo`D000001`3oool400000080oooo0`00000:0?ooo`80
00000`3oool5000000P0oooo0P0000030?ooo`<000002`3oool3000000030?ooo`000000000000<0
00002@3oool000L0oooo1`3Vi^H3000000P0i^KV2@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo
00000100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
0P00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool2000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool000L0oooo203Vi^H00`000000i^KV0>KViP070>KViPT0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03P3oool3000000@0oooo200000030?ooo`D000000P3oool8000000P0oooo00<0
00000?ooo`000000200000050?ooo`030000003oool0oooo00X00000103oool00`000000oooo0?oo
o`030?ooo`P00000103oool01P000000oooo0?ooo`3oool000000?ooo`P00000103oool00`000000
oooo0?ooo`030?ooo`P00000103oool00`000000oooo0?ooo`020?ooo`T000001@3oool00`000000
oooo0?ooo`020?ooo`T00000103oool01P000000oooo0?ooo`3oool000000?ooo`P000000P3oool5
000000<0oooo00<000000?ooo`3oool02@3oool000L0oooo203Vi^H00`000000i^KV0>KViP070>KV
iP030?ooo`000000000000800000103oool00`000000oooo0?ooo`020?ooo`8000001P3oool40000
00<0oooo0P00000?0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo0P0000050?ooo`@00000103o
ool00`000000oooo0?ooo`02000000D0oooo100000020?ooo`<000000P3oool200000080oooo1000
00040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`@00000103oool010000000oooo0?oo
o`3oool4000000<0oooo100000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo100000040?ooo`040000003oool0oooo0?ooo`@000000P3oool4000000D0oooo00<000000?oo
o`3oool00P3oool200000080oooo100000050?ooo`030000003oool0oooo00@000000P3oool40000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`001`3oool80>KV
iP800000203Vi^H90?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403o
ool00`000000oooo0000000C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo000000040?ooo`030000003oool0oooo00T0oooo00070?oo
o`P0i^KV00@000000>KViP3Vi^H000001P3Vi^H80?ooo`800000103oool3000000`0oooo0`00000<
0?ooo`800000403oool300000140oooo0P00000B0?ooo`800000403oool3000000`0oooo0P000004
0?ooo`8000002P3oool2000000@0oooo0`00000:0?ooo`800000103oool2000000X0oooo0P000004
0?ooo`<000002@3oool2000000@0oooo0P00000:0?ooo`800000103oool3000000X0oooo0P000003
0?ooo`8000002`3oool000L0oooo1`3Vi^H5000000H0i^KVo`3oool80?ooo`001`3ooolB0>KViPT0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0bP3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0</0oooo
00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3<0?ooo`001`3ooolB0>KViPT0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`800000403oool200000<l0oooo00070?oo
oa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000403oool200000=40oooo00070?oooa80i^KV203oool3000000l0oooo0`0000040?ooo`80
0000403oool200000=80oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00<0oooo0`00000?0?ooo`<00000d@3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo0007
0?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KViPL0oooo1@0000020?ooo`8000002P3oool20000
0100oooo0P00000B0?ooo`@00000403oool2000000l0oooo0`00000<0?ooo`D000000`3oool30000
00L0oooo1@000000103oool000000000000000090?ooo`@00000103oool3000000P0oooo10000003
0?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`800000103oool2000000/0oooo0`000002
0?ooo`8000002`3oool3000000<0oooo00<000000?ooo`3oool02@3oool000L0oooo1P3Vi^H50000
00L0i^KV2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool0
10000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo00000100oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000080?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool000L0oooo1`3Vi^H01000
0000i^KV0>KViP0000070>KViPT0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`030?ooo`P00000
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo300000040?ooo`040000
003oool0oooo0?ooo`X00000103oool00`000000oooo0?ooo`020?ooo`T000000`3oool00`000000
oooo0?ooo`020?ooo`D000002@3oool00`000000oooo0?ooo`020?ooo`T000001@3oool00`000000
oooo0?ooo`020?ooo`P000001@3oool010000000oooo0?ooo`3oool:00000080oooo1@0000030?oo
o`030000003oool0oooo00L0oooo1@0000030?ooo`030000003oool0oooo00T0oooo00070?ooo`L0
i^KV00<000000>KViP3Vi^H0203Vi^H00`3oool0000000000002000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo100000040?ooo`030000003oool0
oooo00P0oooo100000030?ooo`8000002@3oool400000080oooo00D000000?ooo`3oool000000?oo
o`0200000080oooo100000040?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool4000000@0oooo00<0
00000?ooo`3oool00P3oool2000000<0oooo100000050?ooo`030000003oool0oooo0080oooo0P00
00020?ooo`@000001@3oool010000000oooo0?ooo`3oool300000080oooo100000020?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0100000020?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0203oool000L0oooo1`3Vi^H2000000T0i^KV2@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo00000140oooo00@000000?ooo`3oool00000403oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`0000002@3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo000000020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000
0P3oool010000000oooo0?ooo`00000:0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0
i^KV203oool2000000@0oooo0P00000:0?ooo`800000403oool2000001<0oooo0P00000A0?ooo`<0
00003`3oool3000000`0oooo0P0000050?ooo`8000002@3oool2000000@0oooo0`0000090?ooo`80
00001@3oool2000000X0oooo0P0000040?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`80
0000103oool2000000/0oooo0P0000030?ooo`8000002`3oool200000080oooo1000000:0?ooo`00
1`3oool60>KViPD000001`3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV2@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0D0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool000L0oooo4P3Vi^H90?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01H0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00H0oooo0P00000R0?ooo`800000403oool2000004L0oooo0P0000170?ooo`80
00006@3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0000000R0?ooo`800000403oool2000004L0oooo0P0000160?ooo`030000
003oool0000001/0oooo00070?oooa80i^KV203oool3000000l0oooo0`0000040?ooo`8000008P3o
ool200000100oooo0P0000170?ooo`800000A`3oool2000001`0oooo00070?oooa80i^KV2@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo0`00000Q0?ooo`<000003`3oool3
000004H0oooo0`0000160?ooo`<000006`3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80
i^KVo`3oool80?ooo`001`3ooolB0>KViP/0oooo0P00000=0?ooo`800000403oool2000001<0oooo
0P00000=0?ooo`D000000P3oool2000000T0oooo1@0000020?ooo`8000002@3oool4000000<0oooo
0P0000090?ooo`@000000`3oool2000000X0oooo0P0000040?ooo`8000002`3oool2000000@0oooo
0P00000;0?ooo`<000000P3oool2000000/0oooo0`0000020?ooo`8000002`3oool3000000040?oo
o`0000000000000000/0oooo0`000000103oool0000000000000000;0?ooo`001`3oool60>KViP<0
000000<0i^KV0000000000001P3Vi^H:0?ooo`040000003oool0oooo000000/0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000T0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo00000000000;0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0203oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KV
iPd0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`P000000P3oool01000
0000oooo0?ooo`0000040?ooo`P00000203oool00`000000oooo00000007000000D0oooo00@00000
0?ooo`3oool0oooo2@0000050?ooo`030000003oool0oooo0080oooo2@0000030?ooo`030000003o
ool0oooo0080oooo2P0000030?ooo`030000003oool0oooo00@0oooo200000040?ooo`060000003o
ool0oooo0?ooo`000000oooo200000050?ooo`030000003oool0oooo0080oooo200000030?ooo`D0
000000D0oooo0000003oool0oooo000000080?ooo`D00000103oool00`000000oooo0?ooo`060?oo
o`D0000000D0oooo0000003oool0oooo000000080?ooo`D0000000D0oooo0000003oool0oooo0000
000:0?ooo`001`3oool70>KViP<00000203Vi^H40?ooo`@000000`3oool2000000d0oooo0P000006
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`030?ooo`@000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo100000040?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000020?ooo`@00000103oool00`000000oooo0?ooo`020?oo
o`<000000P3oool4000000@0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo1000
00040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@000001@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo0?ooo`@000001@3oool010000000oooo0?ooo`3oool20000
00<0oooo100000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool400000080oooo00@000000?ooo`3oool000000`3oool2000000<0oooo100000020?ooo`040000
003oool0oooo00000080oooo0`0000030?ooo`@000000P3oool010000000oooo0?ooo`0000020?oo
o`<000002`3oool000L0oooo1`3Vi^H00`000000i^KV000000080>KViP/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool03P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000T0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool02P3oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViP/0oooo
0`00000<0?ooo`<000003`3oool2000001<0oooo0`00000=0?ooo`800000103oool2000000X0oooo
0P0000040?ooo`<000002@3oool2000000@0oooo0P00000:0?ooo`800000103oool3000000T0oooo
0P0000040?ooo`8000002`3oool2000000@0oooo0`00000:0?ooo`8000000`3oool2000000/0oooo
0P0000030?ooo`<000002P3oool2000000<0oooo0`00000:0?ooo`8000000`3oool3000000X0oooo
00070?ooo`H0i^KV0`0000000`3Vi^H00000000000060>KVi_l0oooo203oool000L0oooo4P3Vi^H9
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool000L0oooo4P3Vi^H90?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool000L0oooo4P3Vi^H90?ooo`03
0000003oool0oooo00L0oooo0P00002d0?ooo`030000003oool0oooo00l0oooo0P00000A0?ooo`03
0000003oool0oooo01H0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0;80oooo0P00000A0?ooo`030000003oool0oooo00l0oooo0P00000I0?ooo`001`3o
oolB0>KViPT0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000002c0?ooo`800000403o
ool00`000000oooo0000000?0?ooo`030000003oool0000001/0oooo00070?oooa80i^KV203oool3
000000<0oooo0`00002c0?ooo`800000403oool300000100oooo0P00000L0?ooo`001`3ooolB0>KV
iPT0oooo00<000000?ooo`3oool00P3oool300000;<0oooo0`00000?0?ooo`<00000403oool30000
01/0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3V
i^H80?ooo`8000004@3oool300000080oooo0P00000;0?ooo`<000000P3oool2000000/0oooo0`00
00020?ooo`800000303oool300000080oooo0P00000;0?ooo`<000000P3oool2000000/0oooo0`00
00020?ooo`8000002`3oool300000080oooo0P00000;0?ooo`<000000P3oool2000000`0oooo0`00
00020?ooo`8000002`3oool300000080oooo0P00000;0?ooo`<000000P3oool2000000/0oooo0`00
00020?ooo`8000002`3oool300000080oooo0P00000;0?ooo`001`3ooolB0>KViPL0oooo00@00000
0?ooo`3oool000004@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00070?oooa80i^KV1`3oool010000000
oooo0?ooo`0000030?ooo`T000000P3oool5000000<0oooo200000020?ooo`D000000`3oool80000
0080oooo1@0000030?ooo`P000000`3oool500000080oooo200000030?ooo`D000000P3oool90000
0080oooo1@0000020?ooo`T000000P3oool5000000<0oooo200000020?ooo`D000000`3oool80000
00<0oooo1@0000020?ooo`P000000`3oool500000080oooo200000030?ooo`D000000P3oool90000
0080oooo1@0000030?ooo`P000000P3oool5000000@0oooo00<000000?ooo`3oool0203oool000L0
oooo4P3Vi^H70?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`@000000P3oool01000
0000oooo0?ooo`0000030?ooo`<000000P3oool400000080oooo00@000000?ooo`3oool000000`3o
ool300000080oooo100000020?ooo`040000003oool0oooo000000<0oooo0`0000030?ooo`@00000
0P3oool010000000oooo0?ooo`0000030?ooo`<000000P3oool400000080oooo00@000000?ooo`3o
ool000000`3oool300000080oooo100000020?ooo`040000003oool0oooo000000<0oooo0`000002
0?ooo`@000000P3oool010000000oooo0?ooo`0000030?ooo`<000000P3oool400000080oooo00@0
00000?ooo`3oool000000`3oool3000000<0oooo100000020?ooo`040000003oool0oooo000000<0
oooo0P0000030?ooo`@000000P3oool010000000oooo0?ooo`0000030?ooo`<000000P3oool40000
0080oooo00@000000?ooo`3oool000000`3oool300000080oooo100000020?ooo`040000003oool0
oooo000000<0oooo0`0000020?ooo`@000000P3oool010000000oooo0?ooo`0000030?ooo`800000
2`3oool000L0oooo4P3Vi^H70?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`0:0?ooo`001`3ooolB0>KViPP0oooo0P00000A0?ooo`8000000`3o
ool3000000X0oooo0P0000030?ooo`<000002P3oool2000000<0oooo0`00000;0?ooo`8000000`3o
ool3000000X0oooo0P0000030?ooo`<000002P3oool2000000<0oooo0`00000:0?ooo`8000000`3o
ool3000000X0oooo0P0000030?ooo`<000002`3oool2000000<0oooo0`00000:0?ooo`8000000`3o
ool3000000X0oooo0P0000030?ooo`<000002P3oool2000000<0oooo0`00000:0?ooo`8000000`3o
ool3000000X0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0
oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203o
ool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40
i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooono
0>KViP800000C`3Vi^H90?ooo`001`3ooolZ0>KViP<0000000<0i^KV0000000000003P3Vi^H30000
00h0i^KV0`00000?0>KViP<0000000<0i^KV000000000000303Vi^H3000000030>KViP0000000000
00d0i^KV0P0000000`3Vi^H000000000000>0>KViP8000003P3Vi^H3000000030>KViP000000i^KV
00l0i^KV0P00000>0>KViP<0000000<0i^KV0000000000003@3Vi^H3000000h0i^KV0`00000@0>KV
iP<00000203Vi^H90?ooo`001`3oool[0>KViP040000003Vi^H0i^KV00000100i^KV00<000000>KV
iP3Vi^H03P3Vi^H00`000000i^KV0>KViP0?0>KViP040000003Vi^H0i^KV000000h0i^KV00@00000
0>KViP3Vi^H000003P3Vi^H01@000000i^KV0>KViP3Vi^H0000000d0i^KV00@000000>KViP3Vi^H0
00003P3Vi^H010000000i^KV00000000000?0>KViP040000003Vi^H0i^KV000000h0i^KV00@00000
0>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000>0>KViP030000003Vi^H0i^KV0100i^KV
00<000000>KViP3Vi^H01`3Vi^H90?ooo`001`3oool[0>KViP<000004@3Vi^H00`000000i^KV0>KV
iP0>0>KViP030000003Vi^H0i^KV00l0i^KV00@000000>KViP3Vi^H000003P3Vi^H300000100i^KV
0`00000>0>KViP030000003Vi^H00000008000003@3Vi^H010000000i^KV00000000000?0>KViP04
0000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H000004@3Vi^H00`000000i^KV0>KViP0<
0>KViP<00000403Vi^H00`000000i^KV0>KViP070>KViPT0oooo00070?ooob/0i^KV00<000000>KV
iP000000403Vi^H00`000000i^KV0000000?0>KViP800000403Vi^H4000000h0i^KV00<000000>KV
iP000000403Vi^H00`000000i^KV0000000>0>KViP030000003Vi^H0i^KV00l0i^KV0P0000000`3V
i^H000000>KViP0>0>KViP040000003Vi^H0i^KV000000h0i^KV1000000?0>KViP8000003`3Vi^H0
10000000i^KV0>KViP00000?0>KViP030000003Vi^H0i^KV00L0i^KV2@3oool000L0oooo:`3Vi^H0
10000000i^KV0>KViP00000>0>KViP050000003Vi^H0i^KV0>KViP0000003P3Vi^H010000000i^KV
0>KViP00000>0>KViP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H00000403Vi^H0
0`000000i^KV0>KViP0=0>KViP030000003Vi^H0i^KV00l0i^KV0P0000000`3Vi^H000000>KViP0>
0>KViP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV
0>KViP00000>0>KViP040000003Vi^H0i^KV000000d0i^KV00D000000>KViP000000i^KV00000007
0>KViPT0oooo00070?ooobX0i^KV0`0000000`3Vi^H000000000000<0>KViP<0000000<0i^KV0000
000000003@3Vi^H5000000d0i^KV0P000000103Vi^H0000000000000000<0>KViP<0000000<0i^KV
0000000000003P3Vi^H200000100i^KV0`00000=0>KViP80000000@0i^KV00000000000000003`3V
i^H2000000h0i^KV0P000000103Vi^H0000000000000000=0>KViP@000003@3Vi^H4000000h0i^KV
1@0000070>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool0
00L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.894534, -0.262555, \
0.0550141, 0.0623104}}]
}, Open  ]],

Cell[TextData[{
  "Die bisherigen Befehle und Auswertungen stellen die Infrastruktur bereit, \
um nun das Kernst\[UDoubleDot]ck des Needleman-Wunsch-Algorithmus in die \
Betrachtungen einbeziehen zu k\[ODoubleDot]nnen, n\[ADoubleDot]mlich die \
Ermittlung des Pfades durch diese Matrix, der dem h\[ODoubleDot]chsten \
Alignment-Score der beiden Sequenzen entspricht. F\[UDoubleDot]hren wir zun\
\[ADoubleDot]chst eine Abk\[UDoubleDot]rzung f\[UDoubleDot]r die \
Matrixdimension ein und extrahieren das rechte untere Element, das beim \
Needleman-Wunsch-Algorithmus den Startpunkt f\[UDoubleDot]r den optimalen \
Pfad darstellt. Die Koordinaten des optimalen Pfades schreiben wir in die \
Variable ",
  StyleBox["traX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", die wir als Funktion mit einem Laufindex ",
  StyleBox["i",
    FontSlant->"Italic"],
  " als Argument darstellen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(dX = Dimensions[FFTabB];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(traX[1] = {dX[\([1]\)], dX[\([2]\)]}\)], "Input"],

Cell[BoxData[
    \({9, 14}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Mit einer ",
  StyleBox["While",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife, die \[UDoubleDot]berpr\[UDoubleDot]ft, ob das Ende (genauer: \
der Anfang) der beiden Sequenzen erreicht ist, kann nun der Pfad rekursiv \
konstruiert werden. Wann immer der Zeigerzustand 1 (\"diagonal\") an der \
aktuellen Matrixposition vorliegt, werden beide Indizes um Eins vermindert, \
ansonsten jeweils nur ein Index. Eine Laufvariable ",
  StyleBox["j",
    FontSlant->"Italic"],
  " wird in jedem Schleifendurchlauf erh\[ODoubleDot]ht."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(j = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      FFTabB[\([Sequence @@ traX[j]]\)] =!= 
        0, {traX[j + 1] = 
          traX[j] - 
            Switch[FFTabB[\([Sequence @@ traX[j]]\)], 1, {1, 1}, 2, {1, 0}, 
              3, {0, 1}], j = j + 1}]\)}], "Input"],

Cell[TextData[{
  "Bei n\[ADoubleDot]herem Hinsehen erkennt man einige Besonderheiten. So \
wurde zum Beispiel als Abbruchbedingung der ",
  StyleBox["While",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife das Erreichen eines Zeigerzustands von Null verwendet. Wir \
nutzen also aus, dass dieser Zeigerzustand f\[UDoubleDot]r die obere linke \
Ecke der Matrix reserviert ist. Weiterhin muss man eine \
ung\[UDoubleDot]nstige Klammerung in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " hier umgehen: Ein Zahlenpaar kann nicht ohne Vorbereitung als \
Matrixposition an den ",
  StyleBox["Part",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl (also ",
  StyleBox["[[]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") \[UDoubleDot]bergeben werden. Man muss (wie wir es vom Prinzip her auch \
schon im vorangegangenen ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs gesehen haben) den Kopf dieser Liste durch den einer \
ungeklammerten Zahlenfolge ersetzen. Dies geschieht mit dem Befehl ",
  StyleBox["Sequence",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", zusammen mit ",
  StyleBox["Apply",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " (also ",
  StyleBox["@@",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "). Eine letzte Besonderheit stellt die konkrete Rekursion dar. Hier sieht \
man recht klar, dass sich in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " solche formalen Zuweisungen sehr elegant gestalten lassen. Der ",
  StyleBox["Switch",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl steht explizit als ein Term in der Gleichung f\[UDoubleDot]r die n\
\[ADoubleDot]chsten Pfadkoordinaten. Auf diese Weise wird der Term in Abh\
\[ADoubleDot]ngigkeit des Zeigerzustands hinzugef\[UDoubleDot]gt: entweder ",
  StyleBox["{1, 1}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " oder ",
  StyleBox["{1, 0}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " oder ",
  StyleBox["{0, 1}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". \n\nDie Ausgabe des Pfades erfolgt nun einfach \[UDoubleDot]ber den ",
  StyleBox["Table",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl. Dabei verwenden wir den Wert der Laufvariablen ",
  StyleBox["j",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " am Ende der Schleifendurchl\[ADoubleDot]ufe als obere Grenze. Der letzte \
Eintrag (n\[ADoubleDot]mlich stets die Position ",
  StyleBox["{1, 1}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") wird weggelassen, da sie nicht mehr zum eigentlichen Pfad beitr\
\[ADoubleDot]gt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(path1 = Table[traX[k], {k, 1, j - 1}]\)], "Input"],

Cell[BoxData[
    \({{9, 14}, {8, 13}, {8, 12}, {8, 11}, {7, 10}, {7, 9}, {7, 8}, {6, 
        7}, {6, 6}, {5, 5}, {4, 4}, {3, 3}, {2, 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Ein geeignetes Format f\[UDoubleDot]r die weitere Verarbeitung erreichen \
wir durch erneutes Auslesen der Zeigerzust\[ADoubleDot]nde aus der Tabelle ",
  StyleBox["FFTabB",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und durch Zusammenf\[UDoubleDot]gen mit der Pfadvariablen ",
  StyleBox["path1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ":"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(path2 = Map[FFTabB[\([Sequence @@ #]\)] &, path1]\)], "Input"],

Cell[BoxData[
    \({1, 3, 3, 1, 3, 3, 1, 3, 1, 1, 1, 1, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(path3 = Map[Flatten, Thread[{path2, path1}]]\)], "Input"],

Cell[BoxData[
    \({{1, 9, 14}, {3, 8, 13}, {3, 8, 12}, {1, 8, 11}, {3, 7, 10}, {3, 7, 
        9}, {1, 7, 8}, {3, 6, 7}, {1, 6, 6}, {1, 5, 5}, {1, 4, 4}, {1, 3, 
        3}, {1, 2, 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Man hat dann Wertetripletts: Zeigerzustand, Koordinate 1, Koordinate 2.\n\n\
\n",
  StyleBox["Wir kommen nun zur Visualisierung dieses Pfades. Dabei verwenden \
wir dieselben Graphikbefehle f\[UDoubleDot]r die Pfeile, die wir bereits zu \
Beginn dieses Notebooks eingesetzt haben, nun allerdings mit einer anderen \
Pfeilfarbe und Linienst\[ADoubleDot]rke. Man hat dann eine Farbvariante ",
    FontColor->GrayLevel[0.500008]],
  StyleBox["arrXXc",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  StyleBox[" als Befehl zur Verf\[UDoubleDot]gung, die dem \
urspr\[UDoubleDot]nglichen Metakommando ",
    FontColor->GrayLevel[0.500008]],
  StyleBox["arrXX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  StyleBox[" zur Auswahl des richtigen Pfeils zu einem Zeiger entspricht. ",
    FontColor->GrayLevel[0.500008]]
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(arrAc[i_, j_] := \n
        Show[Graphics[{AbsoluteThickness[3], GrayLevel[0.6], 
              Arrow[{i + 0.7, Length[prot1] + 1.3 - \((j)\)}, {i + 0.3, 
                  Length[prot1] + 1.7 - \((j)\)}, 
                HeadScaling \[Rule] Relative, HeadWidth \[Rule] 2]}], 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(arrBc[i_, j_] := 
        Show[Graphics[{AbsoluteThickness[3], GrayLevel[0.6], 
              Arrow[{i + 1.0, Length[prot1] + 1.3 - \((j)\)}, {i + 1.0, 
                  Length[prot1] + 1.7 - \((j)\)}, 
                HeadScaling \[Rule] Relative, HeadWidth \[Rule] 2]}], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(arrCc[i_, j_] := 
        Show[Graphics[{AbsoluteThickness[3], GrayLevel[0.6], 
              Arrow[{i + 0.7, Length[prot1] + 1.0 - \((j)\)}, {i + 0.3, 
                  Length[prot1] + 1.0 - \((j)\)}, 
                HeadScaling \[Rule] Relative, HeadWidth \[Rule] 2]}], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(arrXXc[ll_, i_, j_] := 
      If[ll \[Equal] 1, arrAc[i, j], 
        If[ll \[Equal] 2, arrBc[i, j], 
          If[ll \[Equal] 3, arrCc[i, j]]]]\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[TextData[{
  "Die Daten ",
  StyleBox["path3",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " kann nun mit dem ",
  StyleBox["Map",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl direkt in ",
  StyleBox["arrXXc",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zur Erzeugung der Grafikbefehle eingef\[UDoubleDot]gt werden. "
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(gr2 = 
        Map[arrXXc[#[\([1]\)], #[\([3]\)] - 1, #[\([2]\)] - 1] &, 
          path3];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p7 = 
        Show[p6, gr2, DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",\

  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0555556 0.0634921 0.0147151 0.0560575 [
[.11905 .57529 -5 -6.28125 ]
[.11905 .57529 5 6.28125 ]
[.18254 .57529 -5 -6.28125 ]
[.18254 .57529 5 6.28125 ]
[.24603 .57529 -5 -6.28125 ]
[.24603 .57529 5 6.28125 ]
[.30952 .57529 -5 -6.28125 ]
[.30952 .57529 5 6.28125 ]
[.37302 .57529 -5 -6.28125 ]
[.37302 .57529 5 6.28125 ]
[.43651 .57529 -5 -6.28125 ]
[.43651 .57529 5 6.28125 ]
[.5 .57529 -5 -6.28125 ]
[.5 .57529 5 6.28125 ]
[.56349 .57529 -5 -6.28125 ]
[.56349 .57529 5 6.28125 ]
[.62698 .57529 -5 -6.28125 ]
[.62698 .57529 5 6.28125 ]
[.69048 .57529 -5 -6.28125 ]
[.69048 .57529 5 6.28125 ]
[.75397 .57529 -5 -6.28125 ]
[.75397 .57529 5 6.28125 ]
[.81746 .57529 -5 -6.28125 ]
[.81746 .57529 5 6.28125 ]
[.88095 .57529 -5 -6.28125 ]
[.88095 .57529 5 6.28125 ]
[.94444 .57529 -5 -6.28125 ]
[.94444 .57529 5 6.28125 ]
[.05556 .51923 -5 -6.28125 ]
[.05556 .51923 5 6.28125 ]
[.05556 .46318 -5 -6.28125 ]
[.05556 .46318 5 6.28125 ]
[.05556 .40712 -5 -6.28125 ]
[.05556 .40712 5 6.28125 ]
[.05556 .35106 -5 -6.28125 ]
[.05556 .35106 5 6.28125 ]
[.05556 .295 -5 -6.28125 ]
[.05556 .295 5 6.28125 ]
[.05556 .23895 -5 -6.28125 ]
[.05556 .23895 5 6.28125 ]
[.05556 .18289 -5 -6.28125 ]
[.05556 .18289 5 6.28125 ]
[.05556 .12683 -5 -6.28125 ]
[.05556 .12683 5 6.28125 ]
[.05556 .07077 -5 -6.28125 ]
[.05556 .07077 5 6.28125 ]
[.11905 .51923 -3 -4.5 ]
[.11905 .51923 3 4.5 ]
[.18254 .51923 -9 -4.5 ]
[.18254 .51923 9 4.5 ]
[.24603 .51923 -9 -4.5 ]
[.24603 .51923 9 4.5 ]
[.30952 .51923 -9 -4.5 ]
[.30952 .51923 9 4.5 ]
[.37302 .51923 -9 -4.5 ]
[.37302 .51923 9 4.5 ]
[.43651 .51923 -9 -4.5 ]
[.43651 .51923 9 4.5 ]
[.5 .51923 -9 -4.5 ]
[.5 .51923 9 4.5 ]
[.56349 .51923 -9 -4.5 ]
[.56349 .51923 9 4.5 ]
[.62698 .51923 -9 -4.5 ]
[.62698 .51923 9 4.5 ]
[.69048 .51923 -9 -4.5 ]
[.69048 .51923 9 4.5 ]
[.75397 .51923 -9 -4.5 ]
[.75397 .51923 9 4.5 ]
[.81746 .51923 -9 -4.5 ]
[.81746 .51923 9 4.5 ]
[.88095 .51923 -9 -4.5 ]
[.88095 .51923 9 4.5 ]
[.94444 .51923 -9 -4.5 ]
[.94444 .51923 9 4.5 ]
[.11905 .46318 -6 -4.5 ]
[.11905 .46318 6 4.5 ]
[.18254 .46318 -3 -4.5 ]
[.18254 .46318 3 4.5 ]
[.24603 .46318 -3 -4.5 ]
[.24603 .46318 3 4.5 ]
[.30952 .46318 -6 -4.5 ]
[.30952 .46318 6 4.5 ]
[.37302 .46318 -9 -4.5 ]
[.37302 .46318 9 4.5 ]
[.43651 .46318 -9 -4.5 ]
[.43651 .46318 9 4.5 ]
[.5 .46318 -9 -4.5 ]
[.5 .46318 9 4.5 ]
[.56349 .46318 -9 -4.5 ]
[.56349 .46318 9 4.5 ]
[.62698 .46318 -9 -4.5 ]
[.62698 .46318 9 4.5 ]
[.69048 .46318 -9 -4.5 ]
[.69048 .46318 9 4.5 ]
[.75397 .46318 -9 -4.5 ]
[.75397 .46318 9 4.5 ]
[.81746 .46318 -9 -4.5 ]
[.81746 .46318 9 4.5 ]
[.88095 .46318 -9 -4.5 ]
[.88095 .46318 9 4.5 ]
[.94444 .46318 -9 -4.5 ]
[.94444 .46318 9 4.5 ]
[.11905 .40712 -9 -4.5 ]
[.11905 .40712 9 4.5 ]
[.18254 .40712 -3 -4.5 ]
[.18254 .40712 3 4.5 ]
[.24603 .40712 -3 -4.5 ]
[.24603 .40712 3 4.5 ]
[.30952 .40712 -6 -4.5 ]
[.30952 .40712 6 4.5 ]
[.37302 .40712 -6 -4.5 ]
[.37302 .40712 6 4.5 ]
[.43651 .40712 -6 -4.5 ]
[.43651 .40712 6 4.5 ]
[.5 .40712 -9 -4.5 ]
[.5 .40712 9 4.5 ]
[.56349 .40712 -9 -4.5 ]
[.56349 .40712 9 4.5 ]
[.62698 .40712 -9 -4.5 ]
[.62698 .40712 9 4.5 ]
[.69048 .40712 -9 -4.5 ]
[.69048 .40712 9 4.5 ]
[.75397 .40712 -9 -4.5 ]
[.75397 .40712 9 4.5 ]
[.81746 .40712 -9 -4.5 ]
[.81746 .40712 9 4.5 ]
[.88095 .40712 -9 -4.5 ]
[.88095 .40712 9 4.5 ]
[.94444 .40712 -9 -4.5 ]
[.94444 .40712 9 4.5 ]
[.11905 .35106 -9 -4.5 ]
[.11905 .35106 9 4.5 ]
[.18254 .35106 -6 -4.5 ]
[.18254 .35106 6 4.5 ]
[.24603 .35106 -3 -4.5 ]
[.24603 .35106 3 4.5 ]
[.30952 .35106 -3 -4.5 ]
[.30952 .35106 3 4.5 ]
[.37302 .35106 -3 -4.5 ]
[.37302 .35106 3 4.5 ]
[.43651 .35106 -6 -4.5 ]
[.43651 .35106 6 4.5 ]
[.5 .35106 -6 -4.5 ]
[.5 .35106 6 4.5 ]
[.56349 .35106 -9 -4.5 ]
[.56349 .35106 9 4.5 ]
[.62698 .35106 -9 -4.5 ]
[.62698 .35106 9 4.5 ]
[.69048 .35106 -9 -4.5 ]
[.69048 .35106 9 4.5 ]
[.75397 .35106 -9 -4.5 ]
[.75397 .35106 9 4.5 ]
[.81746 .35106 -9 -4.5 ]
[.81746 .35106 9 4.5 ]
[.88095 .35106 -9 -4.5 ]
[.88095 .35106 9 4.5 ]
[.94444 .35106 -9 -4.5 ]
[.94444 .35106 9 4.5 ]
[.11905 .295 -9 -4.5 ]
[.11905 .295 9 4.5 ]
[.18254 .295 -9 -4.5 ]
[.18254 .295 9 4.5 ]
[.24603 .295 -6 -4.5 ]
[.24603 .295 6 4.5 ]
[.30952 .295 -3 -4.5 ]
[.30952 .295 3 4.5 ]
[.37302 .295 -6 -4.5 ]
[.37302 .295 6 4.5 ]
[.43651 .295 -6 -4.5 ]
[.43651 .295 6 4.5 ]
[.5 .295 -3 -4.5 ]
[.5 .295 3 4.5 ]
[.56349 .295 -3 -4.5 ]
[.56349 .295 3 4.5 ]
[.62698 .295 -6 -4.5 ]
[.62698 .295 6 4.5 ]
[.69048 .295 -6 -4.5 ]
[.69048 .295 6 4.5 ]
[.75397 .295 -9 -4.5 ]
[.75397 .295 9 4.5 ]
[.81746 .295 -9 -4.5 ]
[.81746 .295 9 4.5 ]
[.88095 .295 -9 -4.5 ]
[.88095 .295 9 4.5 ]
[.94444 .295 -9 -4.5 ]
[.94444 .295 9 4.5 ]
[.11905 .23895 -9 -4.5 ]
[.11905 .23895 9 4.5 ]
[.18254 .23895 -9 -4.5 ]
[.18254 .23895 9 4.5 ]
[.24603 .23895 -6 -4.5 ]
[.24603 .23895 6 4.5 ]
[.30952 .23895 -6 -4.5 ]
[.30952 .23895 6 4.5 ]
[.37302 .23895 -6 -4.5 ]
[.37302 .23895 6 4.5 ]
[.43651 .23895 -6 -4.5 ]
[.43651 .23895 6 4.5 ]
[.5 .23895 -6 -4.5 ]
[.5 .23895 6 4.5 ]
[.56349 .23895 -3 -4.5 ]
[.56349 .23895 3 4.5 ]
[.62698 .23895 -3 -4.5 ]
[.62698 .23895 3 4.5 ]
[.69048 .23895 -3 -4.5 ]
[.69048 .23895 3 4.5 ]
[.75397 .23895 -6 -4.5 ]
[.75397 .23895 6 4.5 ]
[.81746 .23895 -6 -4.5 ]
[.81746 .23895 6 4.5 ]
[.88095 .23895 -9 -4.5 ]
[.88095 .23895 9 4.5 ]
[.94444 .23895 -9 -4.5 ]
[.94444 .23895 9 4.5 ]
[.11905 .18289 -9 -4.5 ]
[.11905 .18289 9 4.5 ]
[.18254 .18289 -9 -4.5 ]
[.18254 .18289 9 4.5 ]
[.24603 .18289 -9 -4.5 ]
[.24603 .18289 9 4.5 ]
[.30952 .18289 -6 -4.5 ]
[.30952 .18289 6 4.5 ]
[.37302 .18289 -3 -4.5 ]
[.37302 .18289 3 4.5 ]
[.43651 .18289 -6 -4.5 ]
[.43651 .18289 6 4.5 ]
[.5 .18289 -6 -4.5 ]
[.5 .18289 6 4.5 ]
[.56349 .18289 -6 -4.5 ]
[.56349 .18289 6 4.5 ]
[.62698 .18289 -6 -4.5 ]
[.62698 .18289 6 4.5 ]
[.69048 .18289 -3 -4.5 ]
[.69048 .18289 3 4.5 ]
[.75397 .18289 -3 -4.5 ]
[.75397 .18289 3 4.5 ]
[.81746 .18289 -6 -4.5 ]
[.81746 .18289 6 4.5 ]
[.88095 .18289 -6 -4.5 ]
[.88095 .18289 6 4.5 ]
[.94444 .18289 -9 -4.5 ]
[.94444 .18289 9 4.5 ]
[.11905 .12683 -9 -4.5 ]
[.11905 .12683 9 4.5 ]
[.18254 .12683 -9 -4.5 ]
[.18254 .12683 9 4.5 ]
[.24603 .12683 -9 -4.5 ]
[.24603 .12683 9 4.5 ]
[.30952 .12683 -9 -4.5 ]
[.30952 .12683 9 4.5 ]
[.37302 .12683 -3 -4.5 ]
[.37302 .12683 3 4.5 ]
[.43651 .12683 -3 -4.5 ]
[.43651 .12683 3 4.5 ]
[.5 .12683 -6 -4.5 ]
[.5 .12683 6 4.5 ]
[.56349 .12683 -6 -4.5 ]
[.56349 .12683 6 4.5 ]
[.62698 .12683 -6 -4.5 ]
[.62698 .12683 6 4.5 ]
[.69048 .12683 -6 -4.5 ]
[.69048 .12683 6 4.5 ]
[.75397 .12683 -6 -4.5 ]
[.75397 .12683 6 4.5 ]
[.81746 .12683 -6 -4.5 ]
[.81746 .12683 6 4.5 ]
[.88095 .12683 -3 -4.5 ]
[.88095 .12683 3 4.5 ]
[.94444 .12683 -3 -4.5 ]
[.94444 .12683 3 4.5 ]
[.11905 .07077 -9 -4.5 ]
[.11905 .07077 9 4.5 ]
[.18254 .07077 -9 -4.5 ]
[.18254 .07077 9 4.5 ]
[.24603 .07077 -9 -4.5 ]
[.24603 .07077 9 4.5 ]
[.30952 .07077 -9 -4.5 ]
[.30952 .07077 9 4.5 ]
[.37302 .07077 -6 -4.5 ]
[.37302 .07077 6 4.5 ]
[.43651 .07077 -3 -4.5 ]
[.43651 .07077 3 4.5 ]
[.5 .07077 -3 -4.5 ]
[.5 .07077 3 4.5 ]
[.56349 .07077 -6 -4.5 ]
[.56349 .07077 6 4.5 ]
[.62698 .07077 -6 -4.5 ]
[.62698 .07077 6 4.5 ]
[.69048 .07077 -6 -4.5 ]
[.69048 .07077 6 4.5 ]
[.75397 .07077 -6 -4.5 ]
[.75397 .07077 6 4.5 ]
[.81746 .07077 -6 -4.5 ]
[.81746 .07077 6 4.5 ]
[.88095 .07077 -6 -4.5 ]
[.88095 .07077 6 4.5 ]
[.94444 .07077 -6 -4.5 ]
[.94444 .07077 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto fill
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto
-0.2 0.1 lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.2 0.2 moveto 0 0 lineto
-0.2 -0.2 lineto fill
-0.2 0.2 moveto 0 0 lineto
-0.2 -0.2 lineto
-0.2 0.2 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.9 g
.0873 .54726 m
.0873 .60332 L
.97619 .60332 L
.97619 .54726 L
F
0 g
gsave
.11905 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18254 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24603 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30952 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37302 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43651 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56349 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62698 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75397 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81746 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88095 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.94444 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.9 g
.02381 .01472 m
.02381 .60332 L
.0873 .60332 L
.0873 .01472 L
F
0 g
gsave
.05556 .51923 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .46318 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .40712 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .35106 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .295 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .23895 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .18289 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .12683 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .07077 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
[(0)] .11905 .51923 0 0 Mshowa
[(-45)] .18254 .51923 0 0 Mshowa
[(-45)] .24603 .51923 0 0 Mshowa
[(-45)] .30952 .51923 0 0 Mshowa
[(-45)] .37302 .51923 0 0 Mshowa
[(-45)] .43651 .51923 0 0 Mshowa
[(-45)] .5 .51923 0 0 Mshowa
[(-45)] .56349 .51923 0 0 Mshowa
[(-45)] .62698 .51923 0 0 Mshowa
[(-45)] .69048 .51923 0 0 Mshowa
[(-45)] .75397 .51923 0 0 Mshowa
[(-45)] .81746 .51923 0 0 Mshowa
[(-45)] .88095 .51923 0 0 Mshowa
[(-45)] .94444 .51923 0 0 Mshowa
[(-5)] .11905 .46318 0 0 Mshowa
[(5)] .18254 .46318 0 0 Mshowa
[(0)] .24603 .46318 0 0 Mshowa
[(-5)] .30952 .46318 0 0 Mshowa
[(-10)] .37302 .46318 0 0 Mshowa
[(-15)] .43651 .46318 0 0 Mshowa
[(-20)] .5 .46318 0 0 Mshowa
[(-25)] .56349 .46318 0 0 Mshowa
[(-30)] .62698 .46318 0 0 Mshowa
[(-35)] .69048 .46318 0 0 Mshowa
[(-40)] .75397 .46318 0 0 Mshowa
[(-45)] .81746 .46318 0 0 Mshowa
[(-46)] .88095 .46318 0 0 Mshowa
[(-46)] .94444 .46318 0 0 Mshowa
[(-10)] .11905 .40712 0 0 Mshowa
[(0)] .18254 .40712 0 0 Mshowa
[(3)] .24603 .40712 0 0 Mshowa
[(-2)] .30952 .40712 0 0 Mshowa
[(-5)] .37302 .40712 0 0 Mshowa
[(-9)] .43651 .40712 0 0 Mshowa
[(-14)] .5 .40712 0 0 Mshowa
[(-19)] .56349 .40712 0 0 Mshowa
[(-24)] .62698 .40712 0 0 Mshowa
[(-28)] .69048 .40712 0 0 Mshowa
[(-33)] .75397 .40712 0 0 Mshowa
[(-38)] .81746 .40712 0 0 Mshowa
[(-43)] .88095 .40712 0 0 Mshowa
[(-47)] .94444 .40712 0 0 Mshowa
[(-15)] .11905 .35106 0 0 Mshowa
[(-5)] .18254 .35106 0 0 Mshowa
[(3)] .24603 .35106 0 0 Mshowa
[(9)] .30952 .35106 0 0 Mshowa
[(4)] .37302 .35106 0 0 Mshowa
[(-1)] .43651 .35106 0 0 Mshowa
[(-6)] .5 .35106 0 0 Mshowa
[(-11)] .56349 .35106 0 0 Mshowa
[(-16)] .62698 .35106 0 0 Mshowa
[(-21)] .69048 .35106 0 0 Mshowa
[(-26)] .75397 .35106 0 0 Mshowa
[(-31)] .81746 .35106 0 0 Mshowa
[(-36)] .88095 .35106 0 0 Mshowa
[(-41)] .94444 .35106 0 0 Mshowa
[(-20)] .11905 .295 0 0 Mshowa
[(-10)] .18254 .295 0 0 Mshowa
[(-2)] .24603 .295 0 0 Mshowa
[(4)] .30952 .295 0 0 Mshowa
[(17)] .37302 .295 0 0 Mshowa
[(12)] .43651 .295 0 0 Mshowa
[(7)] .5 .295 0 0 Mshowa
[(2)] .56349 .295 0 0 Mshowa
[(-3)] .62698 .295 0 0 Mshowa
[(-8)] .69048 .295 0 0 Mshowa
[(-13)] .75397 .295 0 0 Mshowa
[(-18)] .81746 .295 0 0 Mshowa
[(-23)] .88095 .295 0 0 Mshowa
[(-28)] .94444 .295 0 0 Mshowa
[(-25)] .11905 .23895 0 0 Mshowa
[(-15)] .18254 .23895 0 0 Mshowa
[(-7)] .24603 .23895 0 0 Mshowa
[(-1)] .30952 .23895 0 0 Mshowa
[(12)] .37302 .23895 0 0 Mshowa
[(17)] .43651 .23895 0 0 Mshowa
[(12)] .5 .23895 0 0 Mshowa
[(7)] .56349 .23895 0 0 Mshowa
[(8)] .62698 .23895 0 0 Mshowa
[(3)] .69048 .23895 0 0 Mshowa
[(-2)] .75397 .23895 0 0 Mshowa
[(-7)] .81746 .23895 0 0 Mshowa
[(-12)] .88095 .23895 0 0 Mshowa
[(-17)] .94444 .23895 0 0 Mshowa
[(-30)] .11905 .18289 0 0 Mshowa
[(-20)] .18254 .18289 0 0 Mshowa
[(-12)] .24603 .18289 0 0 Mshowa
[(-6)] .30952 .18289 0 0 Mshowa
[(7)] .37302 .18289 0 0 Mshowa
[(12)] .43651 .18289 0 0 Mshowa
[(17)] .5 .18289 0 0 Mshowa
[(18)] .56349 .18289 0 0 Mshowa
[(13)] .62698 .18289 0 0 Mshowa
[(8)] .69048 .18289 0 0 Mshowa
[(3)] .75397 .18289 0 0 Mshowa
[(-2)] .81746 .18289 0 0 Mshowa
[(-7)] .88095 .18289 0 0 Mshowa
[(-12)] .94444 .18289 0 0 Mshowa
[(-35)] .11905 .12683 0 0 Mshowa
[(-25)] .18254 .12683 0 0 Mshowa
[(-17)] .24603 .12683 0 0 Mshowa
[(-11)] .30952 .12683 0 0 Mshowa
[(2)] .37302 .12683 0 0 Mshowa
[(7)] .43651 .12683 0 0 Mshowa
[(12)] .5 .12683 0 0 Mshowa
[(15)] .56349 .12683 0 0 Mshowa
[(19)] .62698 .12683 0 0 Mshowa
[(14)] .69048 .12683 0 0 Mshowa
[(16)] .75397 .12683 0 0 Mshowa
[(11)] .81746 .12683 0 0 Mshowa
[(6)] .88095 .12683 0 0 Mshowa
[(1)] .94444 .12683 0 0 Mshowa
[(-40)] .11905 .07077 0 0 Mshowa
[(-30)] .18254 .07077 0 0 Mshowa
[(-22)] .24603 .07077 0 0 Mshowa
[(-16)] .30952 .07077 0 0 Mshowa
[(-3)] .37302 .07077 0 0 Mshowa
[(2)] .43651 .07077 0 0 Mshowa
[(7)] .5 .07077 0 0 Mshowa
[(10)] .56349 .07077 0 0 Mshowa
[(15)] .62698 .07077 0 0 Mshowa
[(18)] .69048 .07077 0 0 Mshowa
[(13)] .75397 .07077 0 0 Mshowa
[(17)] .81746 .07077 0 0 Mshowa
[(12)] .88095 .07077 0 0 Mshowa
[(11)] .94444 .07077 0 0 Mshowa
1 g
.008 w
.05556 .01472 Mdot
0 g
.5 Mabswid
[ ] 0 setdash
.16349 .51923 m
.1381 .51923 L
s
% Start of user PostScript
1.7 9. 1.3 9. MAarrowhead1
% End of user PostScript
.22698 .51923 m
.20159 .51923 L
s
% Start of user PostScript
2.7 9. 2.3 9. MAarrowhead1
% End of user PostScript
.29048 .51923 m
.26508 .51923 L
s
% Start of user PostScript
3.7 9. 3.3 9. MAarrowhead1
% End of user PostScript
.35397 .51923 m
.32857 .51923 L
s
% Start of user PostScript
4.7 9. 4.3 9. MAarrowhead1
% End of user PostScript
.41746 .51923 m
.39206 .51923 L
s
% Start of user PostScript
5.7 9. 5.3 9. MAarrowhead1
% End of user PostScript
.48095 .51923 m
.45556 .51923 L
s
% Start of user PostScript
6.7 9. 6.3 9. MAarrowhead1
% End of user PostScript
.54444 .51923 m
.51905 .51923 L
s
% Start of user PostScript
7.7 9. 7.3 9. MAarrowhead1
% End of user PostScript
.60794 .51923 m
.58254 .51923 L
s
% Start of user PostScript
8.7 9. 8.3 9. MAarrowhead1
% End of user PostScript
.67143 .51923 m
.64603 .51923 L
s
% Start of user PostScript
9.7 9. 9.3 9. MAarrowhead1
% End of user PostScript
.73492 .51923 m
.70952 .51923 L
s
% Start of user PostScript
10.7 9. 10.3 9. MAarrowhead1
% End of user PostScript
.79841 .51923 m
.77302 .51923 L
s
% Start of user PostScript
11.7 9. 11.3 9. MAarrowhead1
% End of user PostScript
.8619 .51923 m
.83651 .51923 L
s
% Start of user PostScript
12.7 9. 12.3 9. MAarrowhead1
% End of user PostScript
.9254 .51923 m
.9 .51923 L
s
% Start of user PostScript
13.7 9. 13.3 9. MAarrowhead1
% End of user PostScript
.11905 .47999 m
.11905 .50242 L
s
% Start of user PostScript
1. 8.3 1. 8.7 MAarrowhead1
% End of user PostScript
.16349 .47999 m
.1381 .50242 L
s
% Start of user PostScript
1.7 8.3 1.3 8.7 MAarrowhead1
% End of user PostScript
.22698 .46318 m
.20159 .46318 L
s
% Start of user PostScript
2.7 8. 2.3 8. MAarrowhead1
% End of user PostScript
.29048 .46318 m
.26508 .46318 L
s
% Start of user PostScript
3.7 8. 3.3 8. MAarrowhead1
% End of user PostScript
.35397 .46318 m
.32857 .46318 L
s
% Start of user PostScript
4.7 8. 4.3 8. MAarrowhead1
% End of user PostScript
.41746 .46318 m
.39206 .46318 L
s
% Start of user PostScript
5.7 8. 5.3 8. MAarrowhead1
% End of user PostScript
.48095 .46318 m
.45556 .46318 L
s
% Start of user PostScript
6.7 8. 6.3 8. MAarrowhead1
% End of user PostScript
.54444 .46318 m
.51905 .46318 L
s
% Start of user PostScript
7.7 8. 7.3 8. MAarrowhead1
% End of user PostScript
.60794 .46318 m
.58254 .46318 L
s
% Start of user PostScript
8.7 8. 8.3 8. MAarrowhead1
% End of user PostScript
.67143 .46318 m
.64603 .46318 L
s
% Start of user PostScript
9.7 8. 9.3 8. MAarrowhead1
% End of user PostScript
.73492 .46318 m
.70952 .46318 L
s
% Start of user PostScript
10.7 8. 10.3 8. MAarrowhead1
% End of user PostScript
.79841 .47999 m
.77302 .50242 L
s
% Start of user PostScript
11.7 8.3 11.3 8.7 MAarrowhead1
% End of user PostScript
.8619 .47999 m
.83651 .50242 L
s
% Start of user PostScript
12.7 8.3 12.3 8.7 MAarrowhead1
% End of user PostScript
.9254 .47999 m
.9 .50242 L
s
% Start of user PostScript
13.7 8.3 13.3 8.7 MAarrowhead1
% End of user PostScript
.11905 .42393 m
.11905 .44636 L
s
% Start of user PostScript
1. 7.3 1. 7.7 MAarrowhead1
% End of user PostScript
.18254 .42393 m
.18254 .44636 L
s
% Start of user PostScript
2. 7.3 2. 7.7 MAarrowhead1
% End of user PostScript
.22698 .42393 m
.20159 .44636 L
s
% Start of user PostScript
2.7 7.3 2.3 7.7 MAarrowhead1
% End of user PostScript
.29048 .40712 m
.26508 .40712 L
s
% Start of user PostScript
3.7 7. 3.3 7. MAarrowhead1
% End of user PostScript
.35397 .42393 m
.32857 .44636 L
s
% Start of user PostScript
4.7 7.3 4.3 7.7 MAarrowhead1
% End of user PostScript
.41746 .42393 m
.39206 .44636 L
s
% Start of user PostScript
5.7 7.3 5.3 7.7 MAarrowhead1
% End of user PostScript
.48095 .40712 m
.45556 .40712 L
s
% Start of user PostScript
6.7 7. 6.3 7. MAarrowhead1
% End of user PostScript
.54444 .40712 m
.51905 .40712 L
s
% Start of user PostScript
7.7 7. 7.3 7. MAarrowhead1
% End of user PostScript
.60794 .40712 m
.58254 .40712 L
s
% Start of user PostScript
8.7 7. 8.3 7. MAarrowhead1
% End of user PostScript
.67143 .42393 m
.64603 .44636 L
s
% Start of user PostScript
9.7 7.3 9.3 7.7 MAarrowhead1
% End of user PostScript
.73492 .40712 m
.70952 .40712 L
s
% Start of user PostScript
10.7 7. 10.3 7. MAarrowhead1
% End of user PostScript
.79841 .40712 m
.77302 .40712 L
s
% Start of user PostScript
11.7 7. 11.3 7. MAarrowhead1
% End of user PostScript
.8619 .40712 m
.83651 .40712 L
s
% Start of user PostScript
12.7 7. 12.3 7. MAarrowhead1
% End of user PostScript
.9254 .42393 m
.9 .44636 L
s
% Start of user PostScript
13.7 7.3 13.3 7.7 MAarrowhead1
% End of user PostScript
.11905 .36788 m
.11905 .3903 L
s
% Start of user PostScript
1. 6.3 1. 6.7 MAarrowhead1
% End of user PostScript
.18254 .36788 m
.18254 .3903 L
s
% Start of user PostScript
2. 6.3 2. 6.7 MAarrowhead1
% End of user PostScript
.22698 .36788 m
.20159 .3903 L
s
% Start of user PostScript
2.7 6.3 2.3 6.7 MAarrowhead1
% End of user PostScript
.29048 .36788 m
.26508 .3903 L
s
% Start of user PostScript
3.7 6.3 3.3 6.7 MAarrowhead1
% End of user PostScript
.35397 .35106 m
.32857 .35106 L
s
% Start of user PostScript
4.7 6. 4.3 6. MAarrowhead1
% End of user PostScript
.41746 .35106 m
.39206 .35106 L
s
% Start of user PostScript
5.7 6. 5.3 6. MAarrowhead1
% End of user PostScript
.48095 .35106 m
.45556 .35106 L
s
% Start of user PostScript
6.7 6. 6.3 6. MAarrowhead1
% End of user PostScript
.54444 .35106 m
.51905 .35106 L
s
% Start of user PostScript
7.7 6. 7.3 6. MAarrowhead1
% End of user PostScript
.60794 .35106 m
.58254 .35106 L
s
% Start of user PostScript
8.7 6. 8.3 6. MAarrowhead1
% End of user PostScript
.67143 .35106 m
.64603 .35106 L
s
% Start of user PostScript
9.7 6. 9.3 6. MAarrowhead1
% End of user PostScript
.73492 .35106 m
.70952 .35106 L
s
% Start of user PostScript
10.7 6. 10.3 6. MAarrowhead1
% End of user PostScript
.79841 .35106 m
.77302 .35106 L
s
% Start of user PostScript
11.7 6. 11.3 6. MAarrowhead1
% End of user PostScript
.8619 .35106 m
.83651 .35106 L
s
% Start of user PostScript
12.7 6. 12.3 6. MAarrowhead1
% End of user PostScript
.9254 .35106 m
.9 .35106 L
s
% Start of user PostScript
13.7 6. 13.3 6. MAarrowhead1
% End of user PostScript
.11905 .31182 m
.11905 .33424 L
s
% Start of user PostScript
1. 5.3 1. 5.7 MAarrowhead1
% End of user PostScript
.18254 .31182 m
.18254 .33424 L
s
% Start of user PostScript
2. 5.3 2. 5.7 MAarrowhead1
% End of user PostScript
.24603 .31182 m
.24603 .33424 L
s
% Start of user PostScript
3. 5.3 3. 5.7 MAarrowhead1
% End of user PostScript
.30952 .31182 m
.30952 .33424 L
s
% Start of user PostScript
4. 5.3 4. 5.7 MAarrowhead1
% End of user PostScript
.35397 .31182 m
.32857 .33424 L
s
% Start of user PostScript
4.7 5.3 4.3 5.7 MAarrowhead1
% End of user PostScript
.41746 .295 m
.39206 .295 L
s
% Start of user PostScript
5.7 5. 5.3 5. MAarrowhead1
% End of user PostScript
.48095 .295 m
.45556 .295 L
s
% Start of user PostScript
6.7 5. 6.3 5. MAarrowhead1
% End of user PostScript
.54444 .295 m
.51905 .295 L
s
% Start of user PostScript
7.7 5. 7.3 5. MAarrowhead1
% End of user PostScript
.60794 .295 m
.58254 .295 L
s
% Start of user PostScript
8.7 5. 8.3 5. MAarrowhead1
% End of user PostScript
.67143 .295 m
.64603 .295 L
s
% Start of user PostScript
9.7 5. 9.3 5. MAarrowhead1
% End of user PostScript
.73492 .31182 m
.70952 .33424 L
s
% Start of user PostScript
10.7 5.3 10.3 5.7 MAarrowhead1
% End of user PostScript
.79841 .295 m
.77302 .295 L
s
% Start of user PostScript
11.7 5. 11.3 5. MAarrowhead1
% End of user PostScript
.8619 .295 m
.83651 .295 L
s
% Start of user PostScript
12.7 5. 12.3 5. MAarrowhead1
% End of user PostScript
.9254 .295 m
.9 .295 L
s
% Start of user PostScript
13.7 5. 13.3 5. MAarrowhead1
% End of user PostScript
.11905 .25576 m
.11905 .27819 L
s
% Start of user PostScript
1. 4.3 1. 4.7 MAarrowhead1
% End of user PostScript
.18254 .25576 m
.18254 .27819 L
s
% Start of user PostScript
2. 4.3 2. 4.7 MAarrowhead1
% End of user PostScript
.24603 .25576 m
.24603 .27819 L
s
% Start of user PostScript
3. 4.3 3. 4.7 MAarrowhead1
% End of user PostScript
.30952 .25576 m
.30952 .27819 L
s
% Start of user PostScript
4. 4.3 4. 4.7 MAarrowhead1
% End of user PostScript
.37302 .25576 m
.37302 .27819 L
s
% Start of user PostScript
5. 4.3 5. 4.7 MAarrowhead1
% End of user PostScript
.41746 .25576 m
.39206 .27819 L
s
% Start of user PostScript
5.7 4.3 5.3 4.7 MAarrowhead1
% End of user PostScript
.48095 .23895 m
.45556 .23895 L
s
% Start of user PostScript
6.7 4. 6.3 4. MAarrowhead1
% End of user PostScript
.54444 .25576 m
.51905 .27819 L
s
% Start of user PostScript
7.7 4.3 7.3 4.7 MAarrowhead1
% End of user PostScript
.60794 .25576 m
.58254 .27819 L
s
% Start of user PostScript
8.7 4.3 8.3 4.7 MAarrowhead1
% End of user PostScript
.67143 .23895 m
.64603 .23895 L
s
% Start of user PostScript
9.7 4. 9.3 4. MAarrowhead1
% End of user PostScript
.73492 .23895 m
.70952 .23895 L
s
% Start of user PostScript
10.7 4. 10.3 4. MAarrowhead1
% End of user PostScript
.79841 .23895 m
.77302 .23895 L
s
% Start of user PostScript
11.7 4. 11.3 4. MAarrowhead1
% End of user PostScript
.8619 .23895 m
.83651 .23895 L
s
% Start of user PostScript
12.7 4. 12.3 4. MAarrowhead1
% End of user PostScript
.9254 .23895 m
.9 .23895 L
s
% Start of user PostScript
13.7 4. 13.3 4. MAarrowhead1
% End of user PostScript
.11905 .1997 m
.11905 .22213 L
s
% Start of user PostScript
1. 3.3 1. 3.7 MAarrowhead1
% End of user PostScript
.18254 .1997 m
.18254 .22213 L
s
% Start of user PostScript
2. 3.3 2. 3.7 MAarrowhead1
% End of user PostScript
.24603 .1997 m
.24603 .22213 L
s
% Start of user PostScript
3. 3.3 3. 3.7 MAarrowhead1
% End of user PostScript
.30952 .1997 m
.30952 .22213 L
s
% Start of user PostScript
4. 3.3 4. 3.7 MAarrowhead1
% End of user PostScript
.37302 .1997 m
.37302 .22213 L
s
% Start of user PostScript
5. 3.3 5. 3.7 MAarrowhead1
% End of user PostScript
.43651 .1997 m
.43651 .22213 L
s
% Start of user PostScript
6. 3.3 6. 3.7 MAarrowhead1
% End of user PostScript
.48095 .1997 m
.45556 .22213 L
s
% Start of user PostScript
6.7 3.3 6.3 3.7 MAarrowhead1
% End of user PostScript
.54444 .1997 m
.51905 .22213 L
s
% Start of user PostScript
7.7 3.3 7.3 3.7 MAarrowhead1
% End of user PostScript
.60794 .18289 m
.58254 .18289 L
s
% Start of user PostScript
8.7 3. 8.3 3. MAarrowhead1
% End of user PostScript
.67143 .18289 m
.64603 .18289 L
s
% Start of user PostScript
9.7 3. 9.3 3. MAarrowhead1
% End of user PostScript
.73492 .18289 m
.70952 .18289 L
s
% Start of user PostScript
10.7 3. 10.3 3. MAarrowhead1
% End of user PostScript
.79841 .1997 m
.77302 .22213 L
s
% Start of user PostScript
11.7 3.3 11.3 3.7 MAarrowhead1
% End of user PostScript
.8619 .18289 m
.83651 .18289 L
s
% Start of user PostScript
12.7 3. 12.3 3. MAarrowhead1
% End of user PostScript
.9254 .18289 m
.9 .18289 L
s
% Start of user PostScript
13.7 3. 13.3 3. MAarrowhead1
% End of user PostScript
.11905 .14365 m
.11905 .16607 L
s
% Start of user PostScript
1. 2.3 1. 2.7 MAarrowhead1
% End of user PostScript
.18254 .14365 m
.18254 .16607 L
s
% Start of user PostScript
2. 2.3 2. 2.7 MAarrowhead1
% End of user PostScript
.24603 .14365 m
.24603 .16607 L
s
% Start of user PostScript
3. 2.3 3. 2.7 MAarrowhead1
% End of user PostScript
.30952 .14365 m
.30952 .16607 L
s
% Start of user PostScript
4. 2.3 4. 2.7 MAarrowhead1
% End of user PostScript
.35397 .14365 m
.32857 .16607 L
s
% Start of user PostScript
4.7 2.3 4.3 2.7 MAarrowhead1
% End of user PostScript
.43651 .14365 m
.43651 .16607 L
s
% Start of user PostScript
6. 2.3 6. 2.7 MAarrowhead1
% End of user PostScript
.5 .14365 m
.5 .16607 L
s
% Start of user PostScript
7. 2.3 7. 2.7 MAarrowhead1
% End of user PostScript
.54444 .14365 m
.51905 .16607 L
s
% Start of user PostScript
7.7 2.3 7.3 2.7 MAarrowhead1
% End of user PostScript
.60794 .14365 m
.58254 .16607 L
s
% Start of user PostScript
8.7 2.3 8.3 2.7 MAarrowhead1
% End of user PostScript
.67143 .12683 m
.64603 .12683 L
s
% Start of user PostScript
9.7 2. 9.3 2. MAarrowhead1
% End of user PostScript
.73492 .14365 m
.70952 .16607 L
s
% Start of user PostScript
10.7 2.3 10.3 2.7 MAarrowhead1
% End of user PostScript
.79841 .12683 m
.77302 .12683 L
s
% Start of user PostScript
11.7 2. 11.3 2. MAarrowhead1
% End of user PostScript
.8619 .12683 m
.83651 .12683 L
s
% Start of user PostScript
12.7 2. 12.3 2. MAarrowhead1
% End of user PostScript
.9254 .12683 m
.9 .12683 L
s
% Start of user PostScript
13.7 2. 13.3 2. MAarrowhead1
% End of user PostScript
.11905 .08759 m
.11905 .11001 L
s
% Start of user PostScript
1. 1.3 1. 1.7 MAarrowhead1
% End of user PostScript
.18254 .08759 m
.18254 .11001 L
s
% Start of user PostScript
2. 1.3 2. 1.7 MAarrowhead1
% End of user PostScript
.24603 .08759 m
.24603 .11001 L
s
% Start of user PostScript
3. 1.3 3. 1.7 MAarrowhead1
% End of user PostScript
.30952 .08759 m
.30952 .11001 L
s
% Start of user PostScript
4. 1.3 4. 1.7 MAarrowhead1
% End of user PostScript
.37302 .08759 m
.37302 .11001 L
s
% Start of user PostScript
5. 1.3 5. 1.7 MAarrowhead1
% End of user PostScript
.43651 .08759 m
.43651 .11001 L
s
% Start of user PostScript
6. 1.3 6. 1.7 MAarrowhead1
% End of user PostScript
.48095 .08759 m
.45556 .11001 L
s
% Start of user PostScript
6.7 1.3 6.3 1.7 MAarrowhead1
% End of user PostScript
.54444 .08759 m
.51905 .11001 L
s
% Start of user PostScript
7.7 1.3 7.3 1.7 MAarrowhead1
% End of user PostScript
.60794 .08759 m
.58254 .11001 L
s
% Start of user PostScript
8.7 1.3 8.3 1.7 MAarrowhead1
% End of user PostScript
.67143 .08759 m
.64603 .11001 L
s
% Start of user PostScript
9.7 1.3 9.3 1.7 MAarrowhead1
% End of user PostScript
.73492 .07077 m
.70952 .07077 L
s
% Start of user PostScript
10.7 1. 10.3 1. MAarrowhead1
% End of user PostScript
.79841 .08759 m
.77302 .11001 L
s
% Start of user PostScript
11.7 1.3 11.3 1.7 MAarrowhead1
% End of user PostScript
.8619 .07077 m
.83651 .07077 L
s
% Start of user PostScript
12.7 1. 12.3 1. MAarrowhead1
% End of user PostScript
.9254 .08759 m
.9 .11001 L
s
% Start of user PostScript
13.7 1.3 13.3 1.7 MAarrowhead1
% End of user PostScript
.6 g
3 Mabswid
.9254 .08759 m
.9 .11001 L
s
% Start of user PostScript
13.7 1.3 13.3 1.7 MAarrowhead2
% End of user PostScript
.8619 .12683 m
.83651 .12683 L
s
% Start of user PostScript
12.7 2. 12.3 2. MAarrowhead2
% End of user PostScript
.79841 .12683 m
.77302 .12683 L
s
% Start of user PostScript
11.7 2. 11.3 2. MAarrowhead2
% End of user PostScript
.73492 .14365 m
.70952 .16607 L
s
% Start of user PostScript
10.7 2.3 10.3 2.7 MAarrowhead2
% End of user PostScript
.67143 .18289 m
.64603 .18289 L
s
% Start of user PostScript
9.7 3. 9.3 3. MAarrowhead2
% End of user PostScript
.60794 .18289 m
.58254 .18289 L
s
% Start of user PostScript
8.7 3. 8.3 3. MAarrowhead2
% End of user PostScript
.54444 .1997 m
.51905 .22213 L
s
% Start of user PostScript
7.7 3.3 7.3 3.7 MAarrowhead2
% End of user PostScript
.48095 .23895 m
.45556 .23895 L
s
% Start of user PostScript
6.7 4. 6.3 4. MAarrowhead2
% End of user PostScript
.41746 .25576 m
.39206 .27819 L
s
% Start of user PostScript
5.7 4.3 5.3 4.7 MAarrowhead2
% End of user PostScript
.35397 .31182 m
.32857 .33424 L
s
% Start of user PostScript
4.7 5.3 4.3 5.7 MAarrowhead2
% End of user PostScript
.29048 .36788 m
.26508 .3903 L
s
% Start of user PostScript
3.7 6.3 3.3 6.7 MAarrowhead2
% End of user PostScript
.22698 .42393 m
.20159 .44636 L
s
% Start of user PostScript
2.7 7.3 2.3 7.7 MAarrowhead2
% End of user PostScript
.16349 .47999 m
.1381 .50242 L
s
% Start of user PostScript
1.7 8.3 1.3 8.7 MAarrowhead2
% End of user PostScript
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`00
1`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
o`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1`3Vi^H3000000P0i^KV
2@3oool300000080oooo0P00000:0?ooo`800000103oool2000000T0oooo100000020?ooo`@00000
203oool5000000040?ooo`0000000000000000h0oooo0P00000<0?ooo`@00000403oool00`000000
oooo0?ooo`0:0?ooo`D000000P3oool2000000T0oooo1@0000020?ooo`8000002P3oool500000080
oooo0P0000090?ooo`D000000P3oool2000000T0oooo1@0000030?ooo`030000003oool0oooo00L0
oooo1@0000000`3oool0000000000002000000P0oooo1@0000000`3oool0000000000003000000`0
oooo00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H:0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00070?ooo`P0i^KV
00<000000>KViP3Vi^H01`3Vi^H70?ooo`D0000000D0oooo0000003oool0oooo0000000:0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`T000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo00000008000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo
00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H00`3oool000000000000200000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`@000001@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00@00000103oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo0?ooo`@00000103oool010000000oooo0?ooo`3oool3000000L0oooo1000
00050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0;0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo0P00000<0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00
1`3oool60>KViP050000003Vi^H000000>KViP0000001`3Vi^H80?ooo`030000003oool000000080
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000;0?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0<0?ooo`001`3oool60>KViPD000001`3Vi^H90?ooo`8000000`3oool2000000X0oooo0P000004
0?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`800000103oool3000000d0oooo0P00000=
0?ooo`8000003`3oool4000000`0oooo0P0000040?ooo`8000002P3oool2000000@0oooo0`00000:
0?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000002P3oool2000000<0oooo10000009
0?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000003P3oool000L0oooo4P3Vi^K_0?oo
o`<0VIVI5@3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0803oool509VIVA@0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0200oooo102IVITF0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0P00000@0?ooo`8000004@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803o
ool409VIVAL0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo0P00000@0?ooo`8000008P3oool200000200oooo00<0VIVI0?ooo`2IVIT00`2IVITH
0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?oo
o`030000003oool000000100oooo0P00000R0?ooo`8000008P3oool509VIVAT0oooo00070?oooa80
i^KV203oool3000000l0oooo0`00000@0?ooo`800000403oool200000100oooo0P00000@0?ooo`80
0000103oool3000000l0oooo0`00000@0?ooo`800000403oool200000280oooo0P00000S0?ooo`@0
VIVI6P3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`<000003`3oool4000000l0oooo0`00000?0?ooo`<00000
8@3oool300000200oooo1@2IVITK0?ooo`001`3ooolB0>KVi^P0oooo0`2IVITL0?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo1P3Vi^H3000000030>KViP000000000000H0i^KV203oool20000
00@0oooo0P0000090?ooo`@000000`3oool2000000T0oooo1@0000030?ooo`030000003oool0oooo
00L0oooo1@0000000`3oool0000000000003000000P0oooo1000000@0?ooo`030000003oool0oooo
00X0oooo1@0000000`3oool0000000000002000000P0oooo1@0000020?ooo`8000002@3oool50000
00040?ooo`0000000000000000X0oooo1@0000030?ooo`<000001`3oool5000000040?ooo`000000
0000000000<0oooo00<0VIVI0?ooo`3oool00`3oool5000000030?ooo`000000000000<0000000<0
oooo09VIV@3oool01`3oool3000000l0oooo1@00000?0?ooo`001`3oool70>KViP040000003Vi^H0
i^KV000000L0i^KV1`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo
0?ooo`0000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`X0
VIVI00<0oooo0000003oool0103oool00`000000VIVI09VIV@0909VIV@050?ooo`000000oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00070?ooo`L0
i^KV00@000000>KViP3Vi^H000001`3Vi^H90?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000000000001P0000020?oo
o`040000003oool0oooo0?ooo`D000002@3oool01@000000oooo0?ooo`3oool000000080oooo2P2I
VIT00`3oool000000?ooo`040?ooo`030000002IVIT0VIVI00T0VIVI00D0oooo0000003oool0oooo
000000040?ooo`P00000103oool00`000000oooo0?ooo`0?0?ooo`001`3oool70>KViP@000001`3V
i^H00`3oool0000000000002000000D0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`@00000
103oool00`000000oooo0?ooo`020?ooo`8000000`3oool4000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000/0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000P0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0`00
000:09VIV@030?ooo`000000oooo00@0oooo00<0000009VIV@2IVIT02@2IVIT0103oool000000000
000000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool000L0oooo1`3V
i^H010000000i^KV0>KViP0000070>KViPL0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00l0oooo00070?ooo`H0i^KV0P000000103Vi^H000000000000000060>KViPP0oooo0P0000040?oo
o`<000002@3oool2000000@0oooo0`0000090?ooo`8000000`3oool4000000T0oooo0P0000040?oo
o`8000002`3oool2000000l0oooo1000000<0?ooo`800000103oool2000000X0oooo0P0000040?oo
o`<000002@3oool2000000@0oooo0`00000:0?ooo`8000001@3oool2000000T0oooo0P0000040?oo
o`<000002@3oool2000000@0oooo0P00000=0?ooo`<000003`3oool200000140oooo00070?oooa80
i^KV^03oool309VIVD`0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool07`3oool509VIVD/0oooo00070?oooa80i^KV2@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07`3o
ool409VIVDd0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`8000004@3oool0
0`000000oooo0?ooo`0O0?ooo`@0VIVICP3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00H0oooo0P00000J0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0?0?ooo`8000007`3oool00`2IVIT0oooo09VIV@0309VIVDl0oooo00070?oooa80
i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`040?ooo`800000703oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000Q0?ooo`D0
VIVID03oool000L0oooo4P3Vi^H80?ooo`<000003`3oool300000100oooo0P00000@0?ooo`800000
103oool2000001`0oooo0P00000@0?ooo`<000000`3oool300000100oooo0P00000R0?ooo`@0VIVI
D@3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo0`00000L0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool4000000l0oooo0`00000O0?ooo`H0VIVID@3o
ool000L0oooo4P3Vi^Ja0?ooo`<0VIVID`3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?ooo`P0
i^KV0P0000080>KViPP0oooo0P0000040?ooo`8000002@3oool4000000<0oooo0P0000090?ooo`D0
000000<0oooo0000000000000P00000;0?ooo`<000003`3oool00`000000oooo0?ooo`0:0?ooo`D0
000000<0oooo0000000000000P0000080?ooo`D000000`3oool00`000000oooo0?ooo`070?ooo`D0
00000P3oool2000000<0oooo00<0VIVI0?ooo`3oool00`3oool500000080oooo0P0000030?ooo`03
09VIV@3oool0oooo00P0oooo0P00000@0?ooo`8000004P3oool400000100oooo00<000000?ooo`3o
ool02P3oool5000000030?ooo`0000000000008000002P3oool000L0oooo1`3Vi^H010000000i^KV
0>KViP0000070>KViPL0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?oo
o`3oool0000000h0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0<0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000002IVIT0VIVI00P0VIVI00D00000
0?ooo`3oool0oooo000000020?ooo`030000002IVIT0VIVI00P0VIVI0P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000004@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`050000003oool0oooo0?ooo`0000003@3oool000L0oooo1`3Vi^H00`000000i^KV000000020000
00H0i^KV2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
VIVI09VIV@0809VIV@030000003oool0oooo00<0oooo00<000000?ooo`2IVIT02@2IVIT20?ooo`04
0000003oool0oooo000000<0oooo200000050?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool02@0000070?ooo`030000003oool0oooo00P00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00070?ooo`L0i^KV00<000000>KViP3Vi^H0203Vi^H00`3oool0
000000000002000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo100000020?ooo`<00000403oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`2IVIT0VIVI00P0VIVI00<000000?ooo`3oool0103oool00`000000VIVI09VIV@08
09VIV@<0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool4
000000@0oooo00<000000?ooo`3oool00P0000050?ooo`@000001@3oool010000000oooo0?ooo`00
00020?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo0007
0?ooo`L0i^KV00<000000>KViP3Vi^H0203Vi^H70?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool010000000oooo0?ooo`00000=0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000004@3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo000000d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00P0oooo00070?ooo`P0i^KV0`0000070>KViPP0oooo0P0000040?ooo`8000002P3oool20000
00@0oooo0P00000:0?ooo`800000103oool2000000d0oooo0`00000<0?ooo`@00000303oool20000
00@0oooo0P00000:0?ooo`8000000`3oool4000000T0oooo0P0000040?ooo`8000002P3oool20000
00@0oooo0P00000>0?ooo`800000403oool2000001<0oooo0P00000?0?ooo`@00000303oool20000
00@0oooo0P00000;0?ooo`001`3ooolB0>KViX80oooo0`2IVIV20?ooo`001`3ooolB0>KViPT0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03@3oool409VIVDH0oooo00<000000?ooo`3oool0>@3oool000L0oooo4P3V
i^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00d0oooo1@2IVIU50?ooo`030000003oool0oooo03X0oooo0007
0?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool01`3oool2000000h0oooo1@2IVIU60?ooo`030000003oool0oooo03/0oooo00070?oo
oa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`H0VIVIA@3oool2000003h0oooo00070?oooa80
i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000?0?ooo`D0VIVIA03oool200000400oooo00070?oooa80i^KV
203oool3000000l0oooo0`00000@0?ooo`800000403oool200000100oooo0P00000@0?ooo`800000
103oool3000000h0oooo1@2IVIU50?ooo`800000@@3oool000L0oooo4P3Vi^H90?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`<000003P3o
ool509VIVDD0oooo0`0000100?ooo`001`3ooolB0>KViWX0oooo0`2IVIV:0?ooo`001`3ooolB0>KV
i_l0oooo203oool000L0oooo1P3Vi^H3000000030>KViP000000i^KV00H0i^KV1`3oool4000000<0
oooo0P0000090?ooo`D000000P3oool2000000h0oooo00<000000?ooo`3oool03@3oool5000000P0
oooo1@0000000`3oool0000000000002000000P0oooo1@0000030?ooo`030000003oool0oooo00L0
oooo1@0000000`3oool0000000000002000000d0oooo00<000000?ooo`3oool03P3oool200000140
oooo0P00000B0?ooo`@00000403oool00`000000oooo0?ooo`0:0?ooo`D0000000<0oooo00000000
00000P0000080?ooo`D000000`3oool00`000000oooo0?ooo`090?ooo`001`3oool70>KViP040000
003Vi^H00000000000L0i^KV1`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003@3o
ool00`000000oooo0?ooo`030?ooo`030000002IVIT0VIVI00T0VIVI00D000000?ooo`3oool0oooo
0000000@0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool000L0oooo1`3Vi^H010000000i^KV00000000
00070>KViPP0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00<0000009VIV@2IVIT02@2IVIT00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`P00000
1@3oool00`000000oooo0?ooo`020?ooo`P000001`3oool00`000000oooo0?ooo`08000000P0oooo
00<000000?ooo`000000200000040?ooo`030000003oool0oooo0080oooo2@0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000L0oooo1`3Vi^H2000000030>KViP00
0000i^KV00H0i^KV00<0oooo0000000000000P0000040?ooo`030000003oool0oooo0080oooo0P00
00030?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`8000001P3oool4000000D0oooo00<0
00000?ooo`3oool01P3oool4000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool;09VIV@030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`8000001P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool4000000@0oooo00<000000?ooo`3oool00P0000050?ooo`@000001@3oool010000000oooo0000
000000020?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool4000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`001`3oool70>KViP80000000<0
i^KV0000003Vi^H01P3Vi^H70?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0
0000403oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000A0?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool000L0oooo1P3Vi^H2000000040>KViP0000000000000000H0
i^KV203oool2000000@0oooo0`0000090?ooo`800000103oool3000000/0oooo1000000?0?ooo`80
00002`3oool2000000@0oooo0P00000:0?ooo`8000000`3oool4000000T0oooo0P0000040?ooo`80
0000303oool4000000l0oooo0P00000A0?ooo`8000004`3oool2000000l0oooo1000000<0?ooo`80
0000103oool2000000X0oooo0P0000030?ooo`@000002P3oool000L0oooo4P3Vi^IM0?ooo`<0VIVI
Y`3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3o
ool509VIVB80oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1_0?ooo`001`3ooolB
0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`@0VIVI8`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0700oooo00070?oooa80i^KV2@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo102IVITR0?ooo`8000004@3oool00`00
0000oooo0?ooo`1a0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`@0VIVI8P3oool00`000000oooo0?ooo`0?0?ooo`800000M03oool000L0oooo
4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool509VIVB00oooo
00<000000?ooo`0000003`3oool00`000000oooo0000001f0?ooo`001`3ooolB0>KViPP0oooo0`00
000?0?ooo`<00000403oool200000100oooo0P00000@0?ooo`800000103oool409VIVB00oooo0`00
000@0?ooo`800000M`3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01P2IVITP0?ooo`@000003`3oool3000007H0oooo00070?oooa80i^KVEP3oool309VI
VJh0oooo00070?oooa80i^KVo`3oool80?ooo`001`3oool60>KViP<0000000<0i^KV000000000000
1P3Vi^H70?ooo`@000000`3oool2000000T0oooo1@0000020?ooo`800000303oool4000000d0oooo
0`00000;0?ooo`D000000`3oool00`000000oooo0?ooo`070?ooo`D0000000<0oooo000000000000
0P00000=0?ooo`030000003oool0oooo00d0oooo1000000B0?ooo`8000004@3oool2000000`0oooo
1@0000020?ooo`8000002@3oool500000080oooo0P0000090?ooo`@000000`3oool2000000T0oooo
100000030?ooo`8000002`3oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000X0oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H80?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`D000003@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000L000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T00000103oool00`000000oooo0?ooo`020?ooo`T000000`3oool00`00
0000oooo0?ooo`040?ooo`P000001`3oool00`000000oooo0?ooo`08000000H0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`020?ooo`P000001@3oool010000000oooo0?ooo`3o
ool:000000<0oooo00<000000?ooo`3oool0103oool8000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000:0?ooo`001`3oool70>KViP@000001`3Vi^H00`3oool000000000
0002000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool4000000@0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo008000002`3oool00`000000oooo0?ooo`020?ooo`8000002P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo100000050?ooo`040000003oool0oooo000000H0oooo1000
00030?ooo`8000001P3oool4000000@0oooo00<000000?ooo`3oool00`3oool200000080oooo1000
00040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@00000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@00000103oool00`000000oooo0?ooo`020?ooo`8000002`3o
ool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`0000003P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo00000140oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00
000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000X0oooo00070?ooo`H0i^KV0P000000103Vi^H000000000000000060>KViPP0oooo
0P0000040?ooo`8000002P3oool2000000@0oooo0P00000=0?ooo`8000003P3oool2000000d0oooo
0P0000030?ooo`@000002@3oool2000000@0oooo0P00000<0?ooo`@000003`3oool2000001<0oooo
0P00000A0?ooo`8000003@3oool2000000@0oooo0P00000:0?ooo`800000103oool2000000X0oooo
0P0000040?ooo`8000002P3oool2000000@0oooo0P00000;0?ooo`001`3ooolB0>KViT/0oooo0`2I
VIVi0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool509VIVFX0oooo00<00000
0?ooo`3oool0B`3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo102IVIU[0?oo
o`030000003oool0oooo04`0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`@0
VIVIJ`3oool00`000000oooo0?ooo`1=0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool409VIVFX0oooo0P00001@0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3o
ool509VIVFT0oooo0P00001B0?ooo`001`3ooolB0>KViPP0oooo0`00000?0?ooo`<00000403oool2
00000100oooo0P0000040?ooo`@0VIVIJ@3oool2000005<0oooo00070?oooa80i^KV2@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`3oool609VIVFT0oooo0`00001B0?ooo`001`3ooolB0>KViT@0oooo0`2IVIW00?oo
o`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^H70?ooo`D000000P3oool2000000d0oooo
0P00000=0?ooo`8000003`3oool300000180oooo0`00000@0?ooo`D000003@3oool3000000`0oooo
1@0000000`3oool0000000000003000000L0oooo1@000000103oool0000000000000000:0?ooo`@0
00000P3oool5000000L0oooo100000020?ooo`<000002P3oool2000000<0oooo1@0000080?ooo`80
00000`3oool3000000/0oooo0`0000000`3oool0000000000003000000T0oooo00070?ooo`L0i^KV
0`0000080>KViPT0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`8000002P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo0P0000080?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H90?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo0`00
00040?ooo`P000000`3oool500000080oooo200000080?ooo`030000003oool0000000P000001@3o
ool00`000000oooo0?ooo`0:000000@0oooo00<000000?ooo`3oool00`3oool8000000@0oooo00H0
00000?ooo`3oool0oooo0000003oool8000000@0oooo00<000000?ooo`3oool00`3oool8000000@0
oooo00<000000?ooo`3oool00P3oool9000000D0oooo00<000000?ooo`3oool00P3oool9000000@0
oooo00H000000?ooo`3oool0oooo0000003oool800000080oooo1@0000030?ooo`030000003oool0
oooo00T0oooo00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H00`3oool00000000000020000
00@0oooo00<000000?ooo`3oool00P3oool2000000H0oooo100000030?ooo`8000003`3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000040?ooo`8000001@3oool4000000@0oooo00<000000?ooo`3oool00P00
00050?ooo`@000000P3oool300000080oooo0P0000020?ooo`@00000103oool00`000000oooo0?oo
o`030?ooo`8000000P3oool4000000@0oooo00@000000?ooo`3oool0oooo100000030?ooo`@00000
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`@00000103oool010000000
oooo0?ooo`3oool400000080oooo100000050?ooo`030000003oool0oooo0080oooo0P0000020?oo
o`@000001@3oool00`000000oooo0?ooo`0400000080oooo100000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool02@3oool000L0oooo203Vi^H2000000P0i^KV2@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000>0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`0000004`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`090?ooo`001`3oool80>KViP040000003Vi^H0i^KV
000000H0i^KV203oool2000000@0oooo0`00000<0?ooo`<00000303oool200000100oooo0`00000A
0?ooo`8000004P3oool200000100oooo0`00000<0?ooo`800000103oool2000000X0oooo0P000004
0?ooo`<000002P3oool2000000@0oooo0P00000:0?ooo`800000103oool3000000T0oooo0P000004
0?ooo`8000002P3oool2000000@0oooo0`00000:0?ooo`8000000`3oool2000000/0oooo00070?oo
o`L0i^KV1@0000060>KViST0oooo0`2IVIW;0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo1@2IVIW:0?ooo`00
1`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00d0oooo102IVIW<0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo102IVIW=0?ooo`001`3ooolB
0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`8000003`3oool4
09VIVLh0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000003`3oool509VIVLl0oooo00070?oooa80i^KV203oool3000000l0
oooo0`0000040?ooo`800000403oool409VIVM00oooo00070?oooa80i^KV2@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00<0oooo0`00000=0?ooo`D0VIVId@3oool000L0oooo4P3V
i^Hb0?ooo`<0VIVIdP3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV1`3oool50000
0080oooo0P00000:0?ooo`800000403oool200000180oooo1000000@0?ooo`8000003`3oool30000
00`0oooo1@0000030?ooo`<000001`3oool5000000040?ooo`0000000000000000T0oooo10000004
0?ooo`<00000203oool4000000<0oooo0P00000:0?ooo`800000103oool2000000X0oooo0P000004
0?ooo`8000002`3oool300000080oooo0P00000;0?ooo`<000000`3oool00`000000oooo0?ooo`09
0?ooo`001`3oool60>KViPD000001`3Vi^H90?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
0000403oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`040000003oool00000
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV2@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000@0?ooo`030000
003oool0oooo00<0oooo200000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
3@3oool<000000@0oooo00@000000?ooo`3oool0oooo2P0000040?ooo`030000003oool0oooo0080
oooo2@0000030?ooo`030000003oool0oooo0080oooo1@0000090?ooo`030000003oool0oooo0080
oooo2@0000050?ooo`030000003oool0oooo0080oooo200000050?ooo`040000003oool0oooo0?oo
o`X000000P3oool5000000<0oooo00<000000?ooo`3oool01`3oool5000000<0oooo00<000000?oo
o`3oool02@3oool000L0oooo1`3Vi^H00`000000i^KV0>KViP080>KViP030?ooo`00000000000080
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`00000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool4
000000@0oooo00<000000?ooo`3oool0203oool4000000<0oooo0P0000090?ooo`@000000P3oool0
1@000000oooo0?ooo`000000oooo008000000P3oool4000000@0oooo00H000000?ooo`3oool0oooo
0000003oool200000080oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`04000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`8000000`3oool4000000D0oooo00<0
00000?ooo`3oool00P3oool200000080oooo100000050?ooo`040000003oool0oooo0?ooo`<00000
0P3oool400000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0400000080
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`001`3oool70>KViP80
00002@3Vi^H90?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000004@3oool010000000oooo0?oo
o`00000@0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000003@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000009
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo000000020?ooo`040000003oool0oooo000000X0oooo00070?ooo`L0i^KV
00@000000>KViP3Vi^H000001`3Vi^H80?ooo`800000103oool2000000X0oooo0P00000@0?ooo`80
00004`3oool200000140oooo0`00000?0?ooo`<00000303oool2000000D0oooo0P0000090?ooo`80
0000103oool3000000T0oooo0P0000050?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`80
0000103oool2000000X0oooo0P0000040?ooo`8000002`3oool2000000<0oooo0P00000;0?ooo`80
00000P3oool4000000X0oooo00070?ooo`H0i^KV1@0000070>KViRL0oooo0`2IVIWM0?ooo`001`3o
oolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`D0VIVI8@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0D0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`070?ooo`@0VIVI8P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0E0?ooo`001`3ooolB0>KV
iPT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`@0VIVI8P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0F0?ooo`001`3ooolB0>KViPT0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`050?ooo`@0VIVI8@3oool200000100oooo0P0000170?ooo`800000A`3oool2000001T0
oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo
1@2IVITP0?ooo`800000403oool2000004L0oooo0P0000160?ooo`030000003oool0000001/0oooo
00070?oooa80i^KV203oool3000000l0oooo0`0000040?ooo`@0VIVI803oool200000100oooo0P00
00170?ooo`800000A`3oool2000001`0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`0?
0?ooo`040000003oool0oooo0?ooo`D0VIVI8@3oool3000000l0oooo0`0000160?ooo`<00000AP3o
ool3000001/0oooo00070?oooa80i^KV803oool409VIVN<0oooo00070?oooa80i^KVo`3oool80?oo
o`001`3ooolB0>KViP/0oooo0P00000=0?ooo`800000403oool2000001<0oooo0P00000=0?ooo`D0
00000P3oool2000000T0oooo1@0000020?ooo`8000002@3oool4000000<0oooo0P0000090?ooo`@0
00000`3oool2000000X0oooo0P0000040?ooo`8000002`3oool2000000@0oooo0P00000;0?ooo`<0
00000P3oool2000000/0oooo0`0000020?ooo`8000002`3oool3000000040?ooo`00000000000000
00/0oooo0`000000103oool0000000000000000;0?ooo`001`3oool60>KViP<0000000<0i^KV0000
000000001P3Vi^H:0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000T0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo00000000000;0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0203oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPd0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`P000000P3oool010000000oooo0?ooo`00
00040?ooo`P00000203oool00`000000oooo00000007000000D0oooo00@000000?ooo`3oool0oooo
2@0000050?ooo`030000003oool0oooo0080oooo2@0000030?ooo`030000003oool0oooo0080oooo
2P0000030?ooo`030000003oool0oooo00@0oooo200000040?ooo`060000003oool0oooo0?ooo`00
0000oooo200000050?ooo`030000003oool0oooo0080oooo200000030?ooo`D0000000D0oooo0000
003oool0oooo000000080?ooo`D00000103oool00`000000oooo0?ooo`060?ooo`D0000000D0oooo
0000003oool0oooo000000080?ooo`D0000000D0oooo0000003oool0oooo0000000:0?ooo`001`3o
ool70>KViP<00000203Vi^H40?ooo`@000000`3oool2000000d0oooo0P0000060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`@00000
0`3oool2000000<0oooo00@000000?ooo`3oool0oooo100000040?ooo`060000003oool0oooo0?oo
o`000000oooo0P0000020?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`<000000P3oool4
000000@0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo100000040?ooo`030000
003oool0oooo0080oooo0`0000020?ooo`@000001@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo0?ooo`@000001@3oool010000000oooo0?ooo`3oool2000000<0oooo10000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool400000080oooo
00@000000?ooo`3oool000000`3oool2000000<0oooo100000020?ooo`040000003oool0oooo0000
0080oooo0`0000030?ooo`@000000P3oool010000000oooo0?ooo`0000020?ooo`<000002`3oool0
00L0oooo1`3Vi^H00`000000i^KV000000080>KViP/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0>0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000T0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool02P3oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViP/0oooo0`00000<0?ooo`<0
00003`3oool2000001<0oooo0`00000=0?ooo`800000103oool2000000X0oooo0P0000040?ooo`<0
00002@3oool2000000@0oooo0P00000:0?ooo`800000103oool3000000T0oooo0P0000040?ooo`80
00002`3oool2000000@0oooo0`00000:0?ooo`8000000`3oool2000000/0oooo0P0000030?ooo`<0
00002P3oool2000000<0oooo0`00000:0?ooo`8000000`3oool3000000X0oooo00070?ooo`H0i^KV
0`0000000`3Vi^H00000000000060>KViQD0oooo0`2IVIW_0?ooo`001`3ooolB0>KViPT0oooo00<0
00000?ooo`3oool0203oool409VIVK<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01@0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`07
0?ooo`D0VIVI/P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool05@3oool000L0oooo4P3Vi^H90?ooo`030000003oool0oooo00D0oooo1@2IVIVc0?oo
o`030000003oool0oooo00l0oooo0P00000A0?ooo`030000003oool0oooo01H0oooo00070?oooa80
i^KV2@3oool00`000000oooo0?ooo`040?ooo`D0VIVI/P3oool200000140oooo00<000000?ooo`3o
ool03`3oool2000001T0oooo00070?oooa80i^KV2@3oool00`000000oooo0?ooo`030?ooo`D0VIVI
/@3oool200000100oooo00<000000?ooo`0000003`3oool00`000000oooo0000000K0?ooo`001`3o
oolB0>KViPP0oooo0`0000020?ooo`D0VIVI/P3oool200000100oooo0`00000@0?ooo`800000703o
ool000L0oooo4P3Vi^H90?ooo`040000003oool0oooo0?ooo`@0VIVI/`3oool3000000l0oooo0`00
000@0?ooo`<000006`3oool000L0oooo4P3Vi^H=0?ooo`D0VIVIm@3oool000L0oooo4P3Vi^Ko0?oo
o`P0oooo00070?oooa80i^KV203oool200000140oooo0`0000020?ooo`8000002`3oool300000080
oooo0P00000;0?ooo`<000000P3oool2000000`0oooo0`0000020?ooo`8000002`3oool300000080
oooo0P00000;0?ooo`<000000P3oool2000000/0oooo0`0000020?ooo`8000002`3oool300000080
oooo0P00000<0?ooo`<000000P3oool2000000/0oooo0`0000020?ooo`8000002`3oool300000080
oooo0P00000;0?ooo`<000000P3oool2000000/0oooo0`0000020?ooo`8000002`3oool000L0oooo
4P3Vi^H70?ooo`040000003oool0oooo00000140oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`001`3ooolB
0>KViPL0oooo00@000000?ooo`3oool000000`3oool900000080oooo1@0000030?ooo`P000000P3o
ool5000000<0oooo200000020?ooo`D000000`3oool8000000<0oooo1@0000020?ooo`P000000`3o
ool500000080oooo2@0000020?ooo`D000000P3oool900000080oooo1@0000030?ooo`P000000P3o
ool5000000<0oooo200000030?ooo`D000000P3oool8000000<0oooo1@0000020?ooo`P000000`3o
ool500000080oooo2@0000020?ooo`D000000`3oool800000080oooo1@0000040?ooo`030000003o
ool0oooo00P0oooo00070?oooa80i^KV1`3oool010000000oooo0?ooo`0000040?ooo`8000000P3o
ool400000080oooo00@000000?ooo`3oool000000`3oool300000080oooo100000020?ooo`040000
003oool0oooo000000<0oooo0`0000020?ooo`@000000P3oool010000000oooo0?ooo`0000030?oo
o`<000000`3oool400000080oooo00@000000?ooo`3oool000000`3oool300000080oooo10000002
0?ooo`040000003oool0oooo000000<0oooo0`0000020?ooo`@000000P3oool010000000oooo0?oo
o`0000030?ooo`<000000P3oool400000080oooo00@000000?ooo`3oool000000`3oool300000080
oooo100000020?ooo`040000003oool0oooo000000<0oooo0`0000030?ooo`@000000P3oool01000
0000oooo0?ooo`0000030?ooo`8000000`3oool400000080oooo00@000000?ooo`3oool000000`3o
ool300000080oooo100000020?ooo`040000003oool0oooo000000<0oooo0`0000020?ooo`@00000
0P3oool010000000oooo0?ooo`0000030?ooo`<000000P3oool400000080oooo00@000000?ooo`3o
ool000000`3oool2000000/0oooo00070?oooa80i^KV1`3oool010000000oooo0?ooo`00000?0?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool02P3oool000L0oooo4P3Vi^H80?ooo`80
00004@3oool2000000<0oooo0`00000:0?ooo`8000000`3oool3000000X0oooo0P0000030?ooo`<0
00002`3oool2000000<0oooo0`00000:0?ooo`8000000`3oool3000000X0oooo0P0000030?ooo`<0
00002P3oool2000000<0oooo0`00000:0?ooo`8000000`3oool3000000/0oooo0P0000030?ooo`<0
00002P3oool2000000<0oooo0`00000:0?ooo`8000000`3oool3000000X0oooo0P0000030?ooo`<0
00002P3oool2000000<0oooo0`00000:0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3V
i^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0
oooo4P3Vi^Ko0?ooo`P0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3o
ool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40
i^KV2@3oool000L0oooo_`3Vi^H2000004l0i^KV2@3oool000L0oooo:P3Vi^H3000000030>KViP00
0000000000h0i^KV0`00000>0>KViP<000003`3Vi^H3000000030>KViP000000000000`0i^KV0`00
00000`3Vi^H000000000000=0>KViP80000000<0i^KV0000000000003P3Vi^H2000000h0i^KV0`00
00000`3Vi^H000000>KViP0?0>KViP8000003P3Vi^H3000000030>KViP000000000000d0i^KV0`00
000>0>KViP<00000403Vi^H3000000P0i^KV2@3oool000L0oooo:`3Vi^H010000000i^KV0>KViP00
000@0>KViP030000003Vi^H0i^KV00h0i^KV00<000000>KViP3Vi^H03`3Vi^H010000000i^KV0>KV
iP00000>0>KViP040000003Vi^H0i^KV000000h0i^KV00D000000>KViP3Vi^H0i^KV0000000=0>KV
iP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP00000000003`3Vi^H010000000i^KV0>KV
iP00000>0>KViP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H000003P3Vi^H00`00
0000i^KV0>KViP0@0>KViP030000003Vi^H0i^KV00L0i^KV2@3oool000L0oooo:`3Vi^H300000140
i^KV00<000000>KViP3Vi^H03P3Vi^H00`000000i^KV0>KViP0?0>KViP040000003Vi^H0i^KV0000
00h0i^KV0`00000@0>KViP<000003P3Vi^H00`000000i^KV00000002000000d0i^KV00@000000>KV
iP00000000003`3Vi^H010000000i^KV0>KViP00000>0>KViP040000003Vi^H0i^KV00000140i^KV
00<000000>KViP3Vi^H0303Vi^H300000100i^KV00<000000>KViP3Vi^H01`3Vi^H90?ooo`001`3o
ool[0>KViP030000003Vi^H000000100i^KV00<000000>KViP0000003`3Vi^H200000100i^KV1000
000>0>KViP030000003Vi^H000000100i^KV00<000000>KViP0000003P3Vi^H00`000000i^KV0>KV
iP0?0>KViP80000000<0i^KV0000003Vi^H03P3Vi^H010000000i^KV0>KViP00000>0>KViP@00000
3`3Vi^H2000000l0i^KV00@000000>KViP3Vi^H000003`3Vi^H00`000000i^KV0>KViP070>KViPT0
oooo00070?ooob/0i^KV00@000000>KViP3Vi^H000003P3Vi^H01@000000i^KV0>KViP3Vi^H00000
00h0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000>0>KViP040000003V
i^H0i^KV00000100i^KV00<000000>KViP3Vi^H03@3Vi^H00`000000i^KV0>KViP0?0>KViP800000
00<0i^KV0000003Vi^H03P3Vi^H010000000i^KV0>KViP00000>0>KViP040000003Vi^H0i^KV0000
00h0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000=0>KViP050000003V
i^H000000>KViP0000001`3Vi^H90?ooo`001`3ooolZ0>KViP<0000000<0i^KV000000000000303V
i^H3000000030>KViP000000000000d0i^KV1@00000=0>KViP80000000@0i^KV0000000000000000
303Vi^H3000000030>KViP000000000000h0i^KV0P00000@0>KViP<000003@3Vi^H2000000040>KV
iP0000000000000000l0i^KV0P00000>0>KViP80000000@0i^KV00000000000000003@3Vi^H40000
00d0i^KV1000000>0>KViPD000001`3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0oooo
o`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.894534, -0.262555, \
0.0550141, 0.0623104}}]
}, Open  ]],

Cell["Das Resultat ist in Abb.3.11 gezeigt.", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[TextData[{
  "Die bisherige Ausgabe war die Visualisierung von Nebenrechnungen des \
Verfahrens. Das entscheidende Ergebnis ist nat\[UDoubleDot]rlich das \
Alignment selbst. Diesem Punkt wollen wir uns jetzt zuwenden, um dann sp\
\[ADoubleDot]ter alle Rechenschritte mit Hilfe des ",
  StyleBox["Module",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls zu einer Routine zusammenzuf\[UDoubleDot]gen, die ausgehend von \
zwei Proteinsequenzen unmittelbar das entsprechende \
Needleman-Wunsch-Alignment ausgibt. Diese Schritte werden in dem folgenden ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs behandelt.\n"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Ausgabe des Alignments und weitere Tests"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Wie wir gesehen haben, \[UDoubleDot]bersetzen sich die Zeigerzust\
\[ADoubleDot]nde entlang des wahrscheinlichsten Pfades direkt in \
Handlungsanweisungen zur Konstruktion des Alignments. So bedeutet ein \
Zeigerzustand von 1 etwa, dass die zwei n\[ADoubleDot]chsten Symbole \
kombiniert werden, die anderen beiden Zust\[ADoubleDot]nde erfordern die \
Kombination eines Symbols mit einem Gap. Wir implementieren diese \
Vorschriften mit Hilfe einer ",
  StyleBox["While",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "-Schleife. Zwei Z\[ADoubleDot]hlvariablen, ",
  StyleBox["count1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " und ",
  StyleBox["count2",
    FontSize->12,
    FontWeight->"Bold"],
  ", geben die aktuelle Position in den beiden Sequenzen an. Die Konstruktion \
erfolgt von hinten nach vorne in den Sequenzen. Dabei werden die Spalten in \
der folgenden Weise aufgebaut: Symbol aus Sequenz 1, Verbindungssymbol (also \
Leerzeichen oder Strich), Symbol aus Sequenz 2. Diese Spalten werden bei \
jedem Schleifendurchlauf in die Funktion ",
  StyleBox["alig",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " geschrieben, die als Argument die dritte Z\[ADoubleDot]hlvariable ",
  StyleBox["j",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " besitzt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(count1 = 0;\)\), "\n", 
    \(\(count2 = 0;\)\), "\n", 
    \(\(j = 0;\)\), "\n", 
    \(While[
      j < Length[path2], {j = j + 1, 
        If[path2[\([j]\)] \[Equal] 1, {count1 = count1 + 1, 
            count2 = count2 + 1, 
            alig[j] = {prot1[\([\(-count1\)]\)], 
                If[prot1[\([\(-count1\)]\)] == 
                    prot2[\([\(-count2\)]\)], "\<|\>", "\< \>"], 
                prot2[\([\(-count2\)]\)]}}, 
          If[path2[\([j]\)] \[Equal] 2, {count1 = count1 + 1, 
              alig[j] = {prot1[\([\(-count1\)]\)], "\< \>", "\<-\>"}}, \
\[IndentingNewLine]If[
              path2[\([j]\)] \[Equal] 3, {count2 = count2 + 1, 
                alig[j] = {"\<-\>", "\< \>", 
                    prot2[\([\(-count2\)]\)]}}]]]\[IndentingNewLine]}]\)}], \
"Input"],

Cell[TextData[{
  "Die Ausgabe erfolgt \[UDoubleDot]ber einen entsprechenden ",
  StyleBox["Table",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl, zusammen mit einer Formatierung \[UDoubleDot]ber den Befehl ",
  StyleBox["TableForm",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", den wir im ersten ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs dieses Kapitels bereits kennen gelernt haben:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(alFull = Table[alig[i], {i, j, 1, \(-1\)}]\)], "Input"],

Cell[BoxData[
    \({{"K", "|", "K"}, {"E", " ", "Y"}, {"F", "|", "F"}, {"H", "|", 
        "H"}, {"N", " ", "K"}, {"-", " ", "A"}, {"G", "|", "G"}, {"-", " ", 
        "N"}, {"-", " ", "Q"}, {"H", "|", "H"}, {"-", " ", "S"}, {"-", " ", 
        "P"}, {"T", "|", "T"}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[alFull] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"N\"\>", "\
\<\"-\"\>", "\<\"G\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\
\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", \
"\<\" \"\>", "\<\"|\"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", "\
\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"Q\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Zusammenfassung aller Befehle in einer ",
  StyleBox["Module",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Umgebung ist im Folgenden angegeben. Man hat dann einen Befehl ",
  StyleBox["alignment",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zur Verf\[UDoubleDot]gung, der vier Argumente besitzt: die beiden \
Sequenzen, die Substitutionsmatrix und den Wert des Gap-Penalty."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(\(xxcoordFun[ref_, seq1_, seq2_, posA_, posB_, mat_] := 
      Module[{tmp1, tmp2, tmp3, tmp4}, \[IndentingNewLine]tmp1 = 
          seq1[\([posA]\)]; \[IndentingNewLine]tmp2 = 
          seq2[\([posB]\)]; \[IndentingNewLine]tmp3 = \(Position[ref, 
              tmp1]\)[\([1, 1]\)]; \[IndentingNewLine]tmp4 = \(Position[ref, 
              tmp2]\)[\([1, 1]\)]; \[IndentingNewLine]mat[\([tmp3, 
            tmp4]\)]]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(alignment[seq1_, seq2_, mat_, del_] := 
      Module[{xxproteinRef, xxFF, xxFFTab, xxtmp1, j, xxFFTabA, xxFFTabB, 
          xxdX, xxtraX, xxpath1, xxpath2, xxcount1, xxcount2, xxalig, 
          xxalFull}, \[IndentingNewLine]xxproteinRef = 
          Characters["\<ARNDCQEGHILKMFPSTWYVBZX*\>"]; \[IndentingNewLine]xxFF[
            0, 0] = {0, 0}; \[IndentingNewLine]xxFF[i_, 0] = {\(-i\)*del, 
            2}; \[IndentingNewLine]xxFF[0, j_] = {\(-j\)*del, 
            3}; \[IndentingNewLine]Do[{xxtmp1 = {\(xxFF[i - 1, 
                      j - 1]\)[\([1]\)] + 
                  xxcoordFun[xxproteinRef, seq1, seq2, i, j, 
                    mat], \[IndentingNewLine]\(xxFF[i - 1, j]\)[\([1]\)] - 
                  del, \(xxFF[i, j - 1]\)[\([1]\)] - del}; 
            xxFF[i, j] = {Max[
                  xxtmp1], \(Position[xxtmp1, Max[xxtmp1]]\)[\([1, 
                    1]\)]}}, {i, 1, Length[seq1]}, {j, 1, 
            Length[seq2]}]; \[IndentingNewLine]xxFFTab = 
          Table[xxFF[i, j], {i, 0, Length[seq1]}, {j, 0, 
              Length[seq2]}]; \[IndentingNewLine]xxFFTabA = 
          xxFFTab /. {n1_, n2_Integer} \[Rule] 
              n1; \[IndentingNewLine]xxFFTabB = 
          xxFFTab /. {n1_, n2_Integer} \[Rule] n2; \[IndentingNewLine]xxdX = 
          Dimensions[xxFFTabB]; \[IndentingNewLine]xxtraX[
            1] = {xxdX[\([1]\)], xxdX[\([2]\)]}; \[IndentingNewLine]j = 
          1; \[IndentingNewLine]While[
          xxFFTabB[\([Sequence @@ xxtraX[j]]\)] =!= 
            0, {xxtraX[j + 1] = 
              xxtraX[j] - 
                Switch[xxFFTabB[\([Sequence @@ xxtraX[j]]\)], 1, {1, 1}, 
                  2, {1, 0}, 3, {0, 1}], 
            j = j + 1}]; \[IndentingNewLine]xxpath1 = 
          Table[xxtraX[k], {k, 1, j - 1}]; \[IndentingNewLine]xxpath2 = 
          Map[xxFFTabB[\([#[\([1]\)], #[\([2]\)]]\)] &, 
            xxpath1]; \[IndentingNewLine]xxcount1 = 
          0; \[IndentingNewLine]xxcount2 = 0; \[IndentingNewLine]j = 
          0; \[IndentingNewLine]While[
          j < Length[xxpath2], {j = j + 1, 
            If[xxpath2[\([j]\)] \[Equal] 1, {xxcount1 = xxcount1 + 1, 
                xxcount2 = xxcount2 + 1, 
                xxalig[j] = {seq1[\([\(-xxcount1\)]\)], 
                    If[seq1[\([\(-xxcount1\)]\)] \[Equal] 
                        seq2[\([\(-xxcount2\)]\)], "\<|\>", "\< \>"], 
                    seq2[\([\(-xxcount2\)]\)]}}, 
              If[xxpath2[\([j]\)] \[Equal] 2, {xxcount1 = xxcount1 + 1, 
                  xxalig[j] = {seq1[\([\(-xxcount1\)]\)], "\< \>", "\<-\>"}}, \
\[IndentingNewLine]If[
                  xxpath2[\([j]\)] \[Equal] 3, {xxcount2 = xxcount2 + 1, 
                    xxalig[j] = {"\<-\>", "\< \>", 
                        seq2[\([\(-xxcount2\)]\)]}}]]]}]; \
\[IndentingNewLine]xxalFull = 
          Table[xxalig[i], {i, j, 1, \(-1\)}]; \[IndentingNewLine]Transpose[
            xxalFull] // TableForm]\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell["\<\
Wir \[UDoubleDot]berpr\[UDoubleDot]fen zuerst, ob sich mit dieser neuen \
Routine das vorangegangene Alignment reproduzieren l\[ADoubleDot]sst:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(alignment[prot1, prot2, blosum, 5]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"N\"\>", "\
\<\"-\"\>", "\<\"G\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\
\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", \
"\<\" \"\>", "\<\"|\"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", "\
\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"Q\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Als erste Anwendung dieser neuen Routine wollen wir die \
Abh\[ADoubleDot]ngigkeit dieses Ergebnisses vom Gap-Penalty n\[ADoubleDot]her \
untersuchen.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(alignment[prot1, prot2, blosum, 0]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"-\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\
\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"-\"\>", "\<\"G\"\>", \
"\<\"H\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"T\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\
\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", \
"\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"-\"\>", "\<\"F\"\>", "\<\"H\"\>", "\
\<\"K\"\>", "\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"Q\"\>", "\<\"-\"\>", \
"\<\"H\"\>", "\<\"S\"\>", "\<\"P\"\>", "\<\"T\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alignment[prot1, prot2, blosum, 1]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"N\"\>", "\
\<\"-\"\>", "\<\"G\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\
\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", \
"\<\" \"\>", "\<\"|\"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", "\
\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"Q\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alignment[prot1, prot2, blosum, 15]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"N\"\>", "\
\<\"-\"\>", "\<\"G\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\
\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", \
"\<\" \"\>", "\<\"|\"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", "\
\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"Q\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Dieses Verhalten in Abh\[ADoubleDot]ngigkeit des Gap-Penalty ist nach unserer \
Diskussion des Needleman-Wunsch-Verfahrens in Kapitel 3.1.2 sicherlich zu \
erwarten. Dennoch illustriert es den wichtigen Befund, dass ein scheinbar \
automatisiertes, algorithmisch gefasstes Verfahren der Bioinformatik je nach \
Parameterwahl ein ganzes Spektrum von Ergebnissen produzieren kann. Es gibt \
also kein eindeutiges bestes Alignment zweier Sequenzen gem\[ADoubleDot]\[SZ] \
diesem Algorithmus, sondern das Resultat ist selbst unter demselben Verfahren \
stets eine Funktion der gew\[ADoubleDot]hlten Parameter. Die Strategie, eine \
solche Parameterabh\[ADoubleDot]ngigkeit in einer bioinformatischen Analyse \
zu kontrollieren, liegt bei Betrachtung dieser Ergebnisse jedoch auf der \
Hand: Offensichtlich \[ADoubleDot]ndert sich in diesem Fall das Alignment \
\[UDoubleDot]ber einen recht gro\[SZ]en Bereich des Gap-Penalty nicht. Wir \
haben also f\[UDoubleDot]r diese beiden Sequenzen ein gegen\[UDoubleDot]ber \
einer Parametervariation relativ robustes Ergebnis vorliegen.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell["\<\
Als n\[ADoubleDot]chsten Schritt wollen wir den Smith-Waterman-Algorithmus in \
\[ADoubleDot]hnlicher Weise implementieren, um ihn \[UDoubleDot]ber die \
formale Diskussion des vorangegangenen Kapitels hinaus kennen zu lernen und \
auch hier zum Beispiel Parameterabh\[ADoubleDot]ngigkeiten zu untersuchen.
\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "lokales Alignment mit dem Smith-Waterman-Verfahren"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Zuerst wollen wir die Rekursionsgleichung der neuen ",
  StyleBox["F",
    FontSlant->"Italic"],
  "-Matrix implementieren. Die Initialisierung erfolgt, wie wir gesehen \
haben, nun nicht mehr \[UDoubleDot]ber den Gap-Penalty, sondern \
\[UDoubleDot]ber einen Rahmen von Nullen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(fWaterman[0, 0] = {0, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(fWaterman[i_, 0] = {0, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(fWaterman[0, j_] = {0, 0};\)\)], "Input"],

Cell[TextData[{
  "F\[UDoubleDot]r unsere erste beispielhafte Darstellung verwenden wir \
denselben Wert des Gap-Penalty (",
  StyleBox["gP=5",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") wie im vorangegangenen ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs. Ebenso verwenden wir dieselbe Scoring-Matrix (abgelegt in der \
Variablen ",
  StyleBox["blosum",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "), dieselben Beispielsequenzen, sowie die Funktion ",
  StyleBox["coordFun",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", die Eintr\[ADoubleDot]ge der Scoring-Matrix extrahiert. \n\nDie \
Rekursion unterscheidet sich von der Needleman-Wunsch-Vorschrift nur in der \
Null, die noch in die Maximumsabfrage eingeht. Man hat:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(Do[{\[IndentingNewLine]tmp1 = {0, \(fWaterman[i - 1, 
                  j - 1]\)[\([1]\)] + 
              coordFun[proteinRef, prot1, prot2, i, j, 
                blosum], \[IndentingNewLine]\(fWaterman[i - 1, 
                  j]\)[\([1]\)] - gP, \(fWaterman[i, j - 1]\)[\([1]\)] - 
              gP}, \[IndentingNewLine]\ 
        fWaterman[i, 
            j] = {Max[tmp1], \(Position[tmp1, Max[tmp1]]\)[\([\(-1\), 1]\)] - 
              1}}, {i, 1, Length[prot1]}, {j, 1, Length[prot2]}]\)], "Input"],

Cell[TextData[{
  "Dabei ist zu beachten, dass wir nun die Position in der Maximumsabfrage \
minus Eins als Zeigerzustand verwenden. Da als erster Eintrag die Null in der \
Liste zum Maximum steht, stellt diese Verschiebung die Konsistenz zu unseren \
vorangegangenen Zeigerzust\[ADoubleDot]nden her. \[CapitalUDoubleDot]ber \
dieselben Darstellungsmechanismen wie zuvor k\[ODoubleDot]nnen wir nun diese \
Matrix abbilden und die entsprechenden Zeigerzust\[ADoubleDot]nde \
einzeichnen. Das Ergebnis bildet das Ger\[UDoubleDot]st von Abb. 3.12. Um als \
N\[ADoubleDot]chstes das lokale Alignment ausgeben zu k\[ODoubleDot]nnen, m\
\[UDoubleDot]ssen wir den Anfangspunkt und die Abbruchbedingung des \
Traceback-Verfahrens implementieren. Der Anfangspunkt ist durch die Position \
des Maximums in der neuen ",
  StyleBox["F",
    FontSlant->"Italic"],
  "-Matrix gegeben. Wie zuvor legen wir die Ergebnisse in Einzeltabellen ab."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(fWatermanTab = 
        Table[fWaterman[i, j], {i, 0, Length[prot1]}, {j, 0, 
            Length[prot2]}];\)\)], "Input"],

Cell[BoxData[
    \(\(\(fWatermanTabA = 
        fWatermanTab /. {n1_, n2_Integer} \[Rule] \ 
            n1\ ;\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(fWatermanTabB = \((fWatermanTab /. {n1_, n2_Integer} \[Rule] \ 
              n2\ )\);\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Die Koordinaten extrahieren wir in bew\[ADoubleDot]hrter Weise \
mit dem Befehl ",
    FontSize->13],
  StyleBox["Position[matrix, Max[matrix]]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[". Ein um diese Struktur gesetzter ",
    FontSize->13],
  StyleBox["Flatten",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["-Befehl beseitigt \[UDoubleDot]berz\[ADoubleDot]hlige Klammern. \
Wir setzen nun die Variable ",
    FontSize->13],
  StyleBox["dX",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[" auf diese Koordinaten und ",
    FontSize->13],
  StyleBox["verwenden von da ab eine vollkommen analoge Befehlsfolge zur \
Pfadrekonstruktion wie im Fall des Needleman-Wunsch-Algorithmus.",
    FontFamily->"Times New Roman",
    FontSize->13]
}], "Text"],

Cell[BoxData[
    \(\(dX = 
        Flatten[Position[fWatermanTabA, Max[fWatermanTabA]]];\)\)], "Input"],

Cell[TextData[{
  "Dieser Anfangspunkt (bzw. Endpunkt) des Pfades wird wie zuvor als erster \
Funktionswert von ",
  StyleBox["traX",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " festgelegt:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(traX[1] = {dX[\([1]\)], dX[\([2]\)]}\)], "Input"],

Cell[BoxData[
    \({8, 9}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Zur weiteren Pfadbestimmung k\[ODoubleDot]nnen wir die ",
  StyleBox["While",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife des Needleman-Wunsch-Algorithmus exakt wiederverwenden. Dort \
hatten wir das Auffinden einer Null in der Zeigermatrix als Abbruchbedingung \
benutzt (was dort die linke obere Ecke der Matrix kennzeichnete). Durch die \
obige Zeigercodierung wissen wir, dass dies auch das Ende des Pfades im \
Smith-Waterman-Algorithmus darstellt.\n",
  "\n",
  "Dieselbe Befehlsfolge (Traceback mit Hilfe einer ",
  StyleBox["While",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife, Auslesen der Zeiger entlang des Pfades, Umsetzung dieser \
Koordinaten-Zeigerzustand-Kombinationen in eine Abfolge von Graphikbefehlen) \
wie f\[UDoubleDot]r das entsprechende Resultat des \
Needleman-Wunsch-Algorithmus f\[UDoubleDot]hrt auf die in Abb. 3.12 \
angegebene Struktur. "
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(j = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      fWatermanTabB[\([Sequence @@ traX[j]]\)] =!= 
        0, \ {traX[j + 1]\  = \ 
          traX[j] - 
            Switch[fWatermanTabB[\([Sequence @@ traX[j]]\)], 1, \ \ {1, 1}, 
              2, \ {1, 0}, 3, \ {0, 1}], j = j + 1}]\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(path1\  = \ Table[traX[k], {k, 1, j - 1}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({{8, 9}, {7, 8}, {6, 7}, {6, 6}, {5, 5}, {4, 4}, {3, 3}, {2, 
        2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(path2\  = \ Map[FFTabB[\([Sequence @@ #]\)] &, path1];\)\), "\n", 
    \(path3\  = \ Map[Flatten, Thread[{path2, path1}]]\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({{1, 8, 9}, {1, 7, 8}, {3, 6, 7}, {1, 6, 6}, {1, 5, 5}, {1, 4, 4}, {1, 
        3, 3}, {1, 2, 2}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(gr3\  = \ 
        Map[arrXXc[#[\([1]\)], #[\([3]\)] - 1, #[\([2]\)] - 1] &, 
          path3];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(pW1\  = \ 
        Show[Graphics[
            Table[Text[
                fWatermanTabA[\([i, 
                    j]\)], {j, \(Dimensions[
                        fWatermanTabA]\)[\([1]\)] - \((i - 1)\)}], {i, 
                1, \(Dimensions[fWatermanTabA]\)[\([1]\)]}, {j, 
                1, \(Dimensions[fWatermanTabA]\)[\([2]\)]}]], 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pW4 = 
        Show[p3, p2, pW1, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0555556 0.0634921 0.0147151 0.0560575 [
[.11905 .57529 -5 -6.28125 ]
[.11905 .57529 5 6.28125 ]
[.18254 .57529 -5 -6.28125 ]
[.18254 .57529 5 6.28125 ]
[.24603 .57529 -5 -6.28125 ]
[.24603 .57529 5 6.28125 ]
[.30952 .57529 -5 -6.28125 ]
[.30952 .57529 5 6.28125 ]
[.37302 .57529 -5 -6.28125 ]
[.37302 .57529 5 6.28125 ]
[.43651 .57529 -5 -6.28125 ]
[.43651 .57529 5 6.28125 ]
[.5 .57529 -5 -6.28125 ]
[.5 .57529 5 6.28125 ]
[.56349 .57529 -5 -6.28125 ]
[.56349 .57529 5 6.28125 ]
[.62698 .57529 -5 -6.28125 ]
[.62698 .57529 5 6.28125 ]
[.69048 .57529 -5 -6.28125 ]
[.69048 .57529 5 6.28125 ]
[.75397 .57529 -5 -6.28125 ]
[.75397 .57529 5 6.28125 ]
[.81746 .57529 -5 -6.28125 ]
[.81746 .57529 5 6.28125 ]
[.88095 .57529 -5 -6.28125 ]
[.88095 .57529 5 6.28125 ]
[.94444 .57529 -5 -6.28125 ]
[.94444 .57529 5 6.28125 ]
[.05556 .51923 -5 -6.28125 ]
[.05556 .51923 5 6.28125 ]
[.05556 .46318 -5 -6.28125 ]
[.05556 .46318 5 6.28125 ]
[.05556 .40712 -5 -6.28125 ]
[.05556 .40712 5 6.28125 ]
[.05556 .35106 -5 -6.28125 ]
[.05556 .35106 5 6.28125 ]
[.05556 .295 -5 -6.28125 ]
[.05556 .295 5 6.28125 ]
[.05556 .23895 -5 -6.28125 ]
[.05556 .23895 5 6.28125 ]
[.05556 .18289 -5 -6.28125 ]
[.05556 .18289 5 6.28125 ]
[.05556 .12683 -5 -6.28125 ]
[.05556 .12683 5 6.28125 ]
[.05556 .07077 -5 -6.28125 ]
[.05556 .07077 5 6.28125 ]
[.11905 .51923 -3 -4.5 ]
[.11905 .51923 3 4.5 ]
[.18254 .51923 -3 -4.5 ]
[.18254 .51923 3 4.5 ]
[.24603 .51923 -3 -4.5 ]
[.24603 .51923 3 4.5 ]
[.30952 .51923 -3 -4.5 ]
[.30952 .51923 3 4.5 ]
[.37302 .51923 -3 -4.5 ]
[.37302 .51923 3 4.5 ]
[.43651 .51923 -3 -4.5 ]
[.43651 .51923 3 4.5 ]
[.5 .51923 -3 -4.5 ]
[.5 .51923 3 4.5 ]
[.56349 .51923 -3 -4.5 ]
[.56349 .51923 3 4.5 ]
[.62698 .51923 -3 -4.5 ]
[.62698 .51923 3 4.5 ]
[.69048 .51923 -3 -4.5 ]
[.69048 .51923 3 4.5 ]
[.75397 .51923 -3 -4.5 ]
[.75397 .51923 3 4.5 ]
[.81746 .51923 -3 -4.5 ]
[.81746 .51923 3 4.5 ]
[.88095 .51923 -3 -4.5 ]
[.88095 .51923 3 4.5 ]
[.94444 .51923 -3 -4.5 ]
[.94444 .51923 3 4.5 ]
[.11905 .46318 -3 -4.5 ]
[.11905 .46318 3 4.5 ]
[.18254 .46318 -3 -4.5 ]
[.18254 .46318 3 4.5 ]
[.24603 .46318 -3 -4.5 ]
[.24603 .46318 3 4.5 ]
[.30952 .46318 -3 -4.5 ]
[.30952 .46318 3 4.5 ]
[.37302 .46318 -3 -4.5 ]
[.37302 .46318 3 4.5 ]
[.43651 .46318 -3 -4.5 ]
[.43651 .46318 3 4.5 ]
[.5 .46318 -3 -4.5 ]
[.5 .46318 3 4.5 ]
[.56349 .46318 -3 -4.5 ]
[.56349 .46318 3 4.5 ]
[.62698 .46318 -3 -4.5 ]
[.62698 .46318 3 4.5 ]
[.69048 .46318 -3 -4.5 ]
[.69048 .46318 3 4.5 ]
[.75397 .46318 -3 -4.5 ]
[.75397 .46318 3 4.5 ]
[.81746 .46318 -3 -4.5 ]
[.81746 .46318 3 4.5 ]
[.88095 .46318 -3 -4.5 ]
[.88095 .46318 3 4.5 ]
[.94444 .46318 -3 -4.5 ]
[.94444 .46318 3 4.5 ]
[.11905 .40712 -3 -4.5 ]
[.11905 .40712 3 4.5 ]
[.18254 .40712 -3 -4.5 ]
[.18254 .40712 3 4.5 ]
[.24603 .40712 -3 -4.5 ]
[.24603 .40712 3 4.5 ]
[.30952 .40712 -3 -4.5 ]
[.30952 .40712 3 4.5 ]
[.37302 .40712 -3 -4.5 ]
[.37302 .40712 3 4.5 ]
[.43651 .40712 -3 -4.5 ]
[.43651 .40712 3 4.5 ]
[.5 .40712 -3 -4.5 ]
[.5 .40712 3 4.5 ]
[.56349 .40712 -3 -4.5 ]
[.56349 .40712 3 4.5 ]
[.62698 .40712 -3 -4.5 ]
[.62698 .40712 3 4.5 ]
[.69048 .40712 -3 -4.5 ]
[.69048 .40712 3 4.5 ]
[.75397 .40712 -3 -4.5 ]
[.75397 .40712 3 4.5 ]
[.81746 .40712 -3 -4.5 ]
[.81746 .40712 3 4.5 ]
[.88095 .40712 -3 -4.5 ]
[.88095 .40712 3 4.5 ]
[.94444 .40712 -3 -4.5 ]
[.94444 .40712 3 4.5 ]
[.11905 .35106 -3 -4.5 ]
[.11905 .35106 3 4.5 ]
[.18254 .35106 -3 -4.5 ]
[.18254 .35106 3 4.5 ]
[.24603 .35106 -3 -4.5 ]
[.24603 .35106 3 4.5 ]
[.30952 .35106 -3 -4.5 ]
[.30952 .35106 3 4.5 ]
[.37302 .35106 -3 -4.5 ]
[.37302 .35106 3 4.5 ]
[.43651 .35106 -3 -4.5 ]
[.43651 .35106 3 4.5 ]
[.5 .35106 -3 -4.5 ]
[.5 .35106 3 4.5 ]
[.56349 .35106 -3 -4.5 ]
[.56349 .35106 3 4.5 ]
[.62698 .35106 -3 -4.5 ]
[.62698 .35106 3 4.5 ]
[.69048 .35106 -3 -4.5 ]
[.69048 .35106 3 4.5 ]
[.75397 .35106 -3 -4.5 ]
[.75397 .35106 3 4.5 ]
[.81746 .35106 -3 -4.5 ]
[.81746 .35106 3 4.5 ]
[.88095 .35106 -3 -4.5 ]
[.88095 .35106 3 4.5 ]
[.94444 .35106 -3 -4.5 ]
[.94444 .35106 3 4.5 ]
[.11905 .295 -3 -4.5 ]
[.11905 .295 3 4.5 ]
[.18254 .295 -3 -4.5 ]
[.18254 .295 3 4.5 ]
[.24603 .295 -3 -4.5 ]
[.24603 .295 3 4.5 ]
[.30952 .295 -3 -4.5 ]
[.30952 .295 3 4.5 ]
[.37302 .295 -6 -4.5 ]
[.37302 .295 6 4.5 ]
[.43651 .295 -6 -4.5 ]
[.43651 .295 6 4.5 ]
[.5 .295 -3 -4.5 ]
[.5 .295 3 4.5 ]
[.56349 .295 -3 -4.5 ]
[.56349 .295 3 4.5 ]
[.62698 .295 -3 -4.5 ]
[.62698 .295 3 4.5 ]
[.69048 .295 -3 -4.5 ]
[.69048 .295 3 4.5 ]
[.75397 .295 -3 -4.5 ]
[.75397 .295 3 4.5 ]
[.81746 .295 -3 -4.5 ]
[.81746 .295 3 4.5 ]
[.88095 .295 -3 -4.5 ]
[.88095 .295 3 4.5 ]
[.94444 .295 -3 -4.5 ]
[.94444 .295 3 4.5 ]
[.11905 .23895 -3 -4.5 ]
[.11905 .23895 3 4.5 ]
[.18254 .23895 -3 -4.5 ]
[.18254 .23895 3 4.5 ]
[.24603 .23895 -3 -4.5 ]
[.24603 .23895 3 4.5 ]
[.30952 .23895 -3 -4.5 ]
[.30952 .23895 3 4.5 ]
[.37302 .23895 -6 -4.5 ]
[.37302 .23895 6 4.5 ]
[.43651 .23895 -6 -4.5 ]
[.43651 .23895 6 4.5 ]
[.5 .23895 -6 -4.5 ]
[.5 .23895 6 4.5 ]
[.56349 .23895 -3 -4.5 ]
[.56349 .23895 3 4.5 ]
[.62698 .23895 -3 -4.5 ]
[.62698 .23895 3 4.5 ]
[.69048 .23895 -3 -4.5 ]
[.69048 .23895 3 4.5 ]
[.75397 .23895 -3 -4.5 ]
[.75397 .23895 3 4.5 ]
[.81746 .23895 -3 -4.5 ]
[.81746 .23895 3 4.5 ]
[.88095 .23895 -3 -4.5 ]
[.88095 .23895 3 4.5 ]
[.94444 .23895 -3 -4.5 ]
[.94444 .23895 3 4.5 ]
[.11905 .18289 -3 -4.5 ]
[.11905 .18289 3 4.5 ]
[.18254 .18289 -3 -4.5 ]
[.18254 .18289 3 4.5 ]
[.24603 .18289 -3 -4.5 ]
[.24603 .18289 3 4.5 ]
[.30952 .18289 -3 -4.5 ]
[.30952 .18289 3 4.5 ]
[.37302 .18289 -3 -4.5 ]
[.37302 .18289 3 4.5 ]
[.43651 .18289 -6 -4.5 ]
[.43651 .18289 6 4.5 ]
[.5 .18289 -6 -4.5 ]
[.5 .18289 6 4.5 ]
[.56349 .18289 -6 -4.5 ]
[.56349 .18289 6 4.5 ]
[.62698 .18289 -6 -4.5 ]
[.62698 .18289 6 4.5 ]
[.69048 .18289 -3 -4.5 ]
[.69048 .18289 3 4.5 ]
[.75397 .18289 -3 -4.5 ]
[.75397 .18289 3 4.5 ]
[.81746 .18289 -3 -4.5 ]
[.81746 .18289 3 4.5 ]
[.88095 .18289 -3 -4.5 ]
[.88095 .18289 3 4.5 ]
[.94444 .18289 -3 -4.5 ]
[.94444 .18289 3 4.5 ]
[.11905 .12683 -3 -4.5 ]
[.11905 .12683 3 4.5 ]
[.18254 .12683 -3 -4.5 ]
[.18254 .12683 3 4.5 ]
[.24603 .12683 -3 -4.5 ]
[.24603 .12683 3 4.5 ]
[.30952 .12683 -3 -4.5 ]
[.30952 .12683 3 4.5 ]
[.37302 .12683 -3 -4.5 ]
[.37302 .12683 3 4.5 ]
[.43651 .12683 -3 -4.5 ]
[.43651 .12683 3 4.5 ]
[.5 .12683 -6 -4.5 ]
[.5 .12683 6 4.5 ]
[.56349 .12683 -6 -4.5 ]
[.56349 .12683 6 4.5 ]
[.62698 .12683 -6 -4.5 ]
[.62698 .12683 6 4.5 ]
[.69048 .12683 -6 -4.5 ]
[.69048 .12683 6 4.5 ]
[.75397 .12683 -6 -4.5 ]
[.75397 .12683 6 4.5 ]
[.81746 .12683 -6 -4.5 ]
[.81746 .12683 6 4.5 ]
[.88095 .12683 -3 -4.5 ]
[.88095 .12683 3 4.5 ]
[.94444 .12683 -3 -4.5 ]
[.94444 .12683 3 4.5 ]
[.11905 .07077 -3 -4.5 ]
[.11905 .07077 3 4.5 ]
[.18254 .07077 -3 -4.5 ]
[.18254 .07077 3 4.5 ]
[.24603 .07077 -3 -4.5 ]
[.24603 .07077 3 4.5 ]
[.30952 .07077 -3 -4.5 ]
[.30952 .07077 3 4.5 ]
[.37302 .07077 -3 -4.5 ]
[.37302 .07077 3 4.5 ]
[.43651 .07077 -3 -4.5 ]
[.43651 .07077 3 4.5 ]
[.5 .07077 -3 -4.5 ]
[.5 .07077 3 4.5 ]
[.56349 .07077 -6 -4.5 ]
[.56349 .07077 6 4.5 ]
[.62698 .07077 -6 -4.5 ]
[.62698 .07077 6 4.5 ]
[.69048 .07077 -6 -4.5 ]
[.69048 .07077 6 4.5 ]
[.75397 .07077 -6 -4.5 ]
[.75397 .07077 6 4.5 ]
[.81746 .07077 -6 -4.5 ]
[.81746 .07077 6 4.5 ]
[.88095 .07077 -6 -4.5 ]
[.88095 .07077 6 4.5 ]
[.94444 .07077 -6 -4.5 ]
[.94444 .07077 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.9 g
.0873 .54726 m
.0873 .60332 L
.97619 .60332 L
.97619 .54726 L
F
0 g
gsave
.11905 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18254 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24603 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30952 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37302 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43651 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56349 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62698 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75397 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81746 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88095 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.94444 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.9 g
.02381 .01472 m
.02381 .60332 L
.0873 .60332 L
.0873 .01472 L
F
0 g
gsave
.05556 .51923 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .46318 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .40712 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .35106 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .295 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .23895 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .18289 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .12683 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .07077 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
[(0)] .11905 .51923 0 0 Mshowa
[(0)] .18254 .51923 0 0 Mshowa
[(0)] .24603 .51923 0 0 Mshowa
[(0)] .30952 .51923 0 0 Mshowa
[(0)] .37302 .51923 0 0 Mshowa
[(0)] .43651 .51923 0 0 Mshowa
[(0)] .5 .51923 0 0 Mshowa
[(0)] .56349 .51923 0 0 Mshowa
[(0)] .62698 .51923 0 0 Mshowa
[(0)] .69048 .51923 0 0 Mshowa
[(0)] .75397 .51923 0 0 Mshowa
[(0)] .81746 .51923 0 0 Mshowa
[(0)] .88095 .51923 0 0 Mshowa
[(0)] .94444 .51923 0 0 Mshowa
[(0)] .11905 .46318 0 0 Mshowa
[(5)] .18254 .46318 0 0 Mshowa
[(0)] .24603 .46318 0 0 Mshowa
[(0)] .30952 .46318 0 0 Mshowa
[(0)] .37302 .46318 0 0 Mshowa
[(5)] .43651 .46318 0 0 Mshowa
[(0)] .5 .46318 0 0 Mshowa
[(0)] .56349 .46318 0 0 Mshowa
[(0)] .62698 .46318 0 0 Mshowa
[(1)] .69048 .46318 0 0 Mshowa
[(0)] .75397 .46318 0 0 Mshowa
[(0)] .81746 .46318 0 0 Mshowa
[(0)] .88095 .46318 0 0 Mshowa
[(0)] .94444 .46318 0 0 Mshowa
[(0)] .11905 .40712 0 0 Mshowa
[(1)] .18254 .40712 0 0 Mshowa
[(3)] .24603 .40712 0 0 Mshowa
[(0)] .30952 .40712 0 0 Mshowa
[(0)] .37302 .40712 0 0 Mshowa
[(1)] .43651 .40712 0 0 Mshowa
[(4)] .5 .40712 0 0 Mshowa
[(0)] .56349 .40712 0 0 Mshowa
[(0)] .62698 .40712 0 0 Mshowa
[(2)] .69048 .40712 0 0 Mshowa
[(1)] .75397 .40712 0 0 Mshowa
[(0)] .81746 .40712 0 0 Mshowa
[(0)] .88095 .40712 0 0 Mshowa
[(0)] .94444 .40712 0 0 Mshowa
[(0)] .11905 .35106 0 0 Mshowa
[(0)] .18254 .35106 0 0 Mshowa
[(4)] .24603 .35106 0 0 Mshowa
[(9)] .30952 .35106 0 0 Mshowa
[(4)] .37302 .35106 0 0 Mshowa
[(0)] .43651 .35106 0 0 Mshowa
[(0)] .5 .35106 0 0 Mshowa
[(1)] .56349 .35106 0 0 Mshowa
[(0)] .62698 .35106 0 0 Mshowa
[(0)] .69048 .35106 0 0 Mshowa
[(1)] .75397 .35106 0 0 Mshowa
[(0)] .81746 .35106 0 0 Mshowa
[(0)] .88095 .35106 0 0 Mshowa
[(0)] .94444 .35106 0 0 Mshowa
[(0)] .11905 .295 0 0 Mshowa
[(0)] .18254 .295 0 0 Mshowa
[(2)] .24603 .295 0 0 Mshowa
[(4)] .30952 .295 0 0 Mshowa
[(17)] .37302 .295 0 0 Mshowa
[(12)] .43651 .295 0 0 Mshowa
[(7)] .5 .295 0 0 Mshowa
[(2)] .56349 .295 0 0 Mshowa
[(2)] .62698 .295 0 0 Mshowa
[(0)] .69048 .295 0 0 Mshowa
[(8)] .75397 .295 0 0 Mshowa
[(3)] .81746 .295 0 0 Mshowa
[(0)] .88095 .295 0 0 Mshowa
[(0)] .94444 .295 0 0 Mshowa
[(0)] .11905 .23895 0 0 Mshowa
[(0)] .18254 .23895 0 0 Mshowa
[(0)] .24603 .23895 0 0 Mshowa
[(0)] .30952 .23895 0 0 Mshowa
[(12)] .37302 .23895 0 0 Mshowa
[(17)] .43651 .23895 0 0 Mshowa
[(12)] .5 .23895 0 0 Mshowa
[(7)] .56349 .23895 0 0 Mshowa
[(8)] .62698 .23895 0 0 Mshowa
[(3)] .69048 .23895 0 0 Mshowa
[(3)] .75397 .23895 0 0 Mshowa
[(9)] .81746 .23895 0 0 Mshowa
[(4)] .88095 .23895 0 0 Mshowa
[(0)] .94444 .23895 0 0 Mshowa
[(0)] .11905 .18289 0 0 Mshowa
[(0)] .18254 .18289 0 0 Mshowa
[(0)] .24603 .18289 0 0 Mshowa
[(0)] .30952 .18289 0 0 Mshowa
[(7)] .37302 .18289 0 0 Mshowa
[(12)] .43651 .18289 0 0 Mshowa
[(17)] .5 .18289 0 0 Mshowa
[(18)] .56349 .18289 0 0 Mshowa
[(13)] .62698 .18289 0 0 Mshowa
[(8)] .69048 .18289 0 0 Mshowa
[(3)] .75397 .18289 0 0 Mshowa
[(4)] .81746 .18289 0 0 Mshowa
[(7)] .88095 .18289 0 0 Mshowa
[(2)] .94444 .18289 0 0 Mshowa
[(0)] .11905 .12683 0 0 Mshowa
[(0)] .18254 .12683 0 0 Mshowa
[(2)] .24603 .12683 0 0 Mshowa
[(0)] .30952 .12683 0 0 Mshowa
[(8)] .37302 .12683 0 0 Mshowa
[(7)] .43651 .12683 0 0 Mshowa
[(12)] .5 .12683 0 0 Mshowa
[(15)] .56349 .12683 0 0 Mshowa
[(19)] .62698 .12683 0 0 Mshowa
[(14)] .69048 .12683 0 0 Mshowa
[(16)] .75397 .12683 0 0 Mshowa
[(11)] .81746 .12683 0 0 Mshowa
[(6)] .88095 .12683 0 0 Mshowa
[(5)] .94444 .12683 0 0 Mshowa
[(0)] .11905 .07077 0 0 Mshowa
[(0)] .18254 .07077 0 0 Mshowa
[(0)] .24603 .07077 0 0 Mshowa
[(0)] .30952 .07077 0 0 Mshowa
[(3)] .37302 .07077 0 0 Mshowa
[(7)] .43651 .07077 0 0 Mshowa
[(7)] .5 .07077 0 0 Mshowa
[(10)] .56349 .07077 0 0 Mshowa
[(15)] .62698 .07077 0 0 Mshowa
[(18)] .69048 .07077 0 0 Mshowa
[(13)] .75397 .07077 0 0 Mshowa
[(17)] .81746 .07077 0 0 Mshowa
[(12)] .88095 .07077 0 0 Mshowa
[(11)] .94444 .07077 0 0 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`00
1`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
o`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1`3Vi^H3000000P0i^KV
203oool200000100oooo0P00000@0?ooo`800000403oool200000140oooo0P00000A0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool500000080oooo0P0000090?ooo`D00000
0P3oool2000000X0oooo1@0000020?ooo`8000002@3oool500000080oooo0P0000090?ooo`D00000
0`3oool00`000000oooo0?ooo`070?ooo`D0000000<0oooo0000000000000P0000080?ooo`D00000
00<0oooo0000000000000`00000<0?ooo`001`3oool80>KViP030000003Vi^H0i^KV00L0i^KV1`3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo00000100oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`001`3oool80>KViP030000003Vi^H0
i^KV00L0i^KV1`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00070?ooo`P0i^KV00<00000
0>KViP3Vi^H01`3Vi^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool2
000000`0oooo00<000000?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`001`3oool60>KViP050000003Vi^H000000>KViP0000001`3Vi^H7
0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool000003P3oool0
10000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000d0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool000L0oooo1P3Vi^H5000000L0i^KV203oool200000100oooo0P00000@0?ooo`800000403o
ool200000140oooo0P00000?0?ooo`@000003P3oool4000000`0oooo0P0000040?ooo`8000002P3o
ool2000000@0oooo0`00000:0?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000002P3o
ool2000000<0oooo100000090?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000003P3o
ool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0
oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`00
1`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?ooo`H0i^KV0`000000
0`3Vi^H00000000000060>KViPP0oooo0P00000@0?ooo`8000003`3oool4000000l0oooo0P00000A
0?ooo`8000004@3oool00`000000oooo0?ooo`0:0?ooo`D0000000<0oooo0000000000000P000008
0?ooo`D000000P3oool2000000T0oooo1@000000103oool0000000000000000:0?ooo`D000000`3o
ool3000000L0oooo1@000000103oool000000000000000090?ooo`D0000000<0oooo000000000000
0`00000:0?ooo`<00000403oool200000140oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H00000
1`3Vi^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool00`00
0000oooo0?ooo`0?0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool00000403o
ool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo00000100oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`040000003o
ool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`0>0?ooo`04
0000003oool0oooo000000l0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool3000000/0oooo00@00000
0?ooo`3oool0oooo1@0000090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo00h0oooo00070?ooo`L0i^KV100000070>KViPL0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`3oool00000403oool200000180oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2
000000/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
oooo0`00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool300000100
oooo0P00000A0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV1`3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`001`3oool60>KViP80000000@0i^KV00000000000000001P3Vi^H80?ooo`800000403o
ool200000100oooo0P00000@0?ooo`8000004@3oool2000000l0oooo1000000<0?ooo`800000103o
ool2000000X0oooo0P0000040?ooo`<000002@3oool2000000@0oooo0`00000:0?ooo`8000001@3o
ool2000000T0oooo0P0000040?ooo`<000002@3oool2000000@0oooo0P00000=0?ooo`<000003`3o
ool300000100oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0
oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203o
ool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0
oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3oool8
0>KViP800000203Vi^H80?ooo`800000403oool200000100oooo0P00000@0?ooo`8000004P3oool0
0`000000oooo0?ooo`0:0?ooo`D0000000<0oooo0000000000000P0000080?ooo`D000000`3oool0
0`000000oooo0?ooo`070?ooo`D000000P3oool2000000T0oooo1@0000020?ooo`8000003P3oool2
00000100oooo0P00000A0?ooo`<000003`3oool00`000000oooo0?ooo`0=0?ooo`@00000403oool0
00L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000003@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?oo
o`001`3oool70>KViP030000003Vi^H00000008000001P3Vi^H70?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003o
ool0oooo00000140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo
00d0oooo1@00000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool000L0
oooo1`3Vi^H00`000000i^KV0>KViP080>KViPL0oooo00@000000?ooo`3oool000003P3oool01000
0000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool2000000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`800000
4P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`001`3oool70>KViP030000003Vi^H0i^KV00P0i^KV
1`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000d0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`03
0000003oool0000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@
0?ooo`001`3oool80>KViP<000001`3Vi^H80?ooo`800000403oool200000100oooo0P00000@0?oo
o`800000403oool4000000`0oooo0P0000040?ooo`8000002P3oool2000000<0oooo100000090?oo
o`800000103oool2000000X0oooo0P0000040?ooo`8000003P3oool200000100oooo0P00000A0?oo
o`8000003P3oool4000000l0oooo0P00000A0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo
4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool0
00L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo
203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KV
i_l0oooo203oool000L0oooo1P3Vi^H3000000030>KViP000000i^KV00H0i^KV203oool200000100
oooo0P00000@0?ooo`800000403oool2000000d0oooo1@0000000`3oool0000000000002000000P0
oooo1@0000030?ooo`030000003oool0oooo00L0oooo1@0000000`3oool0000000000002000000d0
oooo00<000000?ooo`3oool03P3oool200000140oooo0P00000@0?ooo`8000003`3oool300000140
oooo0`00000>0?ooo`8000004@3oool000L0oooo1`3Vi^H010000000i^KV0000000000070>KViPL0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003P3oool01@000000oooo0?ooo`3oool0000000d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000l0oooo00@00000
0?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000@0?ooo`001`3oool70>KViP040000
003Vi^H00000000000L0i^KV1`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo0`00000>0?ooo`D000003@3oool010000000oooo0?ooo`00000@0?oo
o`001`3oool70>KViP80000000<0i^KV0000003Vi^H01P3Vi^H70?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool2000001<0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000@0?ooo`001`3oool70>KViP80000000<0i^KV0000
003Vi^H01P3Vi^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000?0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool00000403oool000L0oooo1P3V
i^H2000000040>KViP0000000000000000H0i^KV203oool200000100oooo0P00000@0?ooo`800000
403oool2000000h0oooo0P0000040?ooo`8000002P3oool2000000<0oooo100000090?ooo`800000
103oool2000000`0oooo1000000?0?ooo`8000004@3oool200000100oooo0P00000@0?ooo`<00000
403oool2000000l0oooo0P00000A0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko
0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo
4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool0
00L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo
203oool000L0oooo1P3Vi^H3000000030>KViP000000000000H0i^KV203oool200000100oooo0P00
000?0?ooo`@00000403oool3000000/0oooo1@0000030?ooo`030000003oool0oooo00L0oooo1@00
00000`3oool0000000000002000000d0oooo00<000000?ooo`3oool03@3oool4000000h0oooo1000
000@0?ooo`800000403oool200000100oooo0P00000@0?ooo`800000403oool200000140oooo0007
0?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo0000
0100oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`040000003oool0oooo
000000h0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`0>0?ooo`D000003@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool0
0000403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool00000403oool000L0oooo1`3Vi^H4000000L0i^KV1`3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`00000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000003`3oool200000180
oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
00000100oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`03
0000003oool0000000h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`00
1`3oool60>KViP80000000@0i^KV00000000000000001P3Vi^H80?ooo`800000403oool200000100
oooo0P00000A0?ooo`8000003@3oool2000000<0oooo100000090?ooo`800000103oool2000000`0
oooo1000000?0?ooo`800000403oool200000140oooo0P00000@0?ooo`800000403oool200000100
oooo0P00000@0?ooo`8000004@3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3o
ool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80
i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo0007
0?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0
oooo00070?oooa80i^KV203oool200000100oooo0P00000A0?ooo`<000003@3oool300000180oooo
0`00000>0?ooo`800000403oool2000000l0oooo1@00000>0?ooo`8000004@3oool2000000l0oooo
1@00000>0?ooo`800000403oool200000100oooo0P00000A0?ooo`001`3oool70>KViP<00000203V
i^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000004@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool03@3oool0
10000000oooo0?ooo`00000?0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool00000403oool000L0oooo203Vi^H00`000000i^KV0>KViP070>KViPL0oooo00@000000?oo
o`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`D000003P3oool3000000l0oooo1@00
000=0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool00000403oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000@0?ooo`001`3oool80>KViP030000003Vi^H0i^KV00L0i^KV
1`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000@0?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo00000100oooo00070?ooo`P0i^KV0P0000080>KViPL0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0000000h0oooo00@00000
0?ooo`3oool00000403oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
00l0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`00
1`3oool80>KViP040000003Vi^H0i^KV000000H0i^KV203oool200000100oooo0P00000A0?ooo`80
00003`3oool300000140oooo0P00000?0?ooo`800000403oool200000100oooo0P00000@0?ooo`80
00004@3oool200000100oooo0P00000@0?ooo`800000403oool200000100oooo0P00000A0?ooo`00
1`3oool70>KViPD000001P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`00
1`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
203oool2000000l0oooo1@00000>0?ooo`800000403oool200000140oooo0P00000?0?ooo`D00000
3`3oool3000000h0oooo0P00000@0?ooo`800000403oool4000000h0oooo1@00000>0?ooo`800000
403oool200000100oooo0P00000A0?ooo`001`3oool60>KViPD000001`3Vi^H70?ooo`040000003o
ool0oooo00000100oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo000000l0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403oool0
00L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo00@000000?ooo`3oool00000403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
3`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00d0oooo1@00000=0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000>0?ooo`040000003oool0oooo00000100oooo00070?ooo`L0i^KV00<000000>KViP3Vi^H0
203Vi^H70?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0<0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool00000403oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool00000403oool000L0oooo1`3Vi^H2000000T0i^KV1`3oool010000000oooo0?ooo`00
000@0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000?0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0000000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3o
ool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo00000100oooo00070?oo
o`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H80?ooo`800000403oool200000100oooo0P00000@
0?ooo`8000004@3oool200000100oooo0P00000A0?ooo`8000003`3oool200000100oooo0P00000A
0?ooo`800000403oool200000100oooo0P00000@0?ooo`800000403oool200000140oooo00070?oo
o`H0i^KV1@0000070>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
o`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo
00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^H80?oo
o`800000403oool200000100oooo0P00000@0?ooo`8000004@3oool200000100oooo0P00000@0?oo
o`800000403oool200000100oooo0P00000@0?ooo`D000003P3oool200000100oooo0P00000@0?oo
o`800000403oool200000140oooo00070?ooo`H0i^KV0`0000000`3Vi^H00000000000060>KViPL0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000>0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool0
10000000oooo0?ooo`00000@0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV1`3o
ool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0
00003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0303oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003o
ool0oooo00000100oooo00070?ooo`L0i^KV0`0000080>KViPL0oooo00@000000?ooo`3oool00000
3`3oool2000000l0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?oo
o`040000003oool0oooo000000l0oooo0P00000?0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool00000403oool000L0oooo1`3Vi^H00`000000i^KV0000
00080>KViPL0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`0>0?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000?
0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000>0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool03@3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000@0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV
203oool200000100oooo0`00000?0?ooo`800000403oool200000140oooo0P00000@0?ooo`<00000
3`3oool200000100oooo0P00000@0?ooo`8000004@3oool200000100oooo0P00000@0?ooo`800000
403oool200000100oooo0P00000A0?ooo`001`3oool60>KViP<0000000<0i^KV0000000000001P3V
i^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0
oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203o
ool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0
oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV203oool200000100oooo0P00
000@0?ooo`800000403oool200000140oooo0P00000@0?ooo`800000403oool200000100oooo0P00
000@0?ooo`8000004@3oool200000100oooo0P00000@0?ooo`800000403oool200000100oooo0P00
000A0?ooo`001`3ooolB0>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool01000
0000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00@000000?oo
o`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`001`3ooolB0>KViPL0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000>0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool000003P3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000@0?ooo`001`3ooolB0>KViPL0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
000000l0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@
0?ooo`001`3ooolB0>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`001`3ooolB0>KViPP0oooo
0P00000@0?ooo`800000403oool200000100oooo0P00000A0?ooo`800000403oool200000100oooo
0P00000@0?ooo`800000403oool200000140oooo0P00000@0?ooo`800000403oool200000100oooo
0P00000@0?ooo`8000004@3oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV
o`3oool80?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?oookl0i^KV0P00001?0>KViPT0oooo00070?ooobX0i^KV0`0000000`3Vi^H000000000000>
0>KViP<000003P3Vi^H3000000l0i^KV0`0000000`3Vi^H000000000000<0>KViP<0000000<0i^KV
0000000000003@3Vi^H2000000030>KViP000000000000h0i^KV0P00000>0>KViP<0000000<0i^KV
0000003Vi^H03`3Vi^H2000000h0i^KV0`0000000`3Vi^H000000000000=0>KViP<000003P3Vi^H3
00000100i^KV0`0000080>KViPT0oooo00070?ooob/0i^KV00@000000>KViP3Vi^H00000403Vi^H0
0`000000i^KV0>KViP0>0>KViP030000003Vi^H0i^KV00l0i^KV00@000000>KViP3Vi^H000003P3V
i^H010000000i^KV0>KViP00000>0>KViP050000003Vi^H0i^KV0>KViP0000003@3Vi^H010000000
i^KV0>KViP00000>0>KViP040000003Vi^H00000000000l0i^KV00@000000>KViP3Vi^H000003P3V
i^H010000000i^KV0>KViP00000>0>KViP040000003Vi^H0i^KV000000h0i^KV00<000000>KViP3V
i^H0403Vi^H00`000000i^KV0>KViP070>KViPT0oooo00070?ooob/0i^KV0`00000A0>KViP030000
003Vi^H0i^KV00h0i^KV00<000000>KViP3Vi^H03`3Vi^H010000000i^KV0>KViP00000>0>KViP<0
0000403Vi^H3000000h0i^KV00<000000>KViP0000000P00000=0>KViP040000003Vi^H000000000
00l0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000A0>KViP030000003V
i^H0i^KV00`0i^KV0`00000@0>KViP030000003Vi^H0i^KV00L0i^KV2@3oool000L0oooo:`3Vi^H0
0`000000i^KV0000000@0>KViP030000003Vi^H0000000l0i^KV0P00000@0>KViP@000003P3Vi^H0
0`000000i^KV0000000@0>KViP030000003Vi^H0000000h0i^KV00<000000>KViP3Vi^H03`3Vi^H2
000000030>KViP000000i^KV00h0i^KV00@000000>KViP3Vi^H000003P3Vi^H4000000l0i^KV0P00
000?0>KViP040000003Vi^H0i^KV000000l0i^KV00<000000>KViP3Vi^H01`3Vi^H90?ooo`001`3o
ool[0>KViP040000003Vi^H0i^KV000000h0i^KV00D000000>KViP3Vi^H0i^KV0000000>0>KViP04
0000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00
000@0>KViP030000003Vi^H0i^KV00d0i^KV00<000000>KViP3Vi^H03`3Vi^H2000000030>KViP00
0000i^KV00h0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000>0>KViP04
0000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H000003@3Vi^H01@000000i^KV0000003V
i^H0000000L0i^KV2@3oool000L0oooo:P3Vi^H3000000030>KViP000000000000`0i^KV0`000000
0`3Vi^H000000000000=0>KViPD000003@3Vi^H2000000040>KViP0000000000000000`0i^KV0`00
00000`3Vi^H000000000000>0>KViP800000403Vi^H3000000d0i^KV0P000000103Vi^H000000000
0000000?0>KViP8000003P3Vi^H2000000040>KViP0000000000000000d0i^KV1000000=0>KViP@0
00003P3Vi^H5000000L0i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3V
i^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.894534, -0.262555, \
0.0550141, 0.0623104}}]
}, Open  ]],

Cell[BoxData[
    \(arrD[i_, j_] := \ 
      Show[Graphics[Arrow[{0, 0}, {0, 0}]], 
        DisplayFunction \[Rule] Identity]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(arrXX2[ll_, i_, j_]\  := \ 
      If[ll \[Equal] 1, arrA[i, j], 
        If[ll \[Equal] 2, arrB[i, j], 
          If[ll \[Equal] 3, arrC[i, j], 
            If[ll \[Equal] 0, arrD[i, j]]]]]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(arrowfield2[mat_] := \ 
      Module[{dd1, 
          dd2}, \[IndentingNewLine]dd1\  = \ \(Dimensions[
              mat]\)[\([1]\)]; \[IndentingNewLine]dd2\  = \ \(Dimensions[
              mat]\)[\([2]\)]; \[IndentingNewLine]Table[
          arrXX2[mat[\([i, j]\)], \((j - 1)\), \((i - 1)\)], {i, 1, dd1}, {j, 
            1, dd2}]]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(grW1\  = \ arrowfield2[fWatermanTabB];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[grW1, DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0695169 0.0147151 0.0676556 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto fill
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto
-0.2 0.1 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.14199 .57626 m
.11418 .60332 L
s
% Start of user PostScript
1.7 8.3 1.3 8.7 MAarrowhead1
% End of user PostScript
.21151 .55596 m
.1837 .55596 L
s
% Start of user PostScript
2.7 8. 2.3 8. MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.42006 .57626 m
.39225 .60332 L
s
% Start of user PostScript
5.7 8.3 5.3 8.7 MAarrowhead1
% End of user PostScript
.48957 .55596 m
.46177 .55596 L
s
% Start of user PostScript
6.7 8. 6.3 8. MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.62861 .57626 m
.6008 .60332 L
s
% Start of user PostScript
8.7 8.3 8.3 8.7 MAarrowhead1
% End of user PostScript
.69812 .57626 m
.67032 .60332 L
s
% Start of user PostScript
9.7 8.3 9.3 8.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.83716 .57626 m
.80935 .60332 L
s
% Start of user PostScript
11.7 8.3 11.3 8.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.14199 .5086 m
.11418 .53566 L
s
% Start of user PostScript
1.7 7.3 1.3 7.7 MAarrowhead1
% End of user PostScript
.21151 .5086 m
.1837 .53566 L
s
% Start of user PostScript
2.7 7.3 2.3 7.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.35054 .5086 m
.32273 .53566 L
s
% Start of user PostScript
4.7 7.3 4.3 7.7 MAarrowhead1
% End of user PostScript
.42006 .5086 m
.39225 .53566 L
s
% Start of user PostScript
5.7 7.3 5.3 7.7 MAarrowhead1
% End of user PostScript
.48957 .5086 m
.46177 .53566 L
s
% Start of user PostScript
6.7 7.3 6.3 7.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.62861 .5086 m
.6008 .53566 L
s
% Start of user PostScript
8.7 7.3 8.3 7.7 MAarrowhead1
% End of user PostScript
.69812 .5086 m
.67032 .53566 L
s
% Start of user PostScript
9.7 7.3 9.3 7.7 MAarrowhead1
% End of user PostScript
.76764 .5086 m
.73983 .53566 L
s
% Start of user PostScript
10.7 7.3 10.3 7.7 MAarrowhead1
% End of user PostScript
.83716 .5086 m
.80935 .53566 L
s
% Start of user PostScript
11.7 7.3 11.3 7.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.21151 .44095 m
.1837 .46801 L
s
% Start of user PostScript
2.7 6.3 2.3 6.7 MAarrowhead1
% End of user PostScript
.28102 .44095 m
.25322 .46801 L
s
% Start of user PostScript
3.7 6.3 3.3 6.7 MAarrowhead1
% End of user PostScript
.35054 .42065 m
.32273 .42065 L
s
% Start of user PostScript
4.7 6. 4.3 6. MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.55909 .44095 m
.53128 .46801 L
s
% Start of user PostScript
7.7 6.3 7.3 6.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.76764 .44095 m
.73983 .46801 L
s
% Start of user PostScript
10.7 6.3 10.3 6.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.21151 .37329 m
.1837 .40035 L
s
% Start of user PostScript
2.7 5.3 2.3 5.7 MAarrowhead1
% End of user PostScript
.30188 .37329 m
.30188 .40035 L
s
% Start of user PostScript
4. 5.3 4. 5.7 MAarrowhead1
% End of user PostScript
.35054 .37329 m
.32273 .40035 L
s
% Start of user PostScript
4.7 5.3 4.3 5.7 MAarrowhead1
% End of user PostScript
.42006 .35299 m
.39225 .35299 L
s
% Start of user PostScript
5.7 5. 5.3 5. MAarrowhead1
% End of user PostScript
.48957 .35299 m
.46177 .35299 L
s
% Start of user PostScript
6.7 5. 6.3 5. MAarrowhead1
% End of user PostScript
.55909 .35299 m
.53128 .35299 L
s
% Start of user PostScript
7.7 5. 7.3 5. MAarrowhead1
% End of user PostScript
.62861 .37329 m
.6008 .40035 L
s
% Start of user PostScript
8.7 5.3 8.3 5.7 MAarrowhead1
% End of user PostScript
.69812 .37329 m
.67032 .40035 L
s
% Start of user PostScript
9.7 5.3 9.3 5.7 MAarrowhead1
% End of user PostScript
.76764 .37329 m
.73983 .40035 L
s
% Start of user PostScript
10.7 5.3 10.3 5.7 MAarrowhead1
% End of user PostScript
.83716 .35299 m
.80935 .35299 L
s
% Start of user PostScript
11.7 5. 11.3 5. MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.14199 .30563 m
.11418 .3327 L
s
% Start of user PostScript
1.7 4.3 1.3 4.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.37139 .30563 m
.37139 .3327 L
s
% Start of user PostScript
5. 4.3 5. 4.7 MAarrowhead1
% End of user PostScript
.42006 .30563 m
.39225 .3327 L
s
% Start of user PostScript
5.7 4.3 5.3 4.7 MAarrowhead1
% End of user PostScript
.48957 .28534 m
.46177 .28534 L
s
% Start of user PostScript
6.7 4. 6.3 4. MAarrowhead1
% End of user PostScript
.55909 .28534 m
.53128 .28534 L
s
% Start of user PostScript
7.7 4. 7.3 4. MAarrowhead1
% End of user PostScript
.62861 .30563 m
.6008 .3327 L
s
% Start of user PostScript
8.7 4.3 8.3 4.7 MAarrowhead1
% End of user PostScript
.69812 .28534 m
.67032 .28534 L
s
% Start of user PostScript
9.7 4. 9.3 4. MAarrowhead1
% End of user PostScript
.78849 .30563 m
.78849 .3327 L
s
% Start of user PostScript
11. 4.3 11. 4.7 MAarrowhead1
% End of user PostScript
.83716 .30563 m
.80935 .3327 L
s
% Start of user PostScript
11.7 4.3 11.3 4.7 MAarrowhead1
% End of user PostScript
.90667 .28534 m
.87887 .28534 L
s
% Start of user PostScript
12.7 4. 12.3 4. MAarrowhead1
% End of user PostScript
.97619 .30563 m
.94838 .3327 L
s
% Start of user PostScript
13.7 4.3 13.3 4.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.37139 .23798 m
.37139 .26504 L
s
% Start of user PostScript
5. 3.3 5. 3.7 MAarrowhead1
% End of user PostScript
.44091 .23798 m
.44091 .26504 L
s
% Start of user PostScript
6. 3.3 6. 3.7 MAarrowhead1
% End of user PostScript
.48957 .23798 m
.46177 .26504 L
s
% Start of user PostScript
6.7 3.3 6.3 3.7 MAarrowhead1
% End of user PostScript
.55909 .23798 m
.53128 .26504 L
s
% Start of user PostScript
7.7 3.3 7.3 3.7 MAarrowhead1
% End of user PostScript
.62861 .21768 m
.6008 .21768 L
s
% Start of user PostScript
8.7 3. 8.3 3. MAarrowhead1
% End of user PostScript
.69812 .21768 m
.67032 .21768 L
s
% Start of user PostScript
9.7 3. 9.3 3. MAarrowhead1
% End of user PostScript
.76764 .21768 m
.73983 .21768 L
s
% Start of user PostScript
10.7 3. 10.3 3. MAarrowhead1
% End of user PostScript
.85801 .23798 m
.85801 .26504 L
s
% Start of user PostScript
12. 3.3 12. 3.7 MAarrowhead1
% End of user PostScript
.90667 .23798 m
.87887 .26504 L
s
% Start of user PostScript
12.7 3.3 12.3 3.7 MAarrowhead1
% End of user PostScript
.97619 .21768 m
.94838 .21768 L
s
% Start of user PostScript
13.7 3. 13.3 3. MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.21151 .17032 m
.1837 .19739 L
s
% Start of user PostScript
2.7 2.3 2.3 2.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.35054 .17032 m
.32273 .19739 L
s
% Start of user PostScript
4.7 2.3 4.3 2.7 MAarrowhead1
% End of user PostScript
.44091 .17032 m
.44091 .19739 L
s
% Start of user PostScript
6. 2.3 6. 2.7 MAarrowhead1
% End of user PostScript
.51043 .17032 m
.51043 .19739 L
s
% Start of user PostScript
7. 2.3 7. 2.7 MAarrowhead1
% End of user PostScript
.55909 .17032 m
.53128 .19739 L
s
% Start of user PostScript
7.7 2.3 7.3 2.7 MAarrowhead1
% End of user PostScript
.62861 .17032 m
.6008 .19739 L
s
% Start of user PostScript
8.7 2.3 8.3 2.7 MAarrowhead1
% End of user PostScript
.69812 .15003 m
.67032 .15003 L
s
% Start of user PostScript
9.7 2. 9.3 2. MAarrowhead1
% End of user PostScript
.76764 .17032 m
.73983 .19739 L
s
% Start of user PostScript
10.7 2.3 10.3 2.7 MAarrowhead1
% End of user PostScript
.83716 .15003 m
.80935 .15003 L
s
% Start of user PostScript
11.7 2. 11.3 2. MAarrowhead1
% End of user PostScript
.90667 .15003 m
.87887 .15003 L
s
% Start of user PostScript
12.7 2. 12.3 2. MAarrowhead1
% End of user PostScript
.97619 .17032 m
.94838 .19739 L
s
% Start of user PostScript
13.7 2.3 13.3 2.7 MAarrowhead1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .01472 m
.02381 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.28102 .10267 m
.25322 .12973 L
s
% Start of user PostScript
3.7 1.3 3.3 1.7 MAarrowhead1
% End of user PostScript
.37139 .10267 m
.37139 .12973 L
s
% Start of user PostScript
5. 1.3 5. 1.7 MAarrowhead1
% End of user PostScript
.42006 .10267 m
.39225 .12973 L
s
% Start of user PostScript
5.7 1.3 5.3 1.7 MAarrowhead1
% End of user PostScript
.51043 .10267 m
.51043 .12973 L
s
% Start of user PostScript
7. 1.3 7. 1.7 MAarrowhead1
% End of user PostScript
.57994 .10267 m
.57994 .12973 L
s
% Start of user PostScript
8. 1.3 8. 1.7 MAarrowhead1
% End of user PostScript
.62861 .10267 m
.6008 .12973 L
s
% Start of user PostScript
8.7 1.3 8.3 1.7 MAarrowhead1
% End of user PostScript
.69812 .10267 m
.67032 .12973 L
s
% Start of user PostScript
9.7 1.3 9.3 1.7 MAarrowhead1
% End of user PostScript
.76764 .08237 m
.73983 .08237 L
s
% Start of user PostScript
10.7 1. 10.3 1. MAarrowhead1
% End of user PostScript
.83716 .10267 m
.80935 .12973 L
s
% Start of user PostScript
11.7 1.3 11.3 1.7 MAarrowhead1
% End of user PostScript
.90667 .08237 m
.87887 .08237 L
s
% Start of user PostScript
12.7 1. 12.3 1. MAarrowhead1
% End of user PostScript
.97619 .10267 m
.94838 .12973 L
s
% Start of user PostScript
13.7 1.3 13.3 1.7 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3oool00`000000oooo0?oo
o`3o0?oooaL0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003E0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0803oool00=@0oooo2@00000N0?ooo`T00000703oool00=D0oooo00<0
00000?ooo`3oool0903oool200000280oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo001@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`060?ooo`00C`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool01`3oool004h0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo001=0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`090?ooo`00C03oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02P3oool004T0oooo00<0
00000?ooo`0000007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000001h0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool000000140oooo00<0
00000?ooo`000000903oool010000000oooo0?ooo`00000T0?ooo`030000003oool0000000d0oooo
00190?ooo`8000007P3oool3000000D0oooo0P00000N0?ooo`<000004@3oool3000000D0oooo0P00
000B0?ooo`8000009@3oool3000002D0oooo0P00000>0?ooo`00B03oool4000001d0oooo0P000005
0?ooo`<000007P3oool200000180oooo0P0000050?ooo`<000004@3oool3000002D0oooo0`00000T
0?ooo`@000003@3oool004P0oooo0P00000P0?ooo`030000003oool0oooo00<0oooo0P00000P0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool200000180oooo0P00000V0?oo
o`8000009@3oool2000000l0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo00310?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0P0?ooo`00`03oool9000001l0oooo2@00000:0?ooo`T00000703oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003`0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`060?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00L0oooo000j0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0203o
ool003T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`090?ooo`00>03oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo000g0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool02`3oool003D0oooo0P00000V0?ooo`8000007`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00@0oooo0P00000B0?ooo`8000009@3oool00`000000oooo
0000000i0?ooo`8000003P3oool003@0oooo1000000T0?ooo`@000007@3oool300000140oooo0`00
00040?ooo`<000004@3oool3000002D0oooo0`00000h0?ooo`@000003@3oool003@0oooo0P00000V
0?ooo`800000803oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo0P00000B
0?ooo`8000009P3oool2000003T0oooo0P00000?0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00[@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`00[03oool90000
00/0oooo2@00000;0?ooo`T00000<P3oool9000000P0oooo002]0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`8000003P3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool006X0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo001Z0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`00JP3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0703o
ool006X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01d0oooo001Z0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool20000
0180oooo0P00001H0?ooo`030000003oool0oooo00H0oooo0P00000P0?ooo`00JP3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo0P00000B0?ooo`800000FP3oool00`000000
oooo0?ooo`040?ooo`8000008P3oool006T0oooo0`00000A0?ooo`<00000103oool200000180oooo
0P00001K0?ooo`800000103oool300000280oooo001Z0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool00`3oool300000140oooo0`00001J0?ooo`030000003oool0oooo00<0oooo1000
000Q0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00Q03oool9000000/0oooo2@00000O0?ooo`T00000<P3oool9000001`0oooo00250?oo
o`8000004P3oool2000002H0oooo00<000000?ooo`3oool0>03oool200000280oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000Y0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00H0oooo000X0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo000W0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000V0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00T0oooo000U0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00X0oooo000Q0?oo
o`040000003oool0oooo000004D0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000i
0?ooo`030000003oool000000380oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
000T0?ooo`030000003oool0000000d0oooo000Q0?ooo`<00000A@3oool3000000D0oooo0P00000j
0?ooo`800000<P3oool2000000D0oooo0`00000U0?ooo`8000003P3oool00240oooo0`0000150?oo
o`8000001@3oool3000003T0oooo0`00000b0?ooo`8000001@3oool3000002@0oooo1000000=0?oo
o`008@3oool2000004L0oooo00<000000?ooo`3oool00`3oool2000003X0oooo0P00000d0?ooo`03
0000003oool0oooo00<0oooo0P00000U0?ooo`8000003`3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00780oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0=03oool00700oooo
2@00000;0?ooo`T000002`3oool9000004L0oooo2@00000_0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00?03oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0@@3oool003/0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0480oooo000j0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`130?ooo`00>@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03oool003P0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04D0
oooo000g0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`160?ooo`00=@3oool2000001l0oooo00<000000?ooo`3oool0103oool2000004h0oooo0P00
000B0?ooo`8000004@3oool00`000000oooo000000190?ooo`00=03oool4000001d0oooo0`000004
0?ooo`@00000C03oool300000140oooo0`00000A0?ooo`<00000B@3oool003@0oooo0P00000P0?oo
o`030000003oool0oooo00<0oooo0P00001>0?ooo`8000004P3oool200000180oooo0P00001:0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00GP3oool00`00
0000oooo0?ooo`2o0?ooo`00G03oool900000;/0oooo001M0?ooo`800000`@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003`0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
@@3oool003/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0@P3oool003X0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0@`3oool0
03T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0A03oool003P0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0A@3oool003D0oooo
00<000000?ooo`0000004@3oool00`000000oooo0000001=0?ooo`030000003oool0000003P0oooo
00@000000?ooo`3oool00000B03oool003D0oooo0P00000B0?ooo`800000CP3oool2000003T0oooo
0`0000190?ooo`00=03oool400000100oooo1000001<0?ooo`<00000>@3oool3000004T0oooo000d
0?ooo`8000004P3oool2000004h0oooo0P00000j0?ooo`800000BP3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool002T0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02d0oooo000X0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0^0?ooo`00
9`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
;`3oool002H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0300oooo000U0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0a0?ooo`00903oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0<P3oool00240oooo00<000000?ooo`0000004@3oool2000002H0
oooo0P00000B0?ooo`8000004P3oool2000002H0oooo0P00000B0?ooo`8000004@3oool00`000000
oooo0000000A0?ooo`030000003oool0000003D0oooo000Q0?ooo`<00000403oool4000002@0oooo
1000000@0?ooo`<000004@3oool3000002D0oooo0`00000A0?ooo`<000004@3oool300000140oooo
0`00000e0?ooo`008@3oool200000140oooo0P00000V0?ooo`8000004P3oool200000180oooo0P00
000V0?ooo`8000004P3oool200000180oooo0P00000B0?ooo`800000=P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003H0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`2G0?ooo`00=03oool9000004L0oooo2@00002C0?ooo`00=@3oool20000
04h0oooo0P00002I0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00:@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02d0oooo000X0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0;P3oool002L0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0_0?ooo`009P3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0300oooo000T0?ooo`800000C@3oool2000003X0oooo0P00000B0?ooo`8000009P3oool2
000003<0oooo000Q0?ooo`030000003oool0000004d0oooo0P00000j0?ooo`8000004P3oool20000
02D0oooo00<000000?ooo`000000=@3oool00240oooo0P00001=0?ooo`800000>P3oool200000180
oooo0P00000V0?ooo`800000=P3oool00240oooo0`00001<0?ooo`<00000>@3oool300000140oooo
0`00000U0?ooo`<00000=@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.36034, -0.217546, \
0.0502462, 0.0516286}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pW5 = 
        Show[pW4, grW1, gr3, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0555556 0.0634921 0.0147151 0.0560575 [
[.11905 .57529 -5 -6.28125 ]
[.11905 .57529 5 6.28125 ]
[.18254 .57529 -5 -6.28125 ]
[.18254 .57529 5 6.28125 ]
[.24603 .57529 -5 -6.28125 ]
[.24603 .57529 5 6.28125 ]
[.30952 .57529 -5 -6.28125 ]
[.30952 .57529 5 6.28125 ]
[.37302 .57529 -5 -6.28125 ]
[.37302 .57529 5 6.28125 ]
[.43651 .57529 -5 -6.28125 ]
[.43651 .57529 5 6.28125 ]
[.5 .57529 -5 -6.28125 ]
[.5 .57529 5 6.28125 ]
[.56349 .57529 -5 -6.28125 ]
[.56349 .57529 5 6.28125 ]
[.62698 .57529 -5 -6.28125 ]
[.62698 .57529 5 6.28125 ]
[.69048 .57529 -5 -6.28125 ]
[.69048 .57529 5 6.28125 ]
[.75397 .57529 -5 -6.28125 ]
[.75397 .57529 5 6.28125 ]
[.81746 .57529 -5 -6.28125 ]
[.81746 .57529 5 6.28125 ]
[.88095 .57529 -5 -6.28125 ]
[.88095 .57529 5 6.28125 ]
[.94444 .57529 -5 -6.28125 ]
[.94444 .57529 5 6.28125 ]
[.05556 .51923 -5 -6.28125 ]
[.05556 .51923 5 6.28125 ]
[.05556 .46318 -5 -6.28125 ]
[.05556 .46318 5 6.28125 ]
[.05556 .40712 -5 -6.28125 ]
[.05556 .40712 5 6.28125 ]
[.05556 .35106 -5 -6.28125 ]
[.05556 .35106 5 6.28125 ]
[.05556 .295 -5 -6.28125 ]
[.05556 .295 5 6.28125 ]
[.05556 .23895 -5 -6.28125 ]
[.05556 .23895 5 6.28125 ]
[.05556 .18289 -5 -6.28125 ]
[.05556 .18289 5 6.28125 ]
[.05556 .12683 -5 -6.28125 ]
[.05556 .12683 5 6.28125 ]
[.05556 .07077 -5 -6.28125 ]
[.05556 .07077 5 6.28125 ]
[.11905 .51923 -3 -4.5 ]
[.11905 .51923 3 4.5 ]
[.18254 .51923 -3 -4.5 ]
[.18254 .51923 3 4.5 ]
[.24603 .51923 -3 -4.5 ]
[.24603 .51923 3 4.5 ]
[.30952 .51923 -3 -4.5 ]
[.30952 .51923 3 4.5 ]
[.37302 .51923 -3 -4.5 ]
[.37302 .51923 3 4.5 ]
[.43651 .51923 -3 -4.5 ]
[.43651 .51923 3 4.5 ]
[.5 .51923 -3 -4.5 ]
[.5 .51923 3 4.5 ]
[.56349 .51923 -3 -4.5 ]
[.56349 .51923 3 4.5 ]
[.62698 .51923 -3 -4.5 ]
[.62698 .51923 3 4.5 ]
[.69048 .51923 -3 -4.5 ]
[.69048 .51923 3 4.5 ]
[.75397 .51923 -3 -4.5 ]
[.75397 .51923 3 4.5 ]
[.81746 .51923 -3 -4.5 ]
[.81746 .51923 3 4.5 ]
[.88095 .51923 -3 -4.5 ]
[.88095 .51923 3 4.5 ]
[.94444 .51923 -3 -4.5 ]
[.94444 .51923 3 4.5 ]
[.11905 .46318 -3 -4.5 ]
[.11905 .46318 3 4.5 ]
[.18254 .46318 -3 -4.5 ]
[.18254 .46318 3 4.5 ]
[.24603 .46318 -3 -4.5 ]
[.24603 .46318 3 4.5 ]
[.30952 .46318 -3 -4.5 ]
[.30952 .46318 3 4.5 ]
[.37302 .46318 -3 -4.5 ]
[.37302 .46318 3 4.5 ]
[.43651 .46318 -3 -4.5 ]
[.43651 .46318 3 4.5 ]
[.5 .46318 -3 -4.5 ]
[.5 .46318 3 4.5 ]
[.56349 .46318 -3 -4.5 ]
[.56349 .46318 3 4.5 ]
[.62698 .46318 -3 -4.5 ]
[.62698 .46318 3 4.5 ]
[.69048 .46318 -3 -4.5 ]
[.69048 .46318 3 4.5 ]
[.75397 .46318 -3 -4.5 ]
[.75397 .46318 3 4.5 ]
[.81746 .46318 -3 -4.5 ]
[.81746 .46318 3 4.5 ]
[.88095 .46318 -3 -4.5 ]
[.88095 .46318 3 4.5 ]
[.94444 .46318 -3 -4.5 ]
[.94444 .46318 3 4.5 ]
[.11905 .40712 -3 -4.5 ]
[.11905 .40712 3 4.5 ]
[.18254 .40712 -3 -4.5 ]
[.18254 .40712 3 4.5 ]
[.24603 .40712 -3 -4.5 ]
[.24603 .40712 3 4.5 ]
[.30952 .40712 -3 -4.5 ]
[.30952 .40712 3 4.5 ]
[.37302 .40712 -3 -4.5 ]
[.37302 .40712 3 4.5 ]
[.43651 .40712 -3 -4.5 ]
[.43651 .40712 3 4.5 ]
[.5 .40712 -3 -4.5 ]
[.5 .40712 3 4.5 ]
[.56349 .40712 -3 -4.5 ]
[.56349 .40712 3 4.5 ]
[.62698 .40712 -3 -4.5 ]
[.62698 .40712 3 4.5 ]
[.69048 .40712 -3 -4.5 ]
[.69048 .40712 3 4.5 ]
[.75397 .40712 -3 -4.5 ]
[.75397 .40712 3 4.5 ]
[.81746 .40712 -3 -4.5 ]
[.81746 .40712 3 4.5 ]
[.88095 .40712 -3 -4.5 ]
[.88095 .40712 3 4.5 ]
[.94444 .40712 -3 -4.5 ]
[.94444 .40712 3 4.5 ]
[.11905 .35106 -3 -4.5 ]
[.11905 .35106 3 4.5 ]
[.18254 .35106 -3 -4.5 ]
[.18254 .35106 3 4.5 ]
[.24603 .35106 -3 -4.5 ]
[.24603 .35106 3 4.5 ]
[.30952 .35106 -3 -4.5 ]
[.30952 .35106 3 4.5 ]
[.37302 .35106 -3 -4.5 ]
[.37302 .35106 3 4.5 ]
[.43651 .35106 -3 -4.5 ]
[.43651 .35106 3 4.5 ]
[.5 .35106 -3 -4.5 ]
[.5 .35106 3 4.5 ]
[.56349 .35106 -3 -4.5 ]
[.56349 .35106 3 4.5 ]
[.62698 .35106 -3 -4.5 ]
[.62698 .35106 3 4.5 ]
[.69048 .35106 -3 -4.5 ]
[.69048 .35106 3 4.5 ]
[.75397 .35106 -3 -4.5 ]
[.75397 .35106 3 4.5 ]
[.81746 .35106 -3 -4.5 ]
[.81746 .35106 3 4.5 ]
[.88095 .35106 -3 -4.5 ]
[.88095 .35106 3 4.5 ]
[.94444 .35106 -3 -4.5 ]
[.94444 .35106 3 4.5 ]
[.11905 .295 -3 -4.5 ]
[.11905 .295 3 4.5 ]
[.18254 .295 -3 -4.5 ]
[.18254 .295 3 4.5 ]
[.24603 .295 -3 -4.5 ]
[.24603 .295 3 4.5 ]
[.30952 .295 -3 -4.5 ]
[.30952 .295 3 4.5 ]
[.37302 .295 -6 -4.5 ]
[.37302 .295 6 4.5 ]
[.43651 .295 -6 -4.5 ]
[.43651 .295 6 4.5 ]
[.5 .295 -3 -4.5 ]
[.5 .295 3 4.5 ]
[.56349 .295 -3 -4.5 ]
[.56349 .295 3 4.5 ]
[.62698 .295 -3 -4.5 ]
[.62698 .295 3 4.5 ]
[.69048 .295 -3 -4.5 ]
[.69048 .295 3 4.5 ]
[.75397 .295 -3 -4.5 ]
[.75397 .295 3 4.5 ]
[.81746 .295 -3 -4.5 ]
[.81746 .295 3 4.5 ]
[.88095 .295 -3 -4.5 ]
[.88095 .295 3 4.5 ]
[.94444 .295 -3 -4.5 ]
[.94444 .295 3 4.5 ]
[.11905 .23895 -3 -4.5 ]
[.11905 .23895 3 4.5 ]
[.18254 .23895 -3 -4.5 ]
[.18254 .23895 3 4.5 ]
[.24603 .23895 -3 -4.5 ]
[.24603 .23895 3 4.5 ]
[.30952 .23895 -3 -4.5 ]
[.30952 .23895 3 4.5 ]
[.37302 .23895 -6 -4.5 ]
[.37302 .23895 6 4.5 ]
[.43651 .23895 -6 -4.5 ]
[.43651 .23895 6 4.5 ]
[.5 .23895 -6 -4.5 ]
[.5 .23895 6 4.5 ]
[.56349 .23895 -3 -4.5 ]
[.56349 .23895 3 4.5 ]
[.62698 .23895 -3 -4.5 ]
[.62698 .23895 3 4.5 ]
[.69048 .23895 -3 -4.5 ]
[.69048 .23895 3 4.5 ]
[.75397 .23895 -3 -4.5 ]
[.75397 .23895 3 4.5 ]
[.81746 .23895 -3 -4.5 ]
[.81746 .23895 3 4.5 ]
[.88095 .23895 -3 -4.5 ]
[.88095 .23895 3 4.5 ]
[.94444 .23895 -3 -4.5 ]
[.94444 .23895 3 4.5 ]
[.11905 .18289 -3 -4.5 ]
[.11905 .18289 3 4.5 ]
[.18254 .18289 -3 -4.5 ]
[.18254 .18289 3 4.5 ]
[.24603 .18289 -3 -4.5 ]
[.24603 .18289 3 4.5 ]
[.30952 .18289 -3 -4.5 ]
[.30952 .18289 3 4.5 ]
[.37302 .18289 -3 -4.5 ]
[.37302 .18289 3 4.5 ]
[.43651 .18289 -6 -4.5 ]
[.43651 .18289 6 4.5 ]
[.5 .18289 -6 -4.5 ]
[.5 .18289 6 4.5 ]
[.56349 .18289 -6 -4.5 ]
[.56349 .18289 6 4.5 ]
[.62698 .18289 -6 -4.5 ]
[.62698 .18289 6 4.5 ]
[.69048 .18289 -3 -4.5 ]
[.69048 .18289 3 4.5 ]
[.75397 .18289 -3 -4.5 ]
[.75397 .18289 3 4.5 ]
[.81746 .18289 -3 -4.5 ]
[.81746 .18289 3 4.5 ]
[.88095 .18289 -3 -4.5 ]
[.88095 .18289 3 4.5 ]
[.94444 .18289 -3 -4.5 ]
[.94444 .18289 3 4.5 ]
[.11905 .12683 -3 -4.5 ]
[.11905 .12683 3 4.5 ]
[.18254 .12683 -3 -4.5 ]
[.18254 .12683 3 4.5 ]
[.24603 .12683 -3 -4.5 ]
[.24603 .12683 3 4.5 ]
[.30952 .12683 -3 -4.5 ]
[.30952 .12683 3 4.5 ]
[.37302 .12683 -3 -4.5 ]
[.37302 .12683 3 4.5 ]
[.43651 .12683 -3 -4.5 ]
[.43651 .12683 3 4.5 ]
[.5 .12683 -6 -4.5 ]
[.5 .12683 6 4.5 ]
[.56349 .12683 -6 -4.5 ]
[.56349 .12683 6 4.5 ]
[.62698 .12683 -6 -4.5 ]
[.62698 .12683 6 4.5 ]
[.69048 .12683 -6 -4.5 ]
[.69048 .12683 6 4.5 ]
[.75397 .12683 -6 -4.5 ]
[.75397 .12683 6 4.5 ]
[.81746 .12683 -6 -4.5 ]
[.81746 .12683 6 4.5 ]
[.88095 .12683 -3 -4.5 ]
[.88095 .12683 3 4.5 ]
[.94444 .12683 -3 -4.5 ]
[.94444 .12683 3 4.5 ]
[.11905 .07077 -3 -4.5 ]
[.11905 .07077 3 4.5 ]
[.18254 .07077 -3 -4.5 ]
[.18254 .07077 3 4.5 ]
[.24603 .07077 -3 -4.5 ]
[.24603 .07077 3 4.5 ]
[.30952 .07077 -3 -4.5 ]
[.30952 .07077 3 4.5 ]
[.37302 .07077 -3 -4.5 ]
[.37302 .07077 3 4.5 ]
[.43651 .07077 -3 -4.5 ]
[.43651 .07077 3 4.5 ]
[.5 .07077 -3 -4.5 ]
[.5 .07077 3 4.5 ]
[.56349 .07077 -6 -4.5 ]
[.56349 .07077 6 4.5 ]
[.62698 .07077 -6 -4.5 ]
[.62698 .07077 6 4.5 ]
[.69048 .07077 -6 -4.5 ]
[.69048 .07077 6 4.5 ]
[.75397 .07077 -6 -4.5 ]
[.75397 .07077 6 4.5 ]
[.81746 .07077 -6 -4.5 ]
[.81746 .07077 6 4.5 ]
[.88095 .07077 -6 -4.5 ]
[.88095 .07077 6 4.5 ]
[.94444 .07077 -6 -4.5 ]
[.94444 .07077 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto fill
-0.2 0.1 moveto 0 0 lineto
-0.2 -0.1 lineto
-0.2 0.1 lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.2 0.2 moveto 0 0 lineto
-0.2 -0.2 lineto fill
-0.2 0.2 moveto 0 0 lineto
-0.2 -0.2 lineto
-0.2 0.2 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.9 g
.0873 .54726 m
.0873 .60332 L
.97619 .60332 L
.97619 .54726 L
F
0 g
gsave
.11905 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18254 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24603 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30952 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37302 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43651 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56349 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62698 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75397 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81746 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88095 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.94444 .57529 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.9 g
.02381 .01472 m
.02381 .60332 L
.0873 .60332 L
.0873 .01472 L
F
0 g
gsave
.05556 .51923 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .46318 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .40712 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .35106 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .295 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .23895 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .18289 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .12683 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05556 .07077 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
[(0)] .11905 .51923 0 0 Mshowa
[(0)] .18254 .51923 0 0 Mshowa
[(0)] .24603 .51923 0 0 Mshowa
[(0)] .30952 .51923 0 0 Mshowa
[(0)] .37302 .51923 0 0 Mshowa
[(0)] .43651 .51923 0 0 Mshowa
[(0)] .5 .51923 0 0 Mshowa
[(0)] .56349 .51923 0 0 Mshowa
[(0)] .62698 .51923 0 0 Mshowa
[(0)] .69048 .51923 0 0 Mshowa
[(0)] .75397 .51923 0 0 Mshowa
[(0)] .81746 .51923 0 0 Mshowa
[(0)] .88095 .51923 0 0 Mshowa
[(0)] .94444 .51923 0 0 Mshowa
[(0)] .11905 .46318 0 0 Mshowa
[(5)] .18254 .46318 0 0 Mshowa
[(0)] .24603 .46318 0 0 Mshowa
[(0)] .30952 .46318 0 0 Mshowa
[(0)] .37302 .46318 0 0 Mshowa
[(5)] .43651 .46318 0 0 Mshowa
[(0)] .5 .46318 0 0 Mshowa
[(0)] .56349 .46318 0 0 Mshowa
[(0)] .62698 .46318 0 0 Mshowa
[(1)] .69048 .46318 0 0 Mshowa
[(0)] .75397 .46318 0 0 Mshowa
[(0)] .81746 .46318 0 0 Mshowa
[(0)] .88095 .46318 0 0 Mshowa
[(0)] .94444 .46318 0 0 Mshowa
[(0)] .11905 .40712 0 0 Mshowa
[(1)] .18254 .40712 0 0 Mshowa
[(3)] .24603 .40712 0 0 Mshowa
[(0)] .30952 .40712 0 0 Mshowa
[(0)] .37302 .40712 0 0 Mshowa
[(1)] .43651 .40712 0 0 Mshowa
[(4)] .5 .40712 0 0 Mshowa
[(0)] .56349 .40712 0 0 Mshowa
[(0)] .62698 .40712 0 0 Mshowa
[(2)] .69048 .40712 0 0 Mshowa
[(1)] .75397 .40712 0 0 Mshowa
[(0)] .81746 .40712 0 0 Mshowa
[(0)] .88095 .40712 0 0 Mshowa
[(0)] .94444 .40712 0 0 Mshowa
[(0)] .11905 .35106 0 0 Mshowa
[(0)] .18254 .35106 0 0 Mshowa
[(4)] .24603 .35106 0 0 Mshowa
[(9)] .30952 .35106 0 0 Mshowa
[(4)] .37302 .35106 0 0 Mshowa
[(0)] .43651 .35106 0 0 Mshowa
[(0)] .5 .35106 0 0 Mshowa
[(1)] .56349 .35106 0 0 Mshowa
[(0)] .62698 .35106 0 0 Mshowa
[(0)] .69048 .35106 0 0 Mshowa
[(1)] .75397 .35106 0 0 Mshowa
[(0)] .81746 .35106 0 0 Mshowa
[(0)] .88095 .35106 0 0 Mshowa
[(0)] .94444 .35106 0 0 Mshowa
[(0)] .11905 .295 0 0 Mshowa
[(0)] .18254 .295 0 0 Mshowa
[(2)] .24603 .295 0 0 Mshowa
[(4)] .30952 .295 0 0 Mshowa
[(17)] .37302 .295 0 0 Mshowa
[(12)] .43651 .295 0 0 Mshowa
[(7)] .5 .295 0 0 Mshowa
[(2)] .56349 .295 0 0 Mshowa
[(2)] .62698 .295 0 0 Mshowa
[(0)] .69048 .295 0 0 Mshowa
[(8)] .75397 .295 0 0 Mshowa
[(3)] .81746 .295 0 0 Mshowa
[(0)] .88095 .295 0 0 Mshowa
[(0)] .94444 .295 0 0 Mshowa
[(0)] .11905 .23895 0 0 Mshowa
[(0)] .18254 .23895 0 0 Mshowa
[(0)] .24603 .23895 0 0 Mshowa
[(0)] .30952 .23895 0 0 Mshowa
[(12)] .37302 .23895 0 0 Mshowa
[(17)] .43651 .23895 0 0 Mshowa
[(12)] .5 .23895 0 0 Mshowa
[(7)] .56349 .23895 0 0 Mshowa
[(8)] .62698 .23895 0 0 Mshowa
[(3)] .69048 .23895 0 0 Mshowa
[(3)] .75397 .23895 0 0 Mshowa
[(9)] .81746 .23895 0 0 Mshowa
[(4)] .88095 .23895 0 0 Mshowa
[(0)] .94444 .23895 0 0 Mshowa
[(0)] .11905 .18289 0 0 Mshowa
[(0)] .18254 .18289 0 0 Mshowa
[(0)] .24603 .18289 0 0 Mshowa
[(0)] .30952 .18289 0 0 Mshowa
[(7)] .37302 .18289 0 0 Mshowa
[(12)] .43651 .18289 0 0 Mshowa
[(17)] .5 .18289 0 0 Mshowa
[(18)] .56349 .18289 0 0 Mshowa
[(13)] .62698 .18289 0 0 Mshowa
[(8)] .69048 .18289 0 0 Mshowa
[(3)] .75397 .18289 0 0 Mshowa
[(4)] .81746 .18289 0 0 Mshowa
[(7)] .88095 .18289 0 0 Mshowa
[(2)] .94444 .18289 0 0 Mshowa
[(0)] .11905 .12683 0 0 Mshowa
[(0)] .18254 .12683 0 0 Mshowa
[(2)] .24603 .12683 0 0 Mshowa
[(0)] .30952 .12683 0 0 Mshowa
[(8)] .37302 .12683 0 0 Mshowa
[(7)] .43651 .12683 0 0 Mshowa
[(12)] .5 .12683 0 0 Mshowa
[(15)] .56349 .12683 0 0 Mshowa
[(19)] .62698 .12683 0 0 Mshowa
[(14)] .69048 .12683 0 0 Mshowa
[(16)] .75397 .12683 0 0 Mshowa
[(11)] .81746 .12683 0 0 Mshowa
[(6)] .88095 .12683 0 0 Mshowa
[(5)] .94444 .12683 0 0 Mshowa
[(0)] .11905 .07077 0 0 Mshowa
[(0)] .18254 .07077 0 0 Mshowa
[(0)] .24603 .07077 0 0 Mshowa
[(0)] .30952 .07077 0 0 Mshowa
[(3)] .37302 .07077 0 0 Mshowa
[(7)] .43651 .07077 0 0 Mshowa
[(7)] .5 .07077 0 0 Mshowa
[(10)] .56349 .07077 0 0 Mshowa
[(15)] .62698 .07077 0 0 Mshowa
[(18)] .69048 .07077 0 0 Mshowa
[(13)] .75397 .07077 0 0 Mshowa
[(17)] .81746 .07077 0 0 Mshowa
[(12)] .88095 .07077 0 0 Mshowa
[(11)] .94444 .07077 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.16349 .47999 m
.1381 .50242 L
s
% Start of user PostScript
1.7 8.3 1.3 8.7 MAarrowhead1
% End of user PostScript
.22698 .46318 m
.20159 .46318 L
s
% Start of user PostScript
2.7 8. 2.3 8. MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.41746 .47999 m
.39206 .50242 L
s
% Start of user PostScript
5.7 8.3 5.3 8.7 MAarrowhead1
% End of user PostScript
.48095 .46318 m
.45556 .46318 L
s
% Start of user PostScript
6.7 8. 6.3 8. MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.60794 .47999 m
.58254 .50242 L
s
% Start of user PostScript
8.7 8.3 8.3 8.7 MAarrowhead1
% End of user PostScript
.67143 .47999 m
.64603 .50242 L
s
% Start of user PostScript
9.7 8.3 9.3 8.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.79841 .47999 m
.77302 .50242 L
s
% Start of user PostScript
11.7 8.3 11.3 8.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.16349 .42393 m
.1381 .44636 L
s
% Start of user PostScript
1.7 7.3 1.3 7.7 MAarrowhead1
% End of user PostScript
.22698 .42393 m
.20159 .44636 L
s
% Start of user PostScript
2.7 7.3 2.3 7.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.35397 .42393 m
.32857 .44636 L
s
% Start of user PostScript
4.7 7.3 4.3 7.7 MAarrowhead1
% End of user PostScript
.41746 .42393 m
.39206 .44636 L
s
% Start of user PostScript
5.7 7.3 5.3 7.7 MAarrowhead1
% End of user PostScript
.48095 .42393 m
.45556 .44636 L
s
% Start of user PostScript
6.7 7.3 6.3 7.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.60794 .42393 m
.58254 .44636 L
s
% Start of user PostScript
8.7 7.3 8.3 7.7 MAarrowhead1
% End of user PostScript
.67143 .42393 m
.64603 .44636 L
s
% Start of user PostScript
9.7 7.3 9.3 7.7 MAarrowhead1
% End of user PostScript
.73492 .42393 m
.70952 .44636 L
s
% Start of user PostScript
10.7 7.3 10.3 7.7 MAarrowhead1
% End of user PostScript
.79841 .42393 m
.77302 .44636 L
s
% Start of user PostScript
11.7 7.3 11.3 7.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.22698 .36788 m
.20159 .3903 L
s
% Start of user PostScript
2.7 6.3 2.3 6.7 MAarrowhead1
% End of user PostScript
.29048 .36788 m
.26508 .3903 L
s
% Start of user PostScript
3.7 6.3 3.3 6.7 MAarrowhead1
% End of user PostScript
.35397 .35106 m
.32857 .35106 L
s
% Start of user PostScript
4.7 6. 4.3 6. MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.54444 .36788 m
.51905 .3903 L
s
% Start of user PostScript
7.7 6.3 7.3 6.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.73492 .36788 m
.70952 .3903 L
s
% Start of user PostScript
10.7 6.3 10.3 6.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.22698 .31182 m
.20159 .33424 L
s
% Start of user PostScript
2.7 5.3 2.3 5.7 MAarrowhead1
% End of user PostScript
.30952 .31182 m
.30952 .33424 L
s
% Start of user PostScript
4. 5.3 4. 5.7 MAarrowhead1
% End of user PostScript
.35397 .31182 m
.32857 .33424 L
s
% Start of user PostScript
4.7 5.3 4.3 5.7 MAarrowhead1
% End of user PostScript
.41746 .295 m
.39206 .295 L
s
% Start of user PostScript
5.7 5. 5.3 5. MAarrowhead1
% End of user PostScript
.48095 .295 m
.45556 .295 L
s
% Start of user PostScript
6.7 5. 6.3 5. MAarrowhead1
% End of user PostScript
.54444 .295 m
.51905 .295 L
s
% Start of user PostScript
7.7 5. 7.3 5. MAarrowhead1
% End of user PostScript
.60794 .31182 m
.58254 .33424 L
s
% Start of user PostScript
8.7 5.3 8.3 5.7 MAarrowhead1
% End of user PostScript
.67143 .31182 m
.64603 .33424 L
s
% Start of user PostScript
9.7 5.3 9.3 5.7 MAarrowhead1
% End of user PostScript
.73492 .31182 m
.70952 .33424 L
s
% Start of user PostScript
10.7 5.3 10.3 5.7 MAarrowhead1
% End of user PostScript
.79841 .295 m
.77302 .295 L
s
% Start of user PostScript
11.7 5. 11.3 5. MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.16349 .25576 m
.1381 .27819 L
s
% Start of user PostScript
1.7 4.3 1.3 4.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.37302 .25576 m
.37302 .27819 L
s
% Start of user PostScript
5. 4.3 5. 4.7 MAarrowhead1
% End of user PostScript
.41746 .25576 m
.39206 .27819 L
s
% Start of user PostScript
5.7 4.3 5.3 4.7 MAarrowhead1
% End of user PostScript
.48095 .23895 m
.45556 .23895 L
s
% Start of user PostScript
6.7 4. 6.3 4. MAarrowhead1
% End of user PostScript
.54444 .23895 m
.51905 .23895 L
s
% Start of user PostScript
7.7 4. 7.3 4. MAarrowhead1
% End of user PostScript
.60794 .25576 m
.58254 .27819 L
s
% Start of user PostScript
8.7 4.3 8.3 4.7 MAarrowhead1
% End of user PostScript
.67143 .23895 m
.64603 .23895 L
s
% Start of user PostScript
9.7 4. 9.3 4. MAarrowhead1
% End of user PostScript
.75397 .25576 m
.75397 .27819 L
s
% Start of user PostScript
11. 4.3 11. 4.7 MAarrowhead1
% End of user PostScript
.79841 .25576 m
.77302 .27819 L
s
% Start of user PostScript
11.7 4.3 11.3 4.7 MAarrowhead1
% End of user PostScript
.8619 .23895 m
.83651 .23895 L
s
% Start of user PostScript
12.7 4. 12.3 4. MAarrowhead1
% End of user PostScript
.9254 .25576 m
.9 .27819 L
s
% Start of user PostScript
13.7 4.3 13.3 4.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.37302 .1997 m
.37302 .22213 L
s
% Start of user PostScript
5. 3.3 5. 3.7 MAarrowhead1
% End of user PostScript
.43651 .1997 m
.43651 .22213 L
s
% Start of user PostScript
6. 3.3 6. 3.7 MAarrowhead1
% End of user PostScript
.48095 .1997 m
.45556 .22213 L
s
% Start of user PostScript
6.7 3.3 6.3 3.7 MAarrowhead1
% End of user PostScript
.54444 .1997 m
.51905 .22213 L
s
% Start of user PostScript
7.7 3.3 7.3 3.7 MAarrowhead1
% End of user PostScript
.60794 .18289 m
.58254 .18289 L
s
% Start of user PostScript
8.7 3. 8.3 3. MAarrowhead1
% End of user PostScript
.67143 .18289 m
.64603 .18289 L
s
% Start of user PostScript
9.7 3. 9.3 3. MAarrowhead1
% End of user PostScript
.73492 .18289 m
.70952 .18289 L
s
% Start of user PostScript
10.7 3. 10.3 3. MAarrowhead1
% End of user PostScript
.81746 .1997 m
.81746 .22213 L
s
% Start of user PostScript
12. 3.3 12. 3.7 MAarrowhead1
% End of user PostScript
.8619 .1997 m
.83651 .22213 L
s
% Start of user PostScript
12.7 3.3 12.3 3.7 MAarrowhead1
% End of user PostScript
.9254 .18289 m
.9 .18289 L
s
% Start of user PostScript
13.7 3. 13.3 3. MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.22698 .14365 m
.20159 .16607 L
s
% Start of user PostScript
2.7 2.3 2.3 2.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.35397 .14365 m
.32857 .16607 L
s
% Start of user PostScript
4.7 2.3 4.3 2.7 MAarrowhead1
% End of user PostScript
.43651 .14365 m
.43651 .16607 L
s
% Start of user PostScript
6. 2.3 6. 2.7 MAarrowhead1
% End of user PostScript
.5 .14365 m
.5 .16607 L
s
% Start of user PostScript
7. 2.3 7. 2.7 MAarrowhead1
% End of user PostScript
.54444 .14365 m
.51905 .16607 L
s
% Start of user PostScript
7.7 2.3 7.3 2.7 MAarrowhead1
% End of user PostScript
.60794 .14365 m
.58254 .16607 L
s
% Start of user PostScript
8.7 2.3 8.3 2.7 MAarrowhead1
% End of user PostScript
.67143 .12683 m
.64603 .12683 L
s
% Start of user PostScript
9.7 2. 9.3 2. MAarrowhead1
% End of user PostScript
.73492 .14365 m
.70952 .16607 L
s
% Start of user PostScript
10.7 2.3 10.3 2.7 MAarrowhead1
% End of user PostScript
.79841 .12683 m
.77302 .12683 L
s
% Start of user PostScript
11.7 2. 11.3 2. MAarrowhead1
% End of user PostScript
.8619 .12683 m
.83651 .12683 L
s
% Start of user PostScript
12.7 2. 12.3 2. MAarrowhead1
% End of user PostScript
.9254 .14365 m
.9 .16607 L
s
% Start of user PostScript
13.7 2.3 13.3 2.7 MAarrowhead1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.05556 .01472 m
.05556 .01472 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.29048 .08759 m
.26508 .11001 L
s
% Start of user PostScript
3.7 1.3 3.3 1.7 MAarrowhead1
% End of user PostScript
.37302 .08759 m
.37302 .11001 L
s
% Start of user PostScript
5. 1.3 5. 1.7 MAarrowhead1
% End of user PostScript
.41746 .08759 m
.39206 .11001 L
s
% Start of user PostScript
5.7 1.3 5.3 1.7 MAarrowhead1
% End of user PostScript
.5 .08759 m
.5 .11001 L
s
% Start of user PostScript
7. 1.3 7. 1.7 MAarrowhead1
% End of user PostScript
.56349 .08759 m
.56349 .11001 L
s
% Start of user PostScript
8. 1.3 8. 1.7 MAarrowhead1
% End of user PostScript
.60794 .08759 m
.58254 .11001 L
s
% Start of user PostScript
8.7 1.3 8.3 1.7 MAarrowhead1
% End of user PostScript
.67143 .08759 m
.64603 .11001 L
s
% Start of user PostScript
9.7 1.3 9.3 1.7 MAarrowhead1
% End of user PostScript
.73492 .07077 m
.70952 .07077 L
s
% Start of user PostScript
10.7 1. 10.3 1. MAarrowhead1
% End of user PostScript
.79841 .08759 m
.77302 .11001 L
s
% Start of user PostScript
11.7 1.3 11.3 1.7 MAarrowhead1
% End of user PostScript
.8619 .07077 m
.83651 .07077 L
s
% Start of user PostScript
12.7 1. 12.3 1. MAarrowhead1
% End of user PostScript
.9254 .08759 m
.9 .11001 L
s
% Start of user PostScript
13.7 1.3 13.3 1.7 MAarrowhead1
% End of user PostScript
.6 g
3 Mabswid
.60794 .14365 m
.58254 .16607 L
s
% Start of user PostScript
8.7 2.3 8.3 2.7 MAarrowhead2
% End of user PostScript
.54444 .1997 m
.51905 .22213 L
s
% Start of user PostScript
7.7 3.3 7.3 3.7 MAarrowhead2
% End of user PostScript
.48095 .23895 m
.45556 .23895 L
s
% Start of user PostScript
6.7 4. 6.3 4. MAarrowhead2
% End of user PostScript
.41746 .25576 m
.39206 .27819 L
s
% Start of user PostScript
5.7 4.3 5.3 4.7 MAarrowhead2
% End of user PostScript
.35397 .31182 m
.32857 .33424 L
s
% Start of user PostScript
4.7 5.3 4.3 5.7 MAarrowhead2
% End of user PostScript
.29048 .36788 m
.26508 .3903 L
s
% Start of user PostScript
3.7 6.3 3.3 6.7 MAarrowhead2
% End of user PostScript
.22698 .42393 m
.20159 .44636 L
s
% Start of user PostScript
2.7 7.3 2.3 7.7 MAarrowhead2
% End of user PostScript
.16349 .47999 m
.1381 .50242 L
s
% Start of user PostScript
1.7 8.3 1.3 8.7 MAarrowhead2
% End of user PostScript
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00403oool00`000000oooo0?oo
o`3o0?ooo`h0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0
oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203o
ool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0
oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`001`3ooolB
0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KVo`3oool80?ooo`00
1`3oool70>KViP<00000203Vi^H80?ooo`800000403oool200000100oooo0P00000@0?ooo`800000
4@3oool200000140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`D00000
0P3oool2000000T0oooo1@0000020?ooo`8000002P3oool500000080oooo0P0000090?ooo`D00000
0P3oool2000000T0oooo1@0000030?ooo`030000003oool0oooo00L0oooo1@0000000`3oool00000
00000002000000P0oooo1@0000000`3oool0000000000003000000`0oooo00070?ooo`P0i^KV00<0
00000>KViP3Vi^H01`3Vi^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool0
00003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00@00000
0?ooo`3oool00000403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool000L0oooo203Vi^H00`000000i^KV0>KViP070>KViPL0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`T000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo00000008000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo
00070?ooo`P0i^KV00<000000>KViP3Vi^H01`3Vi^H70?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool2000000`0oooo00<000000?ooo`3oool00P3oool200000080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool010000000oooo0000000000070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo
00070?ooo`H0i^KV00D000000>KViP000000i^KV000000070>KViPL0oooo00@000000?ooo`3oool0
00003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`001`3oool60>KViPD0
00001`3Vi^H80?ooo`800000403oool200000100oooo0P00000@0?ooo`8000004@3oool2000000l0
oooo1000000>0?ooo`@00000303oool2000000@0oooo0P00000:0?ooo`800000103oool3000000X0
oooo0P0000040?ooo`8000002P3oool2000000@0oooo0P00000:0?ooo`8000000`3oool4000000T0
oooo0P0000040?ooo`8000002P3oool2000000@0oooo0P00000>0?ooo`001`3ooolB0>KVi_l0oooo
203oool000L0oooo4P3Vi^Hj0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0D0?ooo`001`3ooolB0>KViST0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01D0oooo00070?oooa80i^KV>03oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool000L0
oooo4P3Vi^Hf0?ooo`8000006P3oool00`000000oooo0?ooo`050?ooo`8000006P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0P00000@0?ooo`8000008P3oool2000002<0
oooo0P00000I0?ooo`001`3ooolB0>KViS@0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo
0P00000L0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0000000@0?ooo`8000008P3oool200000280oooo00<000000?ooo`0000006`3oool000L0oooo4P3V
i^Hc0?ooo`800000703oool2000000@0oooo0P00000L0?ooo`<000003`3oool3000000@0oooo0P00
000@0?ooo`8000008P3oool2000002<0oooo0P00000L0?ooo`001`3ooolB0>KViS<0oooo0`00000L
0?ooo`030000003oool0oooo0080oooo0`00000L0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00`3oool3000000l0oooo0`00000Q0?ooo`<000008P3oool3000001/0oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo1P3Vi^H3000000030>KV
iP000000000000H0i^KV203oool200000100oooo0P00000?0?ooo`@000003`3oool200000140oooo
0P00000A0?ooo`030000003oool0oooo00X0oooo1@0000000`3oool0000000000002000000P0oooo
1@0000020?ooo`8000002@3oool5000000040?ooo`0000000000000000X0oooo1@0000030?ooo`<0
00001`3oool5000000040?ooo`0000000000000000T0oooo1@0000000`3oool00000000000030000
00X0oooo0`00000@0?ooo`8000004@3oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KV
iPL0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo00l0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000@0?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo00000100oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3V
i^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool00`000000
oooo0?ooo`0>0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool00000403oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool3
000000030?ooo`000000000000H000000P3oool010000000oooo0?ooo`3oool5000000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`T000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000P000000P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00h0
oooo00070?ooo`L0i^KV100000070>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000
oooo0?ooo`00000@0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000403oool2
00000180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00P3oool2000000/0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`8000001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00800000203oool300000100oooo0P00000A0?oo
o`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV1`3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`001`3o
ool60>KViP80000000@0i^KV00000000000000001P3Vi^H80?ooo`800000403oool200000100oooo
0P00000@0?ooo`8000004@3oool2000000l0oooo1000000<0?ooo`800000103oool2000000X0oooo
0P0000040?ooo`<000002@3oool2000000@0oooo0`00000:0?ooo`8000001@3oool2000000T0oooo
0P0000040?ooo`<000002@3oool2000000@0oooo0P00000=0?ooo`<000003`3oool300000100oooo
00070?oooa80i^KVU03oool309VIVG00oooo00070?oooa80i^KV:03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00d0oooo1@2IVITQ0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0503oool000L0oooo4P3Vi^HW0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool03@3oool409VIVB80oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0E0?oo
o`001`3ooolB0>KViRH0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool2000000l0oooo102IVITR0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool05P3oool000L0oooo4P3Vi^HT0?ooo`800000
8P3oool2000001X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00`0oooo00<0VIVI0?ooo`2IVIT00`2IVITQ0?ooo`800000=@3oool2000001T0oooo
00070?oooa80i^KV8@3oool00`000000oooo0000000R0?ooo`800000703oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000003`3oool509VIVB00oooo0P00
000d0?ooo`030000003oool0000001/0oooo00070?oooa80i^KV8@3oool200000280oooo0P00000L
0?ooo`800000403oool3000000<0oooo0`00000@0?ooo`@0VIVI803oool2000003D0oooo0P00000L
0?ooo`001`3ooolB0>KViR40oooo0`00000Q0?ooo`<00000703oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0080oooo1000000=0?ooo`D0VIVI8@3oool3000003@0oooo0`00000K0?oo
o`001`3ooolB0>KViXd0oooo0`2IVIUg0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo203V
i^H2000000P0i^KV203oool200000100oooo0P00000@0?ooo`800000403oool200000180oooo00<0
00000?ooo`3oool02P3oool5000000030?ooo`000000000000800000203oool5000000<0oooo00<0
00000?ooo`3oool01`3oool500000080oooo0P0000090?ooo`D000000P3oool2000000h0oooo0P00
000@0?ooo`8000004@3oool3000000l0oooo00<000000?ooo`3oool03@3oool400000100oooo0007
0?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H70?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
00000140oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00070?ooo`L0i^KV00<0
00000>KViP0000000P0000060>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0000000L0000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`08000000<0oooo00@000000?ooo`3oool000000`3oool8000000D0oooo00<000000?ooo`3oool0
3@3oool5000000l0oooo00<000000?ooo`3oool00`3oool8000000<0oooo00<000000?ooo`3oool0
403oool000L0oooo1`3Vi^H00`000000i^KV0>KViP080>KViPL0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000X0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`001`3oool70>KViP030000003V
i^H0i^KV00P0i^KV1`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0
oooo000000d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000?0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000003P3oool010000000
oooo0?ooo`00000@0?ooo`001`3oool80>KViP<000001`3Vi^H80?ooo`800000403oool200000100
oooo0P00000@0?ooo`800000403oool4000000`0oooo0P0000040?ooo`8000002P3oool2000000<0
oooo100000090?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000003P3oool200000100
oooo0P00000A0?ooo`8000003P3oool4000000l0oooo0P00000A0?ooo`001`3ooolB0>KViX80oooo
0`2IVIV20?ooo`001`3ooolB0>KViU80oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00d0oooo102IVIU<0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09P3oool000L0oooo4P3Vi^IB0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`D0VIVIC03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02L0oooo00070?oooa80i^KVDP3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00L0oooo0P00000>0?ooo`D0VIVICP3oool00`000000oooo0?ooo`070?oo
o`800000:P3oool000L0oooo4P3Vi^IB0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0<0?ooo`H0VIVIC`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02X0oooo00070?oooa80i^KVDP3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000003`3oool509VIVE00oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0000000]0?ooo`001`3ooolB0>KViU40oooo0P00000@0?ooo`800000103o
ool3000000h0oooo1@2IVIUA0?ooo`<000000`3oool3000002h0oooo00070?oooa80i^KVDP3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0`00000>0?ooo`D0VIVIDP3oool0
0`000000oooo0?ooo`020?ooo`<00000;P3oool000L0oooo4P3Vi^Ij0?ooo`<0VIVIRP3oool000L0
oooo4P3Vi^Ko0?ooo`P0oooo00070?ooo`H0i^KV0`0000000`3Vi^H000000>KViP060>KViPP0oooo
0P00000@0?ooo`800000403oool200000100oooo0P00000=0?ooo`D0000000<0oooo000000000000
0P0000080?ooo`D000000`3oool00`000000oooo0?ooo`070?ooo`D0000000<0oooo000000000000
0P00000=0?ooo`030000003oool0oooo00h0oooo0P00000A0?ooo`800000403oool2000000l0oooo
0`00000A0?ooo`<000003P3oool200000140oooo00070?ooo`L0i^KV00@000000>KViP0000000000
1`3Vi^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool01000
0000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo
0000000=0?ooo`030000003oool0oooo00<0oooo00<0000009VIV@2IVIT02@2IVIT01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000403oool000L0oooo1`3V
i^H010000000i^KV0000000000070>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool00`000000VIVI09VIV@0909VIV@030000003oool0oooo0080oooo00<000000?ooo`3oool02@00
00040?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000103oool8000000D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`<000000`3oool900000080oooo
1@00000=0?ooo`040000003oool0oooo00000100oooo00070?ooo`L0i^KV0P0000000`3Vi^H00000
0>KViP060>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool;09VIV@030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P00000;0?ooo`030000003oool0oooo00d0oooo0P00
00060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000@0oooo0P0000080?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool00000403oool000L0oooo1`3Vi^H2000000030>KViP000000i^KV00H0
i^KV1`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`09
0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool0
0`000000oooo0000000>0?ooo`040000003oool0oooo00000100oooo00070?ooo`H0i^KV0P000000
103Vi^H000000000000000060>KViPP0oooo0P00000@0?ooo`800000403oool200000100oooo0P00
000>0?ooo`800000103oool2000000X0oooo0P0000030?ooo`@000002@3oool2000000@0oooo0P00
000<0?ooo`@000003`3oool200000140oooo0P00000@0?ooo`800000403oool300000100oooo0P00
000?0?ooo`8000004@3oool000L0oooo4P3Vi^IM0?ooo`<0VIVIY`3oool000L0oooo4P3Vi^HF0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool01`3oool509VIVC@0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0503oool000L0oooo4P3Vi^HE0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool01P3oool409VIVCD0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool000L0oooo4P3Vi^HC0?ooo`800000
?@3oool00`000000oooo0?ooo`050?ooo`@0VIVI=@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`001`3o
oolB0>KViQ80oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?ooo`@0VIVI=03o
ool2000002`0oooo00<000000?ooo`3oool01@3oool2000002<0oooo0P00000I0?ooo`001`3ooolB
0>KViPl0oooo00<000000?ooo`000000@03oool00`000000oooo0?ooo`020?ooo`D0VIVI<P3oool0
0`000000oooo0000000^0?ooo`030000003oool0oooo00<0oooo0P00000R0?ooo`030000003oool0
000001/0oooo00070?oooa80i^KV3P3oool300000400oooo0P0000040?ooo`@0VIVI<`3oool20000
02h0oooo0P0000040?ooo`8000008`3oool2000001`0oooo00070?oooa80i^KV3P3oool300000440
oooo00<000000?ooo`3oool01P2IVITc0?ooo`<00000;P3oool00`000000oooo0?ooo`020?ooo`<0
00008P3oool3000001/0oooo00070?oooa80i^KVEP3oool309VIVJh0oooo00070?oooa80i^KVo`3o
ool80?ooo`001`3oool60>KViP<0000000<0i^KV0000000000001P3Vi^H80?ooo`800000403oool2
000000l0oooo1000000@0?ooo`<000002`3oool5000000<0oooo00<000000?ooo`3oool01`3oool5
000000030?ooo`0000000000008000003@3oool00`000000oooo0?ooo`0=0?ooo`@000003P3oool4
00000100oooo0P00000@0?ooo`800000403oool200000100oooo0P00000@0?ooo`8000004@3oool0
00L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000
oooo0?ooo`00000@0?ooo`001`3oool70>KViP040000003Vi^H0i^KV000000L0i^KV1`3oool01000
0000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool03P3o
ool5000000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000700000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`09000000@0oooo00<000000?ooo`3oool00P3o
ool9000000<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`040000003o
ool0oooo000000h0oooo00@000000?ooo`3oool000000`3oool8000000D0oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo00000100oooo00070?oo
o`L0i^KV100000070>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000@0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000003P3oool00`000000oooo
0?ooo`040?ooo`040000003oool00000000000L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`02000000/0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000l0oooo0P0000050?oo
o`8000002`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool00000403oool000L0oooo1`3Vi^H010000000i^KV0>KViP0000070>KViPL0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo0000
00l0oooo00<000000?ooo`0000003P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo0000
0100oooo00070?ooo`H0i^KV0P000000103Vi^H000000000000000060>KViPP0oooo0P00000@0?oo
o`800000403oool200000140oooo0P00000=0?ooo`8000000`3oool4000000T0oooo0P0000040?oo
o`800000303oool4000000l0oooo0P00000@0?ooo`8000004@3oool200000100oooo0P00000@0?oo
o`800000403oool200000100oooo0P00000A0?ooo`001`3ooolB0>KViT/0oooo0`2IVIVi0?ooo`00
1`3ooolB0>KViRP0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`D0VIVI
AP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
B`3oool000L0oooo4P3Vi^HW0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3o
ool409VIVDL0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo04`0oooo00070?oooa80i^KV9P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00H0oooo102IVIU70?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1=0?ooo`001`3ooolB0>KViR@0oooo0P00000I0?ooo`030000003oool0oooo
00D0oooo102IVIU60?ooo`800000403oool200000100oooo0P00001@0?ooo`001`3ooolB0>KViR40
oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`030?ooo`D0VIVIA03oool00`000000
oooo0000000@0?ooo`800000403oool200000580oooo00070?oooa80i^KV8@3oool2000001`0oooo
0P0000040?ooo`@0VIVIA@3oool200000100oooo0P00000@0?ooo`800000D`3oool000L0oooo4P3V
i^HQ0?ooo`<000006`3oool010000000oooo0?ooo`3oool609VIVDD0oooo0`00000?0?ooo`<00000
3`3oool300000580oooo00070?oooa80i^KVA03oool309VIVL00oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KViPP0oooo0P00000@0?ooo`8000004@3oool3000000d0oooo0`00000B0?oo
o`<000003P3oool200000100oooo0P00000?0?ooo`D000003P3oool200000140oooo0P00000?0?oo
o`D000003P3oool200000100oooo0P00000@0?ooo`8000004@3oool000L0oooo1`3Vi^H3000000P0
i^KV1`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo00000100oooo
00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo0000
0100oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool00000403oool000L0oooo203Vi^H00`000000i^KV0>KV
iP070>KViPL0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`D0
00003P3oool3000000@0oooo200000030?ooo`D000003@3oool010000000oooo0?ooo`00000>0?oo
o`040000003oool0oooo00000100oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00
000?0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403oool0
00L0oooo203Vi^H00`000000i^KV0>KViP070>KViPL0oooo00@000000?ooo`3oool000003P3oool0
10000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00d0oooo00@0
00000?ooo`3oool000003`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo00000100oooo00070?ooo`P0i^KV0P0000080>KViPL0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000?0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool0
0000403oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool00000403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000l0oooo00@0
00000?ooo`3oool00000403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`001`3oool80>KV
iP040000003Vi^H0i^KV000000H0i^KV203oool200000100oooo0P00000A0?ooo`8000003`3oool3
00000140oooo0P00000?0?ooo`800000403oool200000100oooo0P00000@0?ooo`8000004@3oool2
00000100oooo0P00000@0?ooo`800000403oool200000100oooo0P00000A0?ooo`001`3oool70>KV
iPD000001P3Vi^Hi0?ooo`<0VIVIb`3oool000L0oooo4P3Vi^HX0?ooo`030000003oool0oooo00d0
oooo1@2IVIU60?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0B`3oool000L0oooo
4P3Vi^HW0?ooo`030000003oool0oooo00d0oooo102IVIU70?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0C03oool000L0oooo4P3Vi^HV0?ooo`030000003oool0oooo00d0oooo102I
VIU60?ooo`800000=@3oool00`000000oooo0?ooo`1=0?ooo`001`3ooolB0>KViR@0oooo0P00000?
0?ooo`@0VIVIAP3oool00`000000oooo0?ooo`0c0?ooo`800000D03oool000L0oooo4P3Vi^HQ0?oo
o`030000003oool0000000l0oooo1@2IVIU40?ooo`030000003oool0000003@0oooo0P00001B0?oo
o`001`3ooolB0>KViR40oooo0P00000@0?ooo`@0VIVIA03oool3000003@0oooo0P00001C0?ooo`00
1`3ooolB0>KViR40oooo0`00000=0?ooo`D0VIVIA@3oool4000003<0oooo0`00001B0?ooo`001`3o
oolB0>KViS80oooo0`2IVIWB0?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^H80?oo
o`8000003`3oool5000000h0oooo0P00000@0?ooo`8000004@3oool2000000l0oooo1@00000?0?oo
o`<000003P3oool200000100oooo0P00000@0?ooo`@000003P3oool5000000h0oooo0P00000@0?oo
o`800000403oool200000140oooo00070?ooo`H0i^KV1@0000070>KViPL0oooo00@000000?ooo`3o
ool00000403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool000003`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo0000
00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`001`3o
ool70>KViP040000003Vi^H0i^KV000000L0i^KV1`3oool010000000oooo0?ooo`00000@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000?0?oo
o`040000003oool0oooo00000100oooo00<000000?ooo`3oool03@3oool5000000d0oooo00@00000
0?ooo`3oool000003P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool00000403oool000L0oooo1`3Vi^H00`000000i^KV0>KViP080>KV
iPL0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000@0?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?oo
o`040000003oool0oooo00000140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000@0?ooo`001`3oool70>KViP8000002@3Vi^H70?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
000000l0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`04
0000003oool0oooo00000100oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403oool000L0oooo1`3V
i^H010000000i^KV0>KViP0000070>KViPP0oooo0P00000@0?ooo`800000403oool200000100oooo
0P00000A0?ooo`800000403oool200000140oooo0P00000?0?ooo`800000403oool200000140oooo
0P00000@0?ooo`800000403oool200000100oooo0P00000@0?ooo`8000004@3oool000L0oooo1P3V
i^H5000000L0i^KV9`3oool309VIVMd0oooo00070?oooa80i^KV5P3oool00`000000oooo0?ooo`0=
0?ooo`D0VIVI8@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0i0?ooo`001`3ooolB0>KViQD0oooo00<000000?oo
o`3oool03@3oool409VIVB80oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool000L0oooo4P3Vi^HC0?ooo`80
00003`3oool409VIVB80oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`80
00008`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0k0?ooo`001`3ooolB0>KViQ80oooo00<000000?ooo`3oool0
3P3oool409VIVB40oooo0P00000@0?ooo`8000004@3oool00`000000oooo0?ooo`0Q0?ooo`800000
403oool200000100oooo0P00000@0?ooo`800000?P3oool000L0oooo4P3Vi^H?0?ooo`030000003o
ool0000000l0oooo1@2IVITP0?ooo`800000403oool200000100oooo00<000000?ooo`0000008@3o
ool00`000000oooo0000000@0?ooo`800000403oool200000100oooo0P0000100?ooo`001`3ooolB
0>KViPh0oooo0`00000@0?ooo`@0VIVI803oool200000100oooo0P00000@0?ooo`<000008P3oool2
00000100oooo0P00000@0?ooo`800000403oool200000440oooo00070?oooa80i^KV3P3oool30000
00h0oooo1@2IVITQ0?ooo`<000003`3oool3000000l0oooo0`00000R0?ooo`<000003`3oool30000
00l0oooo0`00000?0?ooo`<00000@03oool000L0oooo4P3Vi^HP0?ooo`@0VIVIh`3oool000L0oooo
4P3Vi^Ko0?ooo`P0oooo00070?oooa80i^KV203oool200000100oooo0P00000@0?ooo`800000403o
ool200000140oooo0P00000@0?ooo`800000403oool200000100oooo0P00000@0?ooo`800000403o
ool5000000h0oooo0P00000@0?ooo`800000403oool200000100oooo0P00000A0?ooo`001`3oool6
0>KViP<0000000<0i^KV0000000000001P3Vi^H70?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000>0?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000>0?ooo`040000003oool0oooo00000100oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H0
00001`3Vi^H70?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool00P3oool80000
0080oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003o
ool0oooo00000140oooo00@000000?ooo`3oool0oooo2@0000020?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403oool000L0oooo1`3Vi^H30000
00P0i^KV1`3oool010000000oooo0?ooo`00000?0?ooo`8000001P3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool010000000oooo
0?ooo`00000?0?ooo`8000001@3oool2000000P0oooo00@000000?ooo`3oool000003P3oool01000
0000oooo0?ooo`00000>0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool03@3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000@0?ooo`001`3oool70>KViP030000003Vi^H00000
00P0i^KV1`3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000l0
oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
000000h0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?oo
o`040000003oool0oooo00000100oooo00070?ooo`L0i^KV00@000000>KViP3Vi^H000001`3Vi^H8
0?ooo`800000403oool3000000l0oooo0P00000@0?ooo`8000004@3oool200000100oooo0`00000?
0?ooo`800000403oool200000100oooo0P00000A0?ooo`800000403oool200000100oooo0P00000@
0?ooo`800000403oool200000140oooo00070?ooo`H0i^KV0`0000000`3Vi^H00000000000060>KV
iQD0oooo0`2IVIW_0?ooo`001`3ooolB0>KViQ@0oooo102IVIU60?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03T0
oooo00070?oooa80i^KV4`3oool509VIVDD0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0>P3oool000L0oooo4P3V
i^HA0?ooo`D0VIVIAP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0k0?ooo`001`3ooolB0>KViQ00oooo1@2IVIU5
0?ooo`800000=@3oool200000100oooo0P00000R0?ooo`800000?P3oool000L0oooo4P3Vi^H?0?oo
o`D0VIVIA03oool2000003@0oooo00<000000?ooo`000000403oool200000280oooo0P0000100?oo
o`001`3ooolB0>KViPd0oooo1@2IVIU50?ooo`800000=@3oool200000100oooo0P00000R0?ooo`80
0000@@3oool000L0oooo4P3Vi^H=0?ooo`@0VIVIAP3oool3000003@0oooo0`00000?0?ooo`<00000
8@3oool300000400oooo00070?oooa80i^KV3@3oool509VIVOD0oooo00070?oooa80i^KVo`3oool8
0?ooo`001`3ooolB0>KViPP0oooo0P00000@0?ooo`800000403oool200000100oooo0P00000A0?oo
o`800000403oool200000100oooo0P00000@0?ooo`800000403oool200000140oooo0P00000@0?oo
o`800000403oool200000100oooo0P00000@0?ooo`8000004@3oool000L0oooo4P3Vi^H70?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000>0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool000003P3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool00000403oool000L0oooo4P3Vi^H70?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo
000000l0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?
0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000403oool0
00L0oooo4P3Vi^H70?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003o
ool0oooo000000h0oooo00@000000?ooo`3oool00000403oool000L0oooo4P3Vi^H70?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3oool000003P3oool010000000oooo
0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool0
10000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool0
00003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool00000403oool000L0oooo4P3Vi^H80?ooo`800000403oool200000100oooo0P00000@
0?ooo`8000004@3oool200000100oooo0P00000@0?ooo`800000403oool200000100oooo0P00000A
0?ooo`800000403oool200000100oooo0P00000@0?ooo`800000403oool200000140oooo00070?oo
oa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0oooo4P3Vi^Ko0?ooo`P0oooo
00070?oooa80i^KVo`3oool80?ooo`001`3ooolB0>KVi_l0oooo203oool000L0ooooo`3Vi^HA0>KV
iPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooono0>KViP800000C`3Vi^H90?oo
o`001`3ooolZ0>KViP<0000000<0i^KV0000000000003P3Vi^H3000000h0i^KV0`00000?0>KViP<0
000000<0i^KV000000000000303Vi^H3000000030>KViP000000000000d0i^KV0P0000000`3Vi^H0
00000000000>0>KViP8000003P3Vi^H3000000030>KViP000000i^KV00l0i^KV0P00000>0>KViP<0
000000<0i^KV0000000000003@3Vi^H3000000h0i^KV0`00000@0>KViP<00000203Vi^H90?ooo`00
1`3oool[0>KViP040000003Vi^H0i^KV00000100i^KV00<000000>KViP3Vi^H03P3Vi^H00`000000
i^KV0>KViP0?0>KViP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H000003P3Vi^H0
1@000000i^KV0>KViP3Vi^H0000000d0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV
00000000000?0>KViP040000003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H000003P3Vi^H0
10000000i^KV0>KViP00000>0>KViP030000003Vi^H0i^KV0100i^KV00<000000>KViP3Vi^H01`3V
i^H90?ooo`001`3oool[0>KViP<000004@3Vi^H00`000000i^KV0>KViP0>0>KViP030000003Vi^H0
i^KV00l0i^KV00@000000>KViP3Vi^H000003P3Vi^H300000100i^KV0`00000>0>KViP030000003V
i^H00000008000003@3Vi^H010000000i^KV00000000000?0>KViP040000003Vi^H0i^KV000000h0
i^KV00@000000>KViP3Vi^H000004@3Vi^H00`000000i^KV0>KViP0<0>KViP<00000403Vi^H00`00
0000i^KV0>KViP070>KViPT0oooo00070?ooob/0i^KV00<000000>KViP000000403Vi^H00`000000
i^KV0000000?0>KViP800000403Vi^H4000000h0i^KV00<000000>KViP000000403Vi^H00`000000
i^KV0000000>0>KViP030000003Vi^H0i^KV00l0i^KV0P0000000`3Vi^H000000>KViP0>0>KViP04
0000003Vi^H0i^KV000000h0i^KV1000000?0>KViP8000003`3Vi^H010000000i^KV0>KViP00000?
0>KViP030000003Vi^H0i^KV00L0i^KV2@3oool000L0oooo:`3Vi^H010000000i^KV0>KViP00000>
0>KViP050000003Vi^H0i^KV0>KViP0000003P3Vi^H010000000i^KV0>KViP00000>0>KViP040000
003Vi^H0i^KV000000h0i^KV00@000000>KViP3Vi^H00000403Vi^H00`000000i^KV0>KViP0=0>KV
iP030000003Vi^H0i^KV00l0i^KV0P0000000`3Vi^H000000>KViP0>0>KViP040000003Vi^H0i^KV
000000h0i^KV00@000000>KViP3Vi^H000003P3Vi^H010000000i^KV0>KViP00000>0>KViP040000
003Vi^H0i^KV000000d0i^KV00D000000>KViP000000i^KV000000070>KViPT0oooo00070?ooobX0
i^KV0`0000000`3Vi^H000000000000<0>KViP<0000000<0i^KV0000000000003@3Vi^H5000000d0
i^KV0P000000103Vi^H0000000000000000<0>KViP<0000000<0i^KV0000000000003P3Vi^H20000
0100i^KV0`00000=0>KViP80000000@0i^KV00000000000000003`3Vi^H2000000h0i^KV0P000000
103Vi^H0000000000000000=0>KViP@000003@3Vi^H4000000h0i^KV1@0000070>KViPT0oooo0007
0?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0
oooo00070?ooool0i^KV4@3Vi^H90?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.894534, -0.262555, \
0.0550141, 0.0623104}}]
}, Open  ]],

Cell[TextData[{
  "Auch f\[UDoubleDot]r die Ausgabe des lokalen Alignments auf der \
Sequenzebene k\[ODoubleDot]nnten wir im Prinzip die Befehlsstruktur des \
Needleman-Wunsch-Algorithmus nutzen.Wir wollen hier stattdessen die Ausgabe \
\[UDoubleDot]ber eine ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife realisieren, die bis zur L\[ADoubleDot]nge des rekonstruierten \
Pfades, ",
  StyleBox["Length[path2]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", l\[ADoubleDot]uft. Die Variable ",
  StyleBox["path2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " enth\[ADoubleDot]lt die Abfolge der Zeigerzust\[ADoubleDot]nde entlang \
des Pfades. Sie ergibt sich durch Anwenden (",
  StyleBox["Map",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") der Matrix ",
  StyleBox["fWatermanTabB",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " auf den Pfad ",
  StyleBox["path1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Die einzige Schwierigkeit bei diesem Schritt stellt die Initialisierung \
der beiden Counter-Variablen dar, mit der wir die aktuelle Position in den \
beiden Sequenzen protokollieren. Wir behalten die Z\[ADoubleDot]hlweise \"von \
hinten nach vorne\" des Needleman-Wunsch-Algorithmus bei (die man daran \
erkennt, dass wir den Counter hochz\[ADoubleDot]hlen, aber die Sequenz stets \
von hinten her abfragen: ",
  StyleBox["prot1[[-count1]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "). Wir initialisieren also zum Beispiel den ersten Counter als Sequenzl\
\[ADoubleDot]nge + 1 - erste Koordinate des Pfadbeginns. Die Koordinaten des \
Pfadbeginns extrahieren wir aus der Variablen ",
  StyleBox["path3",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", einer Liste, deren Eintr\[ADoubleDot]ge die Form Zeigerzustand, erste \
Koordinate, zweite Koordinate besitzen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(count1 = \((Length[prot1] + 
              1)\) - \(path3[\([1]\)]\)[\([2]\)];\)\), "\[IndentingNewLine]", \

    \(\(count2 = \((Length[prot2] + 
              1)\) - \(path3[\([1]\)]\)[\([3]\)];\)\)}], "Input"],

Cell[TextData[{
  "Nach diesen ",
  "Vorbereitungen",
  " k\[ODoubleDot]nnen wir die ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife nach dem Vorbild der ",
  StyleBox["While",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife des vorangegangenen Algorithmus formulieren:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(Do[If[
        path2[\([j]\)] \[Equal] 1, {count1 = count1 + 1, count2 = count2 + 1, 
          aligW[j] = {prot1[\([\(-count1\)]\)], 
              If[prot1[\([\(-count1\)]\)] == 
                  prot2[\([\(-count2\)]\)], "\<|\>", "\< \>"], 
              prot2[\([\(-count2\)]\)]}}, 
        If[path2[\([j]\)] \[Equal] 2, {count1 = count1 + 1, 
            aligW[j] = {prot1[\([\(-count1\)]\)], "\< \>", "\<-\>"}}, 
          If[path2[\([j]\)] \[Equal] 
              3, \[IndentingNewLine]{count2 = count2\  + 1, 
              aligW[j] = {"\<-\>", "\< \>", 
                  prot2[\([\(-count2\)]\)]}}]]], {j, 1, 
        Length[path2]}]\)], "Input"],

Cell[TextData[{
  "Zur Ausgabe fragen wir die Eintr\[ADoubleDot]ge in ",
  StyleBox["aligW",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " wieder in umgekehrter Reihenfolge ab und geben sie mit dem Formatbefehl \
",
  StyleBox["TableForm",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " aus:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(alWFull = 
        Table[aligW[j], {j, Length[path2], 
            1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(Transpose[alWFull] // TableForm\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"N\"\>", "\
\<\"-\"\>", "\<\"G\"\>", "\<\"H\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\
\<\" \"\>", "\<\"|\"\>", "\<\" \"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", "\
\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dies ist das Endresultat f\[UDoubleDot]r das lokale Alignment gem\
\[ADoubleDot]\[SZ] dem Smith-Waterman-Algorithmus. Auch hier wollen wir die \
einzelnen Befehle so in einer Module-Umgebung zusammenf\[UDoubleDot]gen, dass \
man ein kompaktes Werkzeug zur Verf\[UDoubleDot]gung hat. Man hat dann einen \
Befehl ",
  StyleBox["alignmentSW",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " mit denselben Argumenten wie beim Needleman-Wunsch-Algorithmus."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(\(xxcoordFun[ref_, seq1_, seq2_, posA_, posB_, mat_] := 
      Module[{tmp1, tmp2, tmp3, tmp4}, \[IndentingNewLine]tmp1 = 
          seq1[\([posA]\)]; \[IndentingNewLine]tmp2 = 
          seq2[\([posB]\)]; \[IndentingNewLine]tmp3 = \(Position[ref, 
              tmp1]\)[\([1, 1]\)]; \[IndentingNewLine]tmp4 = \(Position[ref, 
              tmp2]\)[\([1, 1]\)]; \[IndentingNewLine]mat[\([tmp3, 
            tmp4]\)]]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(alignmentSW[seq1_, seq2_, mat_, del_] := 
      Module[{xxproteinRef, xxfWaterman, xxfWatermanTab, xxtmp1, j, 
          xxfWatermanTabA, xxfWatermanTabB, xxdX, xxtraX, xxpath1, xxpath2, 
          xxcount1, xxcount2, xxalig, 
          xxalFull}, \[IndentingNewLine]xxproteinRef = 
          Characters["\<ARNDCQEGHILKMFPSTWYVBZX*\>"]; \
\[IndentingNewLine]xxfWaterman[0, 0] = {0, 0}; \[IndentingNewLine]xxfWaterman[
            i_, 0] = {0, 0}; \[IndentingNewLine]xxfWaterman[0, j_] = {0, 
            0}; \[IndentingNewLine]Do[{xxtmp1 = {0, \(xxfWaterman[i - 1, 
                      j - 1]\)[\([1]\)] + 
                  xxcoordFun[xxproteinRef, seq1, seq2, i, j, 
                    mat], \[IndentingNewLine]\(xxfWaterman[i - 1, 
                      j]\)[\([1]\)] - 
                  del, \(xxfWaterman[i, j - 1]\)[\([1]\)] - del}; 
            xxfWaterman[i, 
                j] = {Max[
                  xxtmp1], \(Position[xxtmp1, Max[xxtmp1]]\)[\([1, 1]\)] - 
                  1}}, {i, 1, Length[seq1]}, {j, 1, 
            Length[seq2]}]; \[IndentingNewLine]xxfWatermanTab = 
          Table[xxfWaterman[i, j], {i, 0, Length[seq1]}, {j, 0, 
              Length[seq2]}]; \[IndentingNewLine]xxfWatermanTabA = 
          xxfWatermanTab /. {n1_, n2_Integer} \[Rule] 
              n1; \[IndentingNewLine]xxfWatermanTabB = 
          xxfWatermanTab /. {n1_, n2_Integer} \[Rule] 
              n2; \[IndentingNewLine]xxdX = 
          Take[Flatten[Position[xxfWatermanTabA, Max[xxfWatermanTabA]]], 
            2]; \[IndentingNewLine]xxtraX[1] = {xxdX[\([1]\)], 
            xxdX[\([2]\)]}; \[IndentingNewLine]j = 
          1; \[IndentingNewLine]While[
          xxfWatermanTabB[\([Sequence @@ xxtraX[j]]\)] =!= 
            0, {xxtraX[j + 1] = 
              xxtraX[j] - 
                Switch[xxfWatermanTabB[\([Sequence @@ xxtraX[j]]\)], 
                  1, {1, 1}, 2, {1, 0}, 3, {0, 1}], 
            j = j + 1}]; \[IndentingNewLine]xxpath1 = 
          Table[xxtraX[k], {k, 1, j - 1}]; \[IndentingNewLine]xxpath2 = 
          Map[xxfWatermanTabB[\([#[\([1]\)], #[\([2]\)]]\)] &, 
            xxpath1]; \[IndentingNewLine]xxcount1 = \((Length[seq1] + 
                1)\) - \(xxpath1[\([1]\)]\)[\([1]\)]; \
\[IndentingNewLine]xxcount2 = \((Length[seq2] + 
                1)\) - \(xxpath1[\([1]\)]\)[\([2]\)]; \[IndentingNewLine]Do[
          If[xxpath2[\([j]\)] \[Equal] 1, {xxcount1 = xxcount1 + 1, 
              xxcount2 = xxcount2 + 1, 
              xxalig[j] = {seq1[\([\(-xxcount1\)]\)], 
                  If[seq1[\([\(-xxcount1\)]\)] \[Equal] 
                      seq2[\([\(-xxcount2\)]\)], "\<|\>", "\< \>"], 
                  seq2[\([\(-xxcount2\)]\)]}}, 
            If[xxpath2[\([j]\)] \[Equal] 2, {xxcount1 = xxcount1 + 1, 
                xxalig[j] = {seq1[\([\(-xxcount1\)]\)], "\< \>", "\<-\>"}}, \
\[IndentingNewLine]If[
                xxpath2[\([j]\)] \[Equal] 3, {xxcount2 = xxcount2 + 1, 
                  xxalig[j] = {"\<-\>", "\< \>", 
                      seq2[\([\(-xxcount2\)]\)]}}]]], {j, 1, 
            Length[xxpath2]}]; \[IndentingNewLine]xxalFull = 
          Table[xxalig[i], {i, Length[xxpath2], 
              1, \(-1\)}]; \[IndentingNewLine]Transpose[xxalFull] // 
          TableForm]\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell["\<\
Der folgende Befehl reproduziert also unser zuvor gewonnenes lokales \
Alignment:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(alignmentSW[prot1, prot2, blosum, 5]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"N\"\>", "\
\<\"-\"\>", "\<\"G\"\>", "\<\"H\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\
\<\" \"\>", "\<\"|\"\>", "\<\" \"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", "\
\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
In bew\[ADoubleDot]hrter Weise k\[ODoubleDot]nnen wir nun auch betrachten, \
wie sich das Alignment unter Variation des Gap-Parameters \[ADoubleDot]ndert.\
\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(alignmentSW[prot1, prot2, blosum, 1]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"N\"\>", "\
\<\"-\"\>", "\<\"G\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\
\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\" \"\>", \
"\<\" \"\>", "\<\"|\"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", "\
\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"Q\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alignmentSW[prot1, prot2, blosum, 15]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>"},
          {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>"},
          {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In einer Hinsicht ist die bisher erzeugte Ausgabe des lokalen Alignment \
unbefriedigend. In vielen F\[ADoubleDot]llen (vor allem f\[UDoubleDot]r kurze \
Sequenzsegmente, bei denen dadurch die \[CapitalUDoubleDot]bersichtlichkeit \
der Darstellung nicht leidet) m\[ODoubleDot]chte man die nicht in Alignment \
gebrachten Sequenzbereiche an den Enden der Sequenzen ebenfalls sichtbar \
machen. ",
  StyleBox["Diesen Teil der Ergebnisausgabe wollen wir nun in Angriff nehmen. \
Zur Bestimmung der Restsequenzen verwenden wir die Initialisierungen der \
Counter-Variablen und die Counter-Werte nach Durchlauf der ",
    FontColor->GrayLevel[0.500008]],
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  StyleBox["-Schleife. Einsetzen dieser Grenzen (unter \
Ber\[UDoubleDot]cksichtigung der umgekehrten Leserichtung!) in entsprechende \
",
    FontColor->GrayLevel[0.500008]],
  StyleBox["Take",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  StyleBox["-Befehle f\[UDoubleDot]hrt unmittelbar auf die gesuchten \
Segmente: ",
    FontColor->GrayLevel[0.500008]]
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(\(initCount1 = \((Length[prot1] + 
              1)\) - \(path3[\([1]\)]\)[\([2]\)];\)\), "\[IndentingNewLine]", \

    \(\(initCount2 = \((Length[prot2] + 
              1)\) - \(path3[\([1]\)]\)[\([3]\)];\)\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \({initCount1, initCount2, count1, count2}\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({1, 5, 8, 13}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(end1 = Take[prot1, \(-initCount1\)]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({"T"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(end2 = Take[prot2, \(-initCount2\)]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({"Q", "H", "S", "P", "T"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(start1 = Take[prot1, Length[prot1] - count1]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(start2 = Take[prot2, Length[prot2] - count2]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Da es vergleichsweise schwierig ist, an eine gegebene Tabelle (unser \
lokales Alignment) unter Beibehaltung der Struktur Elementgruppen an den R\
\[ADoubleDot]ndern anzuf\[UDoubleDot]gen, gehen wir erneut den Umweg, die \
Tabelle in eine Grafik umzuwandeln, indem wir die \
Tabelleneintr\[ADoubleDot]ge mit Hilfe des ",
  StyleBox["Text",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls als Zeichen an den entsprechenden Koordinaten eintragen. Dies \
geschieht in Grafik ",
  StyleBox["pX1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Die Grafik ",
  StyleBox["pX2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " unterlegt ",
  StyleBox["pX1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " mit einem hellgrauen Kasten; dadurch wird unter anderem eine implizite \
Skalierung der Tabelle erreicht. "
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \({dim1, dim2} = Dimensions[alWFull]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({8, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pX1 = 
        Show[Graphics[
            Table[Text[
                StyleForm[alWFull[\([i, j]\)], 
                  FontFamily \[Rule] "\<Helvetica\>", 
                  FontWeight \[Rule] Bold], {i, dim2 - j}], {i, 1, dim1}, {j, 
                1, dim2}]], AspectRatio \[Rule] 1, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(pX2 = 
        Show[Graphics[{GrayLevel[0.9], 
              Rectangle[{\(-4\), \(-2\)}, {dim1 + 9, dim2 + 1}]}], 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[pX2, pX1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.205215 0.0453515 0.210916 0.0981006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.9 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
0 g
gsave
.25057 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.25057 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.25057 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29592 .40712 -66.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.563 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29592 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29592 .21092 -66.3438 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.688 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34127 .40712 -66.0625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.125 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34127 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34127 .21092 -66.0625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.125 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38662 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38662 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38662 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43197 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43197 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43197 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47732 .40712 -66.3438 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.688 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47732 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47732 .21092 -66.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.813 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52268 .40712 -66.9063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.813 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52268 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52268 .21092 -66.9063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.813 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56803 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56803 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56803 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KV
iPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0
ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3o
ool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40
i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KV
iPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0
ooooo`3Vi^HA0>KViPT0oooo00070?oooch0i^KV00D000000>KViP3Vi^H0i^KV0000000:0>KViP03
0000003Vi^H0i^KV00P0i^KV00<000000>KViP3Vi^H02P3Vi^H01@000000i^KV0>KViP3Vi^H00000
00P0i^KV00D000000>KViP3Vi^H0i^KV000000070>KViP030000003Vi^H0i^KV00<0i^KV00<00000
0>KViP3Vi^H01P3Vi^H4000000P0i^KV00D000000>KViP3Vi^H0i^KV0000001b0>KViPT0oooo0007
0?oooch0i^KV00D000000>KViP3Vi^H0i^KV0000000:0>KViP030000003Vi^H0i^KV00P0i^KV00<0
00000>KViP3Vi^H02P3Vi^H01@000000i^KV0>KViP3Vi^H0000000P0i^KV00D000000>KViP3Vi^H0
i^KV000000080>KViP050000003Vi^H0i^KV0>KViP000000203Vi^H00`000000i^KV0>KViP020>KV
iP030000003Vi^H0i^KV00D0i^KV00<000000>KViP3Vi^H00P00001b0>KViPT0oooo00070?oooch0
i^KV00@000000>KViP3Vi^H000002`3Vi^H00`000000i^KV0>KViP080>KViP030000003Vi^H0i^KV
00X0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP040000003Vi^H0i^KV000000T0i^KV1@00
00080>KViP030000003Vi^H0i^KV0080i^KV00<000000>KViP3Vi^H01@3Vi^H00`000000i^KV0>KV
iP0200000780i^KV2@3oool000L0oooo?P3Vi^H2000000030>KViP000000i^KV00X0i^KV00<00000
0>KViP3Vi^H0203Vi^H4000000T0i^KV1@0000080>KViP80000000<0i^KV0000003Vi^H0203Vi^H0
1@000000i^KV0>KViP3Vi^H0000000P0i^KV00<000000>KViP3Vi^H00`0000070>KViP050000003V
i^H000000>KViP000000LP3Vi^H90?ooo`001`3oooln0>KViP030000003Vi^H0000000/0i^KV00<0
00000>KViP0000002@3Vi^H00`000000i^KV0>KViP0:0>KViP050000003Vi^H0i^KV0>KViP000000
203Vi^H00`000000i^KV0000000;0>KViP030000003Vi^H0000000T0i^KV00<000000>KViP3Vi^H0
2P3Vi^H200000080i^KV00<000000>KViP3Vi^H0L03Vi^H90?ooo`001`3oooln0>KViP040000003V
i^H0i^KV000000T0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP030000003Vi^H0i^KV00X0
i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP040000003Vi^H0i^KV000000X0i^KV00<00000
0>KViP0000002@3Vi^H00`000000i^KV0>KViP020>KViP030000003Vi^H0i^KV00D0i^KV0P000002
0>KViP030000003Vi^H0i^KV0700i^KV2@3oool000L0oooo?P3Vi^H01@000000i^KV0>KViP3Vi^H0
000000P0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP@000002@3Vi^H01@000000i^KV0>KV
iP3Vi^H0000000P0i^KV00D000000>KViP3Vi^H0i^KV0000000:0>KViP030000003Vi^H0i^KV00T0
i^KV100000080>KViP050000003Vi^H0i^KV0>KViP000000LP3Vi^H90?ooo`001`3ooooo0>KViQ40
i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0oooo@03Vi^H20000
01P0i^KV0P00000;0>KViP8000009@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0
i^KV0P00000;0>KViP8000009@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0i^KV
0P00000;0>KViP8000009@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0i^KV0P00
000;0>KViP8000009@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0i^KV0P00000;
0>KViP8000009@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0i^KV0P00000;0>KV
iP8000009@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0i^KV0P00000;0>KViP80
00009@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0i^KV0P00000;0>KViP800000
9@3Vi^H200000800i^KV2@3oool000L0oooo@03Vi^H2000001P0i^KV0P00000;0>KViP8000009@3V
i^H200000800i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?oo
o`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3V
i^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0
i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo0007
0?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0
oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA
0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0oooo
o`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool0
00L0ooooo`3Vi^HA0>KViPT0oooo00070?oooch0i^KV00D000000>KViP3Vi^H0i^KV000000080>KV
iPD00000203Vi^H00`000000i^KV0>KViP0:0>KViP050000003Vi^H0i^KV0>KViP000000203Vi^H0
1@000000i^KV0>KViP3Vi^H0000001H0i^KV100000080>KViP050000003Vi^H0i^KV0>KViP000000
LP3Vi^H90?ooo`001`3oooln0>KViP050000003Vi^H0i^KV0>KViP000000203Vi^H00`000000i^KV
0>KViP0:0>KViP030000003Vi^H0i^KV00X0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP03
0000003Vi^H0i^KV008000005@3Vi^H00`000000i^KV0>KViP020>KViP030000003Vi^H0i^KV00D0
i^KV00D000000>KViP3Vi^H0i^KV0000001b0>KViPT0oooo00070?oooch0i^KV00@000000>KViP3V
i^H000002@3Vi^H00`000000i^KV0>KViP0:0>KViP030000003Vi^H0i^KV00X0i^KV00D000000>KV
iP3Vi^H0i^KV000000080>KViP030000003Vi^H0i^KV00800000203Vi^H5000000P0i^KV00<00000
0>KViP3Vi^H00P3Vi^H00`000000i^KV0>KViP050>KViP050000003Vi^H0i^KV0>KViP000000LP3V
i^H90?ooo`001`3oooln0>KViP80000000<0i^KV0000003Vi^H0203Vi^H5000000P0i^KV10000009
0>KViPD00000203Vi^H01@000000i^KV0000003Vi^H0000001D0i^KV00<000000>KViP3Vi^H00`00
00070>KViPD00000LP3Vi^H90?ooo`001`3oooln0>KViP030000003Vi^H0000000X0i^KV00<00000
0>KViP3Vi^H02P3Vi^H00`000000i^KV0>KViP0:0>KViP050000003Vi^H0i^KV0>KViP000000203V
i^H200000080i^KV00<000000>KViP3Vi^H04`3Vi^H00`000000i^KV0>KViP0:0>KViP050000003V
i^H0i^KV0>KViP000000LP3Vi^H90?ooo`001`3oooln0>KViP040000003Vi^H0i^KV000000T0i^KV
00<000000>KViP3Vi^H02P3Vi^H00`000000i^KV0>KViP0:0>KViP050000003Vi^H0i^KV0>KViP00
0000203Vi^H200000080i^KV00<000000>KViP3Vi^H04`3Vi^H00`000000i^KV0>KViP020>KViP03
0000003Vi^H0i^KV00D0i^KV00D000000>KViP3Vi^H0i^KV0000001b0>KViPT0oooo00070?oooch0
i^KV00D000000>KViP3Vi^H0i^KV000000080>KViPD00000203Vi^H4000000T0i^KV00D000000>KV
iP3Vi^H0i^KV000000080>KViP050000003Vi^H0i^KV0>KViP0000005P3Vi^H4000000P0i^KV00D0
00000>KViP3Vi^H0i^KV0000001b0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KV
iPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0
ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3o
ool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40
i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KV
iPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.55234, -2.15003, \
0.0770198, 0.0356059}}]
}, Open  ]],

Cell[TextData[{
  "Mit Hilfe des Befehls ",
  StyleBox["StyleForm",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " haben wir dabei den Ausgabefont gewechselt und einen Fettdruck der \
Zeichen erreicht. Letzteres wollen wir verwenden, um den Bereich des lokalen \
Alignments von den Randbereichen (Normaldruck) abzuheben.  Mit derselben \
Befehlsstruktur wie f\[UDoubleDot]r ",
  StyleBox["pX1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " k\[ODoubleDot]nnen wir nun die verschiedenen Sequenzsegmente an den Enden \
des Alignments anf\[UDoubleDot]gen. "
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(pX3 = 
        Show[Graphics[
            Table[Text[
                StyleForm[end1[\([i]\)], 
                  FontFamily \[Rule] "\<Helvetica\>"], {\ dim1 + i, 0}], {i, 
                1, Length[end1]}]], AspectRatio \[Rule] 1, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(pX4\  = \ 
        Show[Graphics[
            Table[Text[
                StyleForm[end2[\([i]\)], 
                  FontFamily \[Rule] "\<Helvetica\>"], {\ dim1 + i, 2}], {i, 
                1, Length[end2]}]], AspectRatio \[Rule] 1, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(pX5 = 
        Show[Graphics[
            Table[Text[
                StyleForm[start1[\([i]\)], 
                  FontFamily \[Rule] "\<Helvetica\>"], {\(-Length[start1]\) + 
                    i, 0}], {i, 1, Length[start1]}]], AspectRatio \[Rule] 1, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(pX6 = 
        Show[Graphics[
            Table[Text[
                StyleForm[start2[\([i]\)], 
                  FontFamily \[Rule] "\<Helvetica\>"], {\(-Length[start2]\) + 
                    i, 2}], {i, 1, Length[start2]}]], AspectRatio \[Rule] 1, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[pX2, pX1, pX3, pX4, pX5, pX6, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.205215 0.0453515 0.210916 0.0981006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.9 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
0 g
gsave
.25057 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.25057 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.25057 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29592 .40712 -66.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.563 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29592 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29592 .21092 -66.3438 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.688 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34127 .40712 -66.0625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.125 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34127 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34127 .21092 -66.0625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
69.125 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38662 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38662 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38662 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43197 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43197 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43197 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47732 .40712 -66.3438 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.688 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47732 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47732 .21092 -66.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.813 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52268 .40712 -66.9063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.813 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52268 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(\\310) show
65.750 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52268 .21092 -66.9063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.813 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56803 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56803 .30902 -64.375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56803 .21092 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61338 .21092 -66.125 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.250 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61338 .40712 -66.9063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
70.813 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.65873 .40712 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
70.188 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.70408 .40712 -66.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.563 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74943 .40712 -66.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.563 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79478 .40712 -66.125 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.250 12.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KV
iPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0
ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3o
ool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40
i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
ool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo
00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KV
iPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3V
i^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0
ooooo`3Vi^HA0>KViPT0oooo00070?oooch0i^KV00D000000>KViP3Vi^H0i^KV0000000:0>KViP03
0000003Vi^H0i^KV00P0i^KV00<000000>KViP3Vi^H02P3Vi^H01@000000i^KV0>KViP3Vi^H00000
00P0i^KV00D000000>KViP3Vi^H0i^KV000000070>KViP030000003Vi^H0i^KV00<0i^KV00<00000
0>KViP3Vi^H01P3Vi^H4000000P0i^KV00D000000>KViP3Vi^H0i^KV0000000:0>KViP030000003V
i^H0i^KV06D0i^KV2@3oool000L0oooo?P3Vi^H01@000000i^KV0>KViP3Vi^H0000000X0i^KV00<0
00000>KViP3Vi^H0203Vi^H00`000000i^KV0>KViP0:0>KViP050000003Vi^H0i^KV0>KViP000000
203Vi^H01@000000i^KV0>KViP3Vi^H0000000P0i^KV00D000000>KViP3Vi^H0i^KV000000080>KV
iP030000003Vi^H0i^KV0080i^KV00<000000>KViP3Vi^H01@3Vi^H00`000000i^KV0>KViP020000
00X0i^KV00<000000>KViP3Vi^H0I@3Vi^H90?ooo`001`3oooln0>KViP040000003Vi^H0i^KV0000
00/0i^KV00<000000>KViP3Vi^H0203Vi^H00`000000i^KV0>KViP0:0>KViP050000003Vi^H0i^KV
0>KViP000000203Vi^H010000000i^KV0>KViP0000090>KViPD00000203Vi^H00`000000i^KV0>KV
iP020>KViP030000003Vi^H0i^KV00D0i^KV00<000000>KViP3Vi^H00P00000:0>KViP030000003V
i^H0i^KV06D0i^KV2@3oool000L0oooo?P3Vi^H2000000030>KViP000000i^KV00X0i^KV00<00000
0>KViP3Vi^H0203Vi^H4000000T0i^KV1@0000080>KViP80000000<0i^KV0000003Vi^H0203Vi^H0
1@000000i^KV0>KViP3Vi^H0000000P0i^KV00<000000>KViP3Vi^H00`0000070>KViP050000003V
i^H000000>KViP0000002P3Vi^H00`000000i^KV0>KViP1U0>KViPT0oooo00070?oooch0i^KV00<0
00000>KViP0000002`3Vi^H00`000000i^KV000000090>KViP030000003Vi^H0i^KV00X0i^KV00D0
00000>KViP3Vi^H0i^KV000000080>KViP030000003Vi^H0000000/0i^KV00<000000>KViP000000
2@3Vi^H00`000000i^KV0>KViP0:0>KViP8000000P3Vi^H00`000000i^KV0>KViP080>KViP030000
003Vi^H0i^KV06D0i^KV2@3oool000L0oooo?P3Vi^H010000000i^KV0>KViP0000090>KViP050000
003Vi^H0i^KV0>KViP000000203Vi^H00`000000i^KV0>KViP0:0>KViP050000003Vi^H0i^KV0>KV
iP000000203Vi^H010000000i^KV0>KViP00000:0>KViP030000003Vi^H0000000T0i^KV00<00000
0>KViP3Vi^H00P3Vi^H00`000000i^KV0>KViP050>KViP8000000P3Vi^H00`000000i^KV0>KViP08
0>KViP030000003Vi^H0i^KV06D0i^KV2@3oool000L0oooo?P3Vi^H01@000000i^KV0>KViP3Vi^H0
000000P0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP@000002@3Vi^H01@000000i^KV0>KV
iP3Vi^H0000000P0i^KV00D000000>KViP3Vi^H0i^KV0000000:0>KViP030000003Vi^H0i^KV00T0
i^KV100000080>KViP050000003Vi^H0i^KV0>KViP000000203Vi^H5000006D0i^KV2@3oool000L0
ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3o
ool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40
i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo
0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`00
1`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H9
0?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV
4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?oo
od00i^KV0P00000H0>KViP8000002`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00
i^KV0P00000H0>KViP8000002`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00i^KV
0P00000H0>KViP8000002`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00i^KV0P00
000H0>KViP8000002`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00i^KV0P00000H
0>KViP8000002`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00i^KV0P00000H0>KV
iP8000002`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00i^KV0P00000H0>KViP80
00002`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00i^KV0P00000H0>KViP800000
2`3Vi^H2000002D0i^KV0P0000200>KViPT0oooo00070?oood00i^KV0P00000H0>KViP8000002`3V
i^H2000002D0i^KV0P0000200>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KV
iQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3o
oooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?oo
o`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3V
i^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0
i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo0007
0?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0
oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA
0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3oooln0>KViP050000003Vi^H0i^KV0>KV
iP000000203Vi^H5000000P0i^KV00<000000>KViP3Vi^H02P3Vi^H01@000000i^KV0>KViP3Vi^H0
000000P0i^KV00D000000>KViP3Vi^H0i^KV0000000F0>KViP@00000203Vi^H01@000000i^KV0>KV
iP3Vi^H0000000T0i^KV1@0000070>KViP050000003Vi^H0i^KV0>KViP0000002@3Vi^H3000000T0
i^KV00<000000>KViP3Vi^H0303Vi^H00`000000i^KV0>KViP0a0>KViPT0oooo00070?oooch0i^KV
00D000000>KViP3Vi^H0i^KV000000080>KViP030000003Vi^H0i^KV00X0i^KV00<000000>KViP3V
i^H02P3Vi^H01@000000i^KV0>KViP3Vi^H0000000P0i^KV00<000000>KViP3Vi^H00P00000E0>KV
iP030000003Vi^H0i^KV0080i^KV00<000000>KViP3Vi^H01@3Vi^H01@000000i^KV0>KViP3Vi^H0
000000P0i^KV00<000000>KViP3Vi^H00P0000080>KViP050000003Vi^H0i^KV0>KViP000000203V
i^H01@000000i^KV0>KViP3Vi^H0000000P0i^KV00<000000>KViP3Vi^H0303Vi^H00`000000i^KV
0>KViP0a0>KViPT0oooo00070?oooch0i^KV00@000000>KViP3Vi^H000002@3Vi^H00`000000i^KV
0>KViP0:0>KViP030000003Vi^H0i^KV00X0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP03
0000003Vi^H0i^KV00800000203Vi^H5000000P0i^KV00<000000>KViP3Vi^H00P3Vi^H00`000000
i^KV0>KViP050>KViP050000003Vi^H0i^KV0>KViP000000203Vi^H00`000000i^KV0>KViP020>KV
iP030000003Vi^H0i^KV00D0i^KV00D000000>KViP3Vi^H0i^KV0000000<0>KViP030000003Vi^H0
i^KV00H0i^KV00<000000>KViP3Vi^H0303Vi^H00`000000i^KV0>KViP0a0>KViPT0oooo00070?oo
och0i^KV0P0000000`3Vi^H000000>KViP080>KViPD00000203Vi^H4000000T0i^KV1@0000080>KV
iP050000003Vi^H000000>KViP0000005@3Vi^H00`000000i^KV0>KViP03000000L0i^KV1@000008
0>KViP030000003Vi^H0i^KV0080i^KV00<000000>KViP3Vi^H01@3Vi^H5000000T0i^KV0`000009
0>KViP@000002`3Vi^H00`000000i^KV0>KViP0a0>KViPT0oooo00070?oooch0i^KV00<000000>KV
iP0000002P3Vi^H00`000000i^KV0>KViP0:0>KViP030000003Vi^H0i^KV00X0i^KV00D000000>KV
iP3Vi^H0i^KV000000080>KViP8000000P3Vi^H00`000000i^KV0>KViP0C0>KViP030000003Vi^H0
i^KV00X0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP030000003Vi^H0i^KV0080i^KV00<0
00000>KViP3Vi^H01@3Vi^H01@000000i^KV0>KViP3Vi^H0000000P0i^KV00<000000>KViP3Vi^H0
2P3Vi^H01@000000i^KV0>KViP3Vi^H0000000X0i^KV00<000000>KViP3Vi^H0<@3Vi^H90?ooo`00
1`3oooln0>KViP040000003Vi^H0i^KV000000T0i^KV00<000000>KViP3Vi^H02P3Vi^H00`000000
i^KV0>KViP0:0>KViP050000003Vi^H0i^KV0>KViP000000203Vi^H200000080i^KV00<000000>KV
iP3Vi^H04`3Vi^H00`000000i^KV0>KViP020>KViP030000003Vi^H0i^KV00D0i^KV00D000000>KV
iP3Vi^H0i^KV000000080>KViP030000003Vi^H0i^KV0080i^KV00<000000>KViP3Vi^H01@3Vi^H0
1@000000i^KV0>KViP3Vi^H0000000P0i^KV00D000000>KViP3Vi^H0i^KV000000080>KViP050000
003Vi^H0i^KV0>KViP0000002P3Vi^H00`000000i^KV0>KViP0a0>KViPT0oooo00070?oooch0i^KV
00D000000>KViP3Vi^H0i^KV000000080>KViPD00000203Vi^H4000000T0i^KV00D000000>KViP3V
i^H0i^KV000000080>KViP050000003Vi^H0i^KV0>KViP0000005P3Vi^H4000000P0i^KV00D00000
0>KViP3Vi^H0i^KV000000090>KViP@00000203Vi^H01@000000i^KV0>KViP3Vi^H0000000T0i^KV
0`0000090>KViP@000002@3Vi^H500000340i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo0007
0?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0
oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA
0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0oooo
o`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool0
00L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV
2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KV
iQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3o
oooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?oo
o`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3V
i^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0
i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo0007
0?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0
oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0ooooo`3Vi^HA
0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool000L0oooo
o`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV2@3oool0
00L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KViQ40i^KV
2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3ooooo0>KV
iQ40i^KV2@3oool000L0ooooo`3Vi^HA0>KViPT0oooo00070?ooool0i^KV4@3Vi^H90?ooo`001`3o
oooo0>KViQ40i^KV2@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.55234, -2.15003, \
0.0770198, 0.0356059}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
PageWidth->PaperWidth,
WindowSize->{507, 571},
WindowMargins->{{4, Automatic}, {Automatic, 111}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 196, 6, 97, "Subtitle"],
Cell[2531, 84, 542, 12, 110, "Text"],
Cell[3076, 98, 676, 18, 149, "Text"],
Cell[3755, 118, 75, 1, 30, "Input"],
Cell[3833, 121, 240, 6, 110, "Input"],
Cell[4076, 129, 325, 10, 53, "Text"],

Cell[CellGroupData[{
Cell[4426, 143, 51, 1, 30, "Input"],
Cell[4480, 146, 42, 1, 29, "Output"]
}, Open  ]],
Cell[4537, 150, 519, 13, 110, "Text"],

Cell[CellGroupData[{
Cell[5081, 167, 88, 1, 30, "Input"],
Cell[5172, 170, 161, 2, 48, "Output"]
}, Open  ]],
Cell[5348, 175, 378, 13, 53, "Text"],

Cell[CellGroupData[{
Cell[5751, 192, 162, 2, 70, "Input"],
Cell[5916, 196, 6295, 103, 351, "Output"]
}, Open  ]],
Cell[12226, 302, 414, 11, 91, "Text"],
Cell[12643, 315, 154, 2, 50, "Input"],
Cell[12800, 319, 3769, 100, 634, "Text"],
Cell[16572, 421, 445, 7, 150, "Input"],
Cell[17020, 430, 332, 5, 90, "Text"],

Cell[CellGroupData[{
Cell[17377, 439, 81, 1, 30, "Input"],
Cell[17461, 442, 40, 1, 29, "Output"]
}, Open  ]],
Cell[17516, 446, 801, 23, 131, "Text"],
Cell[18320, 471, 172, 3, 70, "Input"],
Cell[18495, 476, 804, 25, 113, "Text"],

Cell[CellGroupData[{
Cell[19324, 505, 154, 2, 50, "Input"],
Cell[19481, 509, 1656, 31, 167, "Output"]
}, Open  ]],
Cell[21152, 543, 237, 6, 71, "Text"],
Cell[21392, 551, 677, 14, 166, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22106, 570, 184, 6, 97, "Subtitle"],
Cell[22293, 578, 387, 10, 71, "Text"],
Cell[22683, 590, 54, 1, 30, "Input"],
Cell[22740, 593, 1309, 28, 223, "Text"],
Cell[24052, 623, 55, 1, 30, "Input"],
Cell[24110, 626, 64, 1, 30, "Input"],
Cell[24177, 629, 64, 1, 30, "Input"],
Cell[24244, 632, 1296, 33, 227, "Text"],
Cell[25543, 667, 516, 9, 190, "Input"],
Cell[26062, 678, 1780, 41, 379, "Text"],
Cell[27845, 721, 129, 3, 50, "Input"],
Cell[27977, 726, 452, 11, 91, "Text"],
Cell[28432, 739, 184, 3, 50, "Input"],
Cell[28619, 744, 6684, 193, 1026, "Text"],
Cell[35306, 939, 1120, 21, 490, "Input"],
Cell[36429, 962, 430, 15, 73, "Text"],

Cell[CellGroupData[{
Cell[36884, 981, 144, 3, 50, "Input"],
Cell[37031, 986, 79809, 2035, 186, 41240, 1554, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[116855, 3024, 135, 3, 33, "Text"],
Cell[116993, 3029, 871, 17, 204, "Text"],
Cell[117867, 3048, 343, 7, 110, "Input"],
Cell[118213, 3057, 738, 21, 130, "Text"],
Cell[118954, 3080, 638, 13, 210, "Input"],
Cell[119595, 3095, 737, 24, 112, "Text"],
Cell[120335, 3121, 333, 7, 130, "Input"],
Cell[120671, 3130, 383, 8, 90, "Text"],
Cell[121057, 3140, 414, 8, 110, "Input"],
Cell[121474, 3150, 982, 30, 132, "Text"],
Cell[122459, 3182, 95, 2, 30, "Input"],
Cell[122557, 3186, 380, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[122962, 3202, 129, 3, 30, "Input"],
Cell[123094, 3207, 33177, 1059, 186, 15443, 836, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156308, 4271, 142, 4, 30, "Input"],
Cell[156453, 4277, 104693, 2959, 186, 56048, 2354, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[261161, 7239, 974, 21, 205, "Text"],
Cell[262138, 7262, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[262224, 7267, 69, 1, 30, "Input"],
Cell[262296, 7270, 41, 1, 29, "Output"]
}, Open  ]],
Cell[262352, 7274, 646, 16, 129, "Text"],
Cell[263001, 7292, 293, 7, 110, "Input"],
Cell[263297, 7301, 3008, 90, 442, "Text"],

Cell[CellGroupData[{
Cell[266330, 7395, 70, 1, 30, "Input"],
Cell[266403, 7398, 152, 2, 48, "Output"]
}, Open  ]],
Cell[266570, 7403, 492, 15, 73, "Text"],

Cell[CellGroupData[{
Cell[267087, 7422, 82, 1, 30, "Input"],
Cell[267172, 7425, 73, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[267282, 7431, 77, 1, 30, "Input"],
Cell[267362, 7434, 200, 3, 67, "Output"]
}, Open  ]],
Cell[267577, 7440, 1022, 25, 187, "Text"],
Cell[268602, 7467, 1252, 23, 430, "Input"],
Cell[269857, 7492, 523, 20, 53, "Text"],
Cell[270383, 7514, 162, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[270570, 7522, 143, 4, 30, "Input"],
Cell[270716, 7528, 106266, 3057, 186, 57840, 2455, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[376997, 10588, 102, 2, 33, "Text"],
Cell[377102, 10592, 731, 17, 167, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377870, 10614, 198, 6, 97, "Subtitle"],
Cell[378071, 10622, 1452, 37, 265, "Text"],
Cell[379526, 10661, 816, 18, 310, "Input"],
Cell[380345, 10681, 543, 17, 73, "Text"],

Cell[CellGroupData[{
Cell[380913, 10702, 75, 1, 30, "Input"],
Cell[380991, 10705, 282, 4, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[381310, 10714, 63, 1, 30, "Input"],
Cell[381376, 10717, 794, 17, 71, "Output"]
}, Open  ]],
Cell[382185, 10737, 526, 15, 92, "Text"],
Cell[382714, 10754, 3456, 60, 1090, "Input"],
Cell[386173, 10816, 216, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[386414, 10825, 67, 1, 30, "Input"],
Cell[386484, 10828, 794, 17, 71, "Output"]
}, Open  ]],
Cell[387293, 10848, 176, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[387494, 10856, 67, 1, 30, "Input"],
Cell[387564, 10859, 872, 17, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[388473, 10881, 67, 1, 30, "Input"],
Cell[388543, 10884, 794, 17, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389374, 10906, 68, 1, 30, "Input"],
Cell[389445, 10909, 794, 17, 71, "Output"]
}, Open  ]],
Cell[390254, 10929, 1146, 17, 280, "Text"],
Cell[391403, 10948, 380, 8, 109, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[391820, 10961, 208, 6, 126, "Subtitle"],
Cell[392031, 10969, 359, 9, 71, "Text"],
Cell[392393, 10980, 62, 1, 30, "Input"],
Cell[392458, 10983, 63, 1, 30, "Input"],
Cell[392524, 10986, 63, 1, 30, "Input"],
Cell[392590, 10989, 905, 26, 168, "Text"],
Cell[393498, 11017, 526, 9, 170, "Input"],
Cell[394027, 11028, 989, 17, 223, "Text"],
Cell[395019, 11047, 143, 3, 50, "Input"],
Cell[395165, 11052, 134, 3, 30, "Input"],
Cell[395302, 11057, 133, 2, 30, "Input"],
Cell[395438, 11061, 844, 24, 131, "Text"],
Cell[396285, 11087, 104, 2, 50, "Input"],
Cell[396392, 11091, 285, 10, 53, "Text"],

Cell[CellGroupData[{
Cell[396702, 11105, 69, 1, 30, "Input"],
Cell[396774, 11108, 40, 1, 29, "Output"]
}, Open  ]],
Cell[396829, 11112, 1035, 24, 263, "Text"],
Cell[397867, 11138, 355, 8, 110, "Input"],

Cell[CellGroupData[{
Cell[398247, 11150, 108, 2, 30, "Input"],
Cell[398358, 11154, 107, 2, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[398502, 11161, 192, 3, 50, "Input"],
Cell[398697, 11166, 131, 2, 48, "Output"]
}, Open  ]],
Cell[398843, 11171, 166, 4, 30, "Input"],
Cell[399012, 11177, 455, 10, 170, "Input"],

Cell[CellGroupData[{
Cell[399492, 11191, 180, 4, 50, "Input"],
Cell[399675, 11197, 70881, 1926, 186, 41097, 1554, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[470571, 13126, 172, 4, 50, "Input"],
Cell[470746, 13132, 256, 6, 90, "Input"],
Cell[471005, 13140, 401, 8, 110, "Input"],
Cell[471409, 13150, 109, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[471543, 13156, 124, 2, 30, "Input"],
Cell[471670, 13160, 29655, 1028, 186, 15221, 845, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[501362, 14193, 183, 4, 50, "Input"],
Cell[501548, 14199, 94906, 2907, 186, 56896, 2433, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[596469, 17109, 2127, 57, 342, "Text"],
Cell[598599, 17168, 235, 5, 50, "Input"],
Cell[598837, 17175, 429, 16, 54, "Text"],
Cell[599269, 17193, 677, 13, 250, "Input"],
Cell[599949, 17208, 416, 15, 54, "Text"],

Cell[CellGroupData[{
Cell[600390, 17227, 183, 4, 50, "Input"],
Cell[600576, 17233, 593, 14, 71, "Output"]
}, Open  ]],
Cell[601184, 17250, 562, 13, 110, "Text"],
Cell[601749, 17265, 3785, 66, 1230, "Input"],
Cell[605537, 17333, 154, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[605716, 17342, 69, 1, 30, "Input"],
Cell[605788, 17345, 593, 14, 71, "Output"]
}, Open  ]],
Cell[606396, 17362, 229, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[606650, 17372, 69, 1, 30, "Input"],
Cell[606722, 17375, 794, 17, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607553, 17397, 70, 1, 30, "Input"],
Cell[607626, 17400, 431, 11, 71, "Output"]
}, Open  ]],
Cell[608072, 17414, 1281, 30, 206, "Text"],
Cell[609356, 17446, 277, 6, 50, "Input"],

Cell[CellGroupData[{
Cell[609658, 17456, 107, 2, 30, "Input"],
Cell[609768, 17460, 47, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[609852, 17466, 102, 2, 30, "Input"],
Cell[609957, 17470, 39, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610033, 17476, 102, 2, 30, "Input"],
Cell[610138, 17480, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610234, 17486, 111, 2, 30, "Input"],
Cell[610348, 17490, 36, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610421, 17496, 111, 2, 30, "Input"],
Cell[610535, 17500, 36, 1, 29, "Output"]
}, Open  ]],
Cell[610586, 17504, 1050, 31, 169, "Text"],

Cell[CellGroupData[{
Cell[611661, 17539, 101, 2, 30, "Input"],
Cell[611765, 17543, 40, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[611842, 17549, 706, 15, 270, "Input"],
Cell[612551, 17566, 41274, 1265, 186, 32118, 1147, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[653840, 18834, 712, 19, 130, "Text"],
Cell[654555, 18855, 349, 8, 150, "Input"],
Cell[654907, 18865, 353, 8, 150, "Input"],
Cell[655263, 18875, 370, 8, 150, "Input"],
Cell[655636, 18885, 370, 8, 150, "Input"],

Cell[CellGroupData[{
Cell[656031, 18897, 157, 3, 50, "Input"],
Cell[656191, 18902, 50451, 1568, 186, 40072, 1435, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

